(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    398417,      21009]*)
(*NotebookOutlinePosition[    399327,      21041]*)
(*  CellTagsIndexPosition[    399283,      21037]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[BoxData[{
    \(Off[General::"\<spell\>", General::"\<spell1\>", Part::"\<part\>", 
      Graphics::"\<gptn\>"]\), 
    \(\(FormInertiaMatrix[FIM_, k_] := 
      Partition[
        \((ToExpression[StringJoin[{#1, ToString[FIM], ToString[k]}]]&)\)/@
          Flatten[Outer[
              StringJoin[{#1, #2}]&, {"\<Ix\>", "\<Iy\>", "\<Iz\>"}, {
                "\<x\>", "\<y\>", "\<z\>"}], 1], 3]; \)\), 
    \(MatrixForm[FormInertiaMatrix[l, 1]]\)}], "Input",
  PageWidth->Infinity,
  FontFamily->"Courier New",
  FontSize->10,
  FontWeight->"Plain",
  FontSlant->"Plain",
  FontTracking->"Plain",
  FontVariations->{"Underline"->False,
  "Outline"->False,
  "Shadow"->False}],

Cell[BoxData[
    TagBox[
      RowBox[{"(", GridBox[{
            {"Ixxl1", "Ixyl1", "Ixzl1"},
            {"Iyxl1", "Iyyl1", "Iyzl1"},
            {"Izxl1", "Izyl1", "Izzl1"}
            }], ")"}],
      (MatrixForm[ #]&)]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(Off[General::"\<spell\>", General::"\<spell1\>", Part::"\<part\>", 
      Graphics::"\<gptn\>"]\), 
    \(\(FormRn[a_, t_] := 
      Return[{{Cos[t], \(-Sin[t]\), 0}, {Cos[a]\ Sin[t], Cos[a]\ Cos[t], 
            \(-Sin[a]\)}, {Sin[a]\ Sin[t], Sin[a]\ Cos[t], Cos[a]}}]; \)\), 
    \(\(FormAn[a_, t_] := 
      Return[{{Cos[t], \(-Sin[t]\), 0, 0, 0, 0}, {Cos[a]\ Sin[t], 
            Cos[a]\ Cos[t], \(-Sin[a]\), 0, 0, 0}, {Sin[a]\ Sin[t], 
            Sin[a]\ Cos[t], Cos[a], 0, 0, 0}, {0, 0, 0, Cos[t], \(-Sin[t]\), 
            0}, {0, 0, 0, Cos[a]\ Sin[t], Cos[a]\ Cos[t], \(-Sin[a]\)}, {0, 
            0, 0, Sin[a]\ Sin[t], Sin[a]\ Cos[t], Cos[a]}}]; \)\), 
    \(\(ZeroMatrix[n_] := Table[0, {n}, {n}]; \)\), 
    \(\(FormAnBis[a_, t_] := 
      Join[\((Join[
                \(FormRn[a, t]\)\[LeftDoubleBracket]#1\[RightDoubleBracket], 
                \(ZeroMatrix[3]\)\[LeftDoubleBracket]#1
                  \[RightDoubleBracket]]&)\)/@Range[3], 
        \((Join[\(ZeroMatrix[3]\)\[LeftDoubleBracket]#1\[RightDoubleBracket], 
                \(FormRn[a, t]\)\[LeftDoubleBracket]#1\[RightDoubleBracket]]&)
            \)/@{1, 2, 3}]; \)\), 
    \(MatrixForm[FormAn[2, 3]]\), 
    \(MatrixForm[FormAnBis[2, 3]]\)}], "Input",
  PageWidth->Infinity,
  FontFamily->"Courier New",
  FontSize->10,
  FontWeight->"Plain",
  FontSlant->"Plain",
  FontTracking->"Plain",
  FontVariations->{"Underline"->False,
  "Outline"->False,
  "Shadow"->False}],

Cell[BoxData[
    TagBox[
      RowBox[{"(", GridBox[{
            {\(Cos[3]\), \(-Sin[3]\), "0", "0", "0", "0"},
           
             {\(Cos[2]\ Sin[3]\), \(Cos[2]\ Cos[3]\), \(-Sin[2]\), "0", "0", 
              "0"},
           
             {\(Sin[2]\ Sin[3]\), \(Cos[3]\ Sin[2]\), \(Cos[2]\), "0", "0", 
              "0"},
            {"0", "0", "0", \(Cos[3]\), \(-Sin[3]\), "0"},
           
             {"0", "0", "0", \(Cos[2]\ Sin[3]\), \(Cos[2]\ Cos[3]\), 
              \(-Sin[2]\)},
           
             {"0", "0", "0", \(Sin[2]\ Sin[3]\), \(Cos[3]\ Sin[2]\), 
              \(Cos[2]\)}
            }], ")"}],
      (MatrixForm[ #]&)]], "Output"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", GridBox[{
            {\(Cos[3]\), \(-Sin[3]\), "0", "0", "0", "0"},
           
             {\(Cos[2]\ Sin[3]\), \(Cos[2]\ Cos[3]\), \(-Sin[2]\), "0", "0", 
              "0"},
           
             {\(Sin[2]\ Sin[3]\), \(Cos[3]\ Sin[2]\), \(Cos[2]\), "0", "0", 
              "0"},
            {"0", "0", "0", \(Cos[3]\), \(-Sin[3]\), "0"},
           
             {"0", "0", "0", \(Cos[2]\ Sin[3]\), \(Cos[2]\ Cos[3]\), 
              \(-Sin[2]\)},
           
             {"0", "0", "0", \(Sin[2]\ Sin[3]\), \(Cos[3]\ Sin[2]\), 
              \(Cos[2]\)}
            }], ")"}],
      (MatrixForm[ #]&)]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(mat1 = Array[aa, {3, 3}]; \)\), 
    \(\(mat2 = Array[bb, {3, 3}]; \)\), 
    \(\(mat3 = Array[cc, {3, 3}]; \)\), 
    \(\(mat4 = Array[dd, {3, 3}]; \)\), 
    \(MatrixForm[
      Join[\((Join[mat1\[LeftDoubleBracket]#1\[RightDoubleBracket], 
                mat2\[LeftDoubleBracket]#1\[RightDoubleBracket]]&)\)/@{1, 2, 
            3}, \((Join[mat3\[LeftDoubleBracket]#1\[RightDoubleBracket], 
                mat4\[LeftDoubleBracket]#1\[RightDoubleBracket]]&)\)/@{1, 2, 
            3}]]\)}], "Input",
  PageWidth->Infinity,
  FontFamily->"Courier New",
  FontSize->10,
  FontWeight->"Plain",
  FontSlant->"Plain",
  FontTracking->"Plain",
  FontVariations->{"Underline"->False,
  "Outline"->False,
  "Shadow"->False}],

Cell[BoxData[
    TagBox[
      RowBox[{"(", GridBox[{
           
             {\(aa[1, 1]\), \(aa[1, 2]\), \(aa[1, 3]\), \(bb[1, 1]\), 
              \(bb[1, 2]\), \(bb[1, 3]\)},
           
             {\(aa[2, 1]\), \(aa[2, 2]\), \(aa[2, 3]\), \(bb[2, 1]\), 
              \(bb[2, 2]\), \(bb[2, 3]\)},
           
             {\(aa[3, 1]\), \(aa[3, 2]\), \(aa[3, 3]\), \(bb[3, 1]\), 
              \(bb[3, 2]\), \(bb[3, 3]\)},
           
             {\(cc[1, 1]\), \(cc[1, 2]\), \(cc[1, 3]\), \(dd[1, 1]\), 
              \(dd[1, 2]\), \(dd[1, 3]\)},
           
             {\(cc[2, 1]\), \(cc[2, 2]\), \(cc[2, 3]\), \(dd[2, 1]\), 
              \(dd[2, 2]\), \(dd[2, 3]\)},
           
             {\(cc[3, 1]\), \(cc[3, 2]\), \(cc[3, 3]\), \(dd[3, 1]\), 
              \(dd[3, 2]\), \(dd[3, 3]\)}
            }], ")"}],
      (MatrixForm[ #]&)]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(NErr = {{6}, {\(-5\)}, {4}, {7}, {\(-3\)}, {1}}; \)\), 
    \(Abs/@NErr\)}], "Input",
  PageWidth->Infinity,
  FontFamily->"Courier New",
  FontSize->10,
  FontWeight->"Plain",
  FontSlant->"Plain",
  FontTracking->"Plain",
  FontVariations->{"Underline"->False,
  "Outline"->False,
  "Shadow"->False}],

Cell[BoxData[
    \({{6}, {5}, {4}, {7}, {3}, {1}}\)], "Output",
  PageWidth->Infinity,
  Evaluatable->False]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(Off[General::"\<spell\>", General::"\<spell1\>", Part::"\<part\>", 
      Graphics::"\<gptn\>"]\), 
    \(\(NewSimplify
       = {0.\ var_ \[Rule] 0, 1.\ var_ \[Rule] var, 0. + var_ \[Rule] var}; 
    \)\), 
    \(\(NewS[NS_] := NS //. NewSimplify; \)\), 
    \(AccMMinus[1]
         = {{Cos[Qm[1]]\ 
              \((\(-\((Cos[Ql[2]]\ Qpl[2]\ Qpl[3])\)\) - Qppl[3]\ Sin[Ql[2]])
                \) + Qppl[2]\ Sin[Qm[1]] + 
            Qpl[1]\ \((Cos[Qm[1]]\ Qpl[2] + Qpl[3]\ Sin[Ql[2]]\ Sin[Qm[1]])
                \)}, {Cos[Qm[1]]\ Qppl[2] - 
            \((\(-\((Cos[Ql[2]]\ Qpl[2]\ Qpl[3])\)\) - Qppl[3]\ Sin[Ql[2]])
                \)\ Sin[Qm[1]] - 
            Qpl[1]\ \((
                \(-\((Cos[Qm[1]]\ Qpl[3]\ Sin[Ql[2]])\)\) + 
                  Qpl[2]\ Sin[Qm[1]])\)}, {
          0.\ Qppl[2] + Cos[Ql[2]]\ Qppl[3] + Qppm[1] - 
            Qpl[2]\ Qpl[3]\ Sin[Ql[2]] + 
            0.\ \((\(-\((Cos[Ql[2]]\ Qpl[2]\ Qpl[3])\)\) - 
                  Qppl[3]\ Sin[Ql[2]])\)}, {
          \(-0.3\)\ Cos[Qm[1]]\ Qppl[2] - 9.81\ Cos[Qm[1]]\ Sin[Ql[2]] + 
            \((\(-\((Cos[Ql[2]]\ Qppl[3])\)\) + Qpl[2]\ Qpl[3]\ Sin[Ql[2]])
                \)\ \((0.\ Cos[Qm[1]] + 0.\ Sin[Qm[1]])\) + 
            0.3\ \((\(-\((Cos[Ql[2]]\ Qpl[2]\ Qpl[3])\)\) - 
                  Qppl[3]\ Sin[Ql[2]])\)\ Sin[Qm[1]] + 
            Qpl[1]\ \((
                \(-0.3\)\ Cos[Qm[1]]\ Qpl[3]\ Sin[Ql[2]] + 
                  0.3\ Qpl[2]\ Sin[Qm[1]])\)}, {
          0.3\ Cos[Qm[1]]\ 
              \((\(-\((Cos[Ql[2]]\ Qpl[2]\ Qpl[3])\)\) - Qppl[3]\ Sin[Ql[2]])
                \) + \((
                \(-\((Cos[Ql[2]]\ Qppl[3])\)\) + Qpl[2]\ Qpl[3]\ Sin[Ql[2]])
                \)\ \((0.\ Cos[Qm[1]] + 0.\ Sin[Qm[1]])\) + 
            0.3\ Qppl[2]\ Sin[Qm[1]] + 9.81\ Sin[Ql[2]]\ Sin[Qm[1]] - 
            Qpl[1]\ \((
                \(-0.3\)\ Cos[Qm[1]]\ Qpl[2] - 
                  0.3\ Qpl[3]\ Sin[Ql[2]]\ Sin[Qm[1]])\)}, {
          9.81\ Cos[Ql[2]] + 0.\ Qppl[2] + 
            0.\ \((\(-\((Cos[Ql[2]]\ Qpl[2]\ Qpl[3])\)\) - 
                  Qppl[3]\ Sin[Ql[2]])\)}}\), 
    \(NewS[AccMMinus[1]]\)}], "Input",
  PageWidth->Infinity,
  FontFamily->"Courier New",
  FontSize->10,
  FontWeight->"Plain",
  FontSlant->"Plain",
  FontTracking->"Plain",
  FontVariations->{"Underline"->False,
  "Outline"->False,
  "Shadow"->False}],

Cell[BoxData[
    \({{Cos[Qm[1]]\ 
            \((\(-\((Cos[Ql[2]]\ Qpl[2]\ Qpl[3])\)\) - Qppl[3]\ Sin[Ql[2]])
              \) + Qppl[2]\ Sin[Qm[1]] + 
          Qpl[1]\ \((Cos[Qm[1]]\ Qpl[2] + Qpl[3]\ Sin[Ql[2]]\ Sin[Qm[1]])
              \)}, {Cos[Qm[1]]\ Qppl[2] - 
          \((\(-\((Cos[Ql[2]]\ Qpl[2]\ Qpl[3])\)\) - Qppl[3]\ Sin[Ql[2]])\)\ 
            Sin[Qm[1]] - 
          Qpl[1]\ \((
              \(-\((Cos[Qm[1]]\ Qpl[3]\ Sin[Ql[2]])\)\) + Qpl[2]\ Sin[Qm[1]])
              \)}, {0.\ Qppl[2] + Cos[Ql[2]]\ Qppl[3] + Qppm[1] - 
          Qpl[2]\ Qpl[3]\ Sin[Ql[2]] + 
          0.\ \((\(-\((Cos[Ql[2]]\ Qpl[2]\ Qpl[3])\)\) - Qppl[3]\ Sin[Ql[2]])
              \)}, {\(-0.3\)\ Cos[Qm[1]]\ Qppl[2] - 
          9.81\ Cos[Qm[1]]\ Sin[Ql[2]] + 
          \((\(-\((Cos[Ql[2]]\ Qppl[3])\)\) + Qpl[2]\ Qpl[3]\ Sin[Ql[2]])\)\ 
            \((0.\ Cos[Qm[1]] + 0.\ Sin[Qm[1]])\) + 
          0.3\ \((\(-\((Cos[Ql[2]]\ Qpl[2]\ Qpl[3])\)\) - Qppl[3]\ Sin[Ql[2]])
              \)\ Sin[Qm[1]] + 
          Qpl[1]\ \((
              \(-0.3\)\ Cos[Qm[1]]\ Qpl[3]\ Sin[Ql[2]] + 
                0.3\ Qpl[2]\ Sin[Qm[1]])\)}, {
        0.3\ Cos[Qm[1]]\ 
            \((\(-\((Cos[Ql[2]]\ Qpl[2]\ Qpl[3])\)\) - Qppl[3]\ Sin[Ql[2]])
              \) + \((\(-\((Cos[Ql[2]]\ Qppl[3])\)\) + 
                Qpl[2]\ Qpl[3]\ Sin[Ql[2]])\)\ 
            \((0.\ Cos[Qm[1]] + 0.\ Sin[Qm[1]])\) + 
          0.3\ Qppl[2]\ Sin[Qm[1]] + 9.81\ Sin[Ql[2]]\ Sin[Qm[1]] - 
          Qpl[1]\ \((
              \(-0.3\)\ Cos[Qm[1]]\ Qpl[2] - 
                0.3\ Qpl[3]\ Sin[Ql[2]]\ Sin[Qm[1]])\)}, {
        9.81\ Cos[Ql[2]] + 0.\ Qppl[2] + 
          0.\ \((\(-\((Cos[Ql[2]]\ Qpl[2]\ Qpl[3])\)\) - Qppl[3]\ Sin[Ql[2]])
              \)}}\)], "Output",
  PageWidth->Infinity,
  Evaluatable->False],

Cell[BoxData[
    \({{Cos[Qm[1]]\ 
            \((\(-\((Cos[Ql[2]]\ Qpl[2]\ Qpl[3])\)\) - Qppl[3]\ Sin[Ql[2]])
              \) + Qppl[2]\ Sin[Qm[1]] + 
          Qpl[1]\ \((Cos[Qm[1]]\ Qpl[2] + Qpl[3]\ Sin[Ql[2]]\ Sin[Qm[1]])
              \)}, {Cos[Qm[1]]\ Qppl[2] - 
          \((\(-\((Cos[Ql[2]]\ Qpl[2]\ Qpl[3])\)\) - Qppl[3]\ Sin[Ql[2]])\)\ 
            Sin[Qm[1]] - 
          Qpl[1]\ \((
              \(-\((Cos[Qm[1]]\ Qpl[3]\ Sin[Ql[2]])\)\) + Qpl[2]\ Sin[Qm[1]])
              \)}, {Cos[Ql[2]]\ Qppl[3] + Qppm[1] - 
          Qpl[2]\ Qpl[3]\ Sin[Ql[2]]}, {
        \(-0.3\)\ Cos[Qm[1]]\ Qppl[2] - 9.81\ Cos[Qm[1]]\ Sin[Ql[2]] + 
          0.3\ \((\(-\((Cos[Ql[2]]\ Qpl[2]\ Qpl[3])\)\) - Qppl[3]\ Sin[Ql[2]])
              \)\ Sin[Qm[1]] + 
          Qpl[1]\ \((
              \(-0.3\)\ Cos[Qm[1]]\ Qpl[3]\ Sin[Ql[2]] + 
                0.3\ Qpl[2]\ Sin[Qm[1]])\)}, {
        0.3\ Cos[Qm[1]]\ 
            \((\(-\((Cos[Ql[2]]\ Qpl[2]\ Qpl[3])\)\) - Qppl[3]\ Sin[Ql[2]])
              \) + 0.3\ Qppl[2]\ Sin[Qm[1]] + 9.81\ Sin[Ql[2]]\ Sin[Qm[1]] - 
          Qpl[1]\ \((
              \(-0.3\)\ Cos[Qm[1]]\ Qpl[2] - 
                0.3\ Qpl[3]\ Sin[Ql[2]]\ Sin[Qm[1]])\)}, {9.81\ Cos[Ql[2]]}}
      \)], "Output",
  PageWidth->Infinity,
  Evaluatable->False]
}, Open  ]],

Cell[BoxData[{
    \(\(SetDirectory["\<\>"]; \)\), 
    \(<< "\<robo.m\>"\), 
    \(gear1 := 53.69; gear2 := 107.36; gear3 := 62.61; \), 
    \(alfal1 := 0; alfal2 := \(-\(\[Pi]\/2\)\); alfal3 := 0; \), 
    \(alfam1 := \[Pi]\/2; alfam2 := \(-\(\[Pi]\/2\)\); alfam3 := 0; \), 
    \(Lxl1 = 0.02032; Lxl2 = 0.4318; Lxl3 = 0; \), 
    \(Lyl1 = 0.4318; Lyl2 = 0.0; Lyl3 = 0; \), 
    \(Lzl1 = 0.0; Lzl2 = 0.12446; Lzl3 = 0; \), 
    \(Lxm0 = 0.4318; Lxm1 = 0.0; Lxm2 = 0; \), 
    \(Lym0 = \(-0.3\); Lym1 = 0.3; Lym2 = 0; \), 
    \(Lzm0 = 0.0; Lzm1 = 0.0; Lzm2 = 0.4; \), 
    \(pxl1 := 0.0; pxl2 := 0.07; pxl3 := 0.0; \), 
    \(pyl1 := 0.143; pyl2 := 0.0; pyl3 := 0.3088; \), 
    \(pzl1 := 0.0; pzl2 := 0.0; pzl3 := 0.0; \), 
    \(pxm1 := 0.0; pxm2 := 0.0; pxm3 := 0.0; \), 
    \(pym1 := 0.0; pym2 := 0.0; pym3 := 0.0; \), 
    \(pzm1 := 0.0; pzm2 := 0.0; pzm3 := 0.0; \), 
    \(ml[1] := 6.04; ml[2] := 17.4; ml[3] := 8.7; \), 
    \(mm[1] := 0.8; mm[2] := 1.2; mm[3] := 1.0; \), 
    \(Ixxl1 := 0.3155; Ixxl2 := 0.13; Ixxl3 := 0.8316; \), 
    \(Ixyl1 := 0.002; Ixyl2 := 0.005; Ixyl3 := 0.001; \), 
    \(Iyxl1 := Ixyl1; Iyxl2 := Ixyl2; Iyxl3 := Ixyl3; \), 
    \(Ixzl1 := 0.003; Ixzl2 := 0.003; Ixzl3 := 0.001; \), 
    \(Iyyl1 := 0.006; Iyyl2 := 0.6092; Iyyl3 := 0.002; \), 
    \(Iyzl1 := 0.006; Iyzl2 := 0.006; Iyzl3 := 0.001; \), 
    \(Izxl1 := Ixzl1; Izxl2 := Ixzl2; Izxl3 := Ixzl3; \), 
    \(Izyl1 := Iyzl1; Izyl2 := Iyzl2; Izyl3 := Iyzl3; \), 
    \(Izzl1 := 0.3355; Izzl2 := 0.6243; Izzl3 := 1.1796; \), 
    \(Ixxm1 := 0.0; Ixxm2 := 0.0; Ixxm3 := 0.0; \), 
    \(Ixym1 := 0.0; Ixym2 := 0.0; Ixym3 := 0.0; \), 
    \(Ixzm1 := 0.0; Ixzm2 := 0.0; Ixzm3 := 0.0; \), 
    \(Iyxm1 := 0.0; Iyxm2 := 0.0; Iyxm3 := 0.0; \), 
    \(Iyym1 := 0.0; Iyym2 := 0.0; Iyym3 := 0.0; \), 
    \(Iyzm1 := 0.0; Iyzm2 := 0.0; Iyzm3 := 0.0; \), 
    \(Izxm1 := Ixzm1; Izxm2 := Ixzm2; Izxm3 := Ixzm3; \), 
    \(Izym1 := Iyzm1; Izym2 := Iyzm2; Izym3 := Iyzm3; \), 
    \(\(Izzm1 := 0.830\/\(gear1\ gear1\); \)\), 
    \(\(Izzm2 := 4.71\/\(gear2\ gear2\); \)\), 
    \(\(Izzm3 := 1.14\/\(gear3\ gear3\); \)\), 
    \(\(LinkInertia1 = FormInertiaMatrix[l, 1]; \)\), 
    \(\(LinkInertia2 = FormInertiaMatrix[l, 2]; \)\), 
    \(\(LinkInertia3 = FormInertiaMatrix[l, 3]; \)\), 
    \(\(MotorInertia1 = FormInertiaMatrix[m, 1]; \)\), 
    \(\(MotorInertia2 = FormInertiaMatrix[m, 2]; \)\), 
    \(\(MotorInertia3 = FormInertiaMatrix[m, 3]; \)\), 
    \(\(SetJointSetings[1, 3, 4]; \)\), 
    \(\(SetMotorSetings[1, 3, 4]; \)\), 
    \(\(BaseLink = 4; \)\), 
    \(\(BaseMotor = 4; \)\), 
    \(\(externalforce = {0, 0, 0, 0, 0, 0}; \)\), 
    \(\(SetExternalForce[{1}, {externalforce}]; \)\), 
    \(\(Link1
       = {1, Rotationalz, {0}, 2, ml[1], 
        LinkInertia1, {Lxl1, Lyl1, Lzl1}, {pxl1, pyl1, pzl1}, alfal1, {}}; 
    \)\), 
    \(\(Link2
       = {2, Rotationalz, {1}, 3, ml[2], 
        LinkInertia2, {Lxl2, Lyl2, Lzl2}, {pxl2, pyl2, pzl2}, alfal2, {2}}; 
    \)\), 
    \(\(Link3
       = {3, Rotationalz, {2}, BaseLink, ml[3], 
        LinkInertia3, {Lxl3, Lyl3, Lzl3}, {pxl3, pyl3, pzl3}, alfal3, {}}; 
    \)\), 
    \(\(LinkBase
       = {4, Rotationalz, {3}, BaseLink, 0, 
        IdentityMatrix[3], {0, 0, 0}, {0, 0, 0}, 0, {}}; \)\), 
    \(\(Motor1
       = {1, Rotationalz, 2, 1, mm[1], 
        MotorInertia1, {Lxm1, Lym1, Lzm1}, {pxm1, pym1, pzm1}, alfam1, 
        gear1}; \)\), 
    \(\(Motor2
       = {2, Rotationalz, 2, 2, mm[2], 
        MotorInertia2, {Lxm2, Lym2, Lzm2}, {pxm2, pym2, pzm2}, alfam2, 
        gear2}; \)\), 
    \(\(Motor3
       = {3, Rotationalz, BaseMotor, 3, mm[3], 
        MotorInertia3, {Lxm3, Lym3, Lzm3}, {pxm3, pym3, pzm3}, alfam3, 
        gear3}; \)\), 
    \(\(Links = {Link1, Link2, Link3, LinkBase}; \)\), 
    \(\(Motors = {Motor1, Motor2, Motor3}; \)\), 
    \(\(SetSample[100, 4]; \)\), 
    \(\(PrepareMatrix[Links, Motors]; \)\)}], "Input",
  PageWidth->Infinity,
  FontFamily->"Courier New",
  FontSize->10,
  FontWeight->"Plain",
  FontSlant->"Plain",
  FontTracking->"Plain",
  FontVariations->{"Underline"->False,
  "Outline"->False,
  "Shadow"->False}],

Cell[OutputFormData["\<\
No Input Form Generated


\
\>", "\<\

  Robo dual notation 1.0.0  (15.09.1997).
Copyright 1996-1997 Poznan University of Technology
 Chair of Control, Robotics and Computer Science. 
                   Written by
    Adam Bie\:0144kowski
               All rights reserved.


Robo loaded...

Compose matrices 'R', 'A', 'Fi', 'I', 'M', 'H' .

Matrices 'R', 'A', 'Fi', 'I', 'M', 'H' have already been composed.

Package ready... 
\
\>"], "Print",
  PageWidth->Infinity,
  Evaluatable->False],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(ClearAll[Tablica, Angle]; \)\), 
    \(\(Loop = {1.5, \(-2\), 100}; \)\), 
    \(\(Tablica = Reverse[Range[3]]; \)\), 
    \(\(Angle = {0.5, \[Pi]\/3, 1}; \)\), 
    \(\(Weight = {1, 1, 1, 1, 1, 1}; \)\), 
    \(\(DState = N[CIKFD[Tablica, Angle]]; \)\), 
    \(\(ComputeInverseKinematics[Sd, DState, Links, 1, Loop, Weight]; \)\), 
    \(\(Loop = {5, \(-10\), 100}; \)\), 
    \(\(ComputeInverseKinematics[nrS, DState, Links, 1, Loop, Weight]; \)\)}],
   "Input",
  PageWidth->Infinity,
  FontFamily->"Courier New",
  FontSize->10,
  FontWeight->"Plain",
  FontSlant->"Plain",
  FontTracking->"Plain",
  FontVariations->{"Underline"->False,
  "Outline"->False,
  "Shadow"->False}],

Cell[OutputFormData["\<\
No Input Form Generated


\
\>", "\<\
Starting calculating Inverse Kinematics using Steepest Descent method.....
Starting Max Error is : 1.99944
Method Steepest Descent  - done
Ending Max Error is : 0.418568 in step: 100
 
Searching angles are: 
Angle Ql1 = 2.93609
Angle Ql2 = 4.86902
Angle Ql3 = 0.744548
Desired position and orientation was:  
{{0.4318}, {0.}, {0.12446}, {0.0235966}, {0.}, {-0.999722}, {-0.999722}, \
{0.}, {-0.0235966}, {0.}, {1.}, {0.}}
Computed position and orientation is: 
{{0.00845584}, {0.}, {0.211889}, {0.0488516}, {0.}, {-0.998806}, {-0.998806}, \
{0.}, {-0.0488516}, {0.}, {1.}, 
 
 {0.}}
Starting calculating Inverse Kinematics using Newton-Raphson search.....
Starting Max Error is : 1.99944
Method Newton-Raphson Search  - done
Ending Max Error is : 0.414695 in step: 100
 
Searching angles are: 
Angle Ql1 = 5.04561
Angle Ql2 = 2.85325
Angle Ql3 = 6.28308
Desired position and orientation was:  
{{0.4318}, {0.}, {0.12446}, {0.0235966}, {0.}, {-0.999722}, {-0.999722}, \
{0.}, {-0.0235966}, {0.}, {1.}, {0.}}
Computed position and orientation is: 
                                                                    -6
{{0.535108}, {-0.0000586201}, {-0.295292}, {-0.0448556}, {4.91384 10  }, \
{-0.998993}, {-0.998993}, {0.000109438}, 
 
 {0.0448556}, {0.000109548}, {1.}, {0.}}\
\>"], "Print",
  PageWidth->Infinity,
  Evaluatable->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00952381 0.0147151 0.0939516 [
[(20)] .21429 .01472 0 2 Msboxa
[(40)] .40476 .01472 0 2 Msboxa
[(60)] .59524 .01472 0 2 Msboxa
[(80)] .78571 .01472 0 2 Msboxa
[(100)] .97619 .01472 0 2 Msboxa
[(No.)] 1.025 .01472 -1 0 Msboxa
[(Angle Ql[1])] .5 .61803 0 -2 0 0 1 Mouter Mrotsboxa
[(1)] .01131 .10867 1 0 Msboxa
[(2)] .01131 .20262 1 0 Msboxa
[(3)] .01131 .29657 1 0 Msboxa
[(4)] .01131 .39052 1 0 Msboxa
[(5)] .01131 .48447 1 0 Msboxa
[(6)] .01131 .57842 1 0 Msboxa
[(Rad)] .02381 .61803 0 -4 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 .61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.21429 .01472 m
.21429 .02097 L
s
P
[(20)] .21429 .01472 0 2 Mshowa
p
.002 w
.40476 .01472 m
.40476 .02097 L
s
P
[(40)] .40476 .01472 0 2 Mshowa
p
.002 w
.59524 .01472 m
.59524 .02097 L
s
P
[(60)] .59524 .01472 0 2 Mshowa
p
.002 w
.78571 .01472 m
.78571 .02097 L
s
P
[(80)] .78571 .01472 0 2 Mshowa
p
.002 w
.97619 .01472 m
.97619 .02097 L
s
P
[(100)] .97619 .01472 0 2 Mshowa
p
.001 w
.0619 .01472 m
.0619 .01847 L
s
P
p
.001 w
.1 .01472 m
.1 .01847 L
s
P
p
.001 w
.1381 .01472 m
.1381 .01847 L
s
P
p
.001 w
.17619 .01472 m
.17619 .01847 L
s
P
p
.001 w
.25238 .01472 m
.25238 .01847 L
s
P
p
.001 w
.29048 .01472 m
.29048 .01847 L
s
P
p
.001 w
.32857 .01472 m
.32857 .01847 L
s
P
p
.001 w
.36667 .01472 m
.36667 .01847 L
s
P
p
.001 w
.44286 .01472 m
.44286 .01847 L
s
P
p
.001 w
.48095 .01472 m
.48095 .01847 L
s
P
p
.001 w
.51905 .01472 m
.51905 .01847 L
s
P
p
.001 w
.55714 .01472 m
.55714 .01847 L
s
P
p
.001 w
.63333 .01472 m
.63333 .01847 L
s
P
p
.001 w
.67143 .01472 m
.67143 .01847 L
s
P
p
.001 w
.70952 .01472 m
.70952 .01847 L
s
P
p
.001 w
.74762 .01472 m
.74762 .01847 L
s
P
p
.001 w
.82381 .01472 m
.82381 .01847 L
s
P
p
.001 w
.8619 .01472 m
.8619 .01847 L
s
P
p
.001 w
.9 .01472 m
.9 .01847 L
s
P
p
.001 w
.9381 .01472 m
.9381 .01847 L
s
P
[(No.)] 1.025 .01472 -1 0 Mshowa
p
.002 w
0 .01472 m
1 .01472 L
s
P
[(Angle Ql[1])] .5 .61803 0 -2 0 0 1 Mouter Mrotshowa
p
.002 w
.02381 .10867 m
.03006 .10867 L
s
P
[(1)] .01131 .10867 1 0 Mshowa
p
.002 w
.02381 .20262 m
.03006 .20262 L
s
P
[(2)] .01131 .20262 1 0 Mshowa
p
.002 w
.02381 .29657 m
.03006 .29657 L
s
P
[(3)] .01131 .29657 1 0 Mshowa
p
.002 w
.02381 .39052 m
.03006 .39052 L
s
P
[(4)] .01131 .39052 1 0 Mshowa
p
.002 w
.02381 .48447 m
.03006 .48447 L
s
P
[(5)] .01131 .48447 1 0 Mshowa
p
.002 w
.02381 .57842 m
.03006 .57842 L
s
P
[(6)] .01131 .57842 1 0 Mshowa
p
.001 w
.02381 .03351 m
.02756 .03351 L
s
P
p
.001 w
.02381 .0523 m
.02756 .0523 L
s
P
p
.001 w
.02381 .07109 m
.02756 .07109 L
s
P
p
.001 w
.02381 .08988 m
.02756 .08988 L
s
P
p
.001 w
.02381 .12746 m
.02756 .12746 L
s
P
p
.001 w
.02381 .14625 m
.02756 .14625 L
s
P
p
.001 w
.02381 .16504 m
.02756 .16504 L
s
P
p
.001 w
.02381 .18383 m
.02756 .18383 L
s
P
p
.001 w
.02381 .22141 m
.02756 .22141 L
s
P
p
.001 w
.02381 .2402 m
.02756 .2402 L
s
P
p
.001 w
.02381 .25899 m
.02756 .25899 L
s
P
p
.001 w
.02381 .27778 m
.02756 .27778 L
s
P
p
.001 w
.02381 .31536 m
.02756 .31536 L
s
P
p
.001 w
.02381 .33415 m
.02756 .33415 L
s
P
p
.001 w
.02381 .35294 m
.02756 .35294 L
s
P
p
.001 w
.02381 .37173 m
.02756 .37173 L
s
P
p
.001 w
.02381 .40931 m
.02756 .40931 L
s
P
p
.001 w
.02381 .4281 m
.02756 .4281 L
s
P
p
.001 w
.02381 .44689 m
.02756 .44689 L
s
P
p
.001 w
.02381 .46568 m
.02756 .46568 L
s
P
p
.001 w
.02381 .50326 m
.02756 .50326 L
s
P
p
.001 w
.02381 .52205 m
.02756 .52205 L
s
P
p
.001 w
.02381 .54084 m
.02756 .54084 L
s
P
p
.001 w
.02381 .55963 m
.02756 .55963 L
s
P
p
.001 w
.02381 .59722 m
.02756 .59722 L
s
P
p
.001 w
.02381 .61601 m
.02756 .61601 L
s
P
[(Rad)] .02381 .61803 0 -4 Mshowa
p
.002 w
.02381 0 m
.02381 .61803 L
s
P
P
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.004 w
.03333 .01472 m
.04286 .05697 L
.05238 .08045 L
.0619 .08117 L
.07143 .07145 L
.08095 .07244 L
.09048 .06194 L
.1 .06322 L
.10952 .05164 L
.11905 .05323 L
.12857 .04026 L
.1381 .04212 L
.14762 .02747 L
.15714 .02953 L
.16667 .60332 L
.17619 .01516 L
.18571 .58706 L
.19524 .58917 L
.20476 .56876 L
.21429 .57076 L
.22381 .54726 L
.23333 .54918 L
.24286 .5191 L
.25238 .52092 L
.2619 .47201 L
.27143 .47369 L
.28095 .36146 L
.29048 .3564 L
.3 .34898 L
.30952 .34528 L
.31905 .3377 L
.32857 .33474 L
.3381 .32703 L
.34762 .32445 L
.35714 .31668 L
.36667 .31422 L
.37619 .30647 L
.38571 .30391 L
.39524 .29624 L
.40476 .29335 L
.41429 .28579 L
.42381 .28233 L
.43333 .27487 L
.44286 .27053 L
.45238 .26312 L
.4619 .25749 L
.47143 .25006 L
.48095 .24252 L
.49048 .23498 L
.5 .22464 L
Mistroke
.50952 .21684 L
.51905 .20215 L
.52857 .19386 L
.5381 .1721 L
.54762 .16294 L
.55714 .13383 L
.56667 .12393 L
.57619 .10336 L
.58571 .09494 L
.59524 .08699 L
.60476 .07948 L
.61429 .07638 L
.62381 .06889 L
.63333 .06774 L
.64286 .05974 L
.65238 .05966 L
.6619 .05071 L
.67143 .05137 L
.68095 .041 L
.69048 .04224 L
.7 .0299 L
.70952 .03162 L
.71905 .01681 L
.72857 .01885 L
.7381 .5917 L
.74762 .59383 L
.75714 .574 L
.76667 .57603 L
.77619 .55359 L
.78571 .55553 L
.79524 .52783 L
.80476 .52968 L
.81429 .48853 L
.82381 .49029 L
.83333 .39745 L
.84286 .39672 L
.85238 .38601 L
.8619 .38634 L
.87143 .37077 L
.88095 .37188 L
.89048 .35093 L
.9 .35181 L
.90952 .33578 L
.91905 .33655 L
.92857 .3226 L
.9381 .32321 L
.94762 .31093 L
.95714 .31133 L
.96667 .30035 L
.97619 .3005 L
Mistroke
Mfstroke
% End of Graphics
MathPictureEnd\
\>"], "Graphics",
  PageWidth->Infinity,
  Evaluatable->False,
  ImageSize->{299, 185},
  ImageMargins->{{100, Inherited}, {Inherited, 0}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004[0000^@P10`40000100000800002008200000
P800P020P<30`<3L`:K:l:C8l3<006H009T00<`0000c03<c06Hc09Tc0<`c0?lc001V03=V06IV09UV
0<aV0?mV002I03>I06JI09VI0<bI0?nI003<03?<06K<09W<0<c<0?o<03?o06Ko09Wo0<co0000<c<0
<fH0<iT0<l`0<ol0<`0c<c<c<fHc<iTc<l`c<olc<`1V<c=V<fIV<iUV<laV<omV<`2I<c>I<fJI<iVI
<lbI<onI<`3<<c?<<fK<<iW<<lc<<oo<<`3o<c?o<fKo<iWo<lco<ooo<`00IS<0IVH0IYT0I/`0I_l0
IP0cIS<cIVHcIYTcI/`cI_lcIP1VIS=VIVIVIYUVI/aVI_mVIP2IIS>IIVJIIYVII/bII_nIIP3<IS?<
IVK<IYW<I/c<I_o<IP3oIS?oIVKoIYWoI/coI_ooIP00VC<0VFH0VIT0VL`0VOl0V@0cVC<cVFHcVITc
VL`cVOlcV@1VVC=VVFIVVIUVVLaVVOmVV@2IVC>IVFJIVIVIVLbIVOnIV@3<VC?<VFK<VIW<VLc<VOo<
V@3oVC?oVFKoVIWoVLcoVOooV@00c3<0c6H0c9T0c<`0c?l0c00cc3<cc6Hcc9Tcc<`cc?lcc01Vc3=V
c6IVc9UVc<aVc?mVc02Ic3>Ic6JIc9VIc<bIc?nIc03<c3?<c6K<c9W<c<c<c?o<c03oc3?oc6Koc9Wo
c<coc?ooc3<0ofH0oiT0ol`0o`0coc<cofHcoiTcol`coolco`1Voc=VofIVoiUVolaVoomVo`2Ioc>I
ofJIoiVIolbIoonIo`3<oc?<ofK<oiW<olc<ooo<oc?oofKooiWoolcoo`410@820P<30`@410D51@H6
1PL71`P820T92@X:2P/;2``<30h>3Pl?3a0@414A4A8B4Q<C4a@D5000000000000000000000000000
00000?okl:2PY820P?l0003o0?oo0000ool0o`3ooooooooo;?l00?oo;?l00?oo;?l00?oo;?l004Oo
0`03o`030?oo02?o0`02o`030?oo02;o0P04o`030?oo02?o00<0ool00_l00`3oo`0No`D00_l00`3o
o`02o`030?oo02go0017o`030?oo00;o00<0o`009Ol01P3oo`3o02?o00<0o`000_l00`3o000So`03
0?l000;o00<0o`008Ol01`3oool0o`000_l00`3o000^o`00B?l01`3oool0o`008ol40004o`3o02?o
00<0o`000_l00`3o000So`030?l000;o00<0o`008Ol01`3oool0o`000_l00`3o000^o`00B?l01`3o
ool0o`008ol00`3o0002o`030?l002?o0P03o`030?l002Co00L0oooo0?l0027o00L0oooo0?l000;o
00<0o`00;_l004Oo00<0o`000_l00`3o000To`800_l00`3o000So`030?oo00;o00<0o`008ol00`3o
0002o`030?l0027o00L0oooo0?l000;o00<0o`00;_l004So00<0ool00_l00`3oo`0To`050?ooo`00
9Ol200?o00<0ool08ol00`3oo`02o`030?oo01oo0P04o`030?oo00;o00<0ool0;Ol00?oo;?l00?oo
;?l00?oo;?l00?oo;?l00?oo;?l0023o00<0ool0ool9o`008?l00`3oo`3Oo`<000Co0?oo0P03o`03
0?oo01[o000Po`030?oo0>3o00H0o`00o`02o`030?oo01go000Kon801_l01P3o003o00;o00<0ool0
7Ol0023o00<0o`001_l00`3oo`05o`030?oo00Ko00<0ool01Ol00`3oo`06o`030?oo00Ko00<0ool0
1Ol00`3oo`06o`030?oo00Go00<0ool01_l00`3oo`06o`030?oo00Go00<0ool01_l00`3oo`05o`03
0?oo00Ko00<0ool01Ol00`3oo`06o`030?oo00Ko00<0o`000P03o`030?oo00Ko00<0ool01Ol00`3o
o`06o`030?oo00Ko00<0ool01Ol00`3oo`06o`030?oo00Wo0P001?l0ool2023o000Po`030?l001oo
00<0ool01_l00`3oo`0Xo`030?oo02So00<0ool06?l0103oo`0<o`030?oo02So00<0ool02Ol20003
o`3o02?o000Po`040?oo01So00<0ool00ol00`3oo`1go`040?oo04;o0P000ol0000To`008?l0103o
o`0Go`040?l000?o00<0ool0Lol400?o00<0ool0JOl0023o0P000ol0o`0Fo`040?oo00?o00<0ool0
L_l00`3oo`05o`030?oo06Wo000Po`040?oo01Co00<0o`000ol01@3oool0077o00@0ool01ol00`3o
o`1Yo`008?l0103oo`0Co`040?l000?o00D0oooo001`o`040?l000So00<0ool0JOl0023o00D0oooo
000Bo`030?oo00Co00D0oooo001`o`030?oo00Wo00<0ool0JOl0023o0P02o`030?oo00co1007o`05
0?ooo`00KOl300co00<0ool0JOl0023o00D0oooo000=o`030?oo00Wo00D0oooo001/o`030?oo00go
00<0ool0JOl0023o00<0ool00_l00`3oo`07o`<03?l01@3oool006So100@o`030?oo06Wo000Po`03
0?oo00;o00<0ool01_l00`3oo`0=o`050?ooo`00I_l201Co00<0ool0JOl0023o0P04o`030?oo00;o
00@0ool03ol01@3oool006Co0P0Fo`030?oo06Wo000Po`030?oo00?o00H0oooo0?l2013o00D0oooo
001Ro`806?l00`3oo`1Yo`008?l00`3oo`04o`<05?l01@3oool0063o0P0Jo`030?oo06Wo000Po`03
0?oo01_o00D0oooo001Oo`030?oo01[o00<0ool0JOl0023o0P0Lo`050?ooo`00G_l00`3oo`0Ko`03
0?oo06Wo000Po`030?oo01_o00D0oooo001Mo`030?oo01co00<0ool0JOl0023o00<0ool06ol01@3o
ool005co00<0ool07Ol00`3oo`1Yo`006?l500?o00<0ool06ol01@3oool005[o0P0Po`030?oo06Wo
000Jo`030?oo00?o00<0ool06ol01@3oool005Wo00<0ool08?l00`3oo`1Yo`006_l00`3oo`03o`80
7?l01@3oool005Wo00<0ool08?l00`3oo`1Yo`006_l00`3oo`03o`030?oo01_o00@0oooo0P1Go`03
0?oo027o00<0ool0JOl001[o00<0ool00ol00`3oo`0Ko`040?ooo`80Eol00`3oo`0Qo`030?oo06Wo
000Io`801Ol00`3oo`0Ko`040?ooo`80E_l00`3oo`0Ro`030?oo06Wo000Po`807?l0103oool205Go
00<0ool08ol00`3oo`1Yo`008?l00`3oo`0Ko`040?ooo`80E?l00`3oo`0To`030?oo06Wo000Po`03
0?oo01_o00@0oooo0P1Do`030?oo02Co00<0ool0JOl0023o00<0ool06ol0103oool205?o00<0ool0
9Ol00`3oo`1Yo`008?l201co00@0oooo0P1Co`030?oo02Go00<0ool0JOl0023o00<0ool06ol0103o
ool205?o00<0ool09Ol00`3oo`1Yo`008?l00`3oo`0Ko`040?ooo`80Dol00`3oo`0Uo`030?oo06Wo
000Po`030?oo01_o00@0oooo0P1Bo`030?oo02Ko00<0ool0JOl0023o0P0Lo`060?oo0?l0D_l00`3o
o`0Wo`030?oo06So000Po`030?oo01_o00H0ool0o`1Ao`030?oo02So00<0ool0J?l0023o00<0ool0
6ol01P3oo`3o053o00<0ool0:Ol00`3oo`1Xo`008?l00`3oo`0Lo`050?l0o`00D?l00`3oo`0Yo`03
0?oo06So000Po`030?oo01co00D0o`3o001?o`030?oo02[o00<0ool0J?l0023o0P0Mo`050?l0o`00
Col00`3oo`0Zo`030?oo06So000Po`030?oo01co00D0o`3o001>o`030?oo02_o00<0ool0J?l001Wo
0`04o`030?oo01co00D0o`3o001>o`030?oo02_o00<0ool0J?l001Wo00<0ool01?l00`3oo`0Lo`05
0?l0o`00COl00`3oo`0/o`030?oo06So000Jo`030?oo00?o0P0Mo`050?l0o`00C?l00`3oo`0]o`03
0?oo06So000Jo`030?oo00?o00<0ool07?l01@3o0?l004_o00<0ool0;_l00`3oo`1Xo`006Ol00`3o
0004o`030?oo01co00D0o`3o001;o`030?oo02ko00<0ool0J?l001[o00<0ool00ol00`3oo`0Lo`05
0?l0o`00B_l00`3oo`0_o`030?oo06So000Po`807Ol01@3o0?l004So0P0bo`030?oo06So000Po`03
0?oo01co00D0o`3o0017o`030?oo03;o00<0ool0J?l0023o00<0ool07?l01@3o0?l004Ko00<0ool0
<ol00`3oo`1Xo`008?l00`3oo`0Lo`050?l0o`00AOl00`3oo`0do`030?oo06So000Po`807Ol01@3o
0?l004Co00<0ool0=Ol00`3oo`1Xo`008?l00`3oo`0Lo`050?l0o`00@ol00`3oo`0fo`030?oo06So
000Po`030?oo01co00D0o`3o0012o`030?oo03Oo00<0ool0J?l0023o00<0ool07?l01@3o0?l0047o
00<0ool0>?l00`3oo`1Xo`008?l00`3oo`0Lo`050?l0o`00?ol203_o00<0ool0J?l0023o0P0Mo`05
0?l0o`00?Ol203go00<0ool0J?l0023o00<0ool07?l01@3o0?l003co00<0ool0?Ol00`3oo`1Xo`00
8?l00`3oo`0Lo`050?l0o`00>_l2043o00<0ool0J?l0023o00<0ool07?l01@3o0?l003So0P12o`03
0?oo06So000Po`807Ol01@3o0?l003Oo00<0ool0@_l00`3oo`1Xo`008?l00`3oo`0Lo`050?l0o`00
=_l00`3oo`13o`030?oo06So000Io`801Ol00`3oo`0Lo`050?l0o`00=?l204Ko00<0ool0J?l001_o
00<0ool00_l00`3oo`0Lo`050?l0o`00<_l204So00<0ool0J?l001[o00<0ool00ol201go00D0o`3o
000`o`80B_l00`3oo`1Xo`006ol00`3oo`02o`030?oo01co00D0o`3o000_o`030?oo04[o00<0ool0
<_l303?o000Io`030?l000Co00<0ool07?l00`3o0002o`030?oo02Wo0`1=o`030?oo033o0P0fo`00
6_l00`3oo`03o`030?oo01co00<0o`000_l00`3oo`0Wo`80D?l00`3oo`0]o`<0>?l0023o0P0Mo`03
0?l000;o00<0ool09_l00`3oo`1@o`030?oo02co00<0ool0>Ol0023o00<0ool07?l00`3o0002o`03
0?oo02Co0P1Co`030?oo02co00<0ool0>Ol0023o00<0ool07?l00`3o0002o`030?oo02;o0P1Eo`03
0?oo02Wo0`0lo`008?l00`3oo`0Lo`030?l000;o00<0ool08?l205Oo00<0ool0:?l00`3oo`0mo`00
8?l00`3oo`0Lo`030?l000;o00<0ool07ol00`3oo`1Go`030?oo02So00<0ool0?Ol0023o0P0Mo`03
0?l000;o00<0ool07?l305[o00<0ool09Ol3043o000Po`030?oo01co00<0o`000_l00`3oo`0Jo`80
GOl00`3oo`0To`030?oo047o000Po`030?oo01co00<0o`000_l00`3oo`0Io`030?oo05go00<0ool0
9?l00`3oo`11o`008?l00`3oo`0Lo`030?l000;o00<0ool05ol2063o00<0ool08?l404Co000Po`80
7Ol00`3o0002o`030?oo01Ko00<0ool0H?l00`3oo`0Po`030?oo04Go000Po`030?oo01co00<0o`00
0_l00`3oo`0Eo`030?oo067o00<0ool07ol00`3oo`16o`008?l00`3oo`0Lo`030?l000;o00<0ool0
4ol206Co00<0ool07ol00`3oo`16o`008?l00`3oo`0Lo`030?l000;o00<0ool04ol00`3oo`1So`03
0?oo01ko00<0ool0Aol0023o0P0Mo`030?l000;o00<0ool04ol00`3oo`1So`030?oo01co0`19o`00
8?l00`3oo`0Lo`030?l000;o00<0ool04ol00`3oo`1So`030?oo01_o00<0ool0B_l001[o0`03o`03
0?oo01co00<0o`000_l00`3oo`0Co`030?oo06?o00<0ool06ol00`3oo`1:o`006ol00`3oo`02o`03
0?oo01co00<0o`000_l00`3oo`0Co`030?oo06?o00<0ool06?l304go000Io`@00ol201go00<0o`00
0_l00`3oo`0Co`030?oo06?o00<0ool05ol00`3oo`1>o`006Ol00`3o0004o`030?oo01co00<0o`00
0_l00`3oo`0Bo`030?oo06Co00<0ool05ol00`3oo`1>o`006_l200Co00<0ool07?l00`3o0002o`03
0?oo01;o00<0ool0I?l00`3oo`0Do`<0DOl001_o00<0ool00_l00`3oo`0Lo`030?l000;o00<0ool0
4_l00`3oo`1To`030?oo01Co00<0ool0DOl0023o0P0Mo`030?l000;o00<0ool04_l00`3oo`1To`03
0?oo01Co00<0ool0DOl0023o00<0ool07?l00`3o0002o`030?oo01;o00<0ool0I?l00`3oo`0Do`03
0?oo057o000Po`030?oo01co00<0o`000_l00`3oo`0Bo`030?oo06Co00<0ool04ol00`3oo`1Bo`00
8?l00`3oo`0Lo`030?l000;o00<0ool04_l00`3oo`1To`030?oo01?o00<0ool0D_l0023o00<0ool0
7?l00`3o0002o`030?oo01;o00<0ool0I?l00`3oo`0Co`030?oo05;o000Po`807Ol00`3o0002o`03
0?oo01;o00<0ool0I?l00`3oo`0Co`030?oo05;o000Po`030?oo01co00<0o`000_l00`3oo`0Bo`03
0?oo06Co00<0ool04ol00`3oo`1Bo`008?l00`3oo`0Lo`030?l000;o00<0ool04_l00`3oo`1To`03
0?oo01?o00<0ool0D_l0023o00<0ool07?l00`3o0002o`030?oo01;o00<0ool0I?l00`3oo`0Co`03
0?oo05;o000Po`807Ol00`3o0002o`030?oo017o00<0ool0IOl00`3oo`0Bo`030?oo05?o000Po`03
0?oo01co00<0o`000_l00`3oo`0Ao`030?oo06Ko00<0ool04Ol00`3oo`1Co`008?l00`3oo`0Lo`80
0ol00`3oo`0Ao`030?oo06Ko00<0ool04Ol00`3oo`1Co`008?l00`3oo`0Mo`050?ooo`004ol00`3o
o`1Vo`030?oo017o00<0ool0Dol0023o0P0No`050?ooo`004ol00`3oo`1Vo`030?oo017o00<0ool0
Dol0023o00<0ool07Ol01@3oool001?o00<0ool0I_l00`3oo`0Ao`030?oo05?o000Jo`030?oo00?o
00<0ool07Ol01@3oool0017o0`1Xo`030?oo017o00<0ool0Dol001Wo00<0o`001?l00`3oo`0Mo`05
0?ooo`004Ol00`3oo`1Xo`030?oo013o00<0ool0E?l001_o00<0ool00_l201ko00D0oooo000Ao`03
0?oo06So00<0ool04?l00`3oo`1Do`006Ol200Go00<0ool07Ol01@3oool0013o00<0ool0JOl00`3o
o`0>o`030?l005Ko000Io`030?oo00Co00<0ool07Ol01@3oool0013o00<0ool0JOl00`3oo`0>o`<0
E_l001Wo0`04o`030?oo01go00<0ool00_l00`3oo`0=o`030?oo06Wo00<0ool03_l00`3oo`1Fo`00
8?l00`3oo`0Mo`030?oo00;o00<0ool03Ol00`3oo`1Yo`030?oo00go00<0ool0Eol0023o0P0No`03
0?oo00;o00<0ool03Ol00`3oo`1Yo`030?oo00go00<0ool0Eol0023o00<0ool07Ol00`3oo`02o`03
0?oo00go00<0ool0JOl00`3oo`0=o`030?oo05Oo000Po`030?oo01go00<0ool00_l00`3oo`0<o`03
0?oo06[o00<0ool03Ol00`3oo`1Go`008?l00`3oo`0Mo`030?oo00;o00<0ool02Ol20003o`3o06_o
00<0ool03Ol00`3oo`1Go`008?l201ko00<0ool00_l00`3oo`09o`040?l006co00<0ool03?l00`3o
o`1Ho`008?l00`3oo`0Mo`030?oo00;o00<0ool02?l00`3oo`1^o`030?oo00[o00<0o`00F_l0023o
00<0ool07Ol00`3oo`02o`030?oo00So00<0ool0K_l00`3oo`0:o`<0F_l0023o00<0ool07Ol00`3o
o`02o`030?oo00So00<0ool0K_l00`3oo`09o`030?oo05_o000Po`807_l00`3oo`02o`030?oo00So
00<0ool0K_l00`3oo`09o`030?oo05_o000Po`030?oo01go00<0ool00_l00`3oo`07o`030?oo06oo
00<0ool02Ol00`3oo`1Ko`008?l00`3oo`0Mo`030?oo00;o00<0ool01Ol3077o00<0ool02?l00`3o
o`1Lo`008?l00`3oo`0Mo`030?oo00;o00<0ool01Ol00`3oo`1ao`030?oo00Ko0`1No`008?l201ko
00<0ool00_l00`3oo`04o`030?oo07;o00<0ool01_l00`3oo`1No`008?l00`3oo`0Mo`030?oo00;o
00<0ool01?l00`3oo`1bo`030?oo00Go00<0ool0Gol0023o00<0ool07Ol00`3oo`02o`070?ooo`3o
001eo`030?oo00Go00<0ool0Gol001Wo0P05o`030?oo01go00<0ool00_l0103oool307Go00<0ool0
1?l00`3oo`1Po`006Ol00`3o0004o`030?oo01go00<0ool00_l0103oo`1ho`040?ooo`@0H_l001Wo
00<0o`001?l201ko00<0ool00_l0103oo`1ho`040?oo06Ko000Io`801Ol00`3oo`0Mo`030?oo00;o
00<0o`00NOl0103oo`1Vo`006Ol00`3oo`04o`030?oo01go00<0ool00_l307Wo00<0o`00Iol001[o
0P04o`030?oo01go00<0ool0O_l306Oo000Po`807_l00`3oo`3Xo`008?l00`3oo`0Mo`030?oo0>So
000Po`030?oo0?oo2Ol0023o00<0ool0ool9o`008?l20?oo2_l00?oo;?l00?oo;?l00?oo;?l00?oo
;?l00?oo;?l00?oo;?l00?oo;?l007co0P2]o`00O_l00`3oo`0@o`801ol200Oo0P26o`00L?l20003
o`0000800_l00`3oo`030004o`0000?o0P08o`800_l300?o00<0ool01@02o`030?oo08Co001`o`07
0?ooo`3o0002o`030?l000;o00@0ool00ol00`3oo`07o`040?oo00;o00<0ool00_l00`3oo`02o`03
0?oo00;o00<0ool0Q?l0077o0`02o`060?oo0?l00_l0103oo`03o`<01ol0103oo`02o`030?oo00;o
00<0ool00_l00`3oo`02o`030?oo08Co001ao`040?l0o`@00ol300;o00@0oooo0`07o`040?oo00;o
00<0ool00_l00`3oo`02o`030?oo00;o00<0ool0Q?l007;o00<0ool03?l00`3oo`0;o`040?oo00;o
00<0ool00_l00`3oo`02o`030?oo00;o00<0ool0Q?l0077o0P0=o`803_l200;o0P04o`800_l200?o
0P26o`00ool/o`00ool/o`00ool/o`00ool/o`00ool/o`00ool/o`006Ol30003o`3o00@00_l30?oo
1?l001[o00D0ool0o`0300;o00@0ool0ool4o`006_l300Co00@0ool00_l00`3oo`3oo`;o000Jo`04
0?oo00;o0P03o`<0ool4o`006_l0103oo`09o`030?oo0?oo0_l001Wo1009o`80ool4o`00ool/o`00
ool/o`00ool/o`00\
\>"],
  ImageRangeCache->{{{0, 298}, {184, 0}} -> {-15.1683, -0.849893, 0.465795, 
  0.0472174}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00952381 0.0147151 0.0942726 [
[(20)] .21429 .01472 0 2 Msboxa
[(40)] .40476 .01472 0 2 Msboxa
[(60)] .59524 .01472 0 2 Msboxa
[(80)] .78571 .01472 0 2 Msboxa
[(100)] .97619 .01472 0 2 Msboxa
[(No.)] 1.025 .01472 -1 0 Msboxa
[(Angle Ql[2])] .5 .61803 0 -2 0 0 1 Mouter Mrotsboxa
[(1)] .01131 .10899 1 0 Msboxa
[(2)] .01131 .20326 1 0 Msboxa
[(3)] .01131 .29753 1 0 Msboxa
[(4)] .01131 .39181 1 0 Msboxa
[(5)] .01131 .48608 1 0 Msboxa
[(6)] .01131 .58035 1 0 Msboxa
[(Rad)] .02381 .61803 0 -4 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 .61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.21429 .01472 m
.21429 .02097 L
s
P
[(20)] .21429 .01472 0 2 Mshowa
p
.002 w
.40476 .01472 m
.40476 .02097 L
s
P
[(40)] .40476 .01472 0 2 Mshowa
p
.002 w
.59524 .01472 m
.59524 .02097 L
s
P
[(60)] .59524 .01472 0 2 Mshowa
p
.002 w
.78571 .01472 m
.78571 .02097 L
s
P
[(80)] .78571 .01472 0 2 Mshowa
p
.002 w
.97619 .01472 m
.97619 .02097 L
s
P
[(100)] .97619 .01472 0 2 Mshowa
p
.001 w
.0619 .01472 m
.0619 .01847 L
s
P
p
.001 w
.1 .01472 m
.1 .01847 L
s
P
p
.001 w
.1381 .01472 m
.1381 .01847 L
s
P
p
.001 w
.17619 .01472 m
.17619 .01847 L
s
P
p
.001 w
.25238 .01472 m
.25238 .01847 L
s
P
p
.001 w
.29048 .01472 m
.29048 .01847 L
s
P
p
.001 w
.32857 .01472 m
.32857 .01847 L
s
P
p
.001 w
.36667 .01472 m
.36667 .01847 L
s
P
p
.001 w
.44286 .01472 m
.44286 .01847 L
s
P
p
.001 w
.48095 .01472 m
.48095 .01847 L
s
P
p
.001 w
.51905 .01472 m
.51905 .01847 L
s
P
p
.001 w
.55714 .01472 m
.55714 .01847 L
s
P
p
.001 w
.63333 .01472 m
.63333 .01847 L
s
P
p
.001 w
.67143 .01472 m
.67143 .01847 L
s
P
p
.001 w
.70952 .01472 m
.70952 .01847 L
s
P
p
.001 w
.74762 .01472 m
.74762 .01847 L
s
P
p
.001 w
.82381 .01472 m
.82381 .01847 L
s
P
p
.001 w
.8619 .01472 m
.8619 .01847 L
s
P
p
.001 w
.9 .01472 m
.9 .01847 L
s
P
p
.001 w
.9381 .01472 m
.9381 .01847 L
s
P
[(No.)] 1.025 .01472 -1 0 Mshowa
p
.002 w
0 .01472 m
1 .01472 L
s
P
[(Angle Ql[2])] .5 .61803 0 -2 0 0 1 Mouter Mrotshowa
p
.002 w
.02381 .10899 m
.03006 .10899 L
s
P
[(1)] .01131 .10899 1 0 Mshowa
p
.002 w
.02381 .20326 m
.03006 .20326 L
s
P
[(2)] .01131 .20326 1 0 Mshowa
p
.002 w
.02381 .29753 m
.03006 .29753 L
s
P
[(3)] .01131 .29753 1 0 Mshowa
p
.002 w
.02381 .39181 m
.03006 .39181 L
s
P
[(4)] .01131 .39181 1 0 Mshowa
p
.002 w
.02381 .48608 m
.03006 .48608 L
s
P
[(5)] .01131 .48608 1 0 Mshowa
p
.002 w
.02381 .58035 m
.03006 .58035 L
s
P
[(6)] .01131 .58035 1 0 Mshowa
p
.001 w
.02381 .03357 m
.02756 .03357 L
s
P
p
.001 w
.02381 .05242 m
.02756 .05242 L
s
P
p
.001 w
.02381 .07128 m
.02756 .07128 L
s
P
p
.001 w
.02381 .09013 m
.02756 .09013 L
s
P
p
.001 w
.02381 .12784 m
.02756 .12784 L
s
P
p
.001 w
.02381 .1467 m
.02756 .1467 L
s
P
p
.001 w
.02381 .16555 m
.02756 .16555 L
s
P
p
.001 w
.02381 .18441 m
.02756 .18441 L
s
P
p
.001 w
.02381 .22211 m
.02756 .22211 L
s
P
p
.001 w
.02381 .24097 m
.02756 .24097 L
s
P
p
.001 w
.02381 .25982 m
.02756 .25982 L
s
P
p
.001 w
.02381 .27868 m
.02756 .27868 L
s
P
p
.001 w
.02381 .31639 m
.02756 .31639 L
s
P
p
.001 w
.02381 .33524 m
.02756 .33524 L
s
P
p
.001 w
.02381 .3541 m
.02756 .3541 L
s
P
p
.001 w
.02381 .37295 m
.02756 .37295 L
s
P
p
.001 w
.02381 .41066 m
.02756 .41066 L
s
P
p
.001 w
.02381 .42951 m
.02756 .42951 L
s
P
p
.001 w
.02381 .44837 m
.02756 .44837 L
s
P
p
.001 w
.02381 .46722 m
.02756 .46722 L
s
P
p
.001 w
.02381 .50493 m
.02756 .50493 L
s
P
p
.001 w
.02381 .52379 m
.02756 .52379 L
s
P
p
.001 w
.02381 .54264 m
.02756 .54264 L
s
P
p
.001 w
.02381 .5615 m
.02756 .5615 L
s
P
p
.001 w
.02381 .59921 m
.02756 .59921 L
s
P
[(Rad)] .02381 .61803 0 -4 Mshowa
p
.002 w
.02381 0 m
.02381 .61803 L
s
P
P
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.004 w
.03333 .01472 m
.04286 .06103 L
.05238 .08868 L
.0619 .09634 L
.07143 .09799 L
.08095 .10546 L
.09048 .10781 L
.1 .11513 L
.10952 .11844 L
.11905 .12568 L
.12857 .1303 L
.1381 .13749 L
.14762 .14382 L
.15714 .15097 L
.16667 .15941 L
.17619 .16648 L
.18571 .17722 L
.19524 .18414 L
.20476 .1973 L
.21429 .20404 L
.22381 .22061 L
.23333 .22717 L
.24286 .25072 L
.25238 .25708 L
.2619 .29953 L
.27143 .30572 L
.28095 .41149 L
.29048 .42335 L
.3 .42258 L
.30952 .43314 L
.31905 .43261 L
.32857 .44252 L
.3381 .44216 L
.34762 .45181 L
.35714 .45151 L
.36667 .46116 L
.37619 .46082 L
.38571 .47073 L
.39524 .47025 L
.40476 .48066 L
.41429 .47996 L
.42381 .49117 L
.43333 .49019 L
.44286 .50257 L
.45238 .50126 L
.4619 .51533 L
.47143 .51364 L
.48095 .53015 L
.49048 .52803 L
.5 .54816 L
Mistroke
.50952 .5455 L
.51905 .57135 L
.52857 .56795 L
.5381 .60332 L
.54762 .59884 L
.55714 .05194 L
.56667 .0466 L
.57619 .08032 L
.58571 .07673 L
.59524 .0945 L
.60476 .09251 L
.61429 .10408 L
.62381 .10312 L
.63333 .11223 L
.64286 .11218 L
.65238 .12011 L
.6619 .12108 L
.67143 .12844 L
.68095 .13071 L
.69048 .13783 L
.7 .1419 L
.70952 .14896 L
.71905 .1555 L
.72857 .16256 L
.7381 .17211 L
.74762 .17908 L
.75714 .19157 L
.76667 .19836 L
.77619 .21378 L
.78571 .22038 L
.79524 .24145 L
.80476 .24787 L
.81429 .28256 L
.82381 .2888 L
.83333 .37623 L
.84286 .38342 L
.85238 .38566 L
.8619 .39212 L
.87143 .39841 L
.88095 .4048 L
.89048 .41714 L
.9 .42372 L
.90952 .4312 L
.91905 .43794 L
.92857 .44349 L
.9381 .45042 L
.94762 .45442 L
.95714 .46158 L
.96667 .46441 L
.97619 .47185 L
Mistroke
Mfstroke
% End of Graphics
MathPictureEnd\
\>"], "Graphics",
  PageWidth->Infinity,
  Evaluatable->False,
  ImageSize->{299, 185},
  ImageMargins->{{100, Inherited}, {Inherited, 0}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004[0000^@P10`40000100000800002008200000
P800P020P<30`<3L`:K:l:C8l3<006H009T00<`0000c03<c06Hc09Tc0<`c0?lc001V03=V06IV09UV
0<aV0?mV002I03>I06JI09VI0<bI0?nI003<03?<06K<09W<0<c<0?o<03?o06Ko09Wo0<co0000<c<0
<fH0<iT0<l`0<ol0<`0c<c<c<fHc<iTc<l`c<olc<`1V<c=V<fIV<iUV<laV<omV<`2I<c>I<fJI<iVI
<lbI<onI<`3<<c?<<fK<<iW<<lc<<oo<<`3o<c?o<fKo<iWo<lco<ooo<`00IS<0IVH0IYT0I/`0I_l0
IP0cIS<cIVHcIYTcI/`cI_lcIP1VIS=VIVIVIYUVI/aVI_mVIP2IIS>IIVJIIYVII/bII_nIIP3<IS?<
IVK<IYW<I/c<I_o<IP3oIS?oIVKoIYWoI/coI_ooIP00VC<0VFH0VIT0VL`0VOl0V@0cVC<cVFHcVITc
VL`cVOlcV@1VVC=VVFIVVIUVVLaVVOmVV@2IVC>IVFJIVIVIVLbIVOnIV@3<VC?<VFK<VIW<VLc<VOo<
V@3oVC?oVFKoVIWoVLcoVOooV@00c3<0c6H0c9T0c<`0c?l0c00cc3<cc6Hcc9Tcc<`cc?lcc01Vc3=V
c6IVc9UVc<aVc?mVc02Ic3>Ic6JIc9VIc<bIc?nIc03<c3?<c6K<c9W<c<c<c?o<c03oc3?oc6Koc9Wo
c<coc?ooc3<0ofH0oiT0ol`0o`0coc<cofHcoiTcol`coolco`1Voc=VofIVoiUVolaVoomVo`2Ioc>I
ofJIoiVIolbIoonIo`3<oc?<ofK<oiW<olc<ooo<oc?oofKooiWoolcoo`410@820P<30`@410D51@H6
1PL71`P820T92@X:2P/;2``<30h>3Pl?3a0@414A4A8B4Q<C4a@D5000000000000000000000000000
00000?okl:2PY820P?l0003o0?oo0000ool0o`3ooooooooo;?l00?oo;?l00?oo;?l00?oo;?l004Oo
0`03o`030?oo02?o0`02o`030?oo02;o0P04o`030?oo02?o00<0ool00_l00`3oo`0No`D00_l00`3o
o`02o`030?oo02go0017o`030?oo00;o00<0o`009Ol01P3oo`3o02?o00<0o`000_l00`3o000So`03
0?l000;o00<0o`008Ol01`3oool0o`000_l00`3o000^o`00B?l01`3oool0o`008ol40004o`3o02?o
00<0o`000_l00`3o000So`030?l000;o00<0o`008Ol01`3oool0o`000_l00`3o000^o`00B?l01`3o
ool0o`008ol00`3o0002o`030?l002?o0P03o`030?l002Co00L0oooo0?l0027o00L0oooo0?l000;o
00<0o`00;_l004Oo00<0o`000_l00`3o000To`800_l00`3o000So`030?oo00;o00<0o`008ol00`3o
0002o`030?l0027o00L0oooo0?l000;o00<0o`00;_l004So00<0ool00_l00`3oo`0To`050?ooo`00
9Ol200?o00<0ool08ol00`3oo`02o`030?oo01oo0P04o`030?oo00;o00<0ool0;Ol00?oo;?l00?oo
;?l00?oo;?l00?oo;?l00?oo;?l0023o00<0ool0ool9o`008?l00`3oo`3Oo`<000Co0?oo0P03o`03
0?oo01[o000Po`030?oo0>3o00H0o`00o`02o`030?oo01go000Kon801_l01P3o003o00;o00<0ool0
7Ol0023o00<0o`001_l00`3oo`05o`030?oo00Ko00<0ool01Ol00`3oo`06o`030?oo00Ko00<0ool0
1Ol00`3oo`06o`030?oo00Go00<0ool01_l00`3oo`06o`030?oo00Go00<0ool01_l00`3oo`05o`03
0?oo00Ko00<0ool01Ol00`3oo`06o`030?oo00Ko00<0ool01Ol00`3oo`06o`030?oo00Go00<0ool0
1_l00`3oo`06o`030?oo00Go00<0ool01_l00`3oo`09o`8000Co0?oo0P0Po`008?l00`3o000Xo`03
0?oo02So00<0ool0:?l00`3oo`0Xo`030?oo02So00<0ool02Ol20003o`3o02?o000Po`040?oo0=ko
0P000ol0000To`008?l0103oo`3oo`So000Po`8000?o0?l0ool7o`008?l0103oo`3oo`So000Po`04
0?oo0?oo2?l0023o00@0ool0M_l00`3oo`2>o`008?l200;o00<0ool0LOl3093o000Po`050?ooo`00
Lol0103oo`2?o`008?l01@3oool007?o00@0ool0Sol0023o00<0ool00_l00`3oo`1`o`050?ooo`00
S_l0023o0P03o`030?oo073o00D0oooo002>o`008?l00`3oo`03o`030?oo06oo00<0ool00_l00`3o
002;o`008?l00`3oo`03o`030?oo06oo00<0ool00_l20003o`3o08Wo000Po`030?oo00Co00<0ool0
K_l00`3oo`05o`030?oo08So000Po`801Ol00`3oo`1^o`030?oo00Ko00<0ool0Qol0023o00<0ool0
1Ol00`3oo`1]o`030?oo00Ko0`27o`008?l00`3oo`06o`<0K?l00`3oo`09o`030?oo08Co000Ho`D0
0ol00`3oo`09o`030?oo06Wo00<0ool02Ol0103oo`23o`006_l00`3oo`03o`030?oo00[o0`1Xo`03
0?oo00[o0P000ol0o`21o`006_l00`3oo`03o`803_l00`3oo`1Uo`030?oo00ko101no`006_l00`3o
o`03o`030?oo00ko00<0ool0I?l00`3oo`0Bo`030?oo07_o000Jo`030?oo00?o00<0ool03ol206Co
00<0ool04ol307[o000Io`801Ol00`3oo`0Ao`80H_l00`3oo`0Fo`030?oo07Oo000Po`805?l00`3o
o`1Oo`030?oo01Oo00<0ool0M_l0023o00<0ool05?l205oo00<0ool06?l207Ko000Po`030?oo01Ko
0P1Mo`030?oo01[o0P1do`008?l00`3oo`0Ho`030?oo05[o00<0ool07?l207;o000Po`806_l00`3o
o`1Io`030?oo01ko0P1`o`008?l00`3oo`0Jo`80FOl00`3oo`0Po`030?oo06go000Po`030?oo01co
00<0ool0E_l00`3oo`0Qo`80KOl0023o00<0ool07Ol00`3oo`1Eo`030?oo02?o00<0ool0J_l0023o
0P0Oo`030?oo05Co00<0ool09?l00`3oo`1Yo`008?l00`3oo`0Oo`030?oo05?o00<0ool09Ol00`3o
o`1Xo`008?l00`3oo`0Po`80Dol00`3oo`0Vo`030?oo06Oo000Po`030?oo02;o00<0ool0D?l00`3o
o`0Wo`030?oo06Ko000Po`030?oo02?o00<0ool0Col00`3oo`0Xo`030?oo06Go000Po`809Ol00`3o
o`1>o`030?oo02Wo00<0ool0I?l0023o00<0ool09Ol00`3oo`1<o`030?oo02_o00<0ool0Hol001Wo
0`04o`030?oo02Go00<0ool0C?l00`3oo`0/o`80Hol001Wo00<0ool01?l00`3oo`0Vo`030?oo04_o
00<0ool0;_l00`3oo`1Po`006_l00`3oo`03o`80:?l204_o00<0ool0;ol00`3oo`1Oo`006_l00`3o
o`03o`030?oo02Wo00<0ool0B?l00`3oo`0_o`030?oo05oo000Io`030?l000Co00<0ool0:Ol00`3o
o`18o`030?oo033o00<0ool0G_l001[o00<0ool00ol00`3oo`0Zo`030?oo04Oo00<0ool0<Ol00`3o
o`1Mo`008?l202_o00<0ool0Aol00`3oo`0bo`030?oo05co000Po`030?oo02_o0P17o`030?oo03;o
00<0ool0G?l0023o00<0ool0;?l00`3oo`15o`030?oo03?o00<0ool0Fol0023o00<0ool0;Ol00`3o
o`14o`030?oo03?o00<0ool0Fol0023o00<0ool0;Ol00`3oo`14o`030?oo03Co00<0ool0F_l0023o
0P0^o`030?oo04Co00<0ool0=?l00`3oo`1Jo`008?l00`3oo`0^o`030?oo04?o00<0ool0=Ol205[o
000Po`030?oo02ko0P14o`030?oo03Ko00<0ool0F?l0023o00<0ool0<?l204;o00<0ool0=ol00`3o
o`1Go`008?l203;o00<0ool0@?l00`3oo`0go`030?oo05Oo000Po`030?oo037o00<0ool0@?l00`3o
o`0go`030?oo05Oo000Po`030?oo03;o00<0ool0?ol00`3oo`0go`030?oo05Oo000Po`030?oo03;o
00<0ool0?ol00`3oo`0ho`030?oo05Ko000Po`80<ol00`3oo`0oo`030?oo03So00<0ool0E_l0023o
00<0ool0<_l00`3oo`0oo`030?oo03So00<0ool0E_l001Wo0P05o`030?oo03;o00<0ool0?ol00`3o
o`0io`80E_l001_o00<0ool00_l00`3oo`0co`030?oo03ko00<0ool0>_l00`3oo`1Do`006_l00`3o
o`03o`80=?l00`3oo`0no`030?oo03[o00<0ool0E?l001_o00<0ool00_l00`3oo`0co`030?oo03ko
00<0ool0>_l00`3oo`1Do`006Ol00`3o0004o`030?oo03Co0P0no`030?oo03_o00<0ool0Dol001[o
00<0ool00ol00`3oo`0eo`030?oo03co00<0ool0>ol00`3oo`1Co`008?l00`3oo`0eo`030?oo03co
00<0ool0>ol00`3oo`1Co`008?l203Ko00<0ool0??l00`3oo`0ko`030?oo05?o000Po`030?oo03Go
00<0ool0??l00`3oo`0ko`030?oo05?o000Po`030?oo03Go00<0ool0??l00`3oo`0ko`030?oo05?o
000Po`030?oo03Ko00<0ool0>ol00`3oo`0lo`030?oo05;o000Po`80=ol00`3oo`0ko`030?oo03co
00<0ool0D_l0023o00<0ool0=_l00`3oo`0ko`030?oo03co00<0ool0D_l0023o00<0ool0=_l00`3o
o`0ko`030?oo03co00<0ool0D_l0023o00<0ool0=_l00`3oo`0ko`030?oo03co00<0ool0D_l0023o
0P0go`030?oo03_o00<0ool0??l00`3oo`1Bo`008?l00`3oo`0fo`030?oo03_o00<0ool0??l00`3o
o`1Bo`008?l00`3oo`0fo`030?oo03_o00<0ool0?Ol00`3oo`1Ao`008?l00`3oo`0fo`030?oo03_o
00<0ool0?Ol00`3oo`1Ao`008?l203Oo00<0ool0>ol00`3oo`0mo`030?oo057o000Po`030?oo03Ko
00<0ool0>ol00`3oo`0mo`030?oo057o000Po`030?oo03Ko00<0ool0>ol00`3oo`0no`030?oo053o
000Jo`<00ol00`3oo`0go`030?oo03[o00<0ool0?ol304oo000Ko`030?oo00;o00<0ool0=ol00`3o
o`0jo`030?oo04;o00<0ool0C?l001Wo1003o`80>?l00`3oo`0jo`030?oo04?o00<0ool0Bol001Wo
00<0o`001?l00`3oo`0go`030?oo03[o00<0ool0A?l204_o000Jo`801?l00`3oo`0go`030?oo03[o
00<0ool0A_l204Wo000Ko`030?oo00;o00<0ool0=ol00`3oo`0jo`030?oo04So00<0ool0A_l0023o
0P0ho`030?oo03[o00<0ool0B?l00`3oo`16o`008?l00`3oo`0ho`030?oo03Wo00<0ool0BOl00`3o
o`15o`008?l00`3oo`0ho`040?oo03So00<0ool0B_l204Go000Po`030?oo03Wo0P000ol0o`0fo`03
0?oo04co00<0ool0@_l0023o0P0mo`030?oo03Go00<0ool0COl204;o000Po`030?oo03go100co`03
0?oo04oo00<0ool0?ol0023o00<0ool0@Ol00`3oo`0`o`030?oo053o00<0ool0?_l0023o00<0ool0
@_l302oo00<0ool0DOl203ko000Po`80A_l00`3oo`0/o`030?oo05?o00<0ool0>ol0023o00<0ool0
A_l302_o00<0ool0E?l00`3oo`0jo`008?l00`3oo`19o`030?oo02So00<0ool0EOl203[o000Po`03
0?oo04[o100Vo`030?oo05Oo0`0go`008?l00`3oo`1>o`030?oo02;o00<0ool0Fol203Go000Po`80
D?l3027o00<0ool0GOl00`3oo`0bo`008?l00`3oo`1Bo`030?oo01ko00<0ool0G_l00`3oo`0ao`00
6_l00`3oo`03o`030?oo05;o00@0ool07Ol00`3oo`2Bo`006Ol00`3o0004o`030?oo05?o0P000ol0
o`0Ko`030?oo09;o000Ko`030?oo00;o0P1Go`030?oo01[o00<0ool0T_l001Wo0P05o`030?oo05Oo
0`0Io`030?oo09;o000Io`030?oo00Co00<0ool0F_l201Oo00<0ool0T_l001Wo0`04o`030?oo05co
0`0Do`030?oo09;o000Po`80H?l00`3oo`0Ao`030?oo09;o000Po`030?oo05oo00<0ool04Ol00`3o
o`2Bo`008?l00`3oo`1Po`<04?l00`3oo`2Bo`008?l00`3oo`1So`030?oo00go00<0ool0T_l0023o
0P1To`030?oo00go00<0ool0T_l0023o00<0ool0I?l00`3o000<o`030?oo09;o000Po`030?oo06Co
0`0<o`030?oo09;o000Po`030?oo06Oo00<0ool02Ol00`3oo`2Bo`008?l00`3oo`1Wo`030?oo00Wo
00<0ool0T_l0023o0P1Yo`040?l000Oo00<0ool0T_l0023o00<0ool0J?l20003o`3o00Ko00<0ool0
T_l0023o00<0ool0K?l00`3oo`04o`030?oo09;o000Po`030?oo06co00<0ool01?l00`3oo`2Bo`00
8?l206go00<0ool01?l00`3oo`2Bo`008?l00`3oo`1]o`030?l000?o00<0ool0T_l001Wo0P05o`03
0?oo06go0`03o`030?oo09;o000Io`030?l000Co00<0ool0L?l0103oo`2Do`006Ol00`3o0004o`80
LOl0103oo`2Do`006Ol200Go00<0ool0L?l0103oo`2Do`006Ol00`3oo`04o`030?oo073o00@0ool0
U?l001[o0P04o`030?oo077o00<0o`00U?l0023o0P1bo`030?l009Co000Po`030?oo077o0P2Eo`00
8?l00`3oo`3oo`Wo000Po`030?oo0?oo2Ol0023o00<0ool0ool9o`00ool/o`00ool/o`00ool/o`00
ool/o`00ool/o`00ool/o`00ool/o`00O?l20:go001no`030?oo013o0P07o`801ol208Ko001`o`80
00?o00000P02o`030?oo00<000Co00000ol200So0P02o`<00ol0103oool300?o00<0ool0Q?l0073o
00L0oooo0?l000;o00<0o`000_l0103oo`03o`030?oo00Oo00@0ool00_l00`3oo`02o`050?ooo`00
1Ol00`3oo`24o`00LOl300;o00H0ool0o`02o`040?oo00?o0`07o`040?oo00;o00<0ool00_l00`3o
o`02o`030?oo00;o00<0ool0Q?l0077o00@0o`3o1003o`<00_l0103oool300Oo00@0ool00_l00`3o
o`02o`030?oo00;o00<0ool00_l00`3oo`24o`00L_l00`3oo`0<o`030?oo00_o00@0ool00_l00`3o
o`02o`070?ooo`3o0003o`030?oo08Co001ao`803Ol200ko0P02o`801?l200?o00@0oooo0P26o`00
ool/o`00ool/o`00ool/o`00ool/o`00ool/o`00ool/o`006Ol30003o`3o00@00_l30?oo1?l001[o
00D0ool0o`0300;o00@0ool0ool4o`006_l300Co00@0ool00_l00`3oo`3oo`;o000Jo`040?oo00;o
0P03o`<0ool4o`006_l0103oo`09o`030?oo0?oo0_l001Wo1009o`80ool4o`00ool/o`00ool/o`00
ool/o`00\
\>"],
  ImageRangeCache->{{{0, 298}, {184, 0}} -> {-15.1683, -0.846999, 0.465795, 
  0.0470566}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00952381 0.0147151 0.449563 [
[(20)] .21429 .01472 0 2 Msboxa
[(40)] .40476 .01472 0 2 Msboxa
[(60)] .59524 .01472 0 2 Msboxa
[(80)] .78571 .01472 0 2 Msboxa
[(100)] .97619 .01472 0 2 Msboxa
[(No.)] 1.025 .01472 -1 0 Msboxa
[(Angle Ql[3])] .5 .61803 0 -2 0 0 1 Mouter Mrotsboxa
[(0.2)] .01131 .10463 1 0 Msboxa
[(0.4)] .01131 .19454 1 0 Msboxa
[(0.6)] .01131 .28445 1 0 Msboxa
[(0.8)] .01131 .37437 1 0 Msboxa
[(1)] .01131 .46428 1 0 Msboxa
[(1.2)] .01131 .55419 1 0 Msboxa
[(Rad)] .02381 .61803 0 -4 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 .61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.21429 .01472 m
.21429 .02097 L
s
P
[(20)] .21429 .01472 0 2 Mshowa
p
.002 w
.40476 .01472 m
.40476 .02097 L
s
P
[(40)] .40476 .01472 0 2 Mshowa
p
.002 w
.59524 .01472 m
.59524 .02097 L
s
P
[(60)] .59524 .01472 0 2 Mshowa
p
.002 w
.78571 .01472 m
.78571 .02097 L
s
P
[(80)] .78571 .01472 0 2 Mshowa
p
.002 w
.97619 .01472 m
.97619 .02097 L
s
P
[(100)] .97619 .01472 0 2 Mshowa
p
.001 w
.0619 .01472 m
.0619 .01847 L
s
P
p
.001 w
.1 .01472 m
.1 .01847 L
s
P
p
.001 w
.1381 .01472 m
.1381 .01847 L
s
P
p
.001 w
.17619 .01472 m
.17619 .01847 L
s
P
p
.001 w
.25238 .01472 m
.25238 .01847 L
s
P
p
.001 w
.29048 .01472 m
.29048 .01847 L
s
P
p
.001 w
.32857 .01472 m
.32857 .01847 L
s
P
p
.001 w
.36667 .01472 m
.36667 .01847 L
s
P
p
.001 w
.44286 .01472 m
.44286 .01847 L
s
P
p
.001 w
.48095 .01472 m
.48095 .01847 L
s
P
p
.001 w
.51905 .01472 m
.51905 .01847 L
s
P
p
.001 w
.55714 .01472 m
.55714 .01847 L
s
P
p
.001 w
.63333 .01472 m
.63333 .01847 L
s
P
p
.001 w
.67143 .01472 m
.67143 .01847 L
s
P
p
.001 w
.70952 .01472 m
.70952 .01847 L
s
P
p
.001 w
.74762 .01472 m
.74762 .01847 L
s
P
p
.001 w
.82381 .01472 m
.82381 .01847 L
s
P
p
.001 w
.8619 .01472 m
.8619 .01847 L
s
P
p
.001 w
.9 .01472 m
.9 .01847 L
s
P
p
.001 w
.9381 .01472 m
.9381 .01847 L
s
P
[(No.)] 1.025 .01472 -1 0 Mshowa
p
.002 w
0 .01472 m
1 .01472 L
s
P
[(Angle Ql[3])] .5 .61803 0 -2 0 0 1 Mouter Mrotshowa
p
.002 w
.02381 .10463 m
.03006 .10463 L
s
P
[(0.2)] .01131 .10463 1 0 Mshowa
p
.002 w
.02381 .19454 m
.03006 .19454 L
s
P
[(0.4)] .01131 .19454 1 0 Mshowa
p
.002 w
.02381 .28445 m
.03006 .28445 L
s
P
[(0.6)] .01131 .28445 1 0 Mshowa
p
.002 w
.02381 .37437 m
.03006 .37437 L
s
P
[(0.8)] .01131 .37437 1 0 Mshowa
p
.002 w
.02381 .46428 m
.03006 .46428 L
s
P
[(1)] .01131 .46428 1 0 Mshowa
p
.002 w
.02381 .55419 m
.03006 .55419 L
s
P
[(1.2)] .01131 .55419 1 0 Mshowa
p
.001 w
.02381 .0327 m
.02756 .0327 L
s
P
p
.001 w
.02381 .05068 m
.02756 .05068 L
s
P
p
.001 w
.02381 .06866 m
.02756 .06866 L
s
P
p
.001 w
.02381 .08665 m
.02756 .08665 L
s
P
p
.001 w
.02381 .12261 m
.02756 .12261 L
s
P
p
.001 w
.02381 .14059 m
.02756 .14059 L
s
P
p
.001 w
.02381 .15858 m
.02756 .15858 L
s
P
p
.001 w
.02381 .17656 m
.02756 .17656 L
s
P
p
.001 w
.02381 .21252 m
.02756 .21252 L
s
P
p
.001 w
.02381 .23051 m
.02756 .23051 L
s
P
p
.001 w
.02381 .24849 m
.02756 .24849 L
s
P
p
.001 w
.02381 .26647 m
.02756 .26647 L
s
P
p
.001 w
.02381 .30244 m
.02756 .30244 L
s
P
p
.001 w
.02381 .32042 m
.02756 .32042 L
s
P
p
.001 w
.02381 .3384 m
.02756 .3384 L
s
P
p
.001 w
.02381 .35638 m
.02756 .35638 L
s
P
p
.001 w
.02381 .39235 m
.02756 .39235 L
s
P
p
.001 w
.02381 .41033 m
.02756 .41033 L
s
P
p
.001 w
.02381 .42831 m
.02756 .42831 L
s
P
p
.001 w
.02381 .4463 m
.02756 .4463 L
s
P
p
.001 w
.02381 .48226 m
.02756 .48226 L
s
P
p
.001 w
.02381 .50024 m
.02756 .50024 L
s
P
p
.001 w
.02381 .51823 m
.02756 .51823 L
s
P
p
.001 w
.02381 .53621 m
.02756 .53621 L
s
P
p
.001 w
.02381 .57217 m
.02756 .57217 L
s
P
p
.001 w
.02381 .59016 m
.02756 .59016 L
s
P
p
.001 w
.02381 .60814 m
.02756 .60814 L
s
P
[(Rad)] .02381 .61803 0 -4 Mshowa
p
.002 w
.02381 0 m
.02381 .61803 L
s
P
P
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.004 w
.03333 .01472 m
.04286 .01497 L
.05238 .01785 L
.0619 .02491 L
.07143 .03732 L
.08095 .04446 L
.09048 .05948 L
.1 .06661 L
.10952 .08504 L
.11905 .09212 L
.12857 .11493 L
.1381 .12193 L
.14762 .15018 L
.15714 .15708 L
.16667 .19141 L
.17619 .19817 L
.18571 .23822 L
.19524 .2447 L
.20476 .28927 L
.21429 .29523 L
.22381 .34413 L
.23333 .34916 L
.24286 .40426 L
.25238 .40774 L
.2619 .47073 L
.27143 .47119 L
.28095 .47352 L
.29048 .45258 L
.3 .44391 L
.30952 .42539 L
.31905 .41589 L
.32857 .39864 L
.3381 .38857 L
.34762 .37189 L
.35714 .36158 L
.36667 .3449 L
.37619 .33469 L
.38571 .31755 L
.39524 .30777 L
.40476 .28971 L
.41429 .2806 L
.42381 .26114 L
.43333 .25285 L
.44286 .23145 L
.45238 .2241 L
.4619 .20022 L
.47143 .19388 L
.48095 .16706 L
.49048 .16184 L
.5 .13199 L
Mistroke
.50952 .12811 L
.51905 .09631 L
.52857 .0941 L
.5381 .0658 L
.54762 .06585 L
.55714 .06174 L
.56667 .06445 L
.57619 .09256 L
.58571 .09707 L
.59524 .12004 L
.60476 .12598 L
.61429 .14144 L
.62381 .14901 L
.63333 .16078 L
.64286 .17047 L
.65238 .1802 L
.6619 .19277 L
.67143 .20129 L
.68095 .21786 L
.69048 .2256 L
.7 .2477 L
.70952 .25493 L
.71905 .28423 L
.72857 .29111 L
.7381 .32834 L
.74762 .33492 L
.75714 .37843 L
.76667 .38456 L
.77619 .43213 L
.78571 .43746 L
.79524 .49066 L
.80476 .49466 L
.81429 .55553 L
.82381 .55707 L
.83333 .60332 L
.84286 .59596 L
.85238 .58295 L
.8619 .57667 L
.87143 .55288 L
.88095 .54687 L
.89048 .50719 L
.9 .49997 L
.90952 .46926 L
.91905 .4613 L
.92857 .43482 L
.9381 .42618 L
.94762 .40374 L
.95714 .39445 L
.96667 .37545 L
.97619 .36547 L
Mistroke
Mfstroke
% End of Graphics
MathPictureEnd\
\>"], "Graphics",
  PageWidth->Infinity,
  Evaluatable->False,
  ImageSize->{299, 185},
  ImageMargins->{{100, Inherited}, {Inherited, 0}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004[0000^@P10`40000100000800002008200000
P800P020P<30`<3L`:K:l:C8l3<006H009T00<`0000c03<c06Hc09Tc0<`c0?lc001V03=V06IV09UV
0<aV0?mV002I03>I06JI09VI0<bI0?nI003<03?<06K<09W<0<c<0?o<03?o06Ko09Wo0<co0000<c<0
<fH0<iT0<l`0<ol0<`0c<c<c<fHc<iTc<l`c<olc<`1V<c=V<fIV<iUV<laV<omV<`2I<c>I<fJI<iVI
<lbI<onI<`3<<c?<<fK<<iW<<lc<<oo<<`3o<c?o<fKo<iWo<lco<ooo<`00IS<0IVH0IYT0I/`0I_l0
IP0cIS<cIVHcIYTcI/`cI_lcIP1VIS=VIVIVIYUVI/aVI_mVIP2IIS>IIVJIIYVII/bII_nIIP3<IS?<
IVK<IYW<I/c<I_o<IP3oIS?oIVKoIYWoI/coI_ooIP00VC<0VFH0VIT0VL`0VOl0V@0cVC<cVFHcVITc
VL`cVOlcV@1VVC=VVFIVVIUVVLaVVOmVV@2IVC>IVFJIVIVIVLbIVOnIV@3<VC?<VFK<VIW<VLc<VOo<
V@3oVC?oVFKoVIWoVLcoVOooV@00c3<0c6H0c9T0c<`0c?l0c00cc3<cc6Hcc9Tcc<`cc?lcc01Vc3=V
c6IVc9UVc<aVc?mVc02Ic3>Ic6JIc9VIc<bIc?nIc03<c3?<c6K<c9W<c<c<c?o<c03oc3?oc6Koc9Wo
c<coc?ooc3<0ofH0oiT0ol`0o`0coc<cofHcoiTcol`coolco`1Voc=VofIVoiUVolaVoomVo`2Ioc>I
ofJIoiVIolbIoonIo`3<oc?<ofK<oiW<olc<ooo<oc?oofKooiWoolcoo`410@820P<30`@410D51@H6
1PL71`P820T92@X:2P/;2``<30h>3Pl?3a0@414A4A8B4Q<C4a@D5000000000000000000000000000
00000?okl:2PY820P?l0003o0?oo0000ool0o`3ooooooooo;?l00?oo;?l00?oo;?l00?oo;?l004co
0`03o`030?oo02?o0`02o`030?oo02;o0P04o`030?oo02?o00<0ool00_l00`3oo`0No`D00_l00`3o
o`02o`030?oo02So001<o`030?oo00;o00<0o`009Ol01P3oo`3o02?o00<0o`000_l00`3o000So`03
0?l000;o00<0o`008Ol01`3oool0o`000_l00`3o000Yo`00COl01`3oool0o`008ol40004o`3o02?o
00<0o`000_l00`3o000So`030?l000;o00<0o`008Ol01`3oool0o`000_l00`3o000Yo`00COl01`3o
ool0o`008ol00`3o0002o`030?l002?o0P03o`030?l002Co00L0oooo0?l0027o00L0oooo0?l000;o
00<0o`00:Ol004co00<0o`000_l00`3o000To`800_l00`3o000So`030?oo00;o00<0o`008ol00`3o
0002o`030?l0027o00L0oooo0?l000;o00<0o`00:Ol004go00<0ool00_l00`3oo`0To`050?ooo`00
9Ol200?o00<0ool08ol00`3oo`02o`030?oo01oo0P04o`030?oo00;o00<0ool0:?l00?oo;?l00?oo
;?l00?oo;?l00?oo;?l00?oo;?l002Go00<0ool0ool4o`009Ol00`3oo`3Oo`<000Co0?oo0P03o`03
0?oo01Go000Uo`030?oo0>3o00H0o`00o`02o`030?oo01So000Pon801_l01P3o003o00;o00<0ool0
6?l002Go00<0ool01@000ol0o`06o`030?oo00Ko00<0ool01Ol00`3oo`06o`030?oo00Ko00<0ool0
1Ol00`3oo`06o`030?oo00Go00<0ool01_l00`3oo`06o`030?oo00Go00<0ool01_l00`3oo`05o`03
0?oo00Ko00<0ool01Ol00`3oo`06o`030?oo00Ko00<0ool01Ol00`3oo`06o`030?oo00Go00<0ool0
1_l00`3oo`06o`030?oo00Go00<0ool01_l00`3oo`09o`8000Co0?oo0P0Ko`009Ol00`3oo`05o`03
0?oo023o00<0ool0:?l00`3oo`0Xo`030?oo02So00<0ool0:?l00`3oo`09o`8000?o0?l07_l002Go
00<0ool01_l00`3oo`3Fo`8000?o00007ol002Go00<0ool01ol00`3oo`3io`009Ol200So00<0ool0
nOl002Go00<0ool02?l00`3oo`3ho`009Ol00`3oo`09o`80n?l002Go00<0ool02ol00`3oo`3eo`00
9Ol200co00<0ool0mOl002Go00<0ool03?l00`3oo`3do`009Ol00`3oo`0<o`030?oo06Ko00<0ool0
Rol002Go00<0ool03Ol206;o10000ol0002;o`009Ol2013o00<0ool0Gol00`3oo`04o`030?oo08So
000Uo`030?oo00oo00<0ool0G_l00`3oo`05o`030?oo08So000Uo`030?oo013o00<0ool0GOl00`3o
o`06o`030?oo08Oo000Uo`030?oo013o00<0ool0GOl00`3oo`06o`030?oo08Oo000Uo`804_l205co
00<0ool02?l00`3oo`26o`009Ol00`3oo`0Co`030?oo05Wo00<0ool02?l00`3oo`26o`005Ol00`3o
o`02o`040?ooo`<01?l00`3oo`0Co`030?oo05Oo0P0<o`80Q_l001Co00<0o`001ol00`3oo`04o`03
0?oo01Co00<0ool0E_l00`3oo`0<o`030?oo08Co000Do`030?l000So00<0ool00ol201Go00<0ool0
EOl00`3oo`0>o`030?oo08?o000Do`030?l000So00<0ool00ol00`3oo`0Eo`030?oo05Co00<0ool0
3_l00`3oo`23o`005?l00`3o0007o`030?l000Co00<0ool05Ol00`3oo`1Do`030?oo00oo00<0ool0
P_l001Go00<0ool01ol00`3oo`03o`030?oo01Ko00<0ool0Dol00`3oo`0?o`030?oo08;o000Uo`80
6?l00`3oo`1Ao`030?oo017o00<0ool0POl002Go00<0ool05ol00`3oo`1@o`805?l00`3oo`20o`00
9Ol00`3oo`0Ho`030?oo04go0P0Go`030?oo07oo000Uo`030?oo01So00<0ool0COl00`3oo`0Fo`03
0?oo07oo000Uo`806Ol00`3oo`1<o`030?oo01So00<0ool0O_l002Go00<0ool06Ol00`3oo`1;o`03
0?oo01Wo00<0ool0OOl002Go00<0ool06Ol00`3oo`1;o`030?oo01[o00<0ool0O?l002Go00<0ool0
6_l00`3oo`1:o`030?oo01_o00<0ool0Nol002Go0P0Lo`030?oo04So00<0ool07Ol00`3oo`1jo`00
9Ol00`3oo`0Ko`030?oo04So00<0ool07_l00`3oo`1io`009Ol00`3oo`0Lo`030?oo04Go0P0Ro`03
0?oo07So000Uo`030?oo01co00<0ool0AOl00`3oo`0Ro`030?oo07Oo000Uo`807Ol00`3oo`14o`03
0?oo02Co00<0ool0M_l002Go00<0ool07?l00`3oo`14o`030?oo02Go00<0ool0MOl001Go00<0ool0
0_l00`3oo`02o`<00ol00`3oo`0Mo`030?oo04?o00<0ool09_l00`3oo`1do`005?l00`3o0009o`03
0?oo00;o00<0ool07Ol00`3oo`12o`030?oo02Oo00<0ool0M?l001Co00<0o`001ol400?o0P0Oo`03
0?oo047o00<0ool0:?l00`3oo`1co`005?l00`3o0007o`030?l000Co00<0ool07ol00`3oo`0no`80
;?l00`3oo`1bo`005?l00`3o0008o`801?l00`3oo`0Oo`030?oo03ko00<0ool0;?l00`3oo`1ao`00
5Ol00`3oo`08o`030?oo00;o00<0ool08?l00`3oo`0lo`030?oo02ko00<0ool0L?l002Go0P0Qo`03
0?oo03co00<0ool0;_l00`3oo`1`o`009Ol00`3oo`0Po`030?oo03co00<0ool0;ol00`3oo`1_o`00
9Ol00`3oo`0Qo`030?oo03[o00<0ool0<Ol00`3oo`1^o`009Ol00`3oo`0Qo`030?oo03[o00<0ool0
<_l00`3oo`1]o`009Ol202;o00<0ool0>?l203Go00<0ool0KOl002Go00<0ool08_l00`3oo`0fo`03
0?oo03Ko00<0ool0K?l002Go00<0ool08_l00`3oo`0fo`030?oo03Ko00<0ool0K?l002Go00<0ool0
8ol203Go00<0ool0>?l00`3oo`1[o`009Ol202Go00<0ool0<ol00`3oo`0ho`030?oo06_o000Uo`03
0?oo02Co00<0ool0<_l00`3oo`0jo`80Jol002Go00<0ool09Ol00`3oo`0`o`030?oo03go00<0ool0
J?l002Go00<0ool09Ol00`3oo`0_o`030?oo03ko00<0ool0J?l002Go0P0Vo`030?oo02ko00<0ool0
@?l00`3oo`1Wo`009Ol00`3oo`0Uo`030?oo02ko00<0ool0@?l00`3oo`1Wo`005Ol00`3oo`02o`04
0?ooo`801Ol00`3oo`0Uo`030?oo02go00<0ool0@Ol00`3oo`1Wo`005?l00`3o0007o`030?l000Co
00<0ool09_l00`3oo`0/o`030?oo04;o00<0ool0I_l001Co00<0o`001ol00`3o0004o`809ol00`3o
o`0[o`030?oo04?o00<0ool0I_l001Co00<0o`001ol200Go00<0ool09_l00`3oo`0Zo`030?oo04Go
00<0ool0IOl001Co00<0o`001ol00`3oo`04o`030?oo02Oo00<0ool0:Ol00`3oo`16o`030?oo06Co
000Eo`030?oo00Oo0P04o`030?oo02So00<0ool09ol00`3oo`17o`030?oo06Co000Uo`80:Ol00`3o
o`0Wo`030?oo04So00<0ool0Hol002Go00<0ool0:?l00`3oo`0Vo`030?oo04Wo00<0ool0Hol002Go
00<0ool0:Ol00`3oo`0Uo`030?oo04Wo00<0ool0Hol002Go00<0ool0:Ol00`3oo`0To`030?oo04[o
00<0ool0Hol002Go0P0Zo`030?oo02?o00<0ool0C?l00`3oo`1Ro`009Ol00`3oo`0Yo`030?oo02;o
00<0ool0COl00`3oo`1Ro`009Ol00`3oo`0Yo`030?oo02;o00<0ool0COl00`3oo`1Ro`009Ol00`3o
o`0Yo`030?oo027o00<0ool0Col00`3oo`1Qo`009Ol202_o00<0ool08?l00`3oo`1@o`030?oo063o
000Uo`030?oo02[o00<0ool07_l205?o00<0ool0H?l002Go00<0ool0:_l00`3oo`0Mo`030?oo05?o
00<0ool0H?l002Go00<0ool0:ol201co00<0ool0EOl00`3oo`1Oo`009Ol00`3oo`0/o`030?oo01[o
00<0ool0EOl00`3oo`1Oo`009Ol202go00<0ool06Ol00`3oo`1Fo`030?oo05oo000Uo`030?oo02go
00<0ool06?l00`3oo`1Fo`030?oo05oo000Eo`030?oo00;o00<0ool00_l00`3oo`03o`030?oo02go
00<0ool05ol00`3oo`1Ho`030?oo02oo00<0ool0;?l001Co00<0o`001ol00`3o0004o`030?oo02go
00<0ool05_l00`3oo`1Io`030?oo02ko00<0ool0;Ol001Co00<0o`001ol00`3o0004o`80;_l00`3o
o`0Eo`030?oo05[o00<0ool0;Ol00`3oo`0^o`005?l00`3o0008o`030?oo00?o00<0ool0;Ol00`3o
o`0Eo`030?oo05_o0P0/o`030?oo02oo000Do`030?l000Oo00<0o`001?l00`3oo`0]o`030?oo01Co
00<0ool0G_l00`3oo`0Xo`030?oo033o000Eo`030?oo00Oo00<0ool00ol00`3oo`0^o`030?oo01?o
00<0ool0G_l00`3oo`0Xo`030?oo033o000Uo`80;ol00`3oo`0Bo`030?oo05oo00<0ool09ol00`3o
o`0ao`009Ol00`3oo`0^o`030?oo017o00<0ool0HOl00`3oo`0Uo`030?oo03;o000Uo`030?oo02ko
0P0Ao`030?oo06;o00<0ool09?l00`3oo`0co`009Ol00`3oo`0`o`803ol00`3oo`1Ro`030?oo02Co
00<0ool0<ol002Go0P0bo`030?oo00co00<0ool0Hol00`3oo`0So`030?oo03Co000Uo`030?oo037o
00<0ool03?l00`3oo`1So`030?oo02?o00<0ool0=?l002Go00<0ool0<Ol00`3oo`0:o`80I_l00`3o
o`0Ro`030?oo03Go000Uo`030?oo03;o00<0ool02?l00`3oo`1Wo`030?oo027o00<0ool0=Ol002Go
0P0co`030?oo00Oo00<0ool0J?l00`3oo`0Po`030?oo03Ko000Uo`030?oo03;o00<0ool01ol00`3o
o`1Xo`030?oo01oo00<0ool0=ol002Go00<0ool0<_l00`3oo`06o`030?oo06[o0P0Oo`030?oo03Oo
000Uo`030?oo03;o00<0ool01_l00`3oo`1[o`030?oo01co00<0ool0>?l002Go0P0co`030?oo00Go
00<0ool0K?l00`3oo`0Lo`030?oo03So000Uo`030?oo03;o00<0ool01?l00`3oo`1^o`030?oo01_o
00<0ool0>?l001go1@03o`030?oo03?o00<0ool00ol00`3oo`1^o`030?oo01[o00<0ool0>Ol001oo
00<0ool00ol00`3oo`0co`030?oo00;o00<0ool0Kol00`3oo`0Jo`030?oo03Wo000Oo`030?oo00?o
0P0do`030?oo00;o00<0ool0Kol00`3oo`0Io`030?oo03[o000Oo`030?oo00?o00<0ool0<ol30003
o`3o077o00<0ool06?l00`3oo`0ko`007ol00`3oo`03o`030?oo03Ko0P1bo`030?oo01So00<0ool0
>ol001ko0P05o`030?oo0:_o00<0ool05_l00`3oo`0lo`009Ol20:co00<0ool05_l00`3oo`0lo`00
9Ol00`3oo`2[o`030?oo01Ko00<0ool0??l002Go00<0ool0Zol00`3oo`0Fo`030?oo03co000Uo`03
0?oo0:co0P0Eo`030?oo03go000Uo`80[_l00`3oo`0Co`030?oo03go000Uo`030?oo0:go00<0ool0
4Ol2043o000Uo`030?oo0:go00<0ool04?l00`3oo`10o`009Ol00`3oo`2^o`030?oo00oo00<0ool0
@?l002Go0P2_o`030?oo00ko00<0ool0@Ol002Go00<0ool0[_l00`3oo`0>o`030?oo047o000Uo`03
0?oo0:ko00<0ool03_l00`3oo`11o`009Ol00`3oo`2^o`030?oo00ko00<0ool0@Ol002Go0P2_o`03
0?oo00go00<0ool0@_l002Go00<0ool0[ol00`3oo`0<o`030?oo04;o000Co`D00_l0103oool300Co
00<0ool0[ol00`3oo`0<o`030?oo04;o000Eo`030?oo00Ko00<0ool01?l00`3oo`2_o`030?oo00_o
00<0ool0@ol001Go00<0ool01ol00`3oo`03o`80/?l00`3oo`0:o`030?oo04Co000Eo`030?oo00Oo
00<0ool00ol00`3oo`2`o`802_l00`3oo`14o`005Ol00`3oo`06o`030?l000Co00<0ool0/Ol00`3o
o`07o`030?oo04Go000Do`802Ol00`3oo`03o`030?oo0;;o00<0ool01_l00`3oo`15o`009Ol20;?o
00<0ool01Ol00`3oo`16o`009Ol00`3oo`2bo`030?oo00Go00<0ool0A_l002Go00<0ool0/ol00`3o
o`03o`030?oo04Oo000Uo`030?oo0;?o00<0ool00_l00`3oo`18o`009Ol20;Co00D0oooo001;o`00
9Ol00`3oo`2co`050?ooo`00Bol002Go00<0ool0]?l00`3o001<o`009Ol00`3oo`2do`80COl002Go
0P3oo`Go000Uo`030?oo0?oo1?l002Go00<0ool0ool4o`00ool/o`00ool/o`00ool/o`00ool/o`00
ool/o`00ool/o`00ool/o`00POl20:So0023o`030?oo013o0P07o`801ol2087o001eo`8000?o0000
0P02o`030?oo00<000Co00000ol200So0P02o`<00ol0103oool200Co00<0ool0Ool007Go00L0oooo
0?l000;o00<0o`000_l0103oo`03o`030?oo00Oo00@0ool00_l00`3oo`02o`030?oo00?o00D0oooo
0021o`00M_l300;o00H0ool0o`02o`040?oo00?o0`07o`040?oo00;o00<0ool00_l00`3oo`02o`03
0?oo00;o00<0ool0Ool007Ko00@0o`3o1003o`<00_l0103oool300Oo00@0ool00_l00`3oo`02o`03
0?oo00?o00D0oooo0021o`00Mol00`3oo`0<o`030?oo00_o00@0ool00_l00`3oo`02o`070?ooo`3o
0003o`030?oo07oo001fo`803Ol200ko0P02o`801?l200?o00@0oooo0P21o`00ool/o`00ool/o`00
ool/o`00ool/o`00ool/o`00ool/o`007_l30003o`3o00@00_l30?ko000Oo`050?oo0?l00`02o`04
0?oo0?ko000Oo`<01?l0103oo`02o`030?oo0?co000Oo`040?oo00;o0P03o`<0o_l001oo00@0ool0
2Ol00`3oo`3lo`007_l400Wo0P3no`00ool/o`00ool/o`00ool/o`00\
\>"],
  ImageRangeCache->{{{0, 298}, {184, 0}} -> {-17.4972, -0.177614, 0.465795, 
  0.00986769}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00952381 -0.753148 2.46683 [
[(20)] .21429 .23358 0 2 Msboxa
[(40)] .40476 .23358 0 2 Msboxa
[(60)] .59524 .23358 0 2 Msboxa
[(80)] .78571 .23358 0 2 Msboxa
[(100)] .97619 .23358 0 2 Msboxa
[(No.)] 1.025 .23358 -1 0 Msboxa
[(Error n)] .5 .61803 0 -2 0 0 1 Mouter Mrotsboxa
[(0.35)] .01131 .11024 1 0 Msboxa
[(0.45)] .01131 .35692 1 0 Msboxa
[(0.5)] .01131 .48027 1 0 Msboxa
[(0.55)] .01131 .60361 1 0 Msboxa
[(n)] .02381 .61803 0 -4 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 .61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.21429 .23358 m
.21429 .23983 L
s
P
[(20)] .21429 .23358 0 2 Mshowa
p
.002 w
.40476 .23358 m
.40476 .23983 L
s
P
[(40)] .40476 .23358 0 2 Mshowa
p
.002 w
.59524 .23358 m
.59524 .23983 L
s
P
[(60)] .59524 .23358 0 2 Mshowa
p
.002 w
.78571 .23358 m
.78571 .23983 L
s
P
[(80)] .78571 .23358 0 2 Mshowa
p
.002 w
.97619 .23358 m
.97619 .23983 L
s
P
[(100)] .97619 .23358 0 2 Mshowa
p
.001 w
.0619 .23358 m
.0619 .23733 L
s
P
p
.001 w
.1 .23358 m
.1 .23733 L
s
P
p
.001 w
.1381 .23358 m
.1381 .23733 L
s
P
p
.001 w
.17619 .23358 m
.17619 .23733 L
s
P
p
.001 w
.25238 .23358 m
.25238 .23733 L
s
P
p
.001 w
.29048 .23358 m
.29048 .23733 L
s
P
p
.001 w
.32857 .23358 m
.32857 .23733 L
s
P
p
.001 w
.36667 .23358 m
.36667 .23733 L
s
P
p
.001 w
.44286 .23358 m
.44286 .23733 L
s
P
p
.001 w
.48095 .23358 m
.48095 .23733 L
s
P
p
.001 w
.51905 .23358 m
.51905 .23733 L
s
P
p
.001 w
.55714 .23358 m
.55714 .23733 L
s
P
p
.001 w
.63333 .23358 m
.63333 .23733 L
s
P
p
.001 w
.67143 .23358 m
.67143 .23733 L
s
P
p
.001 w
.70952 .23358 m
.70952 .23733 L
s
P
p
.001 w
.74762 .23358 m
.74762 .23733 L
s
P
p
.001 w
.82381 .23358 m
.82381 .23733 L
s
P
p
.001 w
.8619 .23358 m
.8619 .23733 L
s
P
p
.001 w
.9 .23358 m
.9 .23733 L
s
P
p
.001 w
.9381 .23358 m
.9381 .23733 L
s
P
[(No.)] 1.025 .23358 -1 0 Mshowa
p
.002 w
0 .23358 m
1 .23358 L
s
P
[(Error n)] .5 .61803 0 -2 0 0 1 Mouter Mrotshowa
p
.002 w
.02381 .11024 m
.03006 .11024 L
s
P
[(0.35)] .01131 .11024 1 0 Mshowa
p
.002 w
.02381 .35692 m
.03006 .35692 L
s
P
[(0.45)] .01131 .35692 1 0 Mshowa
p
.002 w
.02381 .48027 m
.03006 .48027 L
s
P
[(0.5)] .01131 .48027 1 0 Mshowa
p
.002 w
.02381 .60361 m
.03006 .60361 L
s
P
[(0.55)] .01131 .60361 1 0 Mshowa
p
.001 w
.02381 .13491 m
.02756 .13491 L
s
P
p
.001 w
.02381 .15958 m
.02756 .15958 L
s
P
p
.001 w
.02381 .18425 m
.02756 .18425 L
s
P
p
.001 w
.02381 .20891 m
.02756 .20891 L
s
P
p
.001 w
.02381 .25825 m
.02756 .25825 L
s
P
p
.001 w
.02381 .28292 m
.02756 .28292 L
s
P
p
.001 w
.02381 .30759 m
.02756 .30759 L
s
P
p
.001 w
.02381 .33226 m
.02756 .33226 L
s
P
p
.001 w
.02381 .38159 m
.02756 .38159 L
s
P
p
.001 w
.02381 .40626 m
.02756 .40626 L
s
P
p
.001 w
.02381 .43093 m
.02756 .43093 L
s
P
p
.001 w
.02381 .4556 m
.02756 .4556 L
s
P
p
.001 w
.02381 .50493 m
.02756 .50493 L
s
P
p
.001 w
.02381 .5296 m
.02756 .5296 L
s
P
p
.001 w
.02381 .55427 m
.02756 .55427 L
s
P
p
.001 w
.02381 .57894 m
.02756 .57894 L
s
P
p
.001 w
.02381 .08557 m
.02756 .08557 L
s
P
p
.001 w
.02381 .06091 m
.02756 .06091 L
s
P
p
.001 w
.02381 .03624 m
.02756 .03624 L
s
P
p
.001 w
.02381 .01157 m
.02756 .01157 L
s
P
[(n)] .02381 .61803 0 -4 Mshowa
p
.002 w
.02381 0 m
.02381 .61803 L
s
P
P
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.004 w
s
s
.04984 .61803 m
.05238 .09406 L
s
.05238 .09406 m
.0619 .08907 L
.07143 .15211 L
.08095 .1461 L
.09048 .20445 L
.1 .19792 L
.10952 .24999 L
.11905 .24375 L
.12857 .28635 L
.1381 .28144 L
.14762 .30901 L
.15714 .30668 L
.16667 .31094 L
.17619 .31225 L
.18571 .28307 L
.19524 .28846 L
.20476 .21474 L
.21429 .22407 L
.22381 .088 L
.23333 .10123 L
.24286 .12139 L
.25238 .10942 L
.2619 .30701 L
.27143 .30477 L
.28095 .18159 L
.29048 .2079 L
.3 .24134 L
.30952 .25572 L
.31905 .28028 L
.32857 .28805 L
.3381 .30342 L
.34762 .30698 L
.35714 .31286 L
.36667 .31321 L
.37619 .30952 L
.38571 .3067 L
.39524 .29358 L
.40476 .28683 L
.41429 .26451 L
.42381 .25211 L
.43333 .2207 L
.44286 .19962 L
.45238 .15893 L
.4619 .12416 L
.47143 .07355 L
.48095 .01694 L
.49048 .04388 L
.5 .11684 L
.50952 .16501 L
.51905 .23823 L
Mistroke
.52857 .269 L
.5381 .31145 L
.54762 .31235 L
.55714 .24856 L
.56667 .20454 L
.57619 .07986 L
.58571 .01693 L
.59524 .04696 L
.60476 .10071 L
.61429 .12127 L
.62381 .16713 L
.63333 .17367 L
.64286 .21516 L
.65238 .21554 L
.6619 .25354 L
.67143 .25105 L
.68095 .28447 L
.69048 .28113 L
.7 .30621 L
.70952 .30381 L
.71905 .31288 L
.72857 .3132 L
.7381 .29423 L
.74762 .29851 L
.75714 .23818 L
.76667 .24644 L
.77619 .1302 L
.78571 .14239 L
.79524 .061 L
.80476 .04731 L
.81429 .27055 L
.82381 .26478 L
.83333 .07223 L
.84286 .06693 L
.85238 .01727 L
.8619 .01472 L
.87143 .12624 L
.88095 .11905 L
.89048 .23316 L
.9 .22932 L
.90952 .28544 L
.91905 .28342 L
.92857 .30904 L
.9381 .30841 L
.94762 .31253 L
.95714 .31268 L
.96667 .3015 L
.97619 .30173 L
Mfstroke
% End of Graphics
MathPictureEnd\
\>"], "Graphics",
  PageWidth->Infinity,
  Evaluatable->False,
  ImageSize->{299, 185},
  ImageMargins->{{100, Inherited}, {Inherited, 0}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004[0000^@P10`40000100000800002008200000
P800P020P<30`<3L`:K:l:C8l3<006H009T00<`0000c03<c06Hc09Tc0<`c0?lc001V03=V06IV09UV
0<aV0?mV002I03>I06JI09VI0<bI0?nI003<03?<06K<09W<0<c<0?o<03?o06Ko09Wo0<co0000<c<0
<fH0<iT0<l`0<ol0<`0c<c<c<fHc<iTc<l`c<olc<`1V<c=V<fIV<iUV<laV<omV<`2I<c>I<fJI<iVI
<lbI<onI<`3<<c?<<fK<<iW<<lc<<oo<<`3o<c?o<fKo<iWo<lco<ooo<`00IS<0IVH0IYT0I/`0I_l0
IP0cIS<cIVHcIYTcI/`cI_lcIP1VIS=VIVIVIYUVI/aVI_mVIP2IIS>IIVJIIYVII/bII_nIIP3<IS?<
IVK<IYW<I/c<I_o<IP3oIS?oIVKoIYWoI/coI_ooIP00VC<0VFH0VIT0VL`0VOl0V@0cVC<cVFHcVITc
VL`cVOlcV@1VVC=VVFIVVIUVVLaVVOmVV@2IVC>IVFJIVIVIVLbIVOnIV@3<VC?<VFK<VIW<VLc<VOo<
V@3oVC?oVFKoVIWoVLcoVOooV@00c3<0c6H0c9T0c<`0c?l0c00cc3<cc6Hcc9Tcc<`cc?lcc01Vc3=V
c6IVc9UVc<aVc?mVc02Ic3>Ic6JIc9VIc<bIc?nIc03<c3?<c6K<c9W<c<c<c?o<c03oc3?oc6Koc9Wo
c<coc?ooc3<0ofH0oiT0ol`0o`0coc<cofHcoiTcol`coolco`1Voc=VofIVoiUVolaVoomVo`2Ioc>I
ofJIoiVIolbIoonIo`3<oc?<ofK<oiW<olc<ooo<oc?oofKooiWoolcoo`410@820P<30`@410D51@H6
1PL71`P820T92@X:2P/;2``<30h>3Pl?3a0@414A4A8B4Q<C4a@D5000000000000000000000000000
00000?okl:2PY820P?l0003o0?oo0000ool0o`3ooooooooo;?l001co00<0ool0ool=o`007?l00`3o
o`3oo`go000Lo`030?oo0?oo3Ol001co0P3>o`80?Ol001co00<0ool0Kol00`3oo`0Go`030?oo03oo
0P000ol0o`0lo`007?l00`3oo`1_o`030?oo01Oo00<0ool0?ol0103oo`0mo`007?l00`3oo`1_o`80
6?l2043o00@0ool0?Ol001co00<0ool0K_l00`3o000Go`030?l003oo00D0oooo000mo`007?l00`3o
o`1^o`030?l001Oo00<0o`00?ol01@3oool003go000Lo`80Kol00`3o000Go`030?l003oo00D0oooo
000mo`007?l00`3oo`1^o`040?oo01Ko00@0ool0?_l00`3oo`02o`030?oo03[o000Lo`030?oo06go
00D0oooo000Fo`040?oo03ko00<0ool00_l00`3oo`0jo`007?l00`3oo`1]o`050?ooo`005Ol01@3o
ool003?o00<0ool02?l00`3oo`02o`030?oo03[o000Lo`030?oo06go00D0oooo000Eo`050?ooo`00
<_l200Wo00<0ool00ol00`3oo`0jo`007?l00`3oo`1]o`050?ooo`005Ol00`3oo`02o`030?oo02oo
0P09o`030?oo00?o00<0ool0>_l001co0P1^o`050?ooo`005Ol00`3oo`02o`030?oo02ko00<0o`00
2Ol00`3oo`03o`030?oo03[o000Lo`030?oo06co00<0ool00ol00`3oo`0Bo`030?oo00;o00<0ool0
;_l00`3o0009o`030?oo00?o00<0ool0>_l001co00<0ool0K?l00`3oo`03o`030?oo01;o00<0ool0
0_l00`3oo`0^o`030?l000Oo0P06o`030?oo03[o000Lo`030?oo06co00<0ool00ol00`3oo`0Ao`03
0?oo00Co00<0ool0;Ol00`3o0006o`030?oo00Ko00<0ool0>_l001co00<0ool0K?l00`3oo`03o`03
0?oo017o00<0ool01?l00`3oo`0]o`030?l000Ko00<0ool01_l00`3oo`0jo`007?l00`3oo`1/o`03
0?oo00?o00<0ool04Ol00`3oo`04o`030?oo02co00@0ool01_l00`3oo`06o`030?oo03[o000Lo`80
KOl00`3oo`03o`030?oo017o00<0ool01?l00`3oo`0/o`040?oo00Ko00<0ool01_l00`3oo`0jo`00
7?l00`3oo`06o`030?oo02Ko00<0ool0>Ol00`3oo`04o`030?oo017o00<0ool01?l00`3oo`0/o`05
0?ooo`001Ol00`3oo`06o`030?oo03[o000Lo`030?oo00Co0`0Xo`80>_l00`3oo`04o`030?oo017o
00<0ool01Ol00`3oo`0[o`050?ooo`001Ol00`3oo`06o`030?oo03[o000Lo`030?oo00Co00<0o`00
:?l203[o00<0ool01?l00`3oo`0Ao`030?oo00Go00<0ool0:ol01@3oool000Go00<0ool01ol00`3o
o`0io`001ol00`3oo`02o`040?ooo`801?l00`3oo`03o`030?oo00Co00@0ool09ol00`3o000io`03
0?oo00Go00<0ool04?l00`3oo`05o`030?oo02_o00D0oooo0005o`030?oo00Oo00<0ool0>Ol000Ko
00<0o`002Ol01P3oo`3o00Co00<0ool01?l0103oo`0Wo`040?oo03So00<0ool01Ol00`3oo`0@o`03
0?oo00Go00<0ool0:ol01@3oool000Go00<0ool01ol00`3oo`0io`001_l00`3o0008o`030?oo00?o
00<0ool00_l300Co00@0ool09ol0103oo`03o`030?oo03;o00<0ool01Ol00`3oo`0@o`030?oo00Ko
00<0ool0:_l01@3oool000Go00<0ool01ol00`3oo`0io`001_l00`3o0009o`030?oo00801Ol00`3o
o`04o`040?oo02Ko00<0ool00_l0103o000co`030?oo00Ko00<0ool03ol00`3oo`07o`030?oo02[o
00D0oooo0005o`030?oo00Oo00<0ool0>Ol000Ko00<0o`001ol00`3o0002o`030?oo00Co00<0ool0
1?l0103oo`0Vo`030?oo00;o00@0o`00<ol00`3oo`06o`030?oo00oo00<0ool02?l00`3oo`0Yo`05
0?ooo`001Ol00`3oo`07o`030?l003Wo0007o`030?oo00Oo00@0oooo0`04o`030?oo00Co00D0oooo
000Uo`030?oo00?o00<0o`00<ol00`3oo`06o`030?oo00oo00<0ool02?l00`3oo`0Xo`030?oo00;o
00<0ool00_l00`3oo`08o`<0>Ol001co00<0ool01?l01@3oool002Go00<0ool01Ol00`3oo`0ao`03
0?oo00Oo00<0ool03_l00`3oo`08o`030?oo02So00<0ool00_l00`3oo`02o`030?oo00So00<0o`00
>Ol001co00<0ool01?l01@3oool002Go00<0ool01Ol00`3oo`0ao`030?oo00Oo00<0ool03_l00`3o
o`08o`030?oo02Go00@0ool01?l00`3oo`02o`030?oo00[o00<0ool0=ol001co0P05o`050?ooo`00
9Ol00`3oo`05o`030?oo033o00<0ool02?l00`3oo`0>o`030?oo00Wo00<0ool09?l20003o`3o00?o
00<0ool00_l00`3oo`0:o`030?oo03Oo000Lo`030?oo00Co00D0oooo000Uo`030?oo00Go00<0ool0
<?l00`3oo`08o`030?oo00ko00<0ool02Ol00`3oo`0To`040?l000Co00<0ool00_l00`3oo`0;o`03
0?oo03Ko000Lo`030?oo00Co00D0oooo000Uo`030?oo00Go00<0ool0<?l00`3oo`09o`030?oo00go
00<0ool02Ol00`3oo`0To`040?oo00Co00<0ool00_l00`3oo`0;o`030?oo03Ko000Lo`030?oo00Co
00<0ool00_l00`3o000Ro`030?oo00Go00<0ool0<?l00`3oo`09o`030?oo00go00<0ool02Ol00`3o
o`0To`030?oo00Go00<0ool00_l00`3oo`0;o`030?oo03Ko000Lo`030?oo00Co00<0ool00_l302;o
00<0ool01Ol00`3oo`0_o`030?oo00[o00<0ool03Ol00`3oo`09o`030?oo02Co00<0ool01Ol00`3o
o`02o`030?oo00_o00<0ool0=_l001co00<0ool01?l00`3oo`02o`030?l002;o00<0ool01Ol00`3o
o`0_o`030?oo00[o00<0ool03Ol00`3oo`09o`030?oo02Co00<0ool01Ol00`3oo`02o`030?oo00_o
00<0ool0=_l001co0P05o`030?oo00Go00<0ool07_l00`3oo`06o`030?oo02oo00<0ool02ol00`3o
o`0<o`030?oo00[o00<0ool08ol00`3oo`05o`030?oo00;o00<0ool02ol00`3oo`0fo`007?l00`3o
o`04o`030?oo00Go00<0ool07_l00`3oo`07o`030?oo02ko00<0ool02ol00`3oo`0<o`030?oo00[o
00<0ool08_l00`3oo`07o`050?ooo`003Ol00`3oo`0fo`007?l00`3oo`04o`030?oo00Go00<0ool0
7_l00`3oo`07o`030?oo02go00<0ool03?l00`3oo`0<o`030?oo00[o00<0ool08_l00`3oo`07o`05
0?ooo`003Ol00`3oo`0fo`007?l00`3oo`04o`030?oo00Go00<0ool07_l00`3oo`07o`030?oo02go
00<0ool03?l00`3oo`0<o`030?oo00_o0P0Ro`030?oo00Oo00D0oooo000=o`030?oo03Ko000Lo`03
0?oo00Co00<0ool01Ol00`3oo`0No`030?oo00Oo00<0ool0;Ol00`3oo`0<o`030?oo00co00<0ool0
3Ol00`3oo`0Oo`030?oo00Oo00D0oooo000=o`030?oo03Ko000Lo`030?oo00Co00<0ool01_l00`3o
o`0Ho`<00_l200So00<0ool07ol300;o00<0ool01Ol00`3oo`0=o`030?oo00_o00<0ool00P04o`03
0?oo00Go00<0ool07ol200Co00D0oooo0003o`030?oo00co00<0ool02ol500;o00<0ool00_l00`3o
o`0Ko`007?l00`3oo`04o`030?oo00Ko00<0ool06?l00`3oo`02o`030?l000Oo00<0ool00ol00`3o
o`0Jo`060?oo0?l01_l00`3oo`0=o`030?oo00_o00H0ool0o`02o`030?l000Ko00<0ool07ol00`3o
0002o`030?l000;o00D0oooo000>o`030?oo00go00L0oooo0?l000;o00<0o`007?l001co0P05o`03
0?oo00Ko00<0ool06Ol01`3oool0o`001ol00`3oo`03o`030?oo01So10001?l0o`06o`030?oo00ko
00<0ool02_l01P3oo`3o00;o00<0o`001ol00`3oo`0No`030?l000;o00<0o`000_l01@3oool000ko
00<0ool03Ol01`3oool0o`000_l00`3o000Lo`007?l00`3oo`04o`030?oo00Ko00<0ool06Ol01`3o
ool0o`001ol00`3oo`03o`806Ol00`3o0002o`030?l000Ko00<0ool03_l00`3oo`0:o`030?oo0080
0ol00`3o0007o`030?oo01ko0P03o`030?l000;o00D0oooo000>o`030?oo00go00L0oooo0?l000;o
00<0o`007?l001co00<0ool01?l00`3oo`06o`030?oo01So00<0o`000_l00`3o0007o`030?oo00?o
0P0Jo`800_l00`3o0005o`030?oo00oo00<0ool02_l0103oo`04o`030?l000Oo00<0ool07_l00`3o
0002o`030?l000;o00D0oooo000>o`030?oo00go00L0oooo0?l000;o00<0o`007?l001co00<0ool0
1?l00`3oo`07o`030?l001So00@0oooo0P08o`030?oo00?o0P0Ko`050?ooo`001_l00`3oo`0?o`03
0?oo00[o00@0oooo0P03o`030?oo00Ko00<0ool07_l200Co00D0oooo0003o`030?oo00co00<0ool0
3?l200Co00<0ool00_l00`3oo`0Ko`007?l00`3oo`04o`030?oo00Oo0`0Ko`030?oo00So00<0ool0
0ol00`3o000Uo`030?oo00oo00<0ool02_l00`3oo`0?o`030?oo01ko00<0ool01ol01@3oool000ko
00<0ool0=Ol001co00<0ool01?l00`3oo`07o`030?l001_o00<0ool02?l00`3oo`03o`030?l002Co
00<0ool04?l00`3oo`0:o`030?oo013o00<0ool07Ol00`3oo`07o`050?ooo`003_l00`3oo`0eo`00
7?l200Go00<0ool02Ol00`3oo`0Io`030?oo00So00<0ool00ol00`3o000To`030?oo013o00<0ool0
2_l00`3oo`0@o`030?oo01go00<0ool01ol01@3oool000ko00<0ool0=Ol001co00<0ool01?l00`3o
o`0:o`030?oo01Ko00<0o`002_l00`3oo`02o`050?ooo`008ol00`3oo`0@o`030?oo00[o00<0ool0
4?l301go00<0ool01ol01@3oool000ko00<0ool0=Ol001co00<0ool01?l00`3oo`0:o`030?oo01Ko
0`0:o`030?oo00;o00D0oooo000Ro`030?oo017o00<0ool02Ol00`3oo`0Co`030?oo01[o00<0ool0
2?l0103oo`0@o`030?oo03Co000Lo`030?oo00Co00<0ool02_l00`3oo`0Fo`030?l000[o00<0ool0
0_l01@3oool002;o00<0ool04_l00`3oo`08o`030?oo01Co00<0ool06Ol00`3oo`08o`040?oo013o
00<0ool0=?l001co00<0ool01?l00`3oo`0:o`030?oo01Ko00<0ool02_l00`3oo`02o`030?oo00;o
00<0ool07ol00`3oo`0Bo`030?oo00So00<0ool05?l00`3oo`0Io`030?oo00So00@0ool04?l00`3o
o`0No`<000Co0?oo0P03o`030?oo00Oo000Lo`030?oo00Co00<0ool02_l00`3oo`0Fo`030?oo00[o
00<0ool00_l00`3oo`02o`030?oo01ko00<0ool04ol00`3oo`08o`030?oo01Co00<0ool06Ol00`3o
o`08o`040?oo013o00<0o`007ol01P3o003o00;o00<0ool02_l001KonP06o`060?l00?l00_l00`3o
o`0:o`007?l00`3oo`04o`030?l000Wo00<0o`001_l00`3oo`07o`030?oo00?o00@0ool02Ol200Co
00@0ool00_l00`3oo`04o`030?oo00Ko00<0ool01ol00`3oo`03o`040?oo00Wo00<0ool01_l00`3o
o`07o`801ol00`3oo`07o`030?oo00?o00@0ool02Ol00`3oo`06o`030?l000;o00<0ool00_l00`3o
o`04o`030?l000Wo00<0ool01_l00`3oo`06o`030?oo00Oo00<0ool02_l20004o`3oo`803Ol001co
00<0ool01?l00`3oo`0;o`040?oo01?o00<0ool02ol00`3oo`02o`030?oo00?o00<0ool07Ol00`3o
o`0Co`030?oo00Oo00<0ool05_l00`3oo`0Eo`@02ol00`3o000Bo`030?oo01go0P000ol0o`0@o`00
7?l00`3oo`04o`030?oo00_o100Co`030?oo00_o00<0ool00_l00`3oo`04o`030?oo01_o00<0ool0
5Ol00`3oo`06o`030?oo01Ko00<0ool05Ol0103oo`0;o`030?l001?o00<0ool06ol20003o`00017o
000Lo`030?oo00Co00<0ool02ol0103oo`0Co`030?oo00_o00<0ool00_l00`3oo`04o`030?oo01_o
00<0ool05Ol00`3oo`06o`030?oo01Oo00<0o`005?l00`3oo`0<o`030?l001?o00<0ool0<Ol001co
00<0ool01?l00`3oo`0?o`030?oo013o00<0ool02ol00`3oo`02o`030?oo00Go00<0ool06Ol00`3o
o`0Go`030?oo00Go00<0ool05ol301?o00<0ool03Ol00`3o000Co`030?oo037o000Lo`801Ol00`3o
o`0?o`030?oo013o00<0ool03?l01@3oool000Oo00<0ool06?l00`3oo`0Ho`030?oo00Go00<0ool0
6_l00`3oo`0@o`030?oo00go00<0o`004ol00`3oo`0ao`007?l00`3oo`04o`030?oo00oo00<0ool0
4?l00`3oo`0<o`050?ooo`002?l00`3oo`0Go`030?oo01So00<0ool01?l00`3oo`0Ko`030?oo013o
00<0ool03Ol00`3o000Co`030?oo037o000Lo`030?oo00Co00<0ool03ol00`3oo`0@o`030?oo00co
00D0oooo0008o`030?oo01Ko00<0ool06_l00`3oo`03o`030?oo01_o00<0ool04?l00`3oo`0=o`03
0?l001?o00<0ool0<Ol001co00<0ool01?l00`3oo`0?o`030?oo013o00<0ool03?l01@3oool000So
00<0ool05_l00`3oo`0Jo`030?oo00?o00<0ool07?l00`3oo`0?o`030?oo00go0P0Do`030?oo037o
000Lo`030?oo00Co00<0ool03ol00`3oo`0?o`030?oo00go00D0oooo0009o`030?oo01Co00<0ool0
6ol00`3oo`03o`030?oo01co00<0ool03ol00`3oo`0To`030?oo033o000Lo`030?oo00Co00<0ool0
4?l00`3oo`0>o`030?oo00go00@0ool02_l00`3oo`0Do`030?oo01_o00<0ool00ol00`3oo`0Lo`03
0?oo00oo00<0ool09?l00`3oo`0`o`007?l200Go00<0ool04?l00`3o000;o`040?oo00oo00@0ool0
2ol201?o00<0ool07Ol01@3oool0023o00<0o`003_l00`3oo`0To`040?l002oo000Lo`030?oo00Co
00<0ool04?l300_o100?o`040?oo00go00<0ool04?l00`3oo`0Mo`050?ooo`008?l300go00<0ool0
9Ol20003o`3o02ko000Lo`030?oo00Co00<0ool04ol00`3oo`07o`050?ooo`003ol0103oo`0>o`03
0?oo00go0P0Po`050?ooo`008ol00`3oo`0:o`030?oo02Wo00<0ool0;?l001co00<0ool01?l00`3o
o`0Co`030?oo00Oo00<0ool04Ol0103oo`0>o`030?oo00co00<0ool08?l01@3oool002?o00<0ool0
2?l00`3o000[o`030?oo02co000Lo`030?oo00Co00<0ool05?l00`3oo`06o`030?oo017o00@0ool0
3ol00`3oo`0:o`030?oo027o00D0oooo000So`030?oo00Oo00@0o`00:ol00`3oo`0/o`007?l00`3o
o`04o`030?oo01Co00<0ool01_l00`3oo`0Ao`040?oo00oo0P0;o`030?oo02;o00<0o`009Ol0103o
0005o`030?oo02co00<0ool02?l3027o000Lo`801Ol00`3oo`0Eo`040?l000?o00<0ool04_l4017o
0P08o`030?oo02?o00<0o`009Ol200;o00D0oooo000`o`040?l000Go00<0ool08_l001co00<0ool0
1?l00`3oo`0Eo`800_l402_o00<0ool00_l302Ko0`0Yo`050?ooo`00<?l200;o0P02o`030?oo02?o
000Lo`030?oo00Co00<0ool0BOl405Ko0`0go`809_l001co00<0ool01?l00`3oo`3oo`Ko000Lo`03
0?oo00Co00<0ool0ool6o`007?l00`3oo`04o`030?oo0?oo1_l001co0P05o`030?oo0?oo1_l001co
00<0ool01?l00`3oo`3oo`Ko000Lo`030?oo00Co00<0ool0ool6o`007?l00`3oo`04o`030?oo0?oo
1_l001co00<0ool01?l00`3oo`3oo`Ko0007o`030?oo00;o00<0ool00_l300;o00<0ool00ol00`3o
o`04o`030?oo0?oo1_l000Ko00<0o`002Ol01P3oo`3o00Co00<0ool00ol00`3oo`3oo`Oo0006o`03
0?l000Oo1003o`030?oo00;o0`03o`030?oo0?oo1ol000Ko00<0o`001ol00`3o0002o`801Ol00`3o
o`03o`030?oo0?oo1ol000Ko00<0o`002?l200;o00<0ool01?l00`3oo`03o`030?oo0?oo1ol000Oo
00<0ool02?l00`3oo`0300Co00<0ool00ol00`3oo`3oo`Oo000Lo`030?oo00?o00<0ool0ool7o`00
7?l00`3oo`03o`030?oo0?oo1ol001co0P04o`030?oo0?oo1ol001co00<0ool00ol00`3oo`3oo`Oo
000Lo`030?oo00?o00<0ool0ool7o`007?l00`3oo`03o`030?oo0?oo1ol001co00<0ool00ol00`3o
o`3oo`Oo000Lo`030?oo00?o00<0ool0ool7o`007?l200Co00<0ool0ool7o`007?l00`3oo`03o`03
0?oo0?oo1ol001co00<0ool00ol00`3oo`3oo`Oo000Lo`030?oo00?o00<0ool0ool7o`007?l00`3o
o`03o`030?oo0?oo1ol001co00<0ool00ol00`3oo`3oo`Oo000Lo`801?l00`3oo`3oo`Oo000Lo`03
0?oo00?o00<0ool0ool7o`007?l00`3oo`03o`030?oo0?oo1ol001co00<0ool00ol00`3oo`3oo`Oo
000Lo`030?oo00?o00<0ool0ool7o`007?l00`3oo`03o`030?oo0?oo1ol001co0P04o`030?oo0?oo
1ol001co00<0ool00ol00`3oo`3oo`Oo000Lo`030?oo00?o00<0ool0ool7o`007?l00`3oo`03o`03
0?oo0?oo1ol000co00<0ool00_l00`3oo`02o`030?oo00?o00<0ool00ol00`3oo`3oo`Oo000;o`03
0?l000Oo00<0o`001?l00`3oo`03o`030?oo0?oo1ol000_o00<0o`002Ol00`3oo`02o`<00ol00`3o
o`3oo`Oo000;o`030?l000Oo0P05o`030?oo00?o00<0ool0ool7o`002ol00`3o0007o`030?oo00Co
00<0ool00ol00`3oo`3oo`Oo000<o`030?oo00Ko0`04o`030?oo00?o00<0ool0ool7o`007?l00`3o
o`03o`030?oo0?oo1ol001co00<0ool00ol00`3oo`3oo`Oo000Lo`801?l00`3oo`3oo`Oo000Lo`03
0?oo00?o00<0ool0ool7o`007?l00`3oo`03o`030?oo0?oo1ol001co00<0ool00ol00`3oo`3oo`Oo
000Lo`030?oo00?o00<0ool0ool7o`007?l00`3oo`03o`030?oo0?oo1ol001co0P04o`030?oo0?oo
1ol001co00<0ool00ol00`3oo`3oo`Oo000Lo`030?oo00?o00<0ool0ool7o`007?l00`3oo`03o`03
0?oo0?oo1ol001co00<0ool00ol00`3oo`3oo`Oo000Lo`030?oo00?o00<0ool0ool7o`007?l00`3o
o`03o`030?oo0?oo1ol001co0P04o`030?oo0?oo1ol001co00<0ool00ol00`3oo`3oo`Oo000Lo`03
0?oo00?o00<0ool0ool7o`007?l00`3oo`03o`030?oo0?oo1ol001co00<0ool00ol00`3oo`3oo`Oo
000Lo`030?oo00?o00<0ool0ool7o`007?l200Co00<0ool0ool7o`007?l00`3oo`03o`030?oo0?oo
1ol001co00<0ool00ol00`3oo`3oo`Oo000Lo`030?oo00?o00<0ool0ool7o`001ol00`3oo`02o`03
0?oo00;o00<0ool00_l00`3oo`03o`030?oo00?o00<0ool0ool7o`001_l00`3o0007o`030?l000;o
00<0o`001?l00`3oo`03o`030?oo0?oo1ol000Ko00<0o`002Ol00`3oo`02o`030?oo00;o0`03o`03
0?oo0?oo1ol000Ko00<0o`001ol200?o0P05o`030?oo00?o00<0ool0ool7o`001_l00`3o0007o`03
0?oo00;o00<0ool01?l00`3oo`03o`030?oo0?oo1ol000Oo00<0ool01_l300;o0`04o`030?oo00?o
00<0ool0ool7o`00ool/o`00ool/o`00ool/o`00ool/o`00ool/o`00ool/o`00ool/o`00ool/o`00
ool/o`00POl50004o`0000;o0`03o`800_l300Ko0P02o`030?oo08Go0022o`040?oo00;o00<0ool0
0_l01@3oool000;o00@0ool02?l0103oo`27o`00P_l00`3oo`03o`030?oo00;o00D0oooo0002o`04
0?oo00So00@0ool0Qol008;o0P03o`@000?o00000P02o`800_l400Go1028o`00P_l0103oo`2Uo`00
POl50:Go003oobco003oobco003oobco003oobco003oobco003oobco000Jo`800_l00`3oo`3oo`_o
000Ko`040?oo0?oo3Ol001_o00@0ool0ool=o`006_l40?oo3_l00?oo;?l00?oo;?l00?oo;?l00?oo
;?l00?oo;?l00001\
\>"],
  ImageRangeCache->{{{0, 298}, {184, 0}} -> {-12.0373, 0.304903, 0.42207, 
  0.00162951}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00952381 0.0147151 0.0939726 [
[(20)] .21429 .01472 0 2 Msboxa
[(40)] .40476 .01472 0 2 Msboxa
[(60)] .59524 .01472 0 2 Msboxa
[(80)] .78571 .01472 0 2 Msboxa
[(100)] .97619 .01472 0 2 Msboxa
[(No.)] 1.025 .01472 -1 0 Msboxa
[(Angle Ql[1])] .5 .61803 0 -2 0 0 1 Mouter Mrotsboxa
[(1)] .01131 .10869 1 0 Msboxa
[(2)] .01131 .20266 1 0 Msboxa
[(3)] .01131 .29663 1 0 Msboxa
[(4)] .01131 .39061 1 0 Msboxa
[(5)] .01131 .48458 1 0 Msboxa
[(6)] .01131 .57855 1 0 Msboxa
[(Rad)] .02381 .61803 0 -4 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 .61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.21429 .01472 m
.21429 .02097 L
s
P
[(20)] .21429 .01472 0 2 Mshowa
p
.002 w
.40476 .01472 m
.40476 .02097 L
s
P
[(40)] .40476 .01472 0 2 Mshowa
p
.002 w
.59524 .01472 m
.59524 .02097 L
s
P
[(60)] .59524 .01472 0 2 Mshowa
p
.002 w
.78571 .01472 m
.78571 .02097 L
s
P
[(80)] .78571 .01472 0 2 Mshowa
p
.002 w
.97619 .01472 m
.97619 .02097 L
s
P
[(100)] .97619 .01472 0 2 Mshowa
p
.001 w
.0619 .01472 m
.0619 .01847 L
s
P
p
.001 w
.1 .01472 m
.1 .01847 L
s
P
p
.001 w
.1381 .01472 m
.1381 .01847 L
s
P
p
.001 w
.17619 .01472 m
.17619 .01847 L
s
P
p
.001 w
.25238 .01472 m
.25238 .01847 L
s
P
p
.001 w
.29048 .01472 m
.29048 .01847 L
s
P
p
.001 w
.32857 .01472 m
.32857 .01847 L
s
P
p
.001 w
.36667 .01472 m
.36667 .01847 L
s
P
p
.001 w
.44286 .01472 m
.44286 .01847 L
s
P
p
.001 w
.48095 .01472 m
.48095 .01847 L
s
P
p
.001 w
.51905 .01472 m
.51905 .01847 L
s
P
p
.001 w
.55714 .01472 m
.55714 .01847 L
s
P
p
.001 w
.63333 .01472 m
.63333 .01847 L
s
P
p
.001 w
.67143 .01472 m
.67143 .01847 L
s
P
p
.001 w
.70952 .01472 m
.70952 .01847 L
s
P
p
.001 w
.74762 .01472 m
.74762 .01847 L
s
P
p
.001 w
.82381 .01472 m
.82381 .01847 L
s
P
p
.001 w
.8619 .01472 m
.8619 .01847 L
s
P
p
.001 w
.9 .01472 m
.9 .01847 L
s
P
p
.001 w
.9381 .01472 m
.9381 .01847 L
s
P
[(No.)] 1.025 .01472 -1 0 Mshowa
p
.002 w
0 .01472 m
1 .01472 L
s
P
[(Angle Ql[1])] .5 .61803 0 -2 0 0 1 Mouter Mrotshowa
p
.002 w
.02381 .10869 m
.03006 .10869 L
s
P
[(1)] .01131 .10869 1 0 Mshowa
p
.002 w
.02381 .20266 m
.03006 .20266 L
s
P
[(2)] .01131 .20266 1 0 Mshowa
p
.002 w
.02381 .29663 m
.03006 .29663 L
s
P
[(3)] .01131 .29663 1 0 Mshowa
p
.002 w
.02381 .39061 m
.03006 .39061 L
s
P
[(4)] .01131 .39061 1 0 Mshowa
p
.002 w
.02381 .48458 m
.03006 .48458 L
s
P
[(5)] .01131 .48458 1 0 Mshowa
p
.002 w
.02381 .57855 m
.03006 .57855 L
s
P
[(6)] .01131 .57855 1 0 Mshowa
p
.001 w
.02381 .03351 m
.02756 .03351 L
s
P
p
.001 w
.02381 .0523 m
.02756 .0523 L
s
P
p
.001 w
.02381 .0711 m
.02756 .0711 L
s
P
p
.001 w
.02381 .08989 m
.02756 .08989 L
s
P
p
.001 w
.02381 .12748 m
.02756 .12748 L
s
P
p
.001 w
.02381 .14628 m
.02756 .14628 L
s
P
p
.001 w
.02381 .16507 m
.02756 .16507 L
s
P
p
.001 w
.02381 .18387 m
.02756 .18387 L
s
P
p
.001 w
.02381 .22145 m
.02756 .22145 L
s
P
p
.001 w
.02381 .24025 m
.02756 .24025 L
s
P
p
.001 w
.02381 .25904 m
.02756 .25904 L
s
P
p
.001 w
.02381 .27784 m
.02756 .27784 L
s
P
p
.001 w
.02381 .31543 m
.02756 .31543 L
s
P
p
.001 w
.02381 .33422 m
.02756 .33422 L
s
P
p
.001 w
.02381 .35302 m
.02756 .35302 L
s
P
p
.001 w
.02381 .37181 m
.02756 .37181 L
s
P
p
.001 w
.02381 .4094 m
.02756 .4094 L
s
P
p
.001 w
.02381 .42819 m
.02756 .42819 L
s
P
p
.001 w
.02381 .44699 m
.02756 .44699 L
s
P
p
.001 w
.02381 .46578 m
.02756 .46578 L
s
P
p
.001 w
.02381 .50337 m
.02756 .50337 L
s
P
p
.001 w
.02381 .52217 m
.02756 .52217 L
s
P
p
.001 w
.02381 .54096 m
.02756 .54096 L
s
P
p
.001 w
.02381 .55976 m
.02756 .55976 L
s
P
p
.001 w
.02381 .59735 m
.02756 .59735 L
s
P
p
.001 w
.02381 .61614 m
.02756 .61614 L
s
P
[(Rad)] .02381 .61803 0 -4 Mshowa
p
.002 w
.02381 0 m
.02381 .61803 L
s
P
P
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.004 w
.03333 .01472 m
.04286 .60161 L
.05238 .56341 L
.0619 .48695 L
.07143 .39681 L
.08095 .28905 L
.09048 .1814 L
.1 .07136 L
.10952 .56524 L
.11905 .49242 L
.12857 .40317 L
.1381 .29608 L
.14762 .18806 L
.15714 .07851 L
.16667 .57013 L
.17619 .49741 L
.18571 .40943 L
.19524 .30313 L
.20476 .19473 L
.21429 .08569 L
.22381 .57518 L
.23333 .50231 L
.24286 .41561 L
.25238 .31018 L
.2619 .20142 L
.27143 .0929 L
.28095 .58041 L
.29048 .50715 L
.3 .42173 L
.30952 .31725 L
.31905 .20814 L
.32857 .10012 L
.3381 .58584 L
.34762 .51191 L
.35714 .42778 L
.36667 .3243 L
.37619 .21489 L
.38571 .10734 L
.39524 .59147 L
.40476 .5166 L
.41429 .43375 L
.42381 .33135 L
.43333 .22169 L
.44286 .11453 L
.45238 .59729 L
.4619 .52123 L
.47143 .43964 L
.48095 .33837 L
.49048 .22852 L
.5 .12169 L
Mistroke
.50952 .60332 L
.51905 .52579 L
.52857 .44546 L
.5381 .34535 L
.54762 .23539 L
.55714 .12879 L
.56667 .01908 L
.57619 .53031 L
.58571 .45119 L
.59524 .35228 L
.60476 .24229 L
.61429 .13584 L
.62381 .02546 L
.63333 .53478 L
.64286 .45684 L
.65238 .35915 L
.6619 .24921 L
.67143 .14281 L
.68095 .032 L
.69048 .53923 L
.7 .4624 L
.70952 .36595 L
.71905 .25616 L
.72857 .14971 L
.7381 .03867 L
.74762 .54368 L
.75714 .46787 L
.76667 .37267 L
.77619 .26313 L
.78571 .15654 L
.79524 .04546 L
.80476 .54814 L
.81429 .47325 L
.82381 .37931 L
.83333 .27011 L
.84286 .16331 L
.85238 .05235 L
.8619 .55264 L
.87143 .47854 L
.88095 .38586 L
.89048 .2771 L
.9 .17003 L
.90952 .05932 L
.91905 .55722 L
.92857 .48374 L
.9381 .39233 L
.94762 .28411 L
.95714 .17671 L
.96667 .06637 L
.97619 .56189 L
Mistroke
Mfstroke
% End of Graphics
MathPictureEnd\
\>"], "Graphics",
  PageWidth->Infinity,
  Evaluatable->False,
  ImageSize->{299, 185},
  ImageMargins->{{100, Inherited}, {Inherited, 0}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004[0000^@P10`40000100000800002008200000
P800P020P<30`<3L`:K:l:C8l3<006H009T00<`0000c03<c06Hc09Tc0<`c0?lc001V03=V06IV09UV
0<aV0?mV002I03>I06JI09VI0<bI0?nI003<03?<06K<09W<0<c<0?o<03?o06Ko09Wo0<co0000<c<0
<fH0<iT0<l`0<ol0<`0c<c<c<fHc<iTc<l`c<olc<`1V<c=V<fIV<iUV<laV<omV<`2I<c>I<fJI<iVI
<lbI<onI<`3<<c?<<fK<<iW<<lc<<oo<<`3o<c?o<fKo<iWo<lco<ooo<`00IS<0IVH0IYT0I/`0I_l0
IP0cIS<cIVHcIYTcI/`cI_lcIP1VIS=VIVIVIYUVI/aVI_mVIP2IIS>IIVJIIYVII/bII_nIIP3<IS?<
IVK<IYW<I/c<I_o<IP3oIS?oIVKoIYWoI/coI_ooIP00VC<0VFH0VIT0VL`0VOl0V@0cVC<cVFHcVITc
VL`cVOlcV@1VVC=VVFIVVIUVVLaVVOmVV@2IVC>IVFJIVIVIVLbIVOnIV@3<VC?<VFK<VIW<VLc<VOo<
V@3oVC?oVFKoVIWoVLcoVOooV@00c3<0c6H0c9T0c<`0c?l0c00cc3<cc6Hcc9Tcc<`cc?lcc01Vc3=V
c6IVc9UVc<aVc?mVc02Ic3>Ic6JIc9VIc<bIc?nIc03<c3?<c6K<c9W<c<c<c?o<c03oc3?oc6Koc9Wo
c<coc?ooc3<0ofH0oiT0ol`0o`0coc<cofHcoiTcol`coolco`1Voc=VofIVoiUVolaVoomVo`2Ioc>I
ofJIoiVIolbIoonIo`3<oc?<ofK<oiW<olc<ooo<oc?oofKooiWoolcoo`410@820P<30`@410D51@H6
1PL71`P820T92@X:2P/;2``<30h>3Pl?3a0@414A4A8B4Q<C4a@D5000000000000000000000000000
00000?okl:2PY820P?l0003o0?oo0000ool0o`3ooooooooo;?l00?oo;?l00?oo;?l00?oo;?l004Oo
0`03o`030?oo02?o0`02o`030?oo02;o0P04o`030?oo02?o00<0ool00_l00`3oo`0No`D00_l00`3o
o`02o`030?oo02go0017o`030?oo00;o00<0o`009Ol01P3oo`3o02?o00<0o`000_l00`3o000So`03
0?l000;o00<0o`008Ol01`3oool0o`000_l00`3o000^o`00B?l01`3oool0o`008ol40004o`3o02?o
00<0o`000_l00`3o000So`030?l000;o00<0o`008Ol01`3oool0o`000_l00`3o000^o`00B?l01`3o
ool0o`008ol00`3o0002o`030?l002?o0P03o`030?l002Co00L0oooo0?l0027o00L0oooo0?l000;o
00<0o`00;_l004Oo00<0o`000_l00`3o000To`800_l00`3o000So`030?oo00;o00<0o`008ol00`3o
0002o`030?l0027o00L0oooo0?l000;o00<0o`00;_l004So00<0ool00_l00`3oo`0To`050?ooo`00
9Ol200?o00<0ool08ol00`3oo`02o`030?oo01oo0P04o`030?oo00;o00<0ool0;Ol00?oo;?l00?oo
;?l00?oo;?l00?oo;?l00?oo;?l0023o00<0ool0ool9o`008?l00`3oo`3Oo`<000Co0?oo0P03o`03
0?oo01[o000Po`030?oo0>3o00H0o`00o`02o`030?oo01go000Kon801_l01P3o003o00;o00<0ool0
7Ol0023o00<0o`001_l00`3oo`05o`030?oo00Ko00<0ool01Ol00`3oo`06o`030?oo00Ko00<0ool0
1Ol00`3oo`06o`030?oo00Go00<0ool01_l00`3oo`06o`030?oo00Go00<0ool01_l00`3oo`05o`03
0?l000Ko00<0ool01Ol00`3oo`06o`030?oo00Ko00<0ool01Ol00`3oo`06o`030?oo00Go00<0ool0
1_l00`3oo`06o`030?oo00Go00<0ool01_l00`3oo`09o`8000Co0?oo0P0Po`008?l00`3o000Xo`03
0?oo02So00<0ool08Ol00`3oo`04o`030?oo02So00<0ool0:?l00`3oo`09o`8000?o0?l08ol0023o
00<0o`00Mol00`3oo`0:o`030?oo05So0P000ol0000To`008?l00`3o001go`030?oo00[o00<0ool0
2_l00`3oo`1do`008?l307Oo00<0ool02_l00`3oo`0:o`030?oo07Co000Po`030?l007Oo00<0ool0
2_l00`3oo`0:o`030?oo00[o00<0ool0Iol0023o00<0o`00Mol00`3oo`0:o`030?oo00[o00<0ool0
2_l00`3oo`0:o`030?oo05[o000Po`030?l007Ko0P0<o`030?oo00[o00<0ool02_l00`3oo`0:o`03
0?oo05[o000Po`<0M_l200co00<0ool02_l00`3oo`0:o`030?oo00[o00<0ool02_l00`3oo`1=o`00
8?l00`3o001fo`802ol200co00<0ool02_l00`3oo`0:o`030?oo00[o00<0ool0COl0023o00<0o`00
M_l200_o0P0;o`803?l00`3oo`0:o`030?oo00[o00<0ool02_l00`3oo`10o`008?l00`3o001fo`80
2ol200_o0P0<o`030?oo00[o00<0ool02_l00`3oo`0:o`030?oo00[o00<0ool0<ol0023o0`0>o`03
0?oo06Go0P0;o`802ol200_o0P0<o`030?oo00[o00<0ool02_l00`3oo`0:o`030?oo03?o000Po`03
0?l000ko00<0ool0IOl200_o0P0;o`802ol200_o0P0<o`030?oo00[o00<0ool02_l00`3oo`0co`00
8?l00`3o000>o`030?oo00[o00<0ool0F?l200_o0P0;o`802ol200_o0P0<o`030?oo00[o00<0ool0
2_l00`3oo`0co`008?l00`3o000>o`030?oo00[o00<0ool02_l00`3oo`1;o`802ol200_o0P0;o`80
2ol200_o0P0<o`030?oo00[o00<0ool0<ol0023o0`0>o`030?oo00[o00<0ool02_l00`3oo`1;o`80
2ol200_o0P0;o`802ol200_o0P0<o`030?oo00Wo0P0eo`008?l00`3o000>o`030?oo00[o00<0ool0
2_l00`3oo`0:o`030?oo03ko0P0;o`802ol200_o0P0;o`802ol200_o0P0;o`80=Ol0023o00<0o`00
3_l00`3oo`0:o`030?oo00[o00<0ool02_l00`3oo`0no`802ol200_o0P0;o`802ol200_o0P0;o`80
2ol203Go000Ho`D00ol00`3o000=o`803?l00`3oo`0:o`030?oo00[o00<0ool02_l00`3oo`0`o`03
0?l000_o0P0;o`802ol200_o0P0;o`802ol200_o0P0eo`006_l00`3oo`03o`030?l000go0P0<o`03
0?oo00[o00<0ool02_l00`3oo`0:o`030?oo00[o00<0ool08ol0103oo`0:o`802ol200_o0P0;o`80
2ol200_o0P0;o`80=Ol001[o00<0ool00ol300go0P0;o`803?l00`3oo`0:o`030?oo00[o00<0ool0
2_l00`3oo`0So`040?oo00Wo00<0o`002ol200_o0P0;o`802ol200_o0P0;o`80=Ol001[o00<0ool0
0ol00`3o000=o`802ol200_o0P0<o`030?oo00[o00<0ool02_l00`3oo`0:o`030?oo01Ko00@0ool0
2Ol00`3o000:o`030?l000_o0P0;o`802ol200_o0P0;o`80=Ol001[o00<0ool00ol00`3o000=o`80
2ol200_o0P0<o`030?oo00[o00<0ool02_l00`3oo`0:o`030?oo01Ko00@0ool02Ol00`3o000:o`03
0?l000_o0P0;o`802ol200_o0P0;o`80=Ol001Wo0P05o`030?l000go0P0;o`802ol200_o0P0<o`03
0?oo00[o00<0ool02_l00`3oo`09o`030?oo00[o00@0ool02Ol00`3o000:o`030?l000[o00<0o`00
2ol200_o0P0;o`802_l00`3o000eo`008?l300go0P0;o`802ol200_o0P0;o`803?l00`3oo`0:o`03
0?oo00Wo00<0ool02_l0103oo`09o`030?l000[o00<0o`002_l00`3o000:o`030?l000_o0P0;o`80
2_l00`3o000eo`008?l00`3o000=o`802ol200_o0P0;o`802ol200co00<0ool02Ol200_o00<0ool0
2_l0103oo`09o`030?l000[o00<0o`002_l00`3o000:o`030?l000_o0P0;o`802_l00`3o000eo`00
8?l00`3o000=o`802ol200_o0P0;o`802ol200_o0P0;o`802ol00`3oo`0:o`040?oo00Wo00<0o`00
2_l00`3o000:o`030?l000[o00<0o`002_l00`3o000;o`802_l00`3o000eo`008?l00`3o000=o`80
2ol200_o0P0;o`802ol200_o0P0;o`802ol00`3oo`0:o`040?oo00Wo00<0o`002_l00`3o000:o`03
0?l000[o00<0o`002_l00`3o000;o`802_l00`3o000eo`008?l300go0P0;o`802ol200_o0P0;o`80
2ol200_o0P0;o`030?oo00[o00@0ool02Ol00`3o000:o`030?l000[o00<0o`002_l00`3o000:o`03
0?l000[o00<0o`002_l00`3o000eo`008?l00`3o000=o`802ol200_o0P0;o`802ol200_o0P0;o`80
2_l200co00@0ool02Ol00`3o000:o`030?l000[o00<0o`002_l00`3o000:o`030?l000[o00<0o`00
2_l00`3o000eo`008?l00`3o000<o`030?l000_o0P0;o`802ol200_o0P0;o`802ol200[o0P0;o`05
0?ooo`002Ol0103oo`09o`030?l000[o00<0o`002_l00`3o000:o`030?l000[o00<0o`002_l00`3o
000eo`008?l00`3o000<o`030?l000_o0P0;o`802ol200_o0P0;o`802ol200[o0P0;o`050?ooo`00
2Ol0103oo`09o`040?oo00Wo00<0o`002_l00`3o000:o`030?l000[o00<0o`002Ol0103oo`0eo`00
8?l20003o`3o00[o00<0o`002_l00`3o000;o`802ol200_o0P0;o`802ol200[o0P0;o`050?ooo`00
2?l01@3oool000Wo00@0ool02Ol00`3o000:o`030?l000[o00<0o`002_l00`3o0009o`040?oo03Go
000Po`040?oo00_o00<0o`002_l00`3o000:o`030?l000_o0P0;o`802ol200[o00<0o`002_l200_o
00D0oooo0008o`050?ooo`002?l01@3oool000Wo00@0ool02Ol00`3o000:o`030?l000[o00<0o`00
2Ol0103oo`0eo`008?l0103oo`0;o`030?l000[o00<0o`002_l00`3o000;o`802ol200_o0P0:o`03
0?l000[o0P0;o`050?ooo`002?l01@3oool000So00D0oooo0009o`040?oo00Wo00@0ool02Ol00`3o
000:o`030?l000Wo00@0ool0=Ol0023o00@0ool02ol00`3o000:o`030?l000[o00<0o`002_l00`3o
000;o`802ol200[o00<0o`002_l200_o00D0oooo0008o`050?ooo`002?l01@3oool000So00D0oooo
0009o`040?oo00Wo00<0o`002_l00`3o0009o`040?oo03Go000Po`040?oo00_o00<0o`002_l00`3o
000:o`030?l000[o00<0o`002_l00`3o000;o`802_l00`3o000:o`802ol01@3oool000So00D0oooo
0008o`050?ooo`002?l01@3oool000So00D0oooo0009o`040?oo00Wo00<0o`002Ol0103oo`0eo`00
8?l20003o`3o00[o00<0o`002_l00`3o000:o`030?l000[o00<0o`002_l00`3o000;o`802_l00`3o
000:o`802ol01@3oool000So00D0oooo0008o`050?ooo`002?l01@3oool000So00D0oooo0009o`04
0?oo00Wo00@0ool02?l0103oo`0eo`008?l0103oo`0;o`030?l000[o00<0o`002_l00`3o000:o`03
0?l000[o00<0o`002_l00`3o000:o`030?l000[o0P0;o`050?ooo`002?l01@3oool000So00D0oooo
0008o`050?ooo`002?l01@3oool000So00D0oooo0008o`050?ooo`002?l01@3oool003Co000Io`<0
1?l0103oo`0;o`040?oo00Wo00<0o`002_l00`3o000:o`030?l000[o00<0o`002_l00`3o000:o`03
0?l000[o0P0;o`050?ooo`002?l01@3oool000So00D0oooo0008o`050?ooo`002?l01@3oool000So
00D0oooo0008o`050?ooo`002?l01@3oool003Co000Io`030?oo00Co00@0ool02ol0103oo`09o`03
0?l000[o00<0o`002_l00`3o000:o`030?l000[o00<0o`002_l00`3o000:o`802ol01@3oool000So
00D0oooo0008o`050?ooo`002?l01@3oool000So00D0oooo0008o`050?ooo`002?l01@3oool000So
00D0oooo000do`006_l00`3oo`03o`8000?o0?l02_l0103oo`09o`040?oo00Wo00<0o`002_l00`3o
000:o`030?l000[o00<0o`002Ol0103oo`09o`040?oo00[o00D0oooo0008o`050?ooo`002?l01@3o
ool000So00D0oooo0008o`050?ooo`002?l01@3oool000So00D0oooo0007o`030?oo00;o00<0ool0
<_l001[o00<0ool00ol0103oo`0:o`050?ooo`002Ol0103oo`09o`040?oo00Wo00<0o`002_l00`3o
000:o`030?l000Wo00@0ool02Ol0103oo`09o`030?oo00;o00<0ool01_l01@3oool000So00D0oooo
0008o`050?ooo`002?l01@3oool000So00D0oooo0008o`050?ooo`001ol00`3oo`02o`030?oo03;o
000Io`030?l000Co00@0ool02_l01@3oool000Wo00@0ool02Ol0103oo`09o`030?l000[o00<0o`00
2_l00`3o0009o`040?oo00Wo00@0ool02Ol00`3oo`02o`030?oo00Ko00D0oooo0008o`050?ooo`00
2?l01@3oool000So00D0oooo0008o`050?ooo`002?l01@3oool000Oo00<0ool00_l00`3oo`0bo`00
6_l00`3oo`03o`040?oo00[o00D0oooo0008o`050?ooo`002Ol0103oo`09o`040?oo00Wo00<0o`00
2_l00`3o0009o`040?oo00Wo00@0ool02Ol00`3oo`02o`030?oo00Go00<0ool00_l00`3oo`06o`05
0?ooo`002?l01@3oool000So00D0oooo0008o`050?ooo`002?l01@3oool000Oo00<0ool00_l00`3o
o`0bo`008?l20003o`3o00Wo00D0oooo0008o`050?ooo`002Ol0103oo`09o`040?oo00Wo00<0o`00
2_l00`3o0009o`040?oo00Wo00@0ool02Ol00`3oo`02o`030?oo00Go00<0ool00_l00`3oo`05o`03
0?oo00;o00<0ool01_l01@3oool000So00D0oooo0008o`050?ooo`002?l01@3oool000Oo00<0ool0
0_l00`3oo`0bo`008?l0103oo`0:o`050?ooo`002?l01@3oool000So00D0oooo0009o`040?oo00Wo
00@0ool02Ol00`3o0009o`040?oo00Wo00@0ool02Ol00`3oo`02o`030?oo00Go00<0ool00_l00`3o
o`05o`030?oo00;o00<0ool01_l01@3oool000So00D0oooo0008o`050?ooo`001ol00`3oo`02o`03
0?oo00Go00<0ool00_l00`3oo`0bo`008?l0103oo`0:o`050?ooo`002?l01@3oool000So00D0oooo
0008o`050?ooo`002?l01@3oool000Wo00@0ool02?l0103oo`09o`040?oo00Wo00<0ool00_l00`3o
o`05o`030?oo00;o00<0ool01Ol00`3oo`02o`030?oo00Go00<0ool00_l00`3oo`06o`050?ooo`00
2?l01@3oool000Oo00<0ool00_l00`3oo`05o`030?oo00;o00<0ool0<_l0023o00@0ool02_l01@3o
ool000So00D0oooo0008o`050?ooo`002?l01@3oool000So00D0oooo0008o`050?ooo`002?l0103o
o`09o`040?oo00Wo00<0ool00_l00`3oo`05o`030?oo00;o00<0ool01Ol00`3oo`02o`030?oo00Go
00<0ool00_l00`3oo`05o`030?oo00;o00<0ool01_l01@3oool000Oo00<0ool00_l00`3oo`05o`03
0?oo00;o00<0ool0<_l0023o0P000ol0o`09o`050?ooo`002?l01@3oool000So00D0oooo0008o`05
0?ooo`002?l01@3oool000So00D0oooo0008o`050?ooo`002?l0103oo`09o`030?oo00;o00<0ool0
1Ol00`3oo`02o`030?oo00Go00<0ool00_l00`3oo`05o`030?oo00;o00<0ool01Ol00`3oo`02o`03
0?oo00Ko00D0oooo0007o`030?oo00;o00<0ool01Ol00`3oo`02o`030?oo03;o000Po`040?oo00[o
00D0oooo0008o`050?ooo`002?l01@3oool000So00D0oooo0008o`050?ooo`002?l01@3oool000So
00D0oooo0008o`040?oo00Wo00<0ool00_l00`3oo`05o`030?oo00;o00<0ool01Ol00`3oo`02o`03
0?oo00Go00<0ool00_l00`3oo`05o`030?oo00;o00<0ool01Ol00`3oo`02o`030?oo00Go00<0ool0
0_l00`3oo`05o`030?oo00;o00<0ool0<_l0023o00@0ool02_l01@3oool000So00D0oooo0008o`05
0?ooo`002?l01@3oool000So00D0oooo0008o`050?ooo`002?l01@3oool000So00@0ool02Ol00`3o
o`02o`030?oo00Go00<0ool00_l00`3oo`05o`030?oo00;o00<0ool01Ol00`3oo`02o`030?oo00Go
00<0ool00_l00`3oo`05o`030?oo00;o00<0ool01Ol00`3oo`02o`030?oo00Go00<0ool00_l00`3o
o`0bo`008?l0103oo`0:o`050?ooo`002?l01@3oool000So00D0oooo0008o`050?ooo`002?l01@3o
ool000So00D0oooo0007o`030?oo00;o00<0ool01_l0103oo`09o`030?oo00;o00<0ool01Ol00`3o
o`02o`030?oo00Go00<0ool00_l00`3oo`05o`030?oo00;o00<0ool01Ol00`3oo`02o`030?oo00Go
00<0ool00_l00`3oo`05o`030?oo00;o00<0ool01Ol00`3oo`02o`030?oo03;o000Po`040?oo00[o
00D0oooo0008o`050?ooo`002?l01@3oool000So00D0oooo0008o`050?ooo`002?l01@3oool000Oo
00<0ool00_l00`3oo`05o`050?ooo`002Ol00`3oo`02o`030?oo00Go00<0ool00_l00`3oo`05o`03
0?oo00;o00<0ool01Ol00`3oo`02o`030?oo00Go00<0ool00_l00`3oo`05o`030?oo00;o00<0ool0
1Ol00`3oo`02o`030?oo00Co00<0ool00ol00`3oo`0bo`008?l20003o`3o00So00<0ool00_l00`3o
o`06o`050?ooo`002?l01@3oool000So00D0oooo0008o`050?ooo`002?l01@3oool000Oo00<0ool0
0_l00`3oo`05o`050?ooo`002Ol00`3oo`02o`030?oo00Go00<0ool00_l00`3oo`05o`030?oo00;o
00<0ool01Ol00`3oo`02o`030?oo00Go00<0ool00_l00`3oo`05o`030?oo00;o00<0ool01?l00`3o
o`03o`030?oo00Co00<0ool00ol00`3oo`0bo`008?l0103oo`09o`030?oo00;o00<0ool01_l01@3o
ool000So00D0oooo0008o`050?ooo`001ol00`3oo`02o`030?oo00Ko00D0oooo0007o`030?oo00;o
00<0ool01Ol01@3oool000So00<0ool00ol00`3oo`05o`030?oo00;o00<0ool01Ol00`3oo`02o`03
0?oo00Go00<0ool00_l00`3oo`05o`030?oo00;o00<0ool01Ol00`3oo`02o`030?oo00Co00<0ool0
0ol00`3oo`04o`030?oo00?o00<0ool0<_l0023o00@0ool02Ol00`3oo`02o`030?oo00Go00<0ool0
0_l00`3oo`06o`050?ooo`002?l01@3oool000Oo00<0ool00_l00`3oo`05o`030?oo00;o00<0ool0
1Ol00`3oo`02o`030?oo00Go00D0oooo0008o`030?oo00?o00<0ool01Ol00`3oo`02o`030?oo00Go
00<0ool00_l00`3oo`05o`030?oo00;o00<0ool01Ol00`3oo`02o`030?oo00Go00<0ool00_l00`3o
o`04o`030?oo00?o00<0ool01?l00`3oo`03o`030?oo03;o000Po`040?oo00Wo00<0ool00_l00`3o
o`05o`030?oo00;o00<0ool01_l01@3oool000So00D0oooo0007o`030?oo00;o00<0ool01Ol00`3o
o`02o`030?oo00Go00<0ool00_l00`3oo`05o`050?ooo`002?l00`3oo`04o`030?oo00?o00<0ool0
0ol00`3oo`05o`030?oo00;o00<0ool01Ol00`3oo`02o`030?oo00Go00<0ool00_l00`3oo`05o`03
0?oo00;o00<0ool01?l00`3oo`03o`030?oo00Co00<0ool00ol00`3oo`0bo`008?l20003o`3o00So
00<0ool00_l00`3oo`05o`030?oo00;o00<0ool01Ol00`3oo`02o`030?oo00Ko00D0oooo0007o`03
0?oo00;o00<0ool01Ol00`3oo`02o`030?oo00Go00<0ool00_l00`3oo`05o`050?ooo`002?l00`3o
o`04o`030?oo00?o00<0ool00ol00`3oo`04o`030?oo00?o00<0ool01Ol00`3oo`02o`030?oo00Go
00<0ool00_l00`3oo`05o`030?oo00;o00<0ool01?l00`3oo`03o`030?oo00Co00<0ool00ol00`3o
o`0bo`008?l0103oo`09o`030?oo00;o00<0ool01Ol00`3oo`02o`030?oo00Go00<0ool00_l00`3o
o`05o`030?oo00;o00<0ool01Ol00`3oo`02o`030?oo00Go00<0ool00_l00`3oo`05o`030?oo00;o
00<0ool01Ol01@3oool000So00<0ool01?l00`3oo`03o`030?oo00?o00<0ool01?l00`3oo`03o`03
0?oo00Go00<0ool00_l00`3oo`05o`030?oo00;o00<0ool01Ol00`3oo`02o`030?oo00Co00<0ool0
0ol00`3oo`04o`030?oo00?o00<0ool0<_l001Wo0P05o`040?oo00Wo00<0ool00_l00`3oo`05o`03
0?oo00;o00<0ool01Ol00`3oo`02o`030?oo00Go00<0ool00_l00`3oo`05o`030?oo00;o00<0ool0
1Ol00`3oo`02o`030?oo00Go00<0ool00_l00`3oo`05o`050?ooo`002?l00`3oo`04o`030?oo00?o
00<0ool00ol00`3oo`04o`030?oo00?o00<0ool01?l00`3oo`03o`030?oo00Go00<0ool00_l00`3o
o`05o`030?oo00;o00<0ool01?l00`3oo`03o`030?oo00Co00<0ool00ol00`3oo`0bo`006ol00`3o
o`02o`040?oo00Wo00<0ool00_l00`3oo`05o`030?oo00;o00<0ool01Ol00`3oo`02o`030?oo00Go
00<0ool00_l00`3oo`05o`030?oo00;o00<0ool01Ol00`3oo`02o`030?oo00Go00<0ool00_l00`3o
o`05o`050?ooo`002?l00`3oo`04o`030?oo00?o00<0ool00ol00`3oo`04o`030?oo00?o00<0ool0
1?l00`3oo`03o`030?oo00Co00<0ool00ol00`3oo`04o`030?oo00?o00<0ool01?l00`3oo`03o`03
0?oo00Co00<0ool00ol00`3oo`0bo`006_l00`3oo`03o`8000?o0?l02?l00`3oo`02o`030?oo00Go
00<0ool00_l00`3oo`05o`030?oo00;o00<0ool01Ol00`3oo`02o`030?oo00Go00<0ool00_l00`3o
o`05o`030?oo00;o00<0ool01Ol00`3oo`02o`030?oo00Go00D0oooo0008o`030?oo00Co00<0ool0
0ol00`3oo`03o`030?oo00Co00<0ool00ol00`3oo`04o`030?oo00?o00<0ool01?l00`3oo`03o`03
0?oo00Co00<0ool00ol00`3oo`04o`030?oo00?o00<0ool01?l00`3oo`03o`030?oo03;o000Ko`03
0?oo00;o00@0ool02Ol00`3oo`02o`030?oo00Go00<0ool00_l00`3oo`05o`030?oo00;o00<0ool0
1Ol00`3oo`02o`030?oo00Co00<0ool00ol00`3oo`05o`030?oo00;o00<0ool01Ol00`3oo`02o`03
0?oo00Go00D0oooo0008o`030?oo00Co00<0ool00ol00`3oo`03o`030?oo00Co00<0ool00ol00`3o
o`04o`030?oo00?o00<0ool01?l00`3oo`03o`030?oo00Co00<0ool00ol00`3oo`04o`030?oo00?o
00<0ool01?l00`3oo`03o`030?oo03;o000Io`030?l000Co00@0ool02Ol00`3oo`02o`030?oo00Go
00<0ool00_l00`3oo`05o`030?oo00;o00<0ool01Ol00`3oo`02o`030?oo00Co00<0ool00ol00`3o
o`04o`030?oo00?o00<0ool01?l00`3oo`03o`030?oo00Go00D0oooo0008o`030?oo00Co00<0ool0
0ol00`3oo`03o`030?oo00Co00<0ool00ol00`3oo`04o`030?oo00?o00<0ool01?l00`3oo`03o`03
0?oo00Co00<0ool00ol00`3oo`03o`030?oo00Co00<0ool01?l00`3oo`03o`030?oo03;o000Jo`03
0?oo00?o00@0ool02Ol00`3oo`02o`030?oo00Go00<0ool00_l00`3oo`05o`030?oo00;o00<0ool0
1Ol00`3oo`02o`030?oo00Co00<0ool00ol00`3oo`04o`030?oo00?o00<0ool01?l00`3oo`03o`03
0?oo00Co00<0ool00_l00`3oo`06o`030?oo00Co00<0ool00ol00`3oo`03o`030?oo00Co00<0ool0
0ol00`3oo`04o`030?oo00?o00<0ool01?l00`3oo`03o`030?oo00Co00<0ool00ol00`3oo`03o`03
0?oo00Co00<0ool01?l00`3oo`03o`030?oo03;o000Po`8000?o0?l02?l00`3oo`02o`030?oo00Go
00<0ool00_l00`3oo`05o`030?oo00;o00<0ool01Ol00`3oo`02o`030?oo00Co00<0ool00ol00`3o
o`04o`030?oo00?o00<0ool01?l00`3oo`03o`030?oo00Co00<0ool00_l00`3oo`06o`030?oo00Co
00<0ool00ol00`3oo`03o`030?oo00Co00<0ool00ol00`3oo`04o`030?oo00?o00<0ool01?l00`3o
o`03o`030?oo00Co00<0ool00ol00`3oo`03o`030?oo00Co00<0ool00ol00`3oo`04o`030?oo03;o
000Po`040?oo00So00<0ool00ol00`3oo`05o`030?oo00;o00<0ool01Ol00`3oo`02o`030?oo00Go
00<0ool00_l00`3oo`04o`030?oo00?o00<0ool01?l00`3oo`03o`030?oo00Co00<0ool00ol00`3o
o`04o`030?oo00;o00<0ool01Ol00`3oo`05o`030?oo00?o00<0ool00ol00`3oo`04o`030?oo00?o
00<0ool01?l00`3oo`03o`030?oo00Co00<0ool00ol00`3oo`04o`030?oo00?o00<0ool00ol00`3o
o`04o`030?oo00?o00<0ool01?l00`3oo`0bo`008?l0103oo`08o`030?oo00?o00<0ool01?l00`3o
o`03o`030?oo00Go00<0ool00_l00`3oo`05o`030?oo00;o00<0ool01?l00`3oo`03o`030?oo00Co
00<0ool00ol00`3oo`04o`030?oo00?o00<0ool01?l00`3oo`02o`030?oo00Go00<0ool01Ol00`3o
o`03o`030?oo00?o00<0ool01?l00`3oo`03o`030?oo00Co00<0ool00ol00`3oo`04o`030?oo00?o
00<0ool01?l00`3oo`03o`030?oo00?o00<0ool01?l00`3oo`03o`030?oo00Co00<0ool0<_l0023o
00@0ool02?l00`3oo`03o`030?oo00Co00<0ool00ol00`3oo`05o`030?oo00;o00<0ool01?l00`3o
o`03o`030?oo00Co00<0ool00ol00`3oo`04o`030?oo00?o00<0ool01?l00`3oo`03o`030?oo00Co
00<0ool00_l00`3oo`05o`030?oo00Go00<0ool00_l00`3oo`04o`030?oo00Co00<0ool00ol00`3o
o`04o`030?oo00?o00<0ool01?l00`3oo`03o`030?oo00?o00<0ool01?l00`3oo`03o`030?oo00Co
00<0ool00ol00`3oo`04o`030?oo03;o000Po`040?oo00So00<0ool00ol00`3oo`04o`030?oo00?o
00<0ool01?l00`3oo`03o`030?oo00Co00<0ool00ol00`3oo`04o`030?oo00?o00<0ool01?l00`3o
o`03o`030?oo00Co00<0ool00ol00`3oo`04o`030?oo00;o00<0ool01Ol00`3oo`05o`030?oo00;o
00<0ool01?l00`3oo`03o`030?oo00Co00<0ool01?l00`3oo`03o`030?oo00Co00<0ool00ol00`3o
o`03o`030?oo00Co00<0ool00ol00`3oo`04o`030?oo00?o00<0ool01?l00`3oo`0bo`008?l20003
o`3o00Oo00<0ool00ol00`3oo`04o`030?oo00?o00<0ool01?l00`3oo`03o`030?oo00Co00<0ool0
0ol00`3oo`04o`030?oo00?o00<0ool01?l00`3oo`03o`030?oo00Co00<0ool00ol00`3oo`04o`03
0?oo00;o00<0ool01Ol00`3oo`05o`030?oo00;o00<0ool01?l00`3oo`03o`030?oo00Co00<0ool0
1?l00`3oo`03o`030?oo00Co00<0ool00ol00`3oo`03o`030?oo00Co00<0ool00ol00`3oo`04o`03
0?oo00?o00<0ool01?l00`3oo`0bo`008?l0103oo`08o`030?oo00?o00<0ool01?l00`3oo`03o`03
0?oo00Co00<0ool00ol00`3oo`04o`030?oo00?o00<0ool01?l00`3oo`03o`030?oo00Co00<0ool0
0ol00`3oo`04o`030?oo00?o00<0ool01?l00`3oo`02o`030?oo00Go00<0ool01Ol00`3oo`02o`03
0?oo00Co00<0ool00ol00`3oo`04o`030?oo00?o00<0ool01?l00`3oo`04o`030?oo00?o00<0ool0
0ol00`3oo`04o`030?oo00?o00<0ool01?l00`3oo`03o`030?oo00Co00<0ool0<_l0023o00@0ool0
2?l00`3oo`03o`030?oo00Co00<0ool00ol00`3oo`04o`030?oo00?o00<0ool01?l00`3oo`03o`03
0?oo00?o00<0ool01?l00`3oo`04o`030?oo00?o00<0ool01?l00`3oo`03o`030?oo00Co00<0ool0
0_l00`3oo`05o`030?oo00Go00<0ool00_l00`3oo`04o`030?oo00?o00<0ool01?l00`3oo`03o`03
0?oo00Co00<0ool00ol00`3oo`04o`030?oo00?o00<0ool01?l00`3oo`03o`030?oo00Co00<0ool0
0ol00`3oo`04o`030?oo03;o000Po`040?oo00So00<0ool00ol00`3oo`04o`030?oo00?o00<0ool0
1?l00`3oo`03o`030?oo00Co00<0ool00ol00`3oo`03o`030?oo00Co00<0ool00ol00`3oo`04o`03
0?oo00Co00<0ool00ol00`3oo`04o`030?oo00;o00<0ool01Ol00`3oo`05o`030?oo00;o00<0ool0
1?l00`3oo`03o`030?oo00Co00<0ool00ol00`3oo`04o`030?oo00?o00<0ool01?l00`3oo`03o`03
0?oo00Co00<0ool00ol00`3oo`04o`030?oo00?o00<0ool01?l00`3oo`0bo`008?l20003o`3o00Oo
00<0ool00ol00`3oo`04o`030?oo00?o00<0ool01?l00`3oo`03o`030?oo00Co00<0ool00ol00`3o
o`03o`030?oo00Co00<0ool00ol00`3oo`04o`030?oo00Co00<0ool00ol00`3oo`04o`030?oo00;o
00<0ool01Ol00`3oo`05o`030?oo00;o00<0ool01?l00`3oo`03o`030?oo00Co00<0ool00ol00`3o
o`04o`030?oo00?o00<0ool01?l00`3oo`03o`030?oo00Co00<0ool00ol00`3oo`04o`030?oo00?o
00<0ool01?l00`3oo`0bo`008?l0103oo`08o`030?oo00?o00<0ool01?l00`3oo`03o`030?oo00Co
00<0ool00ol00`3oo`04o`030?oo00?o00<0ool00ol00`3oo`04o`030?oo00?o00<0ool01?l00`3o
o`03o`030?oo00Co00<0ool01?l00`3oo`02o`030?oo00Go00<0ool01Ol00`3oo`02o`030?oo00Co
00<0ool00ol00`3oo`04o`030?oo00?o00<0ool01?l00`3oo`03o`030?oo00Co00<0ool00ol00`3o
o`04o`030?oo00;o00<0ool01Ol00`3oo`03o`030?oo00Co00<0ool0<_l0023o00@0ool02?l00`3o
o`03o`030?oo00Co00<0ool00ol00`3oo`04o`030?oo00?o00<0ool00ol00`3oo`04o`030?oo00?o
00<0ool01?l00`3oo`03o`030?oo00Co00<0ool00ol00`3oo`04o`030?oo00?o00<0ool01?l00`3o
o`04o`030?oo00Go00<0ool00_l00`3oo`04o`030?oo00?o00<0ool01?l00`3oo`03o`030?oo00Co
00<0ool00ol00`3oo`04o`030?oo00;o00<0ool01Ol00`3oo`02o`030?oo00Go00<0ool00ol00`3o
o`04o`030?oo03;o000Po`040?oo00So00<0ool00ol00`3oo`04o`030?oo00?o00<0ool01?l00`3o
o`03o`030?oo00?o00<0ool01?l00`3oo`03o`030?oo00Co00<0ool00ol00`3oo`04o`030?oo00?o
00<0ool01?l00`3oo`03o`030?oo00Co00<0ool01?l00`3oo`05o`030?oo00;o00<0ool01?l00`3o
o`03o`030?oo00Co00<0ool00ol00`3oo`04o`030?oo00?o00<0ool01?l00`3oo`02o`030?oo00Go
00<0ool00_l00`3oo`05o`030?oo00;o00<0ool01Ol00`3oo`0bo`008?l20003o`3o00Ko00<0ool0
1?l00`3oo`04o`030?oo00?o00<0ool01?l00`3oo`03o`030?oo00?o00<0ool01?l00`3oo`03o`03
0?oo00Co00<0ool00ol00`3oo`04o`030?oo00?o00<0ool01?l00`3oo`03o`030?oo00Co00<0ool0
0ol00`3oo`06o`030?oo00;o00<0ool01?l00`3oo`03o`030?oo00Co00<0ool00ol00`3oo`04o`03
0?oo00?o00<0ool01?l00`3oo`02o`030?oo00Go00<0ool00_l00`3oo`05o`030?oo00;o00<0ool0
1Ol00`3oo`0bo`008?l0103oo`07o`030?oo00Co00<0ool00ol00`3oo`04o`030?oo00Co00<0ool0
0ol00`3oo`03o`030?oo00Co00<0ool00ol00`3oo`04o`030?oo00?o00<0ool01?l00`3oo`03o`03
0?oo00Co00<0ool00ol00`3oo`04o`030?oo00?o00<0ool01_l00`3oo`02o`030?oo00Co00<0ool0
0ol00`3oo`04o`030?oo00?o00<0ool01?l00`3oo`03o`030?oo00Co00<0ool00_l00`3oo`05o`03
0?oo00;o00<0ool01Ol00`3oo`02o`030?oo00Go00<0ool0<_l001[o0`03o`040?oo00Oo00<0ool0
1?l00`3oo`03o`030?oo00Co00<0ool01?l00`3oo`03o`030?oo00?o00<0ool01?l00`3oo`03o`03
0?oo00Co00<0ool00ol00`3oo`04o`030?oo00?o00<0ool01?l00`3oo`03o`030?oo00Co00<0ool0
0ol00`3oo`06o`050?ooo`001ol00`3oo`03o`030?oo00Co00<0ool00ol00`3oo`04o`030?oo00?o
00<0ool01?l00`3oo`02o`030?oo00Go00<0ool00_l00`3oo`05o`030?oo00;o00<0ool01Ol00`3o
o`0bo`006ol00`3oo`02o`040?oo00Oo00<0ool01?l00`3oo`03o`030?oo00Co00<0ool00ol00`3o
o`04o`030?oo00?o00<0ool01?l00`3oo`03o`030?oo00Co00<0ool00ol00`3oo`04o`030?oo00?o
00<0ool01?l00`3oo`03o`030?oo00Co00<0ool00ol00`3oo`06o`050?ooo`001ol00`3oo`02o`03
0?oo00Go00<0ool00_l00`3oo`05o`030?oo00?o00<0ool01?l00`3oo`02o`030?oo00Go00<0ool0
0_l00`3oo`05o`030?oo00;o00<0ool01Ol00`3oo`0bo`006Ol400?o0P000ol0o`06o`030?oo00Co
00<0ool00ol00`3oo`04o`030?oo00?o00<0ool01?l00`3oo`03o`030?oo00Co00<0ool00ol00`3o
o`04o`030?oo00?o00<0ool01?l00`3oo`03o`030?oo00Co00<0ool00ol00`3oo`04o`030?oo00?o
00<0ool01_l01@3oool000Oo00<0ool00_l00`3oo`05o`030?oo00;o00<0ool01Ol00`3oo`02o`03
0?oo00Go00<0ool00_l00`3oo`05o`030?oo00;o00<0ool01Ol00`3oo`02o`030?oo00Go00<0ool0
<_l001Wo00<0o`001?l0103oo`07o`030?oo00Co00<0ool00ol00`3oo`04o`030?oo00?o00<0ool0
1?l00`3oo`03o`030?oo00Co00<0ool00ol00`3oo`04o`030?oo00?o00<0ool01?l00`3oo`03o`03
0?oo00Co00<0ool00ol00`3oo`04o`030?oo00?o00<0ool01_l01@3oool000Oo00<0ool00_l00`3o
o`05o`030?oo00;o00<0ool01Ol00`3oo`02o`030?oo00Go00<0ool00_l00`3oo`05o`030?oo00;o
00<0ool01Ol00`3oo`02o`030?oo00Go00<0ool0<_l001[o0P04o`040?oo00Oo00<0ool01?l00`3o
o`03o`030?oo00Co00<0ool00ol00`3oo`04o`030?oo00;o00<0ool01Ol00`3oo`02o`030?oo00Go
00<0ool00ol00`3oo`04o`030?oo00?o00<0ool01?l00`3oo`03o`030?oo00Co00<0ool00ol00`3o
o`06o`050?ooo`001ol00`3oo`02o`030?oo00Go00<0ool00_l00`3oo`05o`030?oo00;o00<0ool0
1Ol00`3oo`02o`030?oo00Go00<0ool00_l00`3oo`05o`030?oo00;o00<0ool01Ol00`3oo`0bo`00
6ol00`3oo`02o`040?oo00Oo00<0ool01?l00`3oo`03o`030?oo00Co00<0ool00ol00`3oo`04o`03
0?oo00;o00<0ool01Ol00`3oo`02o`030?oo00Go00<0ool00_l00`3oo`05o`030?oo00?o00<0ool0
1?l00`3oo`03o`030?oo00Co00<0ool00ol00`3oo`06o`050?ooo`001ol00`3oo`02o`030?oo00Go
00<0ool00_l00`3oo`05o`030?oo00;o00<0ool01Ol00`3oo`02o`030?oo00Go00<0ool00_l00`3o
o`05o`030?oo00;o00<0ool01Ol00`3oo`0bo`008?l20003o`3o00Ko00<0ool01?l00`3oo`03o`03
0?oo00Co00<0ool00ol00`3oo`04o`030?oo00;o00<0ool01Ol00`3oo`02o`030?oo00Go00<0ool0
0_l00`3oo`05o`030?oo00?o00<0ool01?l00`3oo`03o`030?oo00Co00<0ool00ol00`3oo`06o`05
0?ooo`001ol00`3oo`02o`030?oo00Go00<0ool00_l00`3oo`05o`030?oo00;o00<0ool01Ol01@3o
ool000So00<0ool00_l00`3oo`05o`030?oo00;o00<0ool01Ol00`3oo`0bo`008?l0103oo`07o`03
0?oo00Co00<0ool00ol00`3oo`04o`030?oo00?o00<0ool01?l00`3oo`02o`030?oo00Go00<0ool0
0_l00`3oo`05o`030?oo00;o00<0ool01Ol00`3oo`02o`030?oo00Go00<0ool00ol00`3oo`04o`03
0?oo00?o00<0ool01_l01@3oool000So00D0oooo0007o`030?oo00;o00<0ool01Ol00`3oo`02o`03
0?oo00Go00D0oooo0008o`050?ooo`002?l00`3oo`02o`030?oo00Go00<0ool0<_l0023o00@0ool0
1ol00`3oo`04o`030?oo00?o00<0ool01?l00`3oo`03o`030?oo00Co00<0ool00_l00`3oo`05o`03
0?oo00;o00<0ool01Ol00`3oo`02o`030?oo00Go00<0ool00_l00`3oo`05o`030?oo00;o00<0ool0
1Ol00`3oo`03o`030?oo00Ko00D0oooo0008o`050?ooo`002?l0103oo`08o`030?oo00;o00<0ool0
1Ol01@3oool000So00D0oooo0008o`050?ooo`002?l00`3oo`0bo`008?l0103oo`06o`030?oo00Go
00<0ool00ol00`3oo`04o`030?oo00?o00<0ool01?l00`3oo`02o`030?oo00Go00<0ool00_l00`3o
o`05o`030?oo00;o00<0ool01Ol00`3oo`02o`030?oo00Go00<0ool00_l00`3oo`05o`030?oo00?o
00<0ool01_l01@3oool000So00D0oooo0008o`040?oo00Wo00@0ool02?l01@3oool000So00D0oooo
0008o`050?ooo`002?l00`3oo`0bo`008?l0103oo`06o`030?oo00Go00<0ool00_l00`3oo`05o`03
0?oo00;o00<0ool01Ol00`3oo`02o`030?oo00Go00<0ool00_l00`3oo`05o`030?oo00;o00<0ool0
1Ol00`3oo`02o`030?oo00Go00<0ool00_l00`3oo`05o`030?oo00;o00<0ool01ol01@3oool000So
00D0oooo0008o`040?oo00Wo00@0ool02Ol0103oo`08o`050?ooo`002?l01@3oool000So00<0ool0
<_l0023o0P000ol0o`05o`030?oo00Go00<0ool00_l00`3oo`05o`030?oo00;o00<0ool01Ol00`3o
o`02o`030?oo00Go00<0ool00_l00`3oo`05o`030?oo00;o00<0ool01Ol00`3oo`02o`030?oo00Go
00<0ool00_l00`3oo`05o`030?oo00;o00<0ool01ol0103oo`09o`050?ooo`002?l0103oo`09o`04
0?oo00Wo00@0ool02Ol0103oo`08o`050?ooo`002?l00`3oo`0bo`008?l0103oo`06o`030?oo00Go
00<0ool00_l00`3oo`05o`030?oo00;o00<0ool01Ol00`3oo`02o`030?oo00Go00<0ool00_l00`3o
o`05o`030?oo00;o00<0ool01Ol00`3oo`02o`030?oo00Go00<0ool00_l00`3oo`05o`030?oo00;o
00<0ool01ol0103oo`09o`040?oo00Wo00@0ool02Ol0103oo`09o`040?oo00Wo00@0ool02Ol0103o
o`08o`030?oo03;o000Po`040?oo00Ko00<0ool01Ol00`3oo`02o`030?oo00Go00<0ool00_l00`3o
o`05o`050?ooo`002?l00`3oo`02o`030?oo00Go00<0ool00_l00`3oo`05o`030?oo00;o00<0ool0
1Ol00`3oo`02o`030?oo00Go00<0ool00_l00`3oo`07o`040?oo00Wo00@0ool02Ol0103oo`09o`04
0?oo00Wo00@0ool02Ol0103oo`09o`040?oo00Wo00<0ool0<Ol0023o00@0ool01_l00`3oo`06o`05
0?ooo`001ol00`3oo`02o`030?oo00Go00D0oooo0008o`050?ooo`002?l00`3oo`02o`030?oo00Go
00<0ool00_l00`3oo`05o`030?oo00;o00<0ool01Ol00`3oo`02o`030?oo00Oo00@0ool02Ol0103o
o`09o`040?oo00Wo00@0ool02Ol0103oo`09o`040?oo00Wo00@0ool02Ol00`3oo`0ao`008?l20003
o`3o00Go00<0ool01_l01@3oool000Oo00<0ool00_l00`3oo`05o`050?ooo`002?l01@3oool000So
00<0ool00_l00`3oo`05o`030?oo00;o00<0ool01Ol00`3oo`02o`030?oo00Go00<0ool00_l00`3o
o`08o`030?l000Wo00@0ool02Ol00`3o000:o`040?oo00Wo00@0ool02Ol0103oo`09o`040?oo00Wo
00<0ool0<Ol0023o00@0ool01_l00`3oo`06o`050?ooo`002?l0103oo`08o`050?ooo`002?l01@3o
ool000So00D0oooo0008o`030?oo00;o00<0ool01Ol00`3oo`02o`030?oo00Go00<0ool00_l00`3o
o`08o`030?l000Wo00@0ool02Ol00`3o000:o`040?oo00Wo00<0o`002_l0103oo`09o`040?oo00Wo
00<0ool0<Ol0023o00D0oooo0005o`030?oo00Ko00D0oooo0008o`040?oo00Wo00@0ool02?l01@3o
ool000So00D0oooo0008o`050?ooo`002?l00`3oo`02o`030?oo00Go00<0ool00_l00`3oo`08o`03
0?l000Wo00@0ool02Ol00`3o000:o`030?l000[o00<0o`002_l00`3o000:o`040?oo00Wo00<0ool0
<Ol0023o00D0oooo0005o`030?oo00Ko00D0oooo0008o`040?oo00Wo00@0ool02Ol0103oo`08o`05
0?ooo`002?l01@3oool000So00D0oooo0008o`030?oo00;o00<0ool02?l00`3o0009o`040?oo00Wo
00<0o`002_l00`3o000:o`030?l000[o00<0o`002_l00`3o000:o`030?oo037o000Po`800_l00`3o
o`02o`030?oo00Oo00D0oooo0008o`040?oo00Wo00@0ool02Ol0103oo`09o`040?oo00So00D0oooo
0008o`050?ooo`002?l00`3oo`02o`030?oo00So00<0o`002Ol0103oo`09o`030?l000[o00<0o`00
2_l00`3o000:o`030?l000[o00<0o`002_l00`3oo`0ao`008?l01@3oool000Co00<0ool01ol0103o
o`09o`040?oo00Wo00@0ool02Ol0103oo`09o`040?oo00So00D0oooo0008o`050?ooo`002?l01@3o
ool000_o00<0o`002Ol00`3o000:o`030?l000[o00<0o`002_l00`3o000:o`030?l000[o00<0o`00
2_l00`3oo`0ao`006_l00`3oo`03o`050?ooo`001?l00`3oo`07o`040?oo00Wo00@0ool02Ol0103o
o`09o`040?oo00Wo00@0ool02Ol0103oo`08o`050?ooo`002?l01@3oool000_o0P0:o`030?l000[o
00<0o`002_l00`3o000:o`030?l000[o00<0o`002_l00`3o000:o`030?oo037o000Io`030?l000Co
00D0oooo0004o`030?oo00Oo00@0ool02Ol0103oo`09o`040?oo00Wo00@0ool02Ol0103oo`09o`04
0?oo00Wo00@0ool02?l01@3oool000_o0P0:o`030?l000[o00<0o`002_l00`3o000:o`030?l000[o
00<0o`002_l00`3o000:o`030?oo037o000Ko`030?oo00;o0P02o`030?oo00;o00<0ool01ol0103o
o`09o`030?l000[o00<0o`002_l0103oo`09o`040?oo00Wo00@0ool02Ol0103oo`08o`050?ooo`00
2ol200[o00<0o`002_l200_o00<0o`002_l00`3o000:o`030?l000[o00<0o`002_l00`3oo`0ao`00
6Ol200Go00D0oooo0004o`030?oo00Oo00@0ool02Ol00`3o000:o`030?l000[o00<0o`002_l0103o
o`09o`040?oo00Wo00@0ool02?l01@3oool000_o0P0:o`030?l000[o0P0;o`030?l000[o00<0o`00
2_l00`3o000:o`030?l000[o00<0ool0<Ol001Wo00<0ool01?l01@3oool000Co00<0ool01ol0103o
o`09o`030?l000[o00<0o`002_l00`3o000:o`040?oo00Wo00@0ool02Ol0103oo`08o`050?ooo`00
2ol200[o00<0o`002_l200_o0P0;o`030?l000[o00<0o`002_l00`3o000:o`030?oo037o000Io`<0
1?l01@3oool000Co00<0ool01ol0103oo`09o`030?l000[o00<0o`002_l00`3o000:o`030?l000[o
00@0ool02Ol0103oo`08o`050?ooo`002ol200[o0P0;o`802ol200_o0P0;o`030?l000[o00<0o`00
2_l00`3oo`0ao`008?l01@3oool000Co00<0ool01ol0103oo`09o`030?l000[o00<0o`002_l00`3o
000:o`030?l000[o00<0o`002_l0103oo`08o`050?ooo`002ol200[o0P0;o`802ol200_o0P0;o`80
2ol00`3o000:o`030?oo037o000Po`800_l00`3oo`02o`030?oo00Oo00<0o`002_l00`3o000:o`03
0?l000[o00<0o`002_l00`3o000:o`030?l000[o00<0o`002Ol01@3oool000_o0P0:o`802ol200_o
0P0;o`802ol200_o0P0;o`030?oo037o000Po`050?ooo`000ol00`3oo`08o`030?l000[o00<0o`00
2_l00`3o000:o`030?l000[o00<0o`002_l00`3o000:o`030?l000Wo00@0ool03?l200[o0P0;o`80
2ol200_o0P0;o`802ol200_o00<0ool0<Ol0023o00D0oooo0003o`030?oo00So00<0o`002_l00`3o
000:o`030?l000[o00<0o`002_l00`3o000:o`030?l000[o00<0o`002Ol0103oo`0<o`030?oo00Wo
0P0;o`802ol200_o0P0;o`802ol200_o00<0ool0<Ol0023o00D0oooo0003o`030?oo00So00<0o`00
2_l200_o00<0o`002_l00`3o000:o`030?l000[o00<0o`002_l00`3o0009o`040?oo00co00<0ool0
2Ol200_o0P0;o`802ol200_o0P0;o`802ol00`3oo`0ao`008?l200;o00D0oooo000:o`030?l000[o
0P0;o`802ol00`3o000:o`030?l000[o00<0o`002_l00`3o000:o`030?l000co00<0ool02Ol00`3o
o`0:o`030?oo00[o0P0;o`802ol200_o0P0;o`030?oo037o000Po`050?ooo`000ol00`3oo`08o`03
0?l000[o0P0;o`802ol200_o00<0o`002_l00`3o000:o`030?l000[o00<0o`003?l00`3oo`09o`03
0?oo00[o00<0ool02_l00`3oo`0:o`802ol200_o0P0;o`030?oo037o000Po`050?ooo`000ol00`3o
o`08o`802ol200_o0P0;o`802ol200_o00<0o`002_l00`3o000:o`030?l000co00<0ool02Ol00`3o
o`0:o`030?oo00[o00<0ool02_l00`3oo`0:o`802ol200_o00<0ool0<Ol0023o00D0oooo0003o`03
0?oo00So0P0;o`802ol200_o0P0;o`802ol00`3o000:o`030?l000[o00<0o`006?l00`3oo`0:o`03
0?oo00[o00<0ool02_l00`3oo`0:o`030?oo00[o0P0;o`030?oo037o000Po`800_l01@3oool000[o
0P0;o`802ol200_o0P0;o`802ol200_o00<0o`002_l00`3o000Uo`030?oo00[o00<0ool02_l00`3o
o`0:o`030?oo00[o00<0ool02_l00`3oo`0ao`008?l01@3oool000;o00<0ool02Ol200_o0P0;o`80
2ol200_o0P0;o`802ol200_o00<0o`00<_l00`3oo`0:o`030?oo00[o00<0ool02_l00`3oo`0:o`03
0?oo037o000Po`050?ooo`000_l00`3oo`09o`802ol200_o0P0;o`802ol200_o0P0;o`802ol2043o
00<0ool02_l00`3oo`0:o`030?oo00[o00<0ool0<Ol0023o00D0oooo0002o`030?oo00Wo0P0;o`03
0?oo00[o0P0;o`802ol200_o0P0;o`802ol204go00<0ool02_l00`3oo`0:o`030?oo037o000Po`80
0_l0103oo`0;o`030?oo00[o00<0ool02_l00`3oo`0:o`802ol200_o0P0;o`802ol205[o00<0ool0
2_l00`3oo`0ao`008?l01@3oool000;o00<0ool02Ol00`3oo`0:o`030?oo00[o00<0ool02_l00`3o
o`0:o`802ol200_o0P0;o`80Iol00`3oo`0ao`008?l01@3oool000;o00<0ool02Ol00`3oo`0:o`03
0?oo00[o00<0ool02_l00`3oo`0:o`030?oo00[o0P0;o`802ol209_o000Io`801Ol01`3oool0o`00
6Ol00`3oo`0:o`030?oo00[o00<0ool02_l00`3oo`0:o`802ol200_o0P2Ko`006Ol00`3o0004o`07
0?ooo`3o000Vo`030?oo00[o00<0ool02_l00`3oo`0:o`030?oo00[o0P0;o`80Vol001Wo00<0o`00
1?l200;o00<0o`00<ol00`3oo`0:o`030?oo00[o00<0ool02_l00`3oo`0:o`80Vol001Wo0P05o`04
0?ooo`80@Ol00`3oo`0:o`030?oo00[o00<0ool02_l00`3oo`2Jo`006Ol00`3oo`04o`040?ooo`80
C_l00`3oo`0:o`030?oo00[o00<0ool0V_l001[o0P04o`040?ooo`80C_l00`3oo`0:o`030?oo00[o
00<0ool0V_l0023o0P02o`030?oo05[o00<0ool02_l00`3oo`2Jo`008?l01@3oool006Wo00<0ool0
V_l0023o00<0ool0ool9o`008?l00`3oo`3oo`Wo000Po`80ool:o`00ool/o`00ool/o`00ool/o`00
ool/o`00ool/o`00ool/o`00ool/o`00O?l20:go001no`030?oo013o0P07o`801ol208Ko001`o`80
00?o00000P02o`030?oo00<000Co00000ol200So0P02o`<00ol00`3oo`0500;o00<0ool0Q?l0073o
00L0oooo0?l000;o00<0o`000_l0103oo`03o`030?oo00Oo00@0ool00_l00`3oo`02o`030?oo00;o
00<0ool00_l00`3oo`24o`00LOl300;o00H0ool0o`02o`040?oo00?o0`07o`040?oo00;o00<0ool0
0_l00`3oo`02o`030?oo00;o00<0ool0Q?l0077o00@0o`3o1003o`<00_l0103oool300Oo00@0ool0
0_l00`3oo`02o`030?oo00;o00<0ool00_l00`3oo`24o`00L_l00`3oo`0<o`030?oo00_o00@0ool0
0_l00`3oo`02o`030?oo00;o00<0ool00_l00`3oo`24o`00LOl200go0P0>o`800_l200Co0P02o`80
0ol208Ko003oobco003oobco003oobco003oobco003oobco003oobco000Io`<000?o0?l01002o`<0
ool4o`006_l01@3oo`3o00<00_l0103oo`3oo`Co000Jo`<01?l0103oo`02o`030?oo0?oo0_l001[o
00@0ool00_l200?o0`3oo`Co000Jo`040?oo00Wo00<0ool0ool2o`006Ol400Wo0P3oo`Co003oobco
003oobco003oobco0000\
\>"],
  ImageRangeCache->{{{0, 298}, {184, 0}} -> {-15.1683, -0.849703, 0.465795, 
  0.0472068}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00952381 0.0147151 0.0941835 [
[(20)] .21429 .01472 0 2 Msboxa
[(40)] .40476 .01472 0 2 Msboxa
[(60)] .59524 .01472 0 2 Msboxa
[(80)] .78571 .01472 0 2 Msboxa
[(100)] .97619 .01472 0 2 Msboxa
[(No.)] 1.025 .01472 -1 0 Msboxa
[(Angle Ql[2])] .5 .61803 0 -2 0 0 1 Mouter Mrotsboxa
[(1)] .01131 .1089 1 0 Msboxa
[(2)] .01131 .20308 1 0 Msboxa
[(3)] .01131 .29727 1 0 Msboxa
[(4)] .01131 .39145 1 0 Msboxa
[(5)] .01131 .48563 1 0 Msboxa
[(6)] .01131 .57982 1 0 Msboxa
[(Rad)] .02381 .61803 0 -4 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 .61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.21429 .01472 m
.21429 .02097 L
s
P
[(20)] .21429 .01472 0 2 Mshowa
p
.002 w
.40476 .01472 m
.40476 .02097 L
s
P
[(40)] .40476 .01472 0 2 Mshowa
p
.002 w
.59524 .01472 m
.59524 .02097 L
s
P
[(60)] .59524 .01472 0 2 Mshowa
p
.002 w
.78571 .01472 m
.78571 .02097 L
s
P
[(80)] .78571 .01472 0 2 Mshowa
p
.002 w
.97619 .01472 m
.97619 .02097 L
s
P
[(100)] .97619 .01472 0 2 Mshowa
p
.001 w
.0619 .01472 m
.0619 .01847 L
s
P
p
.001 w
.1 .01472 m
.1 .01847 L
s
P
p
.001 w
.1381 .01472 m
.1381 .01847 L
s
P
p
.001 w
.17619 .01472 m
.17619 .01847 L
s
P
p
.001 w
.25238 .01472 m
.25238 .01847 L
s
P
p
.001 w
.29048 .01472 m
.29048 .01847 L
s
P
p
.001 w
.32857 .01472 m
.32857 .01847 L
s
P
p
.001 w
.36667 .01472 m
.36667 .01847 L
s
P
p
.001 w
.44286 .01472 m
.44286 .01847 L
s
P
p
.001 w
.48095 .01472 m
.48095 .01847 L
s
P
p
.001 w
.51905 .01472 m
.51905 .01847 L
s
P
p
.001 w
.55714 .01472 m
.55714 .01847 L
s
P
p
.001 w
.63333 .01472 m
.63333 .01847 L
s
P
p
.001 w
.67143 .01472 m
.67143 .01847 L
s
P
p
.001 w
.70952 .01472 m
.70952 .01847 L
s
P
p
.001 w
.74762 .01472 m
.74762 .01847 L
s
P
p
.001 w
.82381 .01472 m
.82381 .01847 L
s
P
p
.001 w
.8619 .01472 m
.8619 .01847 L
s
P
p
.001 w
.9 .01472 m
.9 .01847 L
s
P
p
.001 w
.9381 .01472 m
.9381 .01847 L
s
P
[(No.)] 1.025 .01472 -1 0 Mshowa
p
.002 w
0 .01472 m
1 .01472 L
s
P
[(Angle Ql[2])] .5 .61803 0 -2 0 0 1 Mouter Mrotshowa
p
.002 w
.02381 .1089 m
.03006 .1089 L
s
P
[(1)] .01131 .1089 1 0 Mshowa
p
.002 w
.02381 .20308 m
.03006 .20308 L
s
P
[(2)] .01131 .20308 1 0 Mshowa
p
.002 w
.02381 .29727 m
.03006 .29727 L
s
P
[(3)] .01131 .29727 1 0 Mshowa
p
.002 w
.02381 .39145 m
.03006 .39145 L
s
P
[(4)] .01131 .39145 1 0 Mshowa
p
.002 w
.02381 .48563 m
.03006 .48563 L
s
P
[(5)] .01131 .48563 1 0 Mshowa
p
.002 w
.02381 .57982 m
.03006 .57982 L
s
P
[(6)] .01131 .57982 1 0 Mshowa
p
.001 w
.02381 .03355 m
.02756 .03355 L
s
P
p
.001 w
.02381 .05239 m
.02756 .05239 L
s
P
p
.001 w
.02381 .07123 m
.02756 .07123 L
s
P
p
.001 w
.02381 .09006 m
.02756 .09006 L
s
P
p
.001 w
.02381 .12774 m
.02756 .12774 L
s
P
p
.001 w
.02381 .14657 m
.02756 .14657 L
s
P
p
.001 w
.02381 .16541 m
.02756 .16541 L
s
P
p
.001 w
.02381 .18425 m
.02756 .18425 L
s
P
p
.001 w
.02381 .22192 m
.02756 .22192 L
s
P
p
.001 w
.02381 .24076 m
.02756 .24076 L
s
P
p
.001 w
.02381 .25959 m
.02756 .25959 L
s
P
p
.001 w
.02381 .27843 m
.02756 .27843 L
s
P
p
.001 w
.02381 .3161 m
.02756 .3161 L
s
P
p
.001 w
.02381 .33494 m
.02756 .33494 L
s
P
p
.001 w
.02381 .35378 m
.02756 .35378 L
s
P
p
.001 w
.02381 .37261 m
.02756 .37261 L
s
P
p
.001 w
.02381 .41029 m
.02756 .41029 L
s
P
p
.001 w
.02381 .42912 m
.02756 .42912 L
s
P
p
.001 w
.02381 .44796 m
.02756 .44796 L
s
P
p
.001 w
.02381 .4668 m
.02756 .4668 L
s
P
p
.001 w
.02381 .50447 m
.02756 .50447 L
s
P
p
.001 w
.02381 .52331 m
.02756 .52331 L
s
P
p
.001 w
.02381 .54214 m
.02756 .54214 L
s
P
p
.001 w
.02381 .56098 m
.02756 .56098 L
s
P
p
.001 w
.02381 .59865 m
.02756 .59865 L
s
P
p
.001 w
.02381 .61749 m
.02756 .61749 L
s
P
[(Rad)] .02381 .61803 0 -4 Mshowa
p
.002 w
.02381 0 m
.02381 .61803 L
s
P
P
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.004 w
.03333 .01472 m
.04286 .10483 L
.05238 .1947 L
.0619 .28539 L
.07143 .38568 L
.08095 .49218 L
.09048 .58263 L
.1 .08746 L
.10952 .18979 L
.11905 .27931 L
.12857 .3789 L
.1381 .4858 L
.14762 .57716 L
.15714 .08075 L
.16667 .18386 L
.17619 .27348 L
.18571 .37216 L
.19524 .47933 L
.20476 .57171 L
.21429 .07408 L
.22381 .17782 L
.23333 .26769 L
.24286 .36546 L
.25238 .47276 L
.2619 .56625 L
.27143 .06745 L
.28095 .17168 L
.29048 .26194 L
.3 .3588 L
.30952 .4661 L
.31905 .56077 L
.32857 .06087 L
.3381 .16542 L
.34762 .25622 L
.35714 .35218 L
.36667 .45936 L
.37619 .55526 L
.38571 .05436 L
.39524 .15906 L
.40476 .25052 L
.41429 .34561 L
.42381 .45255 L
.43333 .5497 L
.44286 .04793 L
.45238 .1526 L
.4619 .24486 L
.47143 .33909 L
.48095 .44568 L
.49048 .54409 L
.5 .04159 L
Mistroke
.50952 .14604 L
.51905 .23922 L
.52857 .33263 L
.5381 .43878 L
.54762 .53841 L
.55714 .03535 L
.56667 .13942 L
.57619 .23359 L
.58571 .32624 L
.59524 .43185 L
.60476 .53267 L
.61429 .02923 L
.62381 .13273 L
.63333 .22798 L
.64286 .31991 L
.65238 .42491 L
.6619 .52686 L
.67143 .02322 L
.68095 .126 L
.69048 .22236 L
.7 .31366 L
.70952 .41797 L
.71905 .52098 L
.72857 .01733 L
.7381 .11925 L
.74762 .21675 L
.75714 .30748 L
.76667 .41105 L
.77619 .51501 L
.78571 .60332 L
.79524 .11248 L
.80476 .2111 L
.81429 .30137 L
.82381 .40416 L
.83333 .50897 L
.84286 .59763 L
.85238 .10571 L
.8619 .20543 L
.87143 .29533 L
.88095 .39729 L
.89048 .50284 L
.9 .59203 L
.90952 .09894 L
.91905 .1997 L
.92857 .28936 L
.9381 .39046 L
.94762 .49662 L
.95714 .58649 L
.96667 .09219 L
.97619 .19391 L
Mistroke
Mfstroke
% End of Graphics
MathPictureEnd\
\>"], "Graphics",
  PageWidth->Infinity,
  Evaluatable->False,
  ImageSize->{299, 185},
  ImageMargins->{{100, Inherited}, {Inherited, 0}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004[0000^@P10`40000100000800002008200000
P800P020P<30`<3L`:K:l:C8l3<006H009T00<`0000c03<c06Hc09Tc0<`c0?lc001V03=V06IV09UV
0<aV0?mV002I03>I06JI09VI0<bI0?nI003<03?<06K<09W<0<c<0?o<03?o06Ko09Wo0<co0000<c<0
<fH0<iT0<l`0<ol0<`0c<c<c<fHc<iTc<l`c<olc<`1V<c=V<fIV<iUV<laV<omV<`2I<c>I<fJI<iVI
<lbI<onI<`3<<c?<<fK<<iW<<lc<<oo<<`3o<c?o<fKo<iWo<lco<ooo<`00IS<0IVH0IYT0I/`0I_l0
IP0cIS<cIVHcIYTcI/`cI_lcIP1VIS=VIVIVIYUVI/aVI_mVIP2IIS>IIVJIIYVII/bII_nIIP3<IS?<
IVK<IYW<I/c<I_o<IP3oIS?oIVKoIYWoI/coI_ooIP00VC<0VFH0VIT0VL`0VOl0V@0cVC<cVFHcVITc
VL`cVOlcV@1VVC=VVFIVVIUVVLaVVOmVV@2IVC>IVFJIVIVIVLbIVOnIV@3<VC?<VFK<VIW<VLc<VOo<
V@3oVC?oVFKoVIWoVLcoVOooV@00c3<0c6H0c9T0c<`0c?l0c00cc3<cc6Hcc9Tcc<`cc?lcc01Vc3=V
c6IVc9UVc<aVc?mVc02Ic3>Ic6JIc9VIc<bIc?nIc03<c3?<c6K<c9W<c<c<c?o<c03oc3?oc6Koc9Wo
c<coc?ooc3<0ofH0oiT0ol`0o`0coc<cofHcoiTcol`coolco`1Voc=VofIVoiUVolaVoomVo`2Ioc>I
ofJIoiVIolbIoonIo`3<oc?<ofK<oiW<olc<ooo<oc?oofKooiWoolcoo`410@820P<30`@410D51@H6
1PL71`P820T92@X:2P/;2``<30h>3Pl?3a0@414A4A8B4Q<C4a@D5000000000000000000000000000
00000?okl:2PY820P?l0003o0?oo0000ool0o`3ooooooooo;?l00?oo;?l00?oo;?l00?oo;?l004Oo
0`03o`030?oo02?o0`02o`030?oo02;o0P04o`030?oo02?o00<0ool00_l00`3oo`0No`D00_l00`3o
o`02o`030?oo02go0017o`030?oo00;o00<0o`009Ol01P3oo`3o02?o00<0o`000_l00`3o000So`03
0?l000;o00<0o`008Ol01`3oool0o`000_l00`3o000^o`00B?l01`3oool0o`008ol40004o`3o02?o
00<0o`000_l00`3o000So`030?l000;o00<0o`008Ol01`3oool0o`000_l00`3o000^o`00B?l01`3o
ool0o`008ol00`3o0002o`030?l002?o0P03o`030?l002Co00L0oooo0?l0027o00L0oooo0?l000;o
00<0o`00;_l004Oo00<0o`000_l00`3o000To`800_l00`3o000So`030?oo00;o00<0o`008ol00`3o
0002o`030?l0027o00L0oooo0?l000;o00<0o`00;_l004So00<0ool00_l00`3oo`0To`050?ooo`00
9Ol200?o00<0ool08ol00`3oo`02o`030?oo01oo0P04o`030?oo00;o00<0ool0;Ol00?oo;?l00?oo
;?l00?oo;?l00?oo;?l00?oo;?l0023o00<0ool0ool9o`008?l00`3oo`3Oo`<000Co0?oo0P03o`03
0?oo01[o000Po`030?oo0>3o00H0o`00o`02o`030?oo01go000Kon801_l01P3o003o00;o00<0ool0
7Ol0023o00<0o`001_l00`3oo`05o`030?oo00Ko00<0ool01Ol00`3oo`06o`030?oo00Ko00<0ool0
1Ol00`3oo`06o`030?oo00Go00<0ool01_l00`3oo`06o`030?oo00Go00<0ool01_l00`3oo`05o`03
0?oo00Ko00<0ool01Ol00`3oo`06o`030?oo00Ko00D0oooo0003o`030?oo00Ko00<0ool01Ol00`3o
o`06o`030?oo00Ko00<0ool01Ol00`3oo`06o`030?oo00Wo0P001?l0ool2023o000Po`030?l002So
00<0ool0:?l00`3oo`0Xo`030?oo00ko00<0ool02_l00`3oo`0:o`030?oo02So00<0ool02Ol20003
o`3o02?o000Po`030?l008oo00<0ool02_l00`3oo`10o`8000?o00009?l0023o00<0o`00P_l00`3o
o`0:o`030?oo00[o00<0ool0JOl0023o0`1eo`030?oo00[o00<0ool02_l00`3oo`0:o`030?oo06Wo
000Po`040?oo07Co00<0ool02_l00`3oo`0:o`030?oo00[o00<0ool0JOl0023o00@0ool0Iol00`3o
o`0:o`030?oo00[o00<0ool02_l00`3oo`0:o`80J_l0023o00@0ool0Fol00`3oo`09o`030?oo00[o
00<0ool02_l00`3oo`0:o`802ol206[o000Po`8000?o0?l0COl00`3oo`0:o`030?oo00Wo00<0ool0
2_l00`3oo`0:o`030?oo00[o0P0;o`80J_l0023o00@0ool0C_l00`3oo`0:o`030?oo00Wo00<0ool0
2_l00`3oo`0:o`802ol200_o0P1Zo`008?l0103oo`11o`030?oo00[o00<0ool02_l00`3oo`09o`80
2ol200_o0P0;o`802ol206[o000Po`040?oo03Co00<0ool02_l00`3oo`0:o`030?oo00[o00<0ool0
2Ol200_o0P0;o`802ol200_o0P1Zo`008?l20003o`3o03?o00<0ool02_l00`3oo`0:o`030?oo00[o
00<0ool02Ol200_o0P0;o`802ol200_o0P1Zo`008?l0103oo`0Wo`030?oo00[o00<0ool02_l00`3o
o`0:o`030?oo00[o0P0:o`802ol200_o0P0;o`802ol206[o000Po`040?oo01[o00<0ool02_l00`3o
o`0:o`030?oo00[o00<0ool02_l200_o0P0:o`802ol200_o0P0;o`802ol206[o000Po`050?ooo`00
6Ol00`3oo`0:o`030?oo00[o00<0ool02_l00`3oo`0:o`802ol200[o0P0;o`802ol200_o0P0;o`80
J_l0023o0P02o`030?oo00[o00<0ool02_l00`3oo`0:o`030?oo00[o00<0ool02_l200_o0P0;o`80
2_l200_o0P0;o`802ol200_o0P1Zo`008?l01@3oool000co00<0ool02_l00`3oo`0:o`030?oo00[o
0P0;o`802ol200_o0P0:o`802ol200_o0P0;o`802ol203Co00<0ool0<ol0023o00D0oooo000<o`03
0?oo00[o00<0ool02_l00`3oo`0:o`802ol200_o0P0;o`802_l00`3o000:o`802ol200_o0P0;o`03
0?l002Ko00<0ool02_l00`3oo`0co`006?l500?o00D0oooo000<o`030?oo00[o00<0ool02_l200_o
0P0;o`802ol200_o0P0:o`030?l000[o0P0;o`802ol00`3o000:o`030?l002Ko00<0ool02_l00`3o
o`0co`006_l00`3oo`03o`050?ooo`003?l00`3oo`0:o`802ol200_o0P0;o`802ol200_o0P0:o`03
0?l000[o0P0;o`802ol00`3o000:o`030?l001Wo00<0ool02_l00`3oo`0:o`030?oo03?o000Jo`03
0?oo00?o0P02o`030?oo00[o00<0ool02_l200_o0P0;o`802ol200_o0P0;o`802_l00`3o000:o`80
2ol00`3o000:o`030?l000[o00<0o`006Ol00`3oo`0:o`030?oo00[o00<0ool0<ol001[o00<0ool0
0ol01@3oool000co0P0;o`802ol200_o0P0;o`802ol200_o0P0:o`030?l000[o00<0o`002_l00`3o
000:o`030?l000[o00<0o`003?l00`3oo`0:o`030?oo00[o00<0ool02_l00`3oo`0co`006_l00`3o
o`03o`050?ooo`003?l200_o0P0;o`802ol200_o0P0;o`802ol200[o00<0o`002_l00`3o000:o`03
0?l000[o00<0o`002_l00`3o000<o`030?oo00[o00<0ool02_l00`3oo`0:o`80=?l001Wo0P05o`03
0?oo00;o00<0ool02Ol200_o0P0;o`802ol200_o0P0;o`802ol200[o00<0o`002_l00`3o000:o`03
0?l000[o00<0o`002_l00`3o000<o`030?oo00[o00<0ool02_l200_o0P0do`008?l200?o00<0ool0
2Ol200_o0P0;o`802ol200_o0P0;o`802ol00`3o0009o`030?l000[o00<0o`002_l00`3o000:o`03
0?l000[o00<0o`003?l00`3oo`0:o`030?oo00[o0P0;o`80=?l0023o00<0ool00_l00`3oo`09o`80
2ol200_o0P0;o`802ol200_o00<0o`002Ol0103oo`09o`040?oo00Wo00<0o`002_l00`3o000:o`03
0?l000[o00<0o`003?l00`3oo`0:o`802ol200_o0P0do`008?l00`3oo`02o`030?oo00Wo0P0;o`80
2ol200_o0P0;o`802ol00`3o0009o`040?oo00Wo00@0ool02Ol00`3o000:o`030?l000[o00<0o`00
2_l00`3o000<o`030?oo00[o0P0;o`802ol203Co000Po`030?oo00;o00<0ool02Ol200_o0P0;o`80
2ol200_o00<0o`002_l00`3o0009o`040?oo00Wo00@0ool02Ol00`3o000:o`030?l000[o00<0o`00
2_l00`3o000<o`802ol200_o0P0;o`80=?l0023o0P03o`030?oo00Wo0P0;o`802ol200_o00<0o`00
2_l00`3o000:o`030?l000Wo00@0ool02Ol0103oo`09o`030?l000[o00<0o`002_l00`3o0009o`05
0?ooo`002ol200_o0P0;o`802ol203Co000Po`030?oo00?o00<0ool02?l200_o0P0;o`802ol00`3o
000:o`030?l000[o00<0o`002Ol0103oo`09o`040?oo00Wo00<0o`002_l00`3o0009o`040?oo00Wo
00D0oooo000;o`802ol200_o0P0;o`80=?l0023o00<0ool00ol00`3oo`08o`802ol200_o00<0o`00
2_l00`3o000:o`030?l000[o00<0o`002Ol0103oo`09o`040?oo00Wo00<0o`002_l00`3o0009o`05
0?ooo`002?l01@3oool000_o0P0;o`802ol200_o0P0do`008?l00`3oo`03o`030?oo00So0P0;o`03
0?l000[o00<0o`002_l00`3o000:o`030?l000[o00<0o`002Ol0103oo`09o`040?oo00Wo00@0ool0
2?l01@3oool000So00D0oooo0008o`050?ooo`002ol200_o0P0;o`802ol203Co000Po`801?l00`3o
o`08o`802ol00`3o000:o`030?l000[o00<0o`002_l00`3o000:o`030?l000Wo00@0ool02Ol0103o
o`08o`050?ooo`002?l01@3oool000So00D0oooo0008o`050?ooo`002ol200_o0P0;o`802ol203Co
000Po`030?oo00?o00<0ool02?l00`3o000:o`030?l000[o00<0o`002_l00`3o000:o`030?l000[o
00<0o`002Ol0103oo`09o`040?oo00So00D0oooo0008o`050?ooo`002?l01@3oool000So00D0oooo
000;o`802ol200_o0P0;o`80=?l0023o00<0ool00ol00`3oo`08o`030?l000[o00<0o`002_l00`3o
000:o`030?l000[o00<0o`002_l00`3o0009o`040?oo00So00<0ool00_l00`3oo`05o`050?ooo`00
2?l01@3oool000So00D0oooo0008o`050?ooo`002ol200_o0P0;o`802ol00`3o000co`008?l00`3o
o`03o`030?oo00So00<0o`002_l00`3o000:o`030?l000[o00<0o`002_l00`3o000:o`030?l000Wo
00D0oooo0007o`030?oo00;o00<0ool01Ol01@3oool000So00D0oooo0008o`050?ooo`002?l01@3o
ool000_o0P0;o`802ol00`3o0009o`040?oo03?o000Po`030?oo00Co00<0ool01ol00`3o000:o`03
0?l000[o00<0o`002_l00`3o000:o`030?l000Wo00@0ool02Ol01@3oool000Oo00<0ool00_l00`3o
o`05o`050?ooo`002?l01@3oool000So00D0oooo0008o`050?ooo`002ol200_o00<0o`002_l00`3o
0009o`040?oo03?o000Po`801Ol00`3oo`07o`030?l000[o00<0o`002_l00`3o000:o`030?l000[o
00<0o`002Ol01@3oool000So00D0oooo0007o`030?oo00;o00<0ool01Ol01@3oool000So00D0oooo
0008o`050?ooo`002?l01@3oool000_o0P0;o`030?l000[o00<0o`002Ol0103oo`0co`008?l00`3o
o`04o`030?oo00Oo00<0o`002_l00`3o000:o`030?l000[o00<0o`002Ol01@3oool000So00D0oooo
0008o`050?ooo`001ol00`3oo`02o`030?oo00Go00<0ool00_l00`3oo`05o`050?ooo`002?l01@3o
ool000So00D0oooo000;o`030?l000[o00<0o`002_l00`3o0009o`040?oo03?o000Io`<01?l00`3o
o`04o`030?oo00Oo00<0o`002_l00`3o000:o`030?l000Wo00D0oooo0008o`050?ooo`002?l01@3o
ool000So00D0oooo0007o`030?oo00;o00<0ool01Ol00`3oo`02o`030?oo00Go00D0oooo0008o`05
0?ooo`002?l00`3oo`02o`030?oo00So00<0o`002_l00`3o000:o`030?l000Wo00@0ool0<ol001Wo
00<0ool01?l00`3oo`04o`030?oo00Oo00<0o`002_l00`3o0009o`040?oo00Wo00D0oooo0008o`05
0?ooo`002?l01@3oool000So00D0oooo0007o`030?oo00;o00<0ool01Ol00`3oo`02o`030?oo00Go
00D0oooo0008o`030?oo00;o00<0ool01Ol00`3oo`02o`030?oo00So00<0o`002_l00`3o000:o`03
0?l000Wo00<0ool0=?l001[o00<0ool00ol200Go00<0ool01ol00`3o0009o`040?oo00Wo00D0oooo
0008o`050?ooo`002?l01@3oool000So00D0oooo0008o`050?ooo`001ol00`3oo`02o`030?oo00Go
00<0ool00_l00`3oo`05o`050?ooo`002?l00`3oo`02o`030?oo00Go00<0ool00_l00`3oo`08o`03
0?l000[o00<0o`002_l00`3o0009o`030?oo03Co000Jo`030?oo00?o00<0ool01?l00`3oo`07o`04
0?oo00So00D0oooo0008o`050?ooo`002?l01@3oool000So00D0oooo0008o`050?ooo`002?l01@3o
ool000Oo00<0ool00_l00`3oo`05o`030?oo00;o00<0ool01Ol00`3oo`02o`030?oo00Go00<0ool0
0_l00`3oo`05o`030?oo00;o00<0ool02?l00`3o000:o`030?l000[o00<0o`002Ol00`3oo`0do`00
6Ol00`3o0004o`030?oo00Co00<0ool01_l01@3oool000So00D0oooo0008o`050?ooo`002?l01@3o
ool000So00D0oooo0008o`050?ooo`002?l01@3oool000Oo00<0ool00_l00`3oo`05o`030?oo00;o
00<0ool01Ol00`3oo`02o`030?oo00Go00<0ool00_l00`3oo`05o`030?oo00;o00<0ool02?l00`3o
000:o`030?l000[o00<0o`002Ol00`3oo`0do`006_l00`3oo`03o`030?oo00Co00<0ool01_l01@3o
ool000So00D0oooo0008o`050?ooo`002?l01@3oool000So00D0oooo0008o`050?ooo`002?l01@3o
ool000Oo00<0ool00ol00`3oo`04o`030?oo00;o00<0ool01Ol00`3oo`02o`030?oo00Go00<0ool0
0_l00`3oo`05o`030?oo00;o00<0ool02?l00`3o000:o`030?l000[o00<0o`002Ol00`3oo`0do`00
8?l200Ko00<0ool01Ol01@3oool000So00D0oooo0008o`050?ooo`002?l01@3oool000So00D0oooo
0008o`050?ooo`002?l00`3oo`02o`030?oo00Co00<0ool00ol00`3oo`04o`030?oo00?o00<0ool0
1?l00`3oo`02o`030?oo00Go00<0ool00_l00`3oo`05o`030?oo00;o00<0ool02?l00`3o000:o`03
0?l000Wo00D0oooo0008o`030?oo03Co000Po`030?oo00Go00<0ool01Ol01@3oool000So00D0oooo
0008o`050?ooo`002?l01@3oool000So00D0oooo0008o`050?ooo`002?l00`3oo`02o`030?oo00Co
00<0ool00ol00`3oo`04o`030?oo00?o00<0ool01?l00`3oo`02o`030?oo00Go00<0ool00_l00`3o
o`05o`030?oo00;o00<0ool02?l00`3o000:o`030?l000Wo00D0oooo0008o`030?oo03Co000Po`03
0?oo00Go00<0ool01Ol01@3oool000So00D0oooo0008o`050?ooo`002?l01@3oool000So00D0oooo
0008o`030?oo00;o00<0ool01Ol00`3oo`02o`030?oo00Co00<0ool00ol00`3oo`04o`030?oo00?o
00<0ool01?l00`3oo`02o`030?oo00Go00<0ool00_l00`3oo`05o`030?oo00;o00<0ool02?l00`3o
0009o`050?ooo`002?l01@3oool000So00<0ool0=?l0023o00<0ool01Ol00`3oo`05o`030?oo00;o
00<0ool01Ol01@3oool000So00D0oooo0008o`050?ooo`002?l00`3oo`02o`030?oo00Go00<0ool0
0_l00`3oo`05o`030?oo00;o00<0ool01?l00`3oo`03o`030?oo00Co00<0ool00ol00`3oo`04o`03
0?oo00;o00<0ool01Ol00`3oo`02o`030?oo00Go00<0ool00_l00`3oo`08o`040?oo00So00D0oooo
0008o`050?ooo`002?l00`3oo`0do`008?l200Ko00<0ool01Ol00`3oo`02o`030?oo00Go00D0oooo
0008o`050?ooo`002?l00`3oo`02o`030?oo00Go00<0ool00_l00`3oo`05o`030?oo00;o00<0ool0
1Ol00`3oo`02o`030?oo00Co00<0ool00ol00`3oo`04o`030?oo00?o00<0ool01?l00`3oo`02o`03
0?oo00Go00<0ool00_l00`3oo`05o`030?oo00?o00<0ool01_l01@3oool000So00D0oooo0008o`05
0?ooo`002?l00`3oo`0do`008?l00`3oo`05o`030?oo00Go00<0ool00_l00`3oo`05o`050?ooo`00
2?l01@3oool000So00<0ool00_l00`3oo`05o`030?oo00;o00<0ool01Ol00`3oo`02o`030?oo00Go
00<0ool00_l00`3oo`04o`030?oo00?o00<0ool01?l00`3oo`03o`030?oo00Co00<0ool00_l00`3o
o`05o`030?oo00;o00<0ool01Ol00`3oo`03o`030?oo00Ko00D0oooo0008o`050?ooo`002?l01@3o
ool000So00<0ool0=?l0023o00<0ool01Ol00`3oo`05o`030?oo00;o00<0ool01Ol01@3oool000So
00<0ool00_l00`3oo`05o`030?oo00;o00<0ool01Ol00`3oo`02o`030?oo00Go00<0ool00_l00`3o
o`05o`030?oo00;o00<0ool01?l00`3oo`03o`030?oo00Co00<0ool00ol00`3oo`04o`030?oo00?o
00<0ool01?l00`3oo`03o`030?oo00Co00<0ool00ol00`3oo`06o`050?ooo`002?l01@3oool000So
00D0oooo0008o`030?oo03Co000Po`030?oo00Go00<0ool01Ol00`3oo`02o`030?oo00Go00<0ool0
0_l00`3oo`05o`030?oo00;o00<0ool01Ol00`3oo`02o`030?oo00Go00<0ool00_l00`3oo`05o`03
0?oo00;o00<0ool01Ol00`3oo`02o`030?oo00Co00<0ool00ol00`3oo`04o`030?oo00?o00<0ool0
1?l00`3oo`03o`030?oo00Co00<0ool00ol00`3oo`04o`030?oo00?o00<0ool01_l01@3oool000So
00D0oooo0008o`050?ooo`002?l00`3oo`0do`008?l00`3oo`05o`030?oo00Go00<0ool00_l00`3o
o`05o`030?oo00;o00<0ool01Ol00`3oo`02o`030?oo00Go00<0ool00_l00`3oo`05o`030?oo00;o
00<0ool01Ol00`3oo`02o`030?oo00Go00<0ool00_l00`3oo`04o`030?oo00?o00<0ool01?l00`3o
o`03o`030?oo00Co00<0ool00ol00`3oo`04o`030?oo00?o00<0ool01?l00`3oo`03o`030?oo00Ko
00D0oooo0008o`050?ooo`002?l01@3oool000So00<0ool0=?l0023o0P06o`030?oo00Go00<0ool0
0_l00`3oo`05o`030?oo00;o00<0ool01Ol00`3oo`02o`030?oo00Go00<0ool00_l00`3oo`05o`03
0?oo00;o00<0ool01Ol00`3oo`02o`030?oo00Go00<0ool00_l00`3oo`04o`030?oo00?o00<0ool0
1?l00`3oo`04o`030?oo00?o00<0ool00ol00`3oo`04o`030?oo00?o00<0ool01?l00`3oo`03o`03
0?oo00Ko00D0oooo0008o`050?ooo`002?l01@3oool000So00<0ool0=?l0023o00<0ool01_l00`3o
o`04o`030?oo00?o00<0ool01?l00`3oo`02o`030?oo00Go00<0ool00_l00`3oo`05o`030?oo00;o
00<0ool01Ol00`3oo`02o`030?oo00Go00<0ool00_l00`3oo`05o`030?oo00;o00<0ool01?l00`3o
o`04o`030?oo00?o00<0ool01?l00`3oo`03o`030?oo00?o00<0ool01?l00`3oo`03o`030?oo00Co
00<0ool00ol00`3oo`06o`050?ooo`002?l01@3oool000So00<0ool00_l00`3oo`05o`030?oo03Co
000Po`030?oo00Ko00<0ool01?l00`3oo`03o`030?oo00Co00<0ool00_l00`3oo`05o`030?oo00;o
00<0ool01Ol00`3oo`02o`030?oo00Go00<0ool00_l00`3oo`05o`030?oo00;o00<0ool01Ol00`3o
o`03o`030?oo00?o00<0ool01?l00`3oo`03o`030?oo00Co00<0ool00ol00`3oo`03o`030?oo00Co
00<0ool00ol00`3oo`04o`030?oo00?o00<0ool01_l01@3oool000So00D0oooo0008o`030?oo00;o
00<0ool01Ol00`3oo`0do`008?l00`3oo`06o`030?oo00Co00<0ool00ol00`3oo`04o`030?oo00;o
00<0ool01Ol00`3oo`02o`030?oo00Go00<0ool00_l00`3oo`05o`030?oo00;o00<0ool01Ol00`3o
o`02o`030?oo00Go00<0ool00ol00`3oo`03o`030?oo00Co00<0ool00ol00`3oo`04o`030?oo00?o
00<0ool01?l00`3oo`03o`030?oo00?o00<0ool01?l00`3oo`03o`030?oo00Ko00D0oooo0008o`03
0?oo00;o00<0ool01Ol00`3oo`02o`030?oo00Go00<0ool0=?l0023o0P07o`030?oo00Co00<0ool0
0ol00`3oo`04o`030?oo00;o00<0ool01Ol00`3oo`02o`030?oo00Go00<0ool00_l00`3oo`05o`03
0?oo00;o00<0ool01Ol00`3oo`03o`030?oo00Co00<0ool00ol00`3oo`03o`030?oo00Co00<0ool0
0ol00`3oo`04o`030?oo00?o00<0ool01?l00`3oo`03o`030?oo00?o00<0ool01?l00`3oo`03o`03
0?oo00Ko00<0ool00_l00`3oo`05o`030?oo00;o00<0ool01Ol00`3oo`02o`030?oo00Go00<0ool0
=?l0023o00<0ool01_l00`3oo`04o`030?oo00?o00<0ool01?l00`3oo`02o`030?oo00Go00<0ool0
0_l00`3oo`05o`030?oo00;o00<0ool01Ol00`3oo`03o`030?oo00Co00<0ool00ol00`3oo`04o`03
0?oo00?o00<0ool00ol00`3oo`04o`030?oo00?o00<0ool01?l00`3oo`03o`030?oo00Co00<0ool0
0ol00`3oo`03o`030?oo00Co00<0ool01?l00`3oo`05o`030?oo00;o00<0ool01Ol00`3oo`02o`03
0?oo00Go00<0ool00_l00`3oo`05o`030?oo03Co000Io`801Ol00`3oo`06o`030?oo00Co00<0ool0
0ol00`3oo`04o`030?oo00;o00<0ool01Ol00`3oo`02o`030?oo00Go00<0ool00ol00`3oo`04o`03
0?oo00?o00<0ool01?l00`3oo`03o`030?oo00Co00<0ool00ol00`3oo`03o`030?oo00Co00<0ool0
0ol00`3oo`04o`030?oo00?o00<0ool01?l00`3oo`03o`030?oo00?o00<0ool01?l00`3oo`04o`03
0?oo00Go00<0ool00_l00`3oo`05o`030?oo00;o00<0ool01Ol00`3oo`02o`030?oo00Go00<0ool0
=?l001_o00<0ool00_l00`3oo`06o`030?oo00Co00<0ool00ol00`3oo`04o`030?oo00?o00<0ool0
1?l00`3oo`02o`030?oo00Go00<0ool00ol00`3oo`04o`030?oo00?o00<0ool01?l00`3oo`03o`03
0?oo00Co00<0ool00ol00`3oo`03o`030?oo00Co00<0ool00ol00`3oo`04o`030?oo00?o00<0ool0
1?l00`3oo`03o`030?oo00Co00<0ool00ol00`3oo`04o`030?oo00Go00<0ool00_l00`3oo`05o`03
0?oo00;o00<0ool01Ol00`3oo`02o`030?oo00Go00<0ool0=?l001[o00<0ool00ol200Oo00<0ool0
1?l00`3oo`03o`030?oo00Co00<0ool00ol00`3oo`04o`030?oo00?o00<0ool01?l00`3oo`03o`03
0?oo00Co00<0ool00ol00`3oo`04o`030?oo00?o00<0ool01?l00`3oo`03o`030?oo00?o00<0ool0
1?l00`3oo`03o`030?oo00Co00<0ool00ol00`3oo`04o`030?oo00?o00<0ool01?l00`3oo`03o`03
0?oo00Co00<0ool01Ol00`3oo`02o`030?oo00Go00<0ool00_l00`3oo`05o`030?oo00;o00<0ool0
1Ol00`3oo`0do`006ol00`3oo`02o`030?oo00Ko00<0ool01?l00`3oo`03o`030?oo00Co00<0ool0
0ol00`3oo`04o`030?oo00?o00<0ool01?l00`3oo`03o`030?oo00Co00<0ool00ol00`3oo`04o`03
0?oo00?o00<0ool00ol00`3oo`04o`030?oo00?o00<0ool01?l00`3oo`03o`030?oo00Co00<0ool0
0ol00`3oo`04o`030?oo00?o00<0ool01?l00`3oo`03o`030?oo00Co00<0ool01Ol00`3oo`02o`03
0?oo00Go00<0ool00_l00`3oo`05o`030?oo00;o00<0ool01Ol00`3oo`0do`006Ol00`3o0004o`03
0?oo00Ko00<0ool01?l00`3oo`04o`030?oo00?o00<0ool00ol00`3oo`04o`030?oo00?o00<0ool0
1?l00`3oo`03o`030?oo00Co00<0ool00ol00`3oo`04o`030?oo00?o00<0ool00ol00`3oo`04o`03
0?oo00?o00<0ool01?l00`3oo`03o`030?oo00Go00<0ool00_l00`3oo`05o`030?oo00;o00<0ool0
1?l00`3oo`03o`030?oo00Co00<0ool01Ol00`3oo`02o`030?oo00Go00<0ool00_l00`3oo`05o`03
0?oo00;o00<0ool01Ol00`3oo`0do`006_l00`3oo`03o`030?oo00Ko00<0ool01?l00`3oo`04o`03
0?oo00?o00<0ool00ol00`3oo`04o`030?oo00?o00<0ool01?l00`3oo`03o`030?oo00Co00<0ool0
0ol00`3oo`04o`030?oo00?o00<0ool00ol00`3oo`04o`030?oo00?o00<0ool01Ol00`3oo`02o`03
0?oo00Go00<0ool00_l00`3oo`05o`030?oo00;o00<0ool01?l00`3oo`03o`030?oo00Co00<0ool0
1Ol00`3oo`02o`030?oo00Go00<0ool00_l00`3oo`05o`030?oo00;o00<0ool01Ol00`3oo`0do`00
8?l200So00<0ool00ol00`3oo`04o`030?oo00?o00<0ool00ol00`3oo`04o`030?oo00?o00<0ool0
1?l00`3oo`03o`030?oo00Co00<0ool00ol00`3oo`04o`030?oo00?o00<0ool00ol00`3oo`04o`03
0?oo00?o00<0ool01Ol00`3oo`02o`030?oo00Go00<0ool00_l00`3oo`05o`030?oo00;o00<0ool0
1?l00`3oo`03o`030?oo00Co00<0ool01Ol00`3oo`02o`030?oo00Go00<0ool00_l00`3oo`05o`03
0?oo00?o00<0ool01?l00`3oo`0do`008?l00`3oo`07o`030?oo00?o00<0ool01?l00`3oo`03o`03
0?oo00?o00<0ool01?l00`3oo`03o`030?oo00Co00<0ool00ol00`3oo`04o`030?oo00?o00<0ool0
1?l00`3oo`03o`030?oo00?o00<0ool01Ol00`3oo`02o`030?oo00Go00<0ool00_l00`3oo`05o`03
0?oo00;o00<0ool01Ol00`3oo`02o`030?oo00Co00<0ool00ol00`3oo`04o`030?oo00Go00<0ool0
0_l00`3oo`05o`030?oo00;o00<0ool01Ol00`3oo`03o`030?oo00Co00<0ool0=?l0023o00<0ool0
1ol00`3oo`03o`030?oo00Co00<0ool00ol00`3oo`04o`030?oo00?o00<0ool00ol00`3oo`04o`03
0?oo00?o00<0ool01?l00`3oo`03o`030?oo00Co00<0ool01?l00`3oo`02o`030?oo00Go00<0ool0
0_l00`3oo`05o`030?oo00;o00<0ool01Ol00`3oo`02o`030?oo00Go00<0ool00_l00`3oo`04o`03
0?oo00?o00<0ool01Ol00`3oo`04o`030?oo00;o00<0ool01Ol00`3oo`03o`030?oo00Co00<0ool0
0ol00`3oo`04o`030?oo03Co000Po`030?oo00Oo00<0ool00ol00`3oo`04o`030?oo00?o00<0ool0
1?l00`3oo`03o`030?oo00?o00<0ool01?l00`3oo`03o`030?oo00Co00<0ool00ol00`3oo`04o`03
0?oo00Co00<0ool00_l00`3oo`05o`030?oo00;o00<0ool01Ol00`3oo`02o`030?oo00Go00<0ool0
0_l00`3oo`05o`030?oo00;o00<0ool01?l00`3oo`03o`030?oo00Go00<0ool01?l00`3oo`03o`03
0?oo00Co00<0ool00ol00`3oo`04o`030?oo00?o00<0ool01?l00`3oo`0do`008?l00`3oo`07o`03
0?oo00?o00<0ool01?l00`3oo`03o`030?oo00Co00<0ool00ol00`3oo`03o`030?oo00Co00<0ool0
0ol00`3oo`04o`030?oo00Co00<0ool00ol00`3oo`04o`030?oo00;o00<0ool01Ol00`3oo`02o`03
0?oo00Go00<0ool00_l00`3oo`05o`030?oo00;o00<0ool01Ol00`3oo`02o`030?oo00Go00<0ool0
0_l00`3oo`05o`030?oo00Co00<0ool00ol00`3oo`04o`030?oo00?o00<0ool01?l00`3oo`03o`03
0?oo00Co00<0ool0=?l0023o0P08o`030?oo00?o00<0ool01?l00`3oo`03o`030?oo00Co00<0ool0
0ol00`3oo`03o`030?oo00Co00<0ool01?l00`3oo`03o`030?oo00Co00<0ool00ol00`3oo`04o`03
0?oo00;o00<0ool01Ol00`3oo`02o`030?oo00Go00<0ool00_l00`3oo`05o`030?oo00;o00<0ool0
1Ol00`3oo`02o`030?oo00Go00<0ool00_l00`3oo`05o`030?oo00Co00<0ool00ol00`3oo`04o`03
0?oo00?o00<0ool01?l00`3oo`03o`030?oo00Co00<0ool0=?l0023o00<0ool01ol00`3oo`03o`03
0?oo00Co00<0ool00ol00`3oo`04o`030?oo00?o00<0ool00ol00`3oo`04o`030?oo00Co00<0ool0
0ol00`3oo`04o`030?oo00?o00<0ool01?l00`3oo`02o`030?oo00Go00<0ool00_l00`3oo`05o`03
0?oo00;o00<0ool01Ol00`3oo`02o`030?oo00Go00<0ool00_l00`3oo`05o`030?oo00;o00<0ool0
1Ol00`3oo`04o`030?oo00?o00<0ool01?l00`3oo`03o`030?oo00Co00<0ool00ol00`3oo`03o`03
0?oo03Go000Po`030?oo00Oo00<0ool00ol00`3oo`04o`030?oo00?o00<0ool01?l00`3oo`03o`03
0?oo00Co00<0ool00ol00`3oo`04o`030?oo00?o00<0ool01?l00`3oo`03o`030?oo00Co00<0ool0
0_l00`3oo`05o`030?oo00;o00<0ool01Ol00`3oo`02o`030?oo00Go00<0ool00_l00`3oo`06o`05
0?ooo`001ol00`3oo`02o`030?oo00Go00<0ool01?l00`3oo`03o`030?oo00Co00<0ool00ol00`3o
o`04o`030?oo00?o00<0ool00ol00`3oo`0eo`008?l00`3oo`07o`030?oo00?o00<0ool01?l00`3o
o`03o`030?oo00Co00<0ool00ol00`3oo`04o`030?oo00?o00<0ool01?l00`3oo`03o`030?oo00Co
00<0ool00ol00`3oo`04o`030?oo00;o00<0ool01Ol00`3oo`02o`030?oo00Go00<0ool00_l00`3o
o`05o`030?oo00;o00<0ool01_l01@3oool000Oo00<0ool00_l00`3oo`05o`030?oo00Co00<0ool0
0ol00`3oo`04o`030?oo00?o00<0ool01?l00`3oo`03o`030?oo00?o00<0ool0=Ol0023o0P08o`03
0?oo00?o00<0ool01?l00`3oo`03o`030?oo00Co00<0ool00ol00`3oo`04o`030?oo00?o00<0ool0
1?l00`3oo`03o`030?oo00Co00<0ool00ol00`3oo`04o`030?oo00;o00<0ool01Ol00`3oo`02o`03
0?oo00Go00<0ool00_l00`3oo`06o`050?ooo`002?l01@3oool000Oo00<0ool00_l00`3oo`05o`03
0?oo00Co00<0ool00ol00`3oo`04o`030?oo00?o00<0ool01?l00`3oo`03o`030?oo00?o00<0ool0
=Ol0023o00<0ool01ol00`3oo`03o`030?oo00Go00<0ool00_l00`3oo`05o`030?oo00;o00<0ool0
1?l00`3oo`03o`030?oo00Co00<0ool00ol00`3oo`04o`030?oo00?o00<0ool01?l00`3oo`02o`03
0?oo00Go00<0ool00_l00`3oo`06o`050?ooo`002?l01@3oool000So00D0oooo0007o`030?oo00;o
00<0ool01_l00`3oo`03o`030?oo00?o00<0ool01?l00`3oo`03o`030?oo00Co00<0ool00ol00`3o
o`03o`030?oo03Go000Po`030?oo00So00<0ool00_l00`3oo`05o`030?oo00;o00<0ool01Ol00`3o
o`02o`030?oo00Co00<0ool00ol00`3oo`04o`030?oo00?o00<0ool01?l00`3oo`03o`030?oo00Co
00<0ool00_l00`3oo`05o`030?oo00;o00<0ool01_l01@3oool000So00D0oooo0008o`050?ooo`00
1ol00`3oo`02o`030?oo00Ko00<0ool00ol00`3oo`03o`030?oo00Co00<0ool00ol00`3oo`04o`03
0?oo00?o00<0ool00ol00`3oo`0eo`008?l00`3oo`08o`030?oo00;o00<0ool01Ol00`3oo`02o`03
0?oo00Go00<0ool00_l00`3oo`04o`030?oo00?o00<0ool01?l00`3oo`03o`030?oo00Co00<0ool0
0ol00`3oo`04o`030?oo00;o00<0ool01_l01@3oool000So00D0oooo0008o`050?ooo`002?l01@3o
ool000So00D0oooo0008o`030?oo00?o00<0ool00ol00`3oo`04o`030?oo00?o00<0ool01?l00`3o
o`04o`030?oo00;o00<0ool0=Ol0023o0P09o`030?oo00;o00<0ool01Ol00`3oo`02o`030?oo00Go
00<0ool00_l00`3oo`04o`030?oo00?o00<0ool01?l00`3oo`03o`030?oo00Co00<0ool00ol00`3o
o`05o`050?ooo`002?l01@3oool000So00D0oooo0008o`050?ooo`002?l01@3oool000So00D0oooo
0008o`030?oo00?o00<0ool00ol00`3oo`04o`030?oo00?o00<0ool01?l00`3oo`04o`030?oo00;o
00<0ool0=Ol0023o00<0ool02?l00`3oo`02o`030?oo00Go00<0ool00_l00`3oo`05o`030?oo00;o
00<0ool01?l00`3oo`03o`030?oo00Co00<0ool00ol00`3oo`04o`030?oo00?o00<0ool01Ol01@3o
ool000So00D0oooo0008o`050?ooo`002?l01@3oool000So00D0oooo0008o`050?ooo`002?l00`3o
o`03o`030?oo00?o00<0ool01?l00`3oo`04o`030?oo00?o00<0ool01?l00`3oo`02o`030?oo03Go
000Jo`<00ol00`3oo`08o`030?oo00;o00<0ool01Ol00`3oo`02o`030?oo00Go00<0ool00_l00`3o
o`04o`030?oo00?o00<0ool01?l00`3oo`03o`030?oo00Go00<0ool00_l00`3oo`05o`050?ooo`00
2?l01@3oool000So00D0oooo0008o`050?ooo`002?l01@3oool000So00D0oooo0008o`030?oo00?o
00<0ool01?l00`3oo`03o`030?oo00Co00<0ool00ol00`3oo`04o`030?oo00;o00<0ool0=Ol001_o
00<0ool00_l00`3oo`08o`030?oo00;o00<0ool01Ol00`3oo`02o`030?oo00Go00<0ool00_l00`3o
o`05o`030?oo00;o00<0ool01Ol00`3oo`02o`030?oo00Go00<0ool00_l00`3oo`05o`050?ooo`00
2?l01@3oool000So00D0oooo0008o`050?ooo`002?l01@3oool000So00D0oooo0008o`030?oo00?o
00<0ool01?l00`3oo`03o`030?oo00Co00<0ool00ol00`3oo`04o`030?oo00;o00<0ool0=Ol001Wo
1003o`802Ol00`3oo`02o`030?oo00Go00<0ool00_l00`3oo`05o`030?oo00;o00<0ool01Ol00`3o
o`02o`030?oo00Go00<0ool00_l00`3oo`05o`030?oo00;o00<0ool01Ol01@3oool000So00D0oooo
0008o`050?ooo`002?l01@3oool000So00D0oooo0008o`050?ooo`002?l00`3oo`03o`030?oo00Co
00<0ool00ol00`3oo`04o`030?oo00?o00<0ool01?l00`3oo`02o`030?oo03Go000Io`030?l000Co
00<0ool02?l00`3oo`02o`030?oo00Go00<0ool00_l00`3oo`05o`030?oo00;o00<0ool01Ol00`3o
o`02o`030?oo00Go00<0ool00_l00`3oo`05o`030?oo00;o00<0ool01Ol01@3oool000So00D0oooo
0008o`050?ooo`002?l01@3oool000So00D0oooo0008o`050?ooo`002Ol00`3oo`02o`030?oo00Co
00<0ool00ol00`3oo`04o`030?oo00?o00<0ool01?l00`3oo`02o`030?oo03Go000Jo`801?l00`3o
o`08o`030?oo00;o00<0ool01Ol00`3oo`02o`030?oo00Ko00D0oooo0007o`030?oo00;o00<0ool0
1Ol00`3oo`02o`030?oo00Go00<0ool00_l00`3oo`05o`050?ooo`002?l01@3oool000So00D0oooo
0008o`050?ooo`002Ol0103oo`08o`040?oo00[o00<0ool00_l00`3oo`04o`030?oo00?o00<0ool0
1?l00`3oo`03o`030?oo00Co00<0ool00_l00`3oo`0eo`006ol00`3oo`02o`030?oo00So00<0ool0
0_l00`3oo`05o`030?oo00;o00<0ool01_l01@3oool000Oo00<0ool00_l00`3oo`05o`030?oo00;o
00<0ool01Ol00`3oo`02o`030?oo00Go00D0oooo0008o`050?ooo`002?l01@3oool000So00D0oooo
0009o`030?l000[o00<0o`002_l00`3oo`02o`030?oo00Co00<0ool00ol00`3oo`04o`030?oo00?o
00<0ool01?l00`3oo`02o`030?oo03Go000Po`030?oo00So00<0ool00_l00`3oo`06o`050?ooo`00
2?l01@3oool000Oo00<0ool00_l00`3oo`05o`030?oo00;o00<0ool01Ol00`3oo`02o`030?oo00Go
00D0oooo0008o`050?ooo`002?l01@3oool000Wo00<0o`002_l00`3o000:o`030?l000[o00<0ool0
0_l00`3oo`04o`030?oo00?o00<0ool01?l00`3oo`03o`030?oo00Co00<0ool00_l00`3oo`0eo`00
8?l200[o00D0oooo0008o`050?ooo`002?l01@3oool000Oo00<0ool00_l00`3oo`05o`030?oo00;o
00<0ool01Ol00`3oo`02o`030?oo00Go00D0oooo0008o`050?ooo`002Ol0103oo`09o`030?l000[o
00<0o`002_l00`3o000:o`030?oo00;o00<0ool01?l00`3oo`03o`030?oo00Co00<0ool00ol00`3o
o`04o`030?oo00;o00<0ool0=Ol0023o00<0ool02Ol01@3oool000So00D0oooo0008o`050?ooo`00
1ol00`3oo`02o`030?oo00Go00<0ool00_l00`3oo`05o`030?oo00;o00<0ool01Ol01@3oool000So
00D0oooo0009o`030?l000[o00<0o`002_l00`3o000:o`030?l000[o00<0ool00_l00`3oo`04o`03
0?oo00?o00<0ool01?l00`3oo`03o`030?oo00Go00D0oooo000go`008?l00`3oo`09o`050?ooo`00
2?l01@3oool000So00D0oooo0008o`050?ooo`001ol00`3oo`02o`030?oo00Go00<0ool00_l00`3o
o`05o`050?ooo`002Ol00`3o000:o`030?l000[o00<0o`002_l00`3o000:o`030?l000[o00<0ool0
0_l00`3oo`05o`030?oo00;o00<0ool01?l00`3oo`03o`030?oo00Go00D0oooo000go`008?l00`3o
o`09o`050?ooo`002?l01@3oool000So00D0oooo0008o`050?ooo`001ol00`3oo`02o`030?oo00Go
00<0ool00_l00`3oo`06o`040?oo00Wo00<0o`002_l00`3o000:o`030?l000[o00<0o`002_l00`3o
000:o`030?oo00;o00<0ool01Ol00`3oo`02o`030?oo00Go00<0ool00_l00`3oo`05o`050?ooo`00
=ol0023o0P0:o`050?ooo`002?l01@3oool000So00D0oooo0008o`050?ooo`001ol00`3oo`02o`03
0?oo00Go00D0oooo0009o`040?oo00Wo00<0o`002_l00`3o000:o`030?l000[o00<0o`002_l00`3o
000:o`030?oo00;o00<0ool01Ol00`3oo`02o`030?oo00Go00<0ool00_l00`3oo`05o`050?ooo`00
=ol0023o00<0ool02Ol01@3oool000So00D0oooo0008o`050?ooo`002?l01@3oool000Oo00<0ool0
0_l00`3oo`06o`040?oo00Wo00@0ool02Ol00`3o000:o`030?l000[o00<0o`002_l00`3o000:o`03
0?l000[o00<0ool00_l00`3oo`05o`030?oo00;o00<0ool01Ol00`3oo`02o`030?oo00Go00D0oooo
000go`008?l00`3oo`09o`050?ooo`002?l01@3oool000So00D0oooo0008o`050?ooo`002?l0103o
o`09o`040?oo00Wo00@0ool02Ol00`3o000:o`030?l000[o00<0o`002_l00`3o000:o`030?l000_o
00D0oooo0007o`030?oo00;o00<0ool01Ol00`3oo`02o`030?oo00Go00D0oooo000go`008?l00`3o
o`09o`050?ooo`002?l01@3oool000So00D0oooo0008o`040?oo00Wo00@0ool02Ol0103oo`09o`04
0?oo00Wo00<0o`002_l00`3o000:o`030?l000[o00<0o`002ol200_o00D0oooo0007o`030?oo00;o
00<0ool01Ol00`3oo`02o`030?oo00Go00D0oooo000go`008?l200[o00D0oooo0008o`050?ooo`00
2?l0103oo`09o`040?oo00Wo00@0ool02Ol0103oo`09o`040?oo00Wo00<0o`002_l00`3o000:o`03
0?l000[o00<0o`002ol200_o00D0oooo0007o`030?oo00;o00<0ool01Ol00`3oo`02o`030?oo00Go
00D0oooo000go`008?l00`3oo`09o`050?ooo`002?l0103oo`0:o`030?l000Wo00@0ool02Ol0103o
o`09o`040?oo00Wo00@0ool02Ol00`3o000:o`030?l000[o00<0o`002ol200_o0P0;o`050?ooo`00
1ol00`3oo`02o`030?oo00Go00<0ool00_l00`3oo`05o`050?ooo`00=ol0023o00<0ool02Ol01@3o
ool000So00@0ool02_l00`3o000:o`030?l000Wo00@0ool02Ol0103oo`09o`040?oo00Wo00<0o`00
2_l00`3o000:o`030?l000_o0P0;o`802ol01@3oool000So00D0oooo0007o`030?oo00;o00<0ool0
1Ol01@3oool003Oo000Po`030?oo00Wo00@0ool02_l00`3o000:o`030?l000[o00<0o`002Ol0103o
o`09o`040?oo00Wo00@0ool02Ol00`3o000:o`030?l000_o0P0;o`802ol200_o00D0oooo0008o`05
0?ooo`001ol00`3oo`02o`030?oo00Go00D0oooo000go`008?l200_o00<0o`002_l00`3o000:o`03
0?l000[o00<0o`002Ol0103oo`09o`040?oo00Wo00@0ool02Ol00`3o000;o`802ol200_o0P0;o`80
2ol01@3oool000So00D0oooo0007o`030?oo00;o00<0ool01Ol01@3oool003Oo000Po`030?oo00[o
00<0o`002_l00`3o000:o`030?l000[o00<0o`002Ol0103oo`09o`040?oo00Wo00<0o`002_l00`3o
000;o`802ol200_o0P0;o`802ol01@3oool000So00D0oooo0007o`050?ooo`002Ol0103oo`0go`00
8?l00`3oo`0:o`030?l000[o00<0o`002_l00`3o000:o`030?l000Wo00@0ool02Ol0103oo`09o`03
0?l000_o0P0;o`802ol200_o0P0;o`802ol01@3oool000So00D0oooo0007o`050?ooo`002Ol0103o
o`0go`006_l00`3oo`03o`030?oo00[o00<0o`002_l00`3o000:o`030?l000[o00<0o`002Ol0103o
o`0:o`030?l000[o0P0;o`802ol200_o0P0;o`802ol200_o00D0oooo0008o`040?oo00Wo00@0ool0
2Ol0103oo`0go`006Ol00`3o0004o`030?oo00[o00<0o`002_l00`3o000:o`030?l000[o00<0o`00
2_l00`3o000:o`030?l000[o0P0;o`802ol200_o0P0;o`802ol200_o00@0ool02Ol0103oo`09o`04
0?oo00Wo00@0ool0=ol001_o00<0ool00_l200_o00<0o`002_l00`3o000:o`030?l000[o00<0o`00
2_l00`3o000:o`030?l000[o0P0;o`802ol200_o0P0;o`802ol200_o00@0ool02Ol0103oo`09o`04
0?oo00Wo00@0ool0=ol001Wo0P05o`030?oo00[o00<0o`002_l00`3o000:o`030?l000[o00<0o`00
2_l00`3o000:o`030?l000[o0P0;o`802ol200_o0P0;o`802ol200co00<0o`002_l00`3o0009o`04
0?oo00Wo00@0ool0=ol001Wo00<0ool01?l00`3oo`0:o`030?l000[o00<0o`002_l00`3o000:o`03
0?l000[o00<0o`002_l00`3o000:o`802ol200_o0P0;o`802ol200co00<0ool02_l00`3o000:o`03
0?l000Wo00@0ool02Ol0103oo`0go`006Ol300Co00<0ool02_l00`3o000:o`030?l000[o00<0o`00
2ol200[o00<0o`002_l00`3o000:o`802ol200_o0P0;o`802ol200co00<0ool02_l00`3o000:o`03
0?l000Wo00@0ool02Ol0103oo`0go`008?l200_o00<0o`002_l00`3o000;o`802ol200[o00<0o`00
2_l00`3o000:o`802ol200_o0P0;o`803?l00`3oo`0:o`030?oo00[o00<0o`002_l00`3o0009o`04
0?oo00Wo00<0o`00>?l0023o00<0ool02_l00`3o000;o`802ol200_o0P0:o`030?l000_o0P0:o`80
2ol200_o0P0<o`030?oo00[o00<0ool02_l00`3oo`0:o`030?l000[o00<0o`002Ol0103oo`09o`03
0?l003So000Po`030?oo00[o00<0o`002ol200_o0P0;o`802ol200_o0P0:o`802ol200_o0P0<o`03
0?oo00[o00<0ool02_l00`3oo`0:o`030?l000[o00<0o`002Ol0103oo`09o`030?l003So000Po`03
0?oo00_o0P0;o`802ol200_o0P0;o`802ol200[o0P0;o`803?l00`3oo`0:o`030?oo00[o00<0ool0
2_l00`3oo`0:o`030?l000[o00<0o`002Ol0103oo`0:o`80>?l0023o0P0<o`802ol200_o0P0;o`80
2ol200_o0P0:o`803?l00`3oo`0:o`030?oo00[o00<0ool02_l00`3oo`0:o`030?oo00[o00<0o`00
2_l00`3o000:o`030?l000[o0P0ho`008?l00`3oo`0;o`802ol200_o0P0;o`802ol200_o0P0;o`03
0?oo00[o00<0ool02_l00`3oo`0:o`030?oo00[o00<0ool05ol00`3o000:o`030?l000[o00<0o`00
2_l203So000Po`030?oo00_o0P0;o`802ol200_o0P0;o`802ol200_o00<0ool02_l00`3oo`0:o`03
0?oo00[o00<0ool09?l00`3o000;o`802_l00`3o000:o`80>?l0023o00<0ool02ol200_o0P0;o`80
2ol200_o0P0;o`802ol00`3oo`0:o`030?oo00[o00<0ool0<_l200_o0P0:o`030?l000[o0P0ho`00
8?l200co0P0;o`802ol200_o0P0;o`803?l00`3oo`09o`030?oo00[o00<0ool02_l00`3oo`0bo`80
2ol200[o00<0o`002_l203So000Po`030?oo00_o0P0;o`802ol200co00<0ool02Ol200co00<0ool0
2Ol00`3oo`0:o`030?oo03oo0P0;o`802_l00`3o000:o`80>?l0023o00<0ool02ol200_o0P0<o`03
0?oo00[o00<0ool02_l00`3oo`0:o`030?oo00Wo00<0ool0C?l200_o0P0;o`802_l203So000Po`03
0?oo00_o0P0<o`030?oo00[o00<0ool02_l00`3oo`0:o`030?oo00[o00<0ool0F?l200_o0P0;o`80
2_l203So000Po`030?oo00_o0P0<o`030?oo00[o00<0ool02_l00`3oo`0:o`030?oo06Go0P0;o`80
2ol200[o0P0ho`008?l200go00<0ool02_l00`3oo`0:o`030?oo00[o00<0ool02_l00`3oo`1Uo`80
2ol200_o0P0;o`030?oo03Ko000Po`030?oo00co00<0ool02_l00`3oo`0:o`030?oo00[o00<0ool0
L_l200_o0P0;o`802ol00`3oo`0fo`006Ol200Go00<0ool03?l00`3oo`0:o`030?oo00[o00<0ool0
Ool200_o0P0;o`802ol00`3oo`0fo`006Ol00`3o0004o`030?oo00co00<0ool02_l00`3oo`2<o`80
3?l00`3oo`09o`802ol00`3oo`0fo`006Ol00`3o0004o`803Ol00`3oo`2Jo`030?oo00[o00<0ool0
2_l00`3oo`09o`030?oo03Ko000Io`801Ol00`3oo`0<o`030?oo09[o00<0ool02_l00`3oo`0:o`03
0?oo00Wo00<0ool0=_l001Wo00<0ool01?l00`3oo`2Yo`030?oo00[o00<0ool02_l00`3oo`12o`00
6_l200Co00<0ool0ZOl00`3oo`0:o`030?oo00[o00<0ool0@_l0023o0P2Zo`030?oo00[o00<0ool0
Col0023o00<0ool0ZOl00`3oo`1Lo`008?l00`3oo`3oo`Wo000Po`030?oo0?oo2Ol0023o0P3oo`[o
003oobco003oobco003oobco003oobco003oobco003oobco003oobco001lo`80[Ol007ko00<0ool0
4?l200Oo0P07o`80Q_l0073o0P000ol0000200;o00<0ool00`001?l00003o`802?l200;o0`03o`04
0?ooo`<00ol00`3oo`24o`00L?l01`3oool0o`000_l00`3o0002o`040?oo00?o00<0ool01ol0103o
o`02o`030?oo00;o00D0oooo0005o`030?oo08Co001ao`<00_l01P3oo`3o00;o00@0ool00ol300Oo
00@0ool00_l00`3oo`02o`030?oo00;o00<0ool00_l00`3oo`24o`00LOl0103o0?l400?o0`02o`04
0?ooo`<01ol0103oo`02o`030?oo00;o00<0ool00_l00`3oo`02o`030?oo08Co001bo`030?oo00co
00<0ool02ol0103oo`02o`030?oo00;o00L0oooo0?l000?o00<0ool0Q?l0077o0P0=o`803_l200;o
0P04o`800ol0103oool208Ko003oobco003oobco003oobco003oobco003oobco003oobco000Io`<0
00?o0?l01002o`<0ool4o`006_l01@3oo`3o00<00_l0103oo`3oo`Co000Jo`<01?l0103oo`02o`03
0?oo0?oo0_l001[o00@0ool00_l200?o0`3oo`Co000Jo`040?oo00Wo00<0ool0ool2o`006Ol400Wo
0P3oo`Co003oobco003oobco003oobco0000\
\>"],
  ImageRangeCache->{{{0, 298}, {184, 0}} -> {-15.1683, -0.8478, 0.465795, 
  0.0471011}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00952381 0.0147151 0.0936797 [
[(20)] .21429 .01472 0 2 Msboxa
[(40)] .40476 .01472 0 2 Msboxa
[(60)] .59524 .01472 0 2 Msboxa
[(80)] .78571 .01472 0 2 Msboxa
[(100)] .97619 .01472 0 2 Msboxa
[(No.)] 1.025 .01472 -1 0 Msboxa
[(Angle Ql[3])] .5 .61803 0 -2 0 0 1 Mouter Mrotsboxa
[(1)] .01131 .10839 1 0 Msboxa
[(2)] .01131 .20207 1 0 Msboxa
[(3)] .01131 .29575 1 0 Msboxa
[(4)] .01131 .38943 1 0 Msboxa
[(5)] .01131 .48311 1 0 Msboxa
[(6)] .01131 .57679 1 0 Msboxa
[(Rad)] .02381 .61803 0 -4 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 .61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.21429 .01472 m
.21429 .02097 L
s
P
[(20)] .21429 .01472 0 2 Mshowa
p
.002 w
.40476 .01472 m
.40476 .02097 L
s
P
[(40)] .40476 .01472 0 2 Mshowa
p
.002 w
.59524 .01472 m
.59524 .02097 L
s
P
[(60)] .59524 .01472 0 2 Mshowa
p
.002 w
.78571 .01472 m
.78571 .02097 L
s
P
[(80)] .78571 .01472 0 2 Mshowa
p
.002 w
.97619 .01472 m
.97619 .02097 L
s
P
[(100)] .97619 .01472 0 2 Mshowa
p
.001 w
.0619 .01472 m
.0619 .01847 L
s
P
p
.001 w
.1 .01472 m
.1 .01847 L
s
P
p
.001 w
.1381 .01472 m
.1381 .01847 L
s
P
p
.001 w
.17619 .01472 m
.17619 .01847 L
s
P
p
.001 w
.25238 .01472 m
.25238 .01847 L
s
P
p
.001 w
.29048 .01472 m
.29048 .01847 L
s
P
p
.001 w
.32857 .01472 m
.32857 .01847 L
s
P
p
.001 w
.36667 .01472 m
.36667 .01847 L
s
P
p
.001 w
.44286 .01472 m
.44286 .01847 L
s
P
p
.001 w
.48095 .01472 m
.48095 .01847 L
s
P
p
.001 w
.51905 .01472 m
.51905 .01847 L
s
P
p
.001 w
.55714 .01472 m
.55714 .01847 L
s
P
p
.001 w
.63333 .01472 m
.63333 .01847 L
s
P
p
.001 w
.67143 .01472 m
.67143 .01847 L
s
P
p
.001 w
.70952 .01472 m
.70952 .01847 L
s
P
p
.001 w
.74762 .01472 m
.74762 .01847 L
s
P
p
.001 w
.82381 .01472 m
.82381 .01847 L
s
P
p
.001 w
.8619 .01472 m
.8619 .01847 L
s
P
p
.001 w
.9 .01472 m
.9 .01847 L
s
P
p
.001 w
.9381 .01472 m
.9381 .01847 L
s
P
[(No.)] 1.025 .01472 -1 0 Mshowa
p
.002 w
0 .01472 m
1 .01472 L
s
P
[(Angle Ql[3])] .5 .61803 0 -2 0 0 1 Mouter Mrotshowa
p
.002 w
.02381 .10839 m
.03006 .10839 L
s
P
[(1)] .01131 .10839 1 0 Mshowa
p
.002 w
.02381 .20207 m
.03006 .20207 L
s
P
[(2)] .01131 .20207 1 0 Mshowa
p
.002 w
.02381 .29575 m
.03006 .29575 L
s
P
[(3)] .01131 .29575 1 0 Mshowa
p
.002 w
.02381 .38943 m
.03006 .38943 L
s
P
[(4)] .01131 .38943 1 0 Mshowa
p
.002 w
.02381 .48311 m
.03006 .48311 L
s
P
[(5)] .01131 .48311 1 0 Mshowa
p
.002 w
.02381 .57679 m
.03006 .57679 L
s
P
[(6)] .01131 .57679 1 0 Mshowa
p
.001 w
.02381 .03345 m
.02756 .03345 L
s
P
p
.001 w
.02381 .05219 m
.02756 .05219 L
s
P
p
.001 w
.02381 .07092 m
.02756 .07092 L
s
P
p
.001 w
.02381 .08966 m
.02756 .08966 L
s
P
p
.001 w
.02381 .12713 m
.02756 .12713 L
s
P
p
.001 w
.02381 .14587 m
.02756 .14587 L
s
P
p
.001 w
.02381 .1646 m
.02756 .1646 L
s
P
p
.001 w
.02381 .18334 m
.02756 .18334 L
s
P
p
.001 w
.02381 .22081 m
.02756 .22081 L
s
P
p
.001 w
.02381 .23955 m
.02756 .23955 L
s
P
p
.001 w
.02381 .25828 m
.02756 .25828 L
s
P
p
.001 w
.02381 .27702 m
.02756 .27702 L
s
P
p
.001 w
.02381 .31449 m
.02756 .31449 L
s
P
p
.001 w
.02381 .33323 m
.02756 .33323 L
s
P
p
.001 w
.02381 .35196 m
.02756 .35196 L
s
P
p
.001 w
.02381 .3707 m
.02756 .3707 L
s
P
p
.001 w
.02381 .40817 m
.02756 .40817 L
s
P
p
.001 w
.02381 .42691 m
.02756 .42691 L
s
P
p
.001 w
.02381 .44564 m
.02756 .44564 L
s
P
p
.001 w
.02381 .46438 m
.02756 .46438 L
s
P
p
.001 w
.02381 .50185 m
.02756 .50185 L
s
P
p
.001 w
.02381 .52059 m
.02756 .52059 L
s
P
p
.001 w
.02381 .53932 m
.02756 .53932 L
s
P
p
.001 w
.02381 .55806 m
.02756 .55806 L
s
P
p
.001 w
.02381 .59553 m
.02756 .59553 L
s
P
p
.001 w
.02381 .61427 m
.02756 .61427 L
s
P
[(Rad)] .02381 .61803 0 -4 Mshowa
p
.002 w
.02381 0 m
.02381 .61803 L
s
P
P
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.004 w
.03333 .01472 m
.04286 .60134 L
.05238 .60238 L
.0619 .6031 L
.07143 .60312 L
.08095 .01473 L
.09048 .60324 L
.1 .01484 L
.10952 .60316 L
.11905 .60332 L
.12857 .6032 L
.1381 .01475 L
.14762 .60325 L
.15714 .01483 L
.16667 .60317 L
.17619 .60332 L
.18571 .60321 L
.19524 .01473 L
.20476 .60327 L
.21429 .01482 L
.22381 .60318 L
.23333 .60332 L
.24286 .60321 L
.25238 .01472 L
.2619 .60328 L
.27143 .01481 L
.28095 .6032 L
.29048 .60332 L
.3 .60322 L
.30952 .60331 L
.31905 .6033 L
.32857 .01479 L
.3381 .60322 L
.34762 .60331 L
.35714 .60322 L
.36667 .60329 L
.37619 .60331 L
.38571 .01477 L
.39524 .60324 L
.40476 .6033 L
.41429 .60323 L
.42381 .60328 L
.43333 .01472 L
.44286 .01475 L
.45238 .60327 L
.4619 .60329 L
.47143 .60324 L
.48095 .60326 L
.49048 .01474 L
.5 .01473 L
Mistroke
.50952 .6033 L
.51905 .60327 L
.52857 .60325 L
.5381 .60325 L
.54762 .01475 L
.55714 .60331 L
.56667 .01472 L
.57619 .60325 L
.58571 .60326 L
.59524 .60323 L
.60476 .01477 L
.61429 .60329 L
.62381 .01475 L
.63333 .60323 L
.64286 .60326 L
.65238 .60322 L
.6619 .01477 L
.67143 .60328 L
.68095 .01477 L
.69048 .60322 L
.7 .60327 L
.70952 .60321 L
.71905 .01478 L
.72857 .60326 L
.7381 .01479 L
.74762 .6032 L
.75714 .60328 L
.76667 .60321 L
.77619 .01478 L
.78571 .60325 L
.79524 .01481 L
.80476 .60318 L
.81429 .60329 L
.82381 .6032 L
.83333 .01478 L
.84286 .60324 L
.85238 .01483 L
.8619 .60317 L
.87143 .6033 L
.88095 .6032 L
.89048 .01477 L
.9 .60324 L
.90952 .01483 L
.91905 .60316 L
.92857 .60331 L
.9381 .6032 L
.94762 .01477 L
.95714 .60324 L
.96667 .01484 L
.97619 .60316 L
Mistroke
Mfstroke
% End of Graphics
MathPictureEnd\
\>"], "Graphics",
  PageWidth->Infinity,
  Evaluatable->False,
  ImageSize->{299, 185},
  ImageMargins->{{100, Inherited}, {Inherited, 0}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004[0000^@P10`40000100000800002008200000
P800P020P<30`<3L`:K:l:C8l3<006H009T00<`0000c03<c06Hc09Tc0<`c0?lc001V03=V06IV09UV
0<aV0?mV002I03>I06JI09VI0<bI0?nI003<03?<06K<09W<0<c<0?o<03?o06Ko09Wo0<co0000<c<0
<fH0<iT0<l`0<ol0<`0c<c<c<fHc<iTc<l`c<olc<`1V<c=V<fIV<iUV<laV<omV<`2I<c>I<fJI<iVI
<lbI<onI<`3<<c?<<fK<<iW<<lc<<oo<<`3o<c?o<fKo<iWo<lco<ooo<`00IS<0IVH0IYT0I/`0I_l0
IP0cIS<cIVHcIYTcI/`cI_lcIP1VIS=VIVIVIYUVI/aVI_mVIP2IIS>IIVJIIYVII/bII_nIIP3<IS?<
IVK<IYW<I/c<I_o<IP3oIS?oIVKoIYWoI/coI_ooIP00VC<0VFH0VIT0VL`0VOl0V@0cVC<cVFHcVITc
VL`cVOlcV@1VVC=VVFIVVIUVVLaVVOmVV@2IVC>IVFJIVIVIVLbIVOnIV@3<VC?<VFK<VIW<VLc<VOo<
V@3oVC?oVFKoVIWoVLcoVOooV@00c3<0c6H0c9T0c<`0c?l0c00cc3<cc6Hcc9Tcc<`cc?lcc01Vc3=V
c6IVc9UVc<aVc?mVc02Ic3>Ic6JIc9VIc<bIc?nIc03<c3?<c6K<c9W<c<c<c?o<c03oc3?oc6Koc9Wo
c<coc?ooc3<0ofH0oiT0ol`0o`0coc<cofHcoiTcol`coolco`1Voc=VofIVoiUVolaVoomVo`2Ioc>I
ofJIoiVIolbIoonIo`3<oc?<ofK<oiW<olc<ooo<oc?oofKooiWoolcoo`410@820P<30`@410D51@H6
1PL71`P820T92@X:2P/;2``<30h>3Pl?3a0@414A4A8B4Q<C4a@D5000000000000000000000000000
00000?okl:2PY820P?l0003o0?oo0000ool0o`3ooooooooo;?l00?oo;?l00?oo;?l00?oo;?l004Oo
0`03o`030?oo02?o0`02o`030?oo02;o0P04o`030?oo02?o00<0ool00_l00`3oo`0No`D00_l00`3o
o`02o`030?oo02go0017o`030?oo00;o00<0o`009Ol01P3oo`3o02?o00<0o`000_l00`3o000So`03
0?l000;o00<0o`008Ol01`3oool0o`000_l00`3o000^o`00B?l01`3oool0o`008ol40004o`3o02?o
00<0o`000_l00`3o000So`030?l000;o00<0o`008Ol01`3oool0o`000_l00`3o000^o`00B?l01`3o
ool0o`008ol00`3o0002o`030?l002?o0P03o`030?l002Co00L0oooo0?l0027o00L0oooo0?l000;o
00<0o`00;_l004Oo00<0o`000_l00`3o000To`800_l00`3o000So`030?oo00;o00<0o`008ol00`3o
0002o`030?l0027o00L0oooo0?l000;o00<0o`00;_l004So00<0ool00_l00`3oo`0To`050?ooo`00
9Ol200?o00<0ool08ol00`3oo`02o`030?oo01oo0P04o`030?oo00;o00<0ool0;Ol00?oo;?l00?oo
;?l00?oo;?l00?oo;?l00?oo;?l0023o00<0ool0ool9o`008?l00`3oo`3Oo`<000Co0?oo0P03o`03
0?oo01[o000Po`030?oo0>3o00H0o`00o`02o`030?oo01go000Kon801_l01P3o003o00;o00<0ool0
7Ol0023o00<0o`001_l01@3oool000?o00<0ool01_l01@3oool000?o00<0ool00_l01@3oool000So
00D0oooo0003o`030?oo00Ko00<0ool01Ol00`3oo`02o`050?ooo`001Ol0103o0007o`030?l00080
1?l00`3oo`03o`050?l0o`001_l00`3o0003o`030?l000Ko00D0o`3o0006o`030?l000?o00<0o`00
1_l01@3o0?l000Go00@0ool00ol00`3o0005o`060?oo0?l01Ol00`3o0004o`030?l000_o0P001?l0
ool2023o000Po`030?l000[o00D0oooo0008o`050?ooo`002?l01@3oool000So00D0oooo000<o`03
0?oo00[o00D0oooo0005o`040?oo00Wo00<0o`002_l01@3oool000Ko00<0o`000ol00`3oo`06o`05
0?ooo`002?l01@3oool000So00D0o`3o0008o`050?ooo`001ol00`3oo`02o`030?oo00Go00<0ool0
0_l00`3o000;o`8000?o0?l08ol0023o00<0o`002_l01@3oool000So00D0oooo0008o`050?ooo`00
2?l01@3oool000co00<0ool02_l00`3oo`07o`040?oo00Wo00<0o`002_l01@3oool000So00D0oooo
0008o`050?ooo`002?l01@3oool000So00D0oooo0008o`050?ooo`001ol00`3oo`02o`030?oo00Go
00<0ool00_l00`3oo`0:o`8000?o00009?l0023o00<0o`002_l01@3oool000So00D0oooo0008o`05
0?ooo`002?l01@3oool000co00<0ool02_l00`3oo`07o`040?oo00Wo00<0o`002_l01@3oool000So
00D0oooo0008o`050?ooo`002?l01@3oool000So00D0oooo0008o`050?ooo`001ol00`3oo`02o`03
0?oo00Go00<0ool00_l00`3oo`0co`008?l300[o00D0oooo0008o`050?ooo`002?l01@3oool000So
00D0oooo000<o`030?oo00[o00<0ool01ol0103oo`09o`030?l000[o00D0oooo0008o`050?ooo`00
2?l01@3oool000So00D0oooo0008o`050?ooo`002?l01@3oool000Oo00<0ool00_l00`3oo`05o`03
0?oo00;o00<0ool0<ol0023o00<0o`002_l01@3oool000So00D0oooo0008o`050?ooo`002?l01@3o
ool000co00<0ool02_l00`3oo`07o`040?oo00Wo00<0o`002_l01@3oool000So00D0oooo0008o`05
0?ooo`002?l01@3oool000So00D0oooo0008o`050?ooo`001ol00`3oo`02o`030?oo00Go00<0ool0
0_l00`3oo`0co`008?l00`3o000:o`050?ooo`002?l01@3oool000So00D0oooo0008o`050?ooo`00
3?l00`3oo`0:o`030?oo00Oo00@0ool02Ol00`3o000:o`050?ooo`002?l01@3oool000So00D0oooo
0008o`050?ooo`002?l01@3oool000So00D0oooo0007o`030?oo00;o00<0ool01Ol00`3oo`02o`03
0?oo03?o000Po`030?l000[o00D0oooo0008o`050?ooo`002?l01@3oool000So00D0oooo000<o`03
0?oo00[o00<0ool01ol0103oo`09o`030?l000[o00D0oooo0008o`050?ooo`002?l01@3oool000So
00D0oooo0008o`050?ooo`002?l01@3oool000Oo00<0ool00_l00`3oo`05o`030?oo00;o00<0ool0
<ol0023o0`0:o`050?ooo`002?l01@3oool000So00D0oooo0008o`050?ooo`003?l00`3oo`0:o`03
0?oo00Oo00@0ool02Ol00`3o000:o`050?ooo`002?l01@3oool000So00D0oooo0008o`050?ooo`00
2?l01@3oool000So00D0oooo0007o`030?oo00;o00<0ool01Ol00`3oo`02o`030?oo03?o000Po`03
0?l000[o00D0oooo0008o`050?ooo`002?l01@3oool000So00D0oooo000<o`030?oo00[o00<0ool0
1ol0103oo`09o`030?l000[o00D0oooo0008o`050?ooo`002?l01@3oool000So00D0oooo0008o`05
0?ooo`002?l01@3oool000Oo00<0ool00_l00`3oo`05o`030?oo00;o00<0ool0<ol0023o00<0o`00
2_l01@3oool000So00D0oooo0008o`050?ooo`002?l01@3oool000co00<0ool02_l00`3oo`07o`04
0?oo00Wo00<0o`002_l01@3oool000So00D0oooo0008o`050?ooo`002?l01@3oool000So00D0oooo
0008o`050?ooo`001ol00`3oo`02o`030?oo00Go00<0ool00_l00`3oo`0co`008?l00`3o000:o`05
0?ooo`002?l01@3oool000So00D0oooo0008o`050?ooo`003?l00`3oo`0:o`030?oo00Oo00@0ool0
2Ol00`3o000:o`050?ooo`002?l01@3oool000So00D0oooo0008o`050?ooo`002?l01@3oool000So
00D0oooo0007o`030?oo00;o00<0ool01Ol00`3oo`02o`030?oo03?o000Po`<02_l01@3oool000So
00D0oooo0008o`050?ooo`002?l01@3oool000co00<0ool02_l00`3oo`07o`040?oo00Wo00<0o`00
2_l01@3oool000So00D0oooo0008o`050?ooo`002?l01@3oool000So00D0oooo0008o`050?ooo`00
1ol00`3oo`02o`030?oo00Go00<0ool00_l00`3oo`0co`008?l00`3o000:o`050?ooo`002?l01@3o
ool000So00D0oooo0008o`050?ooo`003?l00`3oo`0:o`030?oo00Oo00@0ool02Ol00`3o000:o`05
0?ooo`002?l01@3oool000So00D0oooo0008o`050?ooo`002?l01@3oool000So00D0oooo0007o`03
0?oo00;o00<0ool01Ol00`3oo`02o`030?oo03?o000Po`030?l000[o00D0oooo0008o`050?ooo`00
2?l01@3oool000So00D0oooo000<o`030?oo00[o00<0ool01ol0103oo`09o`030?l000[o00D0oooo
0008o`050?ooo`002?l01@3oool000So00D0oooo0008o`050?ooo`002?l01@3oool000Oo00<0ool0
0_l00`3oo`05o`030?oo00;o00<0ool0<ol0023o00<0o`002_l01@3oool000So00D0oooo0008o`05
0?ooo`002?l01@3oool000co00<0ool02_l00`3oo`07o`040?oo00Wo00<0o`002_l01@3oool000So
00D0oooo0008o`050?ooo`002?l01@3oool000So00D0oooo0008o`050?ooo`001ol00`3oo`02o`03
0?oo00Go00<0ool00_l00`3oo`0co`008?l300[o00D0oooo0008o`050?ooo`002?l01@3oool000So
00D0oooo000<o`030?oo00[o00<0ool01ol0103oo`09o`030?l000[o00D0oooo0008o`050?ooo`00
2?l01@3oool000So00D0oooo0008o`050?ooo`002?l01@3oool000Oo00<0ool00_l00`3oo`05o`03
0?oo00;o00<0ool0<ol0023o00<0o`002_l01@3oool000So00D0oooo0008o`050?ooo`002?l01@3o
ool000co00<0ool02_l00`3oo`07o`040?oo00Wo00<0o`002_l01@3oool000So00D0oooo0008o`05
0?ooo`002?l01@3oool000So00D0oooo0008o`050?ooo`001ol00`3oo`02o`030?oo00Go00<0ool0
0_l00`3oo`0co`008?l00`3o000:o`050?ooo`002?l01@3oool000So00D0oooo0008o`050?ooo`00
3?l00`3oo`0:o`030?oo00Oo00@0ool02Ol00`3o000:o`050?ooo`002?l01@3oool000So00D0oooo
0008o`050?ooo`002?l01@3oool000So00D0oooo0007o`030?oo00;o00<0ool01Ol00`3oo`02o`03
0?oo03?o000Ho`D00ol00`3o000:o`050?ooo`002?l01@3oool000So00D0oooo0008o`050?ooo`00
3?l00`3oo`0:o`030?oo00Oo00@0ool02Ol00`3o000:o`050?ooo`002?l01@3oool000So00D0oooo
0008o`050?ooo`002?l01@3oool000So00D0oooo0007o`030?oo00;o00<0ool01Ol00`3oo`02o`03
0?oo03?o000Jo`030?oo00?o00<0o`002_l01@3oool000So00D0oooo0008o`050?ooo`002?l01@3o
ool000co00<0ool02_l00`3oo`07o`040?oo00Wo00<0o`002_l01@3oool000So00D0oooo0008o`05
0?ooo`002?l01@3oool000So00D0oooo0008o`050?ooo`001ol00`3oo`02o`030?oo00Go00<0ool0
0_l00`3oo`0co`006_l00`3oo`03o`<02_l01@3oool000So00D0oooo0008o`050?ooo`002?l01@3o
ool000co00<0ool02_l00`3oo`07o`040?oo00Wo00<0o`002_l01@3oool000So00D0oooo0008o`05
0?ooo`002?l01@3oool000So00D0oooo0008o`050?ooo`001ol00`3oo`02o`030?oo00Go00<0ool0
0_l00`3oo`0co`006_l00`3oo`03o`030?l000[o00D0oooo0008o`050?ooo`002?l01@3oool000Oo
0P03o`030?oo00[o00<0ool02_l00`3oo`07o`040?oo00Wo00@0ool02Ol0103oool200Oo00D0oooo
0008o`050?ooo`002?l01@3oool000So00D0oooo0007o`800ol00`3oo`05o`800ol00`3oo`05o`04
0?ooo`80=Ol001[o00<0ool00ol00`3o000:o`050?ooo`002?l01@3oool000So00D0oooo0007o`80
0ol00`3oo`0:o`030?oo00[o00<0ool01ol0103oo`09o`040?oo00Wo00@0oooo0P07o`050?ooo`00
2?l01@3oool000So00D0oooo0008o`050?ooo`001ol200?o00<0ool01Ol200?o00<0ool01Ol0103o
ool203Go000Io`801Ol00`3o000:o`050?ooo`002?l01@3oool000So00D0oooo0007o`800ol00`3o
o`0:o`030?oo00[o00<0ool01ol0103oo`09o`040?oo00Wo00@0oooo0P07o`050?ooo`002?l01@3o
ool000So00D0oooo0008o`050?ooo`001ol200?o00<0ool01Ol200?o00<0ool01Ol0103oool203Go
000Po`<02_l01@3oool000So00D0oooo0008o`050?ooo`001ol200?o00<0ool02_l00`3oo`0:o`03
0?oo00Oo00@0ool02Ol0103oo`09o`040?ooo`801ol01@3oool000So00D0oooo0008o`050?ooo`00
2?l01@3oool000Oo0P03o`030?oo00Go0P03o`030?oo00Go00@0oooo0P0eo`008?l00`3o000:o`05
0?ooo`002?l01@3oool000So00D0oooo0007o`800ol00`3oo`0:o`030?oo00[o00<0ool01ol0103o
o`09o`040?oo00Wo00@0oooo0P07o`050?ooo`002?l01@3oool000So00D0oooo0008o`050?ooo`00
1ol200?o00<0ool01Ol200?o00<0ool01Ol0103oool203Go000Po`030?l000[o00D0oooo0008o`05
0?ooo`002?l01@3oool000Oo0P03o`030?oo00[o00<0ool02_l00`3oo`07o`040?oo00Wo00@0ool0
2Ol0103oool200Oo00D0oooo0008o`050?ooo`002?l01@3oool000So00D0oooo0007o`800ol00`3o
o`05o`800ol00`3oo`05o`040?ooo`80=Ol0023o00<0o`002_l01@3oool000So00D0oooo0008o`05
0?ooo`001ol200?o00<0ool02_l00`3oo`0:o`030?oo00Oo00@0ool02Ol0103oo`09o`040?ooo`80
1ol01@3oool000So00D0oooo0008o`050?ooo`002?l01@3oool000Oo0P03o`030?oo00Go0P03o`03
0?oo00Go00@0oooo0P0eo`008?l300[o00D0oooo0008o`050?ooo`002?l01@3oool000Oo0P03o`03
0?oo00[o00<0ool02_l00`3oo`07o`040?oo00Wo00@0ool02Ol0103oool200Oo00D0oooo0008o`05
0?ooo`002?l01@3oool000So00D0oooo0007o`800ol00`3oo`05o`800ol00`3oo`05o`040?ooo`80
=Ol0023o00<0o`002_l01@3oool000So00D0oooo0008o`050?ooo`001ol200?o00<0ool02_l00`3o
o`0:o`030?oo00Oo00@0ool02Ol0103oo`09o`040?ooo`801ol01@3oool000So00D0oooo0008o`05
0?ooo`002?l01@3oool000Oo0P03o`030?oo00Go0P03o`030?oo00Go00@0oooo0P0eo`008?l00`3o
000:o`050?ooo`002?l01@3oool000So00D0oooo0007o`800ol00`3oo`0:o`030?oo00[o00<0ool0
1ol0103oo`09o`040?oo00Wo00@0oooo0P07o`050?ooo`002?l01@3oool000So00D0oooo0008o`05
0?ooo`001ol200?o00<0ool01Ol200?o00<0ool01Ol0103oool203Go000Po`030?l000[o00D0oooo
0008o`050?ooo`002?l01@3oool000Oo0P03o`030?oo00[o00<0ool02_l00`3oo`07o`040?oo00Wo
00@0ool02Ol0103oool200Oo00D0oooo0008o`050?ooo`002?l01@3oool000So00D0oooo0007o`80
0ol00`3oo`05o`800ol00`3oo`05o`040?ooo`80=Ol0023o0P000ol0o`07o`070?l0o`3o0006o`07
0?l0o`3o0006o`070?l0o`3o0006o`070?l0o`3o000:o`030?l000[o00<0o`001ol00`3oo`02o`03
0?oo00Go00D0oooo0008o`070?l0o`3o0006o`070?l0o`3o0006o`070?l0o`3o0006o`070?l0o`3o
0006o`070?l0o`3o0006o`070?l0o`3o0005o`030?l000;o00<0o`001Ol00`3o0002o`030?l003Co
000Po`040?oo00So00L0o`3o0?l000Ko00L0o`3o0?l000Ko00L0o`3o0?l000Ko00L0o`3o0?l000[o
00<0o`002_l00`3o0007o`030?oo00;o00<0ool01Ol01@3oool000So00L0o`3o0?l000Ko00L0o`3o
0?l000Ko00L0o`3o0?l000Ko00L0o`3o0?l000Ko00L0o`3o0?l000Ko00L0o`3o0?l000Go00<0o`00
0_l00`3o0005o`030?l000;o00<0o`00=?l0023o00@0ool02?l01`3o0?l0o`001_l01`3o0?l0o`00
1_l01`3o0?l0o`001_l01`3o0?l0o`002_l00`3o000:o`030?l000Oo00<0ool00_l00`3oo`05o`05
0?ooo`002?l01`3o0?l0o`001_l01`3o0?l0o`001_l01`3o0?l0o`001_l01`3o0?l0o`001_l01`3o
0?l0o`001_l01`3o0?l0o`001Ol00`3o0002o`030?l000Go00<0o`000_l00`3o000do`008?l0103o
o`08o`070?l0o`3o0006o`070?l0o`3o0006o`070?l0o`3o0006o`070?l0o`3o000:o`030?l000[o
00<0o`001ol00`3oo`02o`030?oo00Go00D0oooo0008o`070?l0o`3o0006o`070?l0o`3o0006o`07
0?l0o`3o0006o`070?l0o`3o0006o`070?l0o`3o0006o`070?l0o`3o0005o`030?l000;o00<0o`00
1Ol00`3o0002o`030?l003Co000Po`040?oo00So00L0o`3o0?l000Ko00L0o`3o0?l000Ko00L0o`3o
0?l000Ko00L0o`3o0?l000[o00<0o`002_l00`3o0007o`030?oo00;o00<0ool01Ol01@3oool000So
00L0o`3o0?l000Ko00L0o`3o0?l000Ko00L0o`3o0?l000Ko00L0o`3o0?l000Ko00L0o`3o0?l000Ko
00L0o`3o0?l000Go00<0o`000_l00`3o0005o`030?l000;o00<0o`00=?l0023o0P000ol0o`07o`07
0?l0o`3o0006o`070?l0o`3o0006o`070?l0o`3o0006o`070?l0o`3o000:o`030?l000[o00<0o`00
1ol00`3oo`02o`030?oo00Go00D0oooo0008o`070?l0o`3o0006o`070?l0o`3o0006o`070?l0o`3o
0006o`070?l0o`3o0006o`070?l0o`3o0006o`070?l0o`3o0005o`030?l000;o00<0o`001Ol00`3o
0002o`030?l003Co000Po`040?oo00So00L0o`3o0?l000Ko00L0o`3o0?l000Ko00L0o`3o0?l000Ko
00L0o`3o0?l000[o00<0o`002_l00`3o0007o`030?oo00;o00<0ool01Ol01@3oool000So00L0o`3o
0?l000Ko00L0o`3o0?l000Ko00L0o`3o0?l000Ko00L0o`3o0?l000Ko00L0o`3o0?l000Ko00L0o`3o
0?l000Go00<0o`000_l00`3o0005o`030?l000;o00<0o`00=?l001Wo0`04o`040?oo00So00L0o`3o
0?l000Ko00L0o`3o0?l000Ko00L0o`3o0?l000Ko00L0o`3o0?l000[o00<0o`002_l00`3o0007o`03
0?oo00;o00<0ool01Ol01@3oool000So00L0o`3o0?l000Ko00L0o`3o0?l000Ko00L0o`3o0?l000Ko
00L0o`3o0?l000Ko00L0o`3o0?l000Ko00L0o`3o0?l000Go00<0o`000_l00`3o0005o`030?l000;o
00<0o`00=?l001Wo00<0ool01?l0103oo`08o`070?l0o`3o0006o`070?l0o`3o0006o`070?l0o`3o
0006o`070?l0o`3o000:o`030?l000[o00<0o`001ol00`3oo`02o`030?oo00Go00D0oooo0008o`07
0?l0o`3o0006o`070?l0o`3o0006o`070?l0o`3o0006o`070?l0o`3o0006o`070?l0o`3o0006o`07
0?l0o`3o0005o`030?l000;o00<0o`001Ol00`3o0002o`030?l003Co000Jo`030?oo00?o0P000ol0
o`07o`070?l0o`3o0006o`070?l0o`3o0006o`070?l0o`3o0006o`070?l0o`3o000:o`030?l000[o
00<0o`001ol00`3oo`02o`030?oo00Go00D0oooo0008o`070?l0o`3o0006o`070?l0o`3o0006o`07
0?l0o`3o0006o`070?l0o`3o0006o`070?l0o`3o0006o`070?l0o`3o0005o`030?l000;o00<0o`00
1Ol00`3o0002o`030?l003Co000Jo`030?oo00?o00@0ool02?l01`3o0?l0o`001_l01`3o0?l0o`00
1_l01`3o0?l0o`001_l01`3o0?l0o`002_l00`3o000:o`030?l000Oo00<0ool00_l00`3oo`05o`05
0?ooo`002?l01`3o0?l0o`001_l01`3o0?l0o`001_l01`3o0?l0o`001_l01`3o0?l0o`001_l01`3o
0?l0o`001_l01`3o0?l0o`001Ol00`3o0002o`030?l000Go00<0o`000_l00`3o000do`006Ol00`3o
0004o`040?oo00So00L0o`3o0?l000Ko00L0o`3o0?l000Ko00L0o`3o0?l000Ko00L0o`3o0?l000[o
00<0o`002_l00`3o0007o`030?oo00;o00<0ool01Ol01@3oool000So00L0o`3o0?l000Ko00L0o`3o
0?l000Ko00L0o`3o0?l000Ko00L0o`3o0?l000Ko00L0o`3o0?l000Ko00L0o`3o0?l000Go00<0o`00
0_l00`3o0005o`030?l000;o00<0o`00=?l001[o00<0ool00ol0103oo`08o`070?l0o`3o0006o`07
0?l0o`3o0006o`070?l0o`3o0006o`070?l0o`3o000:o`030?l000[o00<0o`001ol00`3oo`02o`03
0?oo00Go00D0oooo0008o`070?l0o`3o0006o`070?l0o`3o0006o`070?l0o`3o0006o`070?l0o`3o
0006o`070?l0o`3o0006o`070?l0o`3o0005o`030?l000;o00<0o`001Ol00`3o0002o`030?l003Co
000Po`8000?o0?l01ol01`3o0?l0o`001_l01`3o0?l0o`001_l01`3o0?l0o`001_l01`3o0?l0o`00
2_l00`3o000:o`030?l000Oo00<0ool00_l00`3oo`05o`050?ooo`002?l01`3o0?l0o`001_l01`3o
0?l0o`001_l01`3o0?l0o`001_l01`3o0?l0o`001_l01`3o0?l0o`001_l01`3o0?l0o`001Ol00`3o
0002o`030?l000Go00<0o`000_l00`3o000do`008?l0103oo`08o`070?l0o`3o0006o`070?l0o`3o
0006o`070?l0o`3o0006o`070?l0o`3o000:o`030?l000[o00<0o`001ol00`3oo`02o`030?oo00Go
00D0oooo0008o`070?l0o`3o0006o`070?l0o`3o0006o`070?l0o`3o0006o`070?l0o`3o0006o`07
0?l0o`3o0006o`070?l0o`3o0005o`030?l000;o00<0o`001Ol00`3o0002o`030?l003Co000Po`04
0?oo00So00L0o`3o0?l000Ko00L0o`3o0?l000Ko00L0o`3o0?l000Ko00L0o`3o0?l000[o00<0o`00
2_l00`3o0007o`030?oo00;o00<0ool01Ol01@3oool000So00L0o`3o0?l000Ko00L0o`3o0?l000Ko
00L0o`3o0?l000Ko00L0o`3o0?l000Ko00L0o`3o0?l000Ko00L0o`3o0?l000Go00<0o`000_l00`3o
0005o`030?l000;o00<0o`00=?l0023o00@0ool02?l01`3o0?l0o`001_l01`3o0?l0o`001_l01`3o
0?l0o`001_l01`3o0?l0o`002_l00`3o000:o`030?l000Oo00<0ool00_l00`3oo`05o`050?ooo`00
2?l01`3o0?l0o`001_l01`3o0?l0o`001_l01`3o0?l0o`001_l01`3o0?l0o`001_l01`3o0?l0o`00
1_l01`3o0?l0o`001Ol00`3o0002o`030?l000Go00<0o`000_l00`3o000do`008?l20003o`3o00Oo
00L0o`3o0?l000Ko00L0o`3o0?l000Ko00L0o`3o0?l000Ko00L0o`3o0?l000[o00<0o`002_l00`3o
0007o`030?oo00;o00<0ool01Ol01@3oool000So00L0o`3o0?l000Ko00L0o`3o0?l000Ko00L0o`3o
0?l000Ko00L0o`3o0?l000Ko00L0o`3o0?l000Ko00L0o`3o0?l000Go00<0o`000_l00`3o0005o`03
0?l000;o00<0o`00=?l0023o00@0ool02?l01`3o0?l0o`001_l01`3o0?l0o`001_l01`3o0?l0o`00
1_l01`3o0?l0o`002_l00`3o000:o`030?l000Oo00<0ool00_l00`3oo`05o`050?ooo`002?l01`3o
0?l0o`001_l01`3o0?l0o`001_l01`3o0?l0o`001_l01`3o0?l0o`001_l01`3o0?l0o`001_l01`3o
0?l0o`001Ol00`3o0002o`030?l000Go00<0o`000_l00`3o000do`008?l0103oo`08o`070?l0o`3o
0006o`070?l0o`3o0006o`070?l0o`3o0006o`070?l0o`3o000:o`030?l000[o00<0o`001ol00`3o
o`02o`030?oo00Go00D0oooo0008o`070?l0o`3o0006o`070?l0o`3o0006o`070?l0o`3o0006o`07
0?l0o`3o0006o`070?l0o`3o0006o`070?l0o`3o0005o`030?l000;o00<0o`001Ol00`3o0002o`03
0?l003Co000Po`040?oo00So00L0o`3o0?l000Ko00L0o`3o0?l000Ko00L0o`3o0?l000Ko00L0o`3o
0?l000[o00<0o`002_l00`3o0007o`030?oo00;o00<0ool01Ol01@3oool000So00L0o`3o0?l000Ko
00L0o`3o0?l000Ko00L0o`3o0?l000Ko00L0o`3o0?l000Ko00L0o`3o0?l000Ko00L0o`3o0?l000Go
00<0o`000_l00`3o0005o`030?l000;o00<0o`00=?l0023o0P000ol0o`07o`070?l0o`3o0006o`07
0?l0o`3o0006o`070?l0o`3o0006o`070?l0o`3o000:o`030?l000[o00<0o`001ol00`3oo`02o`03
0?oo00Go00D0oooo0008o`070?l0o`3o0006o`070?l0o`3o0006o`070?l0o`3o0006o`070?l0o`3o
0006o`070?l0o`3o0006o`070?l0o`3o0005o`030?l000;o00<0o`001Ol00`3o0002o`030?l003Co
000Po`040?oo00So00L0o`3o0?l000Ko00L0o`3o0?l000Ko00L0o`3o0?l000Ko00L0o`3o0?l000[o
00<0o`002_l00`3o0007o`030?oo00;o00<0ool01Ol01@3oool000So00L0o`3o0?l000Ko00L0o`3o
0?l000Ko00L0o`3o0?l000Ko00L0o`3o0?l000Ko00L0o`3o0?l000Ko00L0o`3o0?l000Go00<0o`00
0_l00`3o0005o`030?l000;o00<0o`00=?l0023o00@0ool02?l01`3o0?l0o`001_l01`3o0?l0o`00
1_l01`3o0?l0o`001_l01`3o0?l0o`002_l00`3o000:o`030?l000Oo00<0ool00_l00`3oo`05o`05
0?ooo`002?l01`3o0?l0o`001_l01`3o0?l0o`001_l01`3o0?l0o`001_l01`3o0?l0o`001_l01`3o
0?l0o`001_l01`3o0?l0o`001Ol00`3o0002o`030?l000Go00<0o`000_l00`3o000do`008?l0103o
o`08o`070?l0o`3o0006o`070?l0o`3o0006o`070?l0o`3o0006o`070?l0o`3o000:o`030?l000[o
00<0o`001ol00`3oo`02o`030?oo00Go00D0oooo0008o`070?l0o`3o0006o`070?l0o`3o0006o`07
0?l0o`3o0006o`070?l0o`3o0006o`070?l0o`3o0006o`070?l0o`3o0005o`030?l000;o00<0o`00
1Ol00`3o0002o`030?l003Co000Po`040?oo00So00L0o`3o0?l000Ko00L0o`3o0?l000Ko00L0o`3o
0?l000Ko00L0o`3o0?l000[o00<0o`002_l00`3o0007o`030?oo00;o00<0ool01Ol01@3oool000So
00L0o`3o0?l000Ko00L0o`3o0?l000Ko00L0o`3o0?l000Ko00L0o`3o0?l000Ko00L0o`3o0?l000Ko
00L0o`3o0?l000Go00<0o`000_l00`3o0005o`030?l000;o00<0o`00=?l0023o0P000ol0o`07o`07
0?l0o`3o0006o`070?l0o`3o0006o`070?l0o`3o0006o`070?l0o`3o000:o`030?l000[o00<0o`00
1ol00`3oo`02o`030?oo00Go00D0oooo0008o`070?l0o`3o0006o`070?l0o`3o0006o`070?l0o`3o
0006o`070?l0o`3o0006o`070?l0o`3o0006o`070?l0o`3o0005o`030?l000;o00<0o`001Ol00`3o
0002o`030?l003Co000Po`040?oo00So00L0o`3o0?l000Ko00L0o`3o0?l000Ko00L0o`3o0?l000Ko
00L0o`3o0?l000[o00<0o`002_l00`3o0007o`030?oo00;o00<0ool01Ol01@3oool000So00L0o`3o
0?l000Ko00L0o`3o0?l000Ko00L0o`3o0?l000Ko00L0o`3o0?l000Ko00L0o`3o0?l000Ko00L0o`3o
0?l000Go00<0o`000_l00`3o0005o`030?l000;o00<0o`00=?l001Wo0P05o`040?oo00So00L0o`3o
0?l000Ko00L0o`3o0?l000Ko00L0o`3o0?l000Ko00L0o`3o0?l000[o00<0o`002_l00`3o0007o`03
0?oo00;o00<0ool01Ol01@3oool000So00L0o`3o0?l000Ko00L0o`3o0?l000Ko00L0o`3o0?l000Ko
00L0o`3o0?l000Ko00L0o`3o0?l000Ko00L0o`3o0?l000Go00<0o`000_l00`3o0005o`030?l000;o
00<0o`00=?l001_o00<0ool00_l0103oo`08o`070?l0o`3o0006o`070?l0o`3o0006o`070?l0o`3o
0006o`070?l0o`3o000:o`030?l000[o00<0o`001ol00`3oo`02o`030?oo00Go00D0oooo0008o`07
0?l0o`3o0006o`070?l0o`3o0006o`070?l0o`3o0006o`070?l0o`3o0006o`070?l0o`3o0006o`07
0?l0o`3o0005o`030?l000;o00<0o`001Ol00`3o0002o`030?l003Co000Jo`030?oo00?o0P000ol0
o`07o`070?l0o`3o0006o`070?l0o`3o0006o`070?l0o`3o0006o`070?l0o`3o000:o`030?l000[o
00<0o`001ol00`3oo`02o`030?oo00Go00D0oooo0008o`070?l0o`3o0006o`070?l0o`3o0006o`07
0?l0o`3o0006o`070?l0o`3o0006o`070?l0o`3o0006o`070?l0o`3o0005o`030?l000;o00<0o`00
1Ol00`3o0002o`030?l003Co000Ko`030?oo00;o00@0ool02?l01`3o0?l0o`001_l01`3o0?l0o`00
1_l01`3o0?l0o`001_l01`3o0?l0o`002_l00`3o000:o`030?l000Oo00<0ool00_l00`3oo`05o`05
0?ooo`002?l01`3o0?l0o`001_l01`3o0?l0o`001_l01`3o0?l0o`001_l01`3o0?l0o`001_l01`3o
0?l0o`001_l01`3o0?l0o`001Ol00`3o0002o`030?l000Go00<0o`000_l00`3o000do`006Ol00`3o
0004o`040?oo00So00L0o`3o0?l000Ko00L0o`3o0?l000Ko00L0o`3o0?l000Ko00L0o`3o0?l000[o
00<0o`002_l00`3o0007o`030?oo00;o00<0ool01Ol01@3oool000So00L0o`3o0?l000Ko00L0o`3o
0?l000Ko00L0o`3o0?l000Ko00L0o`3o0?l000Ko00L0o`3o0?l000Ko00L0o`3o0?l000Go00<0o`00
0_l00`3o0005o`030?l000;o00<0o`00=?l001[o00<0ool00ol0103oo`08o`070?l0o`3o0006o`07
0?l0o`3o0006o`070?l0o`3o0005o`080?oo0?l0o`0:o`030?l000[o00<0o`001ol00`3oo`02o`03
0?oo00Go00<0ool00_l00`3oo`05o`050?l0o`000_l00`3oo`03o`070?l0o`3o0006o`070?l0o`3o
0006o`070?l0o`3o0006o`070?l0o`3o0005o`080?oo0?l0o`05o`080?oo0?l0o`05o`050?l0o`00
0_l00`3oo`0bo`008?l20003o`3o00Oo00L0o`3o0?l000Ko00L0o`3o0?l000Ko00L0o`3o0?l000Go
00P0ool0o`3o00[o00<0o`002_l00`3o0007o`030?oo00;o00<0ool01Ol00`3oo`02o`030?oo00Go
00D0o`3o0002o`030?oo00?o00L0o`3o0?l000Ko00L0o`3o0?l000Ko00L0o`3o0?l000Ko00L0o`3o
0?l000Go00P0ool0o`3o00Go00P0ool0o`3o00Go00D0o`3o0002o`030?oo03;o000Po`040?oo00So
00L0o`3o0?l000Ko00L0o`3o0?l000Ko00L0o`3o0?l000Go00P0ool0o`3o00[o00<0o`002_l00`3o
0007o`030?oo00;o00<0ool01Ol00`3oo`02o`030?oo00Go00D0o`3o0002o`030?oo00?o00L0o`3o
0?l000Ko00L0o`3o0?l000Ko00L0o`3o0?l000Ko00L0o`3o0?l000Go00P0ool0o`3o00Go00P0ool0
o`3o00Go00D0o`3o0002o`030?oo03;o000Po`040?oo00So00L0o`3o0?l000Ko00L0o`3o0?l000Ko
00L0o`3o0?l000Go00P0ool0o`3o00[o00<0o`002_l00`3o0007o`030?oo00;o00<0ool01Ol00`3o
o`02o`030?oo00Go00D0o`3o0002o`030?oo00?o00L0o`3o0?l000Ko00L0o`3o0?l000Ko00L0o`3o
0?l000Ko00L0o`3o0?l000Go00P0ool0o`3o00Go00P0ool0o`3o00Go00D0o`3o0002o`030?oo03;o
000Po`040?oo00So00L0o`3o0?l000Ko00L0o`3o0?l000Ko00L0o`3o0?l000Go00P0ool0o`3o00[o
00<0o`002_l00`3o0007o`030?oo00;o00<0ool01Ol00`3oo`02o`030?oo00Go00D0o`3o0002o`03
0?oo00?o00L0o`3o0?l000Ko00L0o`3o0?l000Ko00L0o`3o0?l000Ko00L0o`3o0?l000Go00P0ool0
o`3o00Go00P0ool0o`3o00Go00D0o`3o0002o`030?oo03;o000Po`8000?o0?l01ol01`3o0?l0o`00
1_l01`3o0?l0o`001_l01`3o0?l0o`001Ol0203oo`3o0?l02_l00`3o000:o`030?l000Oo00<0ool0
0_l00`3oo`05o`030?oo00;o00<0ool01Ol01@3o0?l000;o00<0ool00ol01`3o0?l0o`001_l01`3o
0?l0o`001_l01`3o0?l0o`001_l01`3o0?l0o`001Ol0203oo`3o0?l01Ol0203oo`3o0?l01Ol01@3o
0?l000;o00<0ool0<_l0023o00@0ool02?l01`3o0?l0o`001_l01`3o0?l0o`001_l01`3o0?l0o`00
1Ol0203oo`3o0?l02_l00`3o000:o`030?l000Oo00<0ool00_l00`3oo`05o`030?oo00;o00<0ool0
1Ol01@3o0?l000;o00<0ool00ol01`3o0?l0o`001_l01`3o0?l0o`001_l01`3o0?l0o`001_l01`3o
0?l0o`001Ol0203oo`3o0?l01Ol0203oo`3o0?l01Ol01@3o0?l000;o00<0ool0<_l0023o00@0ool0
2?l01`3o0?l0o`001_l01`3o0?l0o`001_l01`3o0?l0o`001Ol0203oo`3o0?l02_l00`3o000:o`03
0?l000Oo00<0ool00_l00`3oo`05o`030?oo00;o00<0ool01Ol01@3o0?l000;o00<0ool00ol01`3o
0?l0o`001_l01`3o0?l0o`001_l01`3o0?l0o`001_l01`3o0?l0o`001Ol0203oo`3o0?l01Ol0203o
o`3o0?l01Ol01@3o0?l000;o00<0ool0<_l0023o00@0ool02?l01`3o0?l0o`001_l01`3o0?l0o`00
1_l01`3o0?l0o`001Ol0203oo`3o0?l02_l00`3o000:o`030?l000Oo00<0ool00_l00`3oo`05o`03
0?oo00;o00<0ool01Ol01@3o0?l000;o00<0ool00ol01`3o0?l0o`001_l01`3o0?l0o`001_l01`3o
0?l0o`001_l01`3o0?l0o`001Ol0203oo`3o0?l01Ol0203oo`3o0?l01Ol01@3o0?l000;o00<0ool0
<_l0023o00@0ool02?l01`3o0?l0o`001_l01`3o0?l0o`001_l01`3o0?l0o`001Ol0203oo`3o0?l0
2_l00`3o000:o`030?l000Oo00<0ool00_l00`3oo`05o`030?oo00;o00<0ool01Ol01@3o0?l000;o
00<0ool00ol01`3o0?l0o`001_l01`3o0?l0o`001_l01`3o0?l0o`001_l01`3o0?l0o`001Ol0203o
o`3o0?l01Ol0203oo`3o0?l01Ol01@3o0?l000;o00<0ool0<_l0023o0P000ol0o`07o`070?l0o`3o
0006o`070?l0o`3o0006o`070?l0o`3o0005o`080?oo0?l0o`0:o`030?l000[o00<0o`001ol00`3o
o`02o`030?oo00Go00<0ool00_l00`3oo`05o`050?l0o`000_l00`3oo`03o`070?l0o`3o0006o`07
0?l0o`3o0006o`070?l0o`3o0006o`070?l0o`3o0005o`080?oo0?l0o`05o`080?oo0?l0o`05o`05
0?l0o`000_l00`3oo`0bo`008?l0103oo`08o`070?l0o`3o0006o`070?l0o`3o0006o`070?l0o`3o
0005o`080?oo0?l0o`0:o`030?l000[o00<0o`001ol00`3oo`02o`030?oo00Go00<0ool00_l00`3o
o`05o`050?l0o`000_l00`3oo`03o`070?l0o`3o0006o`070?l0o`3o0006o`070?l0o`3o0006o`07
0?l0o`3o0005o`080?oo0?l0o`05o`080?oo0?l0o`05o`050?l0o`000_l00`3oo`0bo`008?l0103o
o`08o`070?l0o`3o0006o`070?l0o`3o0006o`070?l0o`3o0005o`080?oo0?l0o`0:o`030?l000[o
00<0o`001ol00`3oo`02o`030?oo00Go00<0ool00_l00`3oo`05o`050?l0o`000_l00`3oo`03o`07
0?l0o`3o0006o`070?l0o`3o0006o`070?l0o`3o0006o`070?l0o`3o0005o`080?oo0?l0o`05o`08
0?oo0?l0o`05o`050?l0o`000_l00`3oo`0bo`008?l0103oo`08o`070?l0o`3o0006o`070?l0o`3o
0006o`070?l0o`3o0005o`080?oo0?l0o`0:o`030?l000[o00<0o`001ol00`3oo`02o`030?oo00Go
00<0ool00_l00`3oo`05o`050?l0o`000_l00`3oo`03o`070?l0o`3o0006o`070?l0o`3o0006o`07
0?l0o`3o0006o`070?l0o`3o0005o`080?oo0?l0o`05o`080?oo0?l0o`05o`050?l0o`000_l00`3o
o`0bo`008?l20003o`3o00Oo00L0o`3o0?l000Ko00L0o`3o0?l000Ko00L0o`3o0?l000Go00P0ool0
o`3o00[o00<0o`002_l00`3o0007o`030?oo00;o00<0ool01Ol00`3oo`02o`030?oo00Go00D0o`3o
0002o`030?oo00?o00L0o`3o0?l000Ko00L0o`3o0?l000Ko00L0o`3o0?l000Ko00L0o`3o0?l000Go
00P0ool0o`3o00Go00P0ool0o`3o00Go00D0o`3o0002o`030?oo03;o000Po`040?oo00So00L0o`3o
0?l000Ko00L0o`3o0?l000Ko00L0o`3o0?l000Go00P0ool0o`3o00[o00<0o`002_l00`3o0007o`03
0?oo00;o00<0ool01Ol00`3oo`02o`030?oo00Go00D0o`3o0002o`030?oo00?o00L0o`3o0?l000Ko
00L0o`3o0?l000Ko00L0o`3o0?l000Ko00L0o`3o0?l000Go00P0ool0o`3o00Go00P0ool0o`3o00Go
00D0o`3o0002o`030?oo03;o000Jo`<00ol0103oo`08o`070?l0o`3o0006o`070?l0o`3o0006o`07
0?l0o`3o0005o`080?oo0?l0o`0:o`030?l000[o00<0o`001ol00`3oo`02o`030?oo00Go00<0ool0
0_l00`3oo`05o`050?l0o`000_l00`3oo`03o`070?l0o`3o0006o`070?l0o`3o0006o`070?l0o`3o
0006o`070?l0o`3o0005o`080?oo0?l0o`05o`080?oo0?l0o`05o`050?l0o`000_l00`3oo`0bo`00
6ol00`3oo`02o`040?oo00So00L0o`3o0?l000Ko00L0o`3o0?l000Ko00L0o`3o0?l000Go00P0ool0
o`3o00[o00<0o`002_l00`3o0007o`030?oo00;o00<0ool01Ol00`3oo`02o`030?oo00Go00D0o`3o
0002o`030?oo00?o00L0o`3o0?l000Ko00L0o`3o0?l000Ko00L0o`3o0?l000Ko00L0o`3o0?l000Go
00P0ool0o`3o00Go00P0ool0o`3o00Go00D0o`3o0002o`030?oo03;o000Io`@00ol20003o`3o00Oo
00L0o`3o0?l000Ko00L0o`3o0?l000Ko00L0o`3o0?l000Go00P0ool0o`3o00[o00<0o`002_l00`3o
0007o`030?oo00;o00<0ool01Ol00`3oo`02o`030?oo00Go00D0o`3o0002o`030?oo00?o00L0o`3o
0?l000Ko00L0o`3o0?l000Ko00L0o`3o0?l000Ko00L0o`3o0?l000Go00P0ool0o`3o00Go00P0ool0
o`3o00Go00D0o`3o0002o`030?oo03;o000Io`030?l000Co00@0ool02?l01`3o0?l0o`001_l01`3o
0?l0o`001_l01`3o0?l0o`001Ol0203oo`3o0?l02_l00`3o000:o`030?l000Oo00<0ool00_l00`3o
o`05o`030?oo00;o00<0ool01Ol01@3o0?l000;o00<0ool00ol01`3o0?l0o`001_l01`3o0?l0o`00
1_l01`3o0?l0o`001_l01`3o0?l0o`001Ol0203oo`3o0?l01Ol0203oo`3o0?l01Ol01@3o0?l000;o
00<0ool0<_l001[o0P04o`040?oo00So00L0o`3o0?l000Ko00L0o`3o0?l000Ko00L0o`3o0?l000Go
00P0ool0o`3o00[o00<0o`002_l00`3o0007o`030?oo00;o00<0ool01Ol00`3oo`02o`030?oo00Go
00D0o`3o0002o`030?oo00?o00L0o`3o0?l000Ko00L0o`3o0?l000Ko00L0o`3o0?l000Ko00L0o`3o
0?l000Go00P0ool0o`3o00Go00P0ool0o`3o00Go00D0o`3o0002o`030?oo03;o000Ko`030?oo00;o
00@0ool02?l01`3o0?l0o`001_l01`3o0?l0o`001_l01`3o0?l0o`001Ol0203oo`3o0?l02_l00`3o
000:o`030?l000Oo00<0ool00_l00`3oo`05o`030?oo00;o00<0ool01Ol01@3o0?l000;o00<0ool0
0ol01`3o0?l0o`001_l01`3o0?l0o`001_l01`3o0?l0o`001_l01`3o0?l0o`001Ol0203oo`3o0?l0
1Ol0203oo`3o0?l01Ol01@3o0?l000;o00<0ool0<_l0023o0P000ol0o`07o`070?l0o`3o0006o`07
0?l0o`3o0006o`070?l0o`3o0005o`080?oo0?l0o`0:o`030?l000[o00<0o`001ol00`3oo`02o`03
0?oo00Go00<0ool00_l00`3oo`05o`050?l0o`000_l00`3oo`03o`070?l0o`3o0006o`070?l0o`3o
0006o`070?l0o`3o0006o`070?l0o`3o0005o`080?oo0?l0o`05o`080?oo0?l0o`05o`050?l0o`00
0_l00`3oo`0bo`008?l0103oo`08o`070?l0o`3o0006o`070?l0o`3o0006o`070?l0o`3o0005o`08
0?oo0?l0o`0:o`030?l000[o00<0o`001ol00`3oo`02o`030?oo00Go00<0ool00_l00`3oo`05o`05
0?l0o`000_l00`3oo`03o`070?l0o`3o0006o`070?l0o`3o0006o`070?l0o`3o0006o`070?l0o`3o
0005o`080?oo0?l0o`05o`080?oo0?l0o`05o`050?l0o`000_l00`3oo`0bo`008?l0103oo`08o`07
0?l0o`3o0006o`070?l0o`3o0006o`070?l0o`3o0005o`080?oo0?l0o`0:o`030?l000[o00<0o`00
1ol00`3oo`02o`030?oo00Go00<0ool00_l00`3oo`05o`050?l0o`000_l00`3oo`03o`070?l0o`3o
0006o`070?l0o`3o0006o`070?l0o`3o0006o`070?l0o`3o0005o`080?oo0?l0o`05o`080?oo0?l0
o`05o`050?l0o`000_l00`3oo`0bo`008?l0103oo`08o`070?l0o`3o0006o`070?l0o`3o0006o`07
0?l0o`3o0005o`080?oo0?l0o`0:o`030?l000[o00<0o`001ol00`3oo`02o`030?oo00Go00<0ool0
0_l00`3oo`05o`050?l0o`000_l00`3oo`03o`070?l0o`3o0006o`070?l0o`3o0006o`070?l0o`3o
0006o`070?l0o`3o0005o`080?oo0?l0o`05o`080?oo0?l0o`05o`050?l0o`000_l00`3oo`0bo`00
8?l20003o`3o00Oo00L0o`3o0?l000Ko00L0o`3o0?l000Ko00L0o`3o0?l000Go00P0ool0o`3o00[o
00<0o`002_l00`3o0007o`030?oo00;o00<0ool01Ol00`3oo`02o`030?oo00Go00D0o`3o0002o`03
0?oo00?o00L0o`3o0?l000Ko00L0o`3o0?l000Ko00L0o`3o0?l000Ko00L0o`3o0?l000Go00P0ool0
o`3o00Go00P0ool0o`3o00Go00D0o`3o0002o`030?oo03;o000Po`040?oo00So00L0o`3o0?l000Ko
00L0o`3o0?l000Ko00L0o`3o0?l000Go00P0ool0o`3o00[o00<0o`002_l00`3o0007o`030?oo00;o
00<0ool01Ol00`3oo`02o`030?oo00Go00D0o`3o0002o`030?oo00?o00L0o`3o0?l000Ko00L0o`3o
0?l000Ko00L0o`3o0?l000Ko00L0o`3o0?l000Go00P0ool0o`3o00Go00P0ool0o`3o00Go00D0o`3o
0002o`030?oo03;o000Po`040?oo00So00L0o`3o0?l000Ko00L0o`3o0?l000Ko00L0o`3o0?l000Go
00P0ool0o`3o00[o00<0o`002_l00`3o0007o`030?oo00;o00<0ool01Ol00`3oo`02o`030?oo00Go
00D0o`3o0002o`030?oo00?o00L0o`3o0?l000Ko00L0o`3o0?l000Ko00L0o`3o0?l000Ko00L0o`3o
0?l000Go00P0ool0o`3o00Go00P0ool0o`3o00Go00D0o`3o0002o`030?oo03;o000Po`040?oo00So
00L0o`3o0?l000Ko00L0o`3o0?l000Ko00L0o`3o0?l000Go00P0ool0o`3o00[o00<0o`002_l00`3o
0007o`030?oo00;o00<0ool01Ol00`3oo`02o`030?oo00Go00D0o`3o0002o`030?oo00?o00L0o`3o
0?l000Ko00L0o`3o0?l000Ko00L0o`3o0?l000Ko00L0o`3o0?l000Go00P0ool0o`3o00Go00P0ool0
o`3o00Go00D0o`3o0002o`030?oo03;o000Po`040?oo00So00L0o`3o0?l000Ko00L0o`3o0?l000Ko
00L0o`3o0?l000Go00P0ool0o`3o00[o00<0o`002_l00`3o0007o`030?oo00;o00<0ool01Ol00`3o
o`02o`030?oo00Go00D0o`3o0002o`030?oo00?o00L0o`3o0?l000Ko00L0o`3o0?l000Ko00L0o`3o
0?l000Ko00L0o`3o0?l000Go00P0ool0o`3o00Go00P0ool0o`3o00Go00D0o`3o0002o`030?oo03;o
000Po`8000?o0?l01ol01`3o0?l0o`001_l01`3o0?l0o`001_l01`3o0?l0o`001Ol0203oo`3o0?l0
2_l00`3o000:o`030?l000Oo00<0ool00_l00`3oo`05o`030?oo00;o00<0ool01Ol01@3o0?l000;o
00<0ool00ol01`3o0?l0o`001_l01`3o0?l0o`001_l01`3o0?l0o`001_l01`3o0?l0o`001Ol0203o
o`3o0?l01Ol0203oo`3o0?l01Ol01@3o0?l000;o00<0ool0<_l0023o00@0ool02?l01`3o0?l0o`00
1_l01`3o0?l0o`001_l01`3o0?l0o`001Ol0203oo`3o0?l02_l00`3o000:o`030?l000Oo00<0ool0
0_l00`3oo`05o`030?oo00;o00<0ool01Ol01@3o0?l000;o00<0ool00ol01`3o0?l0o`001_l01`3o
0?l0o`001_l01`3o0?l0o`001_l01`3o0?l0o`001Ol0203oo`3o0?l01Ol0203oo`3o0?l01Ol01@3o
0?l000;o00<0ool0<_l0023o00D0oooo0006o`050?ooo`000ol00`3oo`02o`050?ooo`000ol00`3o
o`02o`050?ooo`000ol00`3oo`02o`050?ooo`000ol00`3oo`06o`050?ooo`002?l01@3oool000Go
00<0ool01?l00`3oo`03o`030?oo00?o00<0ool01?l01@3oool000?o00<0ool00_l01@3oool000?o
00<0ool00_l01@3oool000?o00<0ool00_l01@3oool000?o00<0ool00_l01@3oool000?o00<0ool0
0_l01@3oool000?o00D0oooo0003o`800ol01@3oool000?o0P03o`030?oo037o000Po`050?ooo`00
1_l01@3oool000?o00<0ool00_l01@3oool000?o00<0ool00_l01@3oool000?o00<0ool00_l01@3o
ool000?o00<0ool01_l01@3oool000So00D0oooo0005o`030?oo00Co00<0ool00ol00`3oo`03o`03
0?oo00Co00D0oooo0003o`030?oo00;o00D0oooo0003o`030?oo00;o00D0oooo0003o`030?oo00;o
00D0oooo0003o`030?oo00;o00D0oooo0003o`030?oo00;o00D0oooo0003o`050?ooo`000ol200?o
00D0oooo0003o`800ol00`3oo`0ao`008?l200;o00<0ool01?l01@3oool000?o00<0ool00_l01@3o
ool000?o00<0ool00_l01@3oool000?o00<0ool00_l01@3oool000?o00<0ool01_l01@3oool000So
00D0oooo0005o`030?oo00Co00<0ool00ol00`3oo`03o`030?oo00Co00D0oooo0003o`030?oo00;o
00D0oooo0003o`030?oo00;o00D0oooo0003o`030?oo00;o00D0oooo0003o`030?oo00;o00D0oooo
0003o`030?oo00;o00D0oooo0003o`050?ooo`000ol200?o00D0oooo0003o`800ol00`3oo`0ao`00
8?l01@3oool000Ko00D0oooo0003o`030?oo00;o00D0oooo0003o`030?oo00;o00D0oooo0003o`03
0?oo00;o00D0oooo0003o`030?oo00Ko00D0oooo0008o`050?ooo`001Ol00`3oo`04o`030?oo00?o
00<0ool00ol00`3oo`04o`050?ooo`000ol00`3oo`02o`050?ooo`000ol00`3oo`02o`050?ooo`00
0ol00`3oo`02o`050?ooo`000ol00`3oo`02o`050?ooo`000ol00`3oo`02o`050?ooo`000ol01@3o
ool000?o0P03o`050?ooo`000ol200?o00<0ool0<Ol001[o00<0ool00ol01@3oool000Ko00D0oooo
0003o`030?oo00;o00D0oooo0003o`030?oo00;o00D0oooo0003o`030?oo00;o00D0oooo0003o`03
0?oo00Ko00D0oooo0008o`050?ooo`001Ol00`3oo`04o`030?oo00?o00<0ool00ol00`3oo`04o`05
0?ooo`000ol00`3oo`02o`050?ooo`000ol00`3oo`02o`050?ooo`000ol00`3oo`02o`050?ooo`00
0ol00`3oo`02o`050?ooo`000ol00`3oo`02o`050?ooo`000ol01@3oool000?o0P03o`050?ooo`00
0ol200?o00<0ool0<Ol001Wo00<0o`001?l01@3oool000Ko00D0oooo0003o`030?oo00;o00D0oooo
0003o`030?oo00;o00D0oooo0003o`030?oo00;o00D0oooo0003o`030?oo00Ko00D0oooo0008o`05
0?ooo`001Ol00`3oo`04o`030?oo00?o00<0ool00ol00`3oo`04o`050?ooo`000ol00`3oo`02o`05
0?ooo`000ol00`3oo`02o`050?ooo`000ol00`3oo`02o`050?ooo`000ol00`3oo`02o`050?ooo`00
0ol00`3oo`02o`050?ooo`000ol01@3oool000?o0P03o`050?ooo`000ol200?o00<0ool0<Ol001_o
00<0ool00_l200;o00<0ool01?l01@3oool000?o00<0ool00_l01@3oool000?o00<0ool00_l01@3o
ool000?o00<0ool00_l01@3oool000?o00<0ool01_l01@3oool000So00D0oooo0005o`030?oo00Co
00<0ool00ol00`3oo`03o`030?oo00Co00D0oooo0003o`030?oo00;o00D0oooo0003o`030?oo00;o
00D0oooo0003o`030?oo00;o00D0oooo0003o`030?oo00;o00D0oooo0003o`030?oo00;o00D0oooo
0003o`050?ooo`000ol200?o00D0oooo0003o`800ol00`3oo`0ao`006Ol200Go00D0oooo0006o`05
0?ooo`000ol00`3oo`02o`050?ooo`000ol00`3oo`02o`050?ooo`000ol00`3oo`02o`050?ooo`00
0ol00`3oo`06o`050?ooo`002?l01@3oool000Go00<0ool01?l00`3oo`03o`030?oo00?o00<0ool0
1?l01@3oool000?o00<0ool00_l01@3oool000?o00<0ool00_l01@3oool000?o00<0ool00_l01@3o
ool000?o00<0ool00_l01@3oool000?o00<0ool00_l01@3oool000?o00D0oooo0003o`800ol01@3o
ool000?o0P03o`030?oo037o000Io`030?oo00Co00D0oooo0006o`050?ooo`000ol00`3oo`02o`05
0?ooo`000ol00`3oo`02o`050?ooo`000ol00`3oo`02o`050?ooo`000ol00`3oo`06o`050?ooo`00
2?l01@3oool000Go00<0ool01?l00`3oo`03o`030?oo00?o00<0ool01?l01@3oool000?o00<0ool0
0_l01@3oool000?o00<0ool00_l01@3oool000?o00<0ool00_l01@3oool000?o00<0ool00_l01@3o
ool000?o00<0ool00_l01@3oool000?o00D0oooo0003o`800ol01@3oool000?o0P03o`030?oo037o
000Io`<01?l01@3oool000Ko00D0oooo0003o`030?oo00;o00D0oooo0003o`030?oo00;o00D0oooo
0003o`030?oo00;o00D0oooo0003o`030?oo00Ko00D0oooo0008o`050?ooo`001Ol00`3oo`04o`03
0?oo00?o00<0ool00ol00`3oo`04o`050?ooo`000ol00`3oo`02o`050?ooo`000ol00`3oo`02o`05
0?ooo`000ol00`3oo`02o`050?ooo`000ol00`3oo`02o`050?ooo`000ol00`3oo`02o`050?ooo`00
0ol01@3oool000?o0P03o`050?ooo`000ol200?o00<0ool0<Ol0023o0P02o`030?oo00Co00D0oooo
0003o`030?oo00;o00D0oooo0003o`030?oo00;o00D0oooo0003o`030?oo00;o00D0oooo0003o`03
0?oo00Ko00D0oooo0008o`050?ooo`001Ol00`3oo`04o`030?oo00?o00<0ool00ol00`3oo`04o`05
0?ooo`000ol00`3oo`02o`050?ooo`000ol00`3oo`02o`050?ooo`000ol00`3oo`02o`050?ooo`00
0ol00`3oo`02o`050?ooo`000ol00`3oo`02o`050?ooo`000ol01@3oool000?o0P03o`050?ooo`00
0ol200?o00<0ool0<Ol0023o00D0oooo0006o`050?ooo`000ol00`3oo`02o`050?ooo`000ol00`3o
o`02o`050?ooo`000ol01@3oool000Co00D0oooo0008o`050?ooo`002?l01@3oool000Go00<0ool0
1?l00`3oo`03o`030?oo00Co00<0ool00ol01@3oool000Co00D0oooo0003o`050?ooo`001?l01@3o
ool000?o00<0ool00_l01@3oool000?o00<0ool00_l01@3oool000?o00D0oooo0004o`050?ooo`00
0ol00`3oo`02o`050?ooo`000ol01@3oool000Co00<0ool0<Ol0023o00D0oooo0006o`050?ooo`00
0ol00`3oo`02o`050?ooo`000ol00`3oo`02o`050?ooo`000ol01@3oool000Co00D0oooo0008o`05
0?ooo`002?l01@3oool000Go00<0ool01?l00`3oo`03o`030?oo00Co00<0ool00ol01@3oool000Co
00D0oooo0003o`050?ooo`001?l01@3oool000?o00<0ool00_l01@3oool000?o00<0ool00_l01@3o
ool000?o00D0oooo0004o`050?ooo`000ol00`3oo`02o`050?ooo`000ol01@3oool000Co00<0ool0
<Ol0023o00D0oooo0006o`050?ooo`000ol00`3oo`02o`050?ooo`000ol00`3oo`02o`050?ooo`00
0ol01@3oool000Co00D0oooo0008o`050?ooo`002?l01@3oool000Go00<0ool01?l00`3oo`03o`03
0?oo00Co00<0ool00ol01@3oool000Co00D0oooo0003o`050?ooo`001?l01@3oool000?o00<0ool0
0_l01@3oool000?o00<0ool00_l01@3oool000?o00D0oooo0004o`050?ooo`000ol00`3oo`02o`05
0?ooo`000ol01@3oool000Co00<0ool0<Ol0023o00D0oooo0006o`050?ooo`000ol00`3oo`02o`05
0?ooo`000ol00`3oo`02o`050?ooo`000ol01@3oool000Co00D0oooo0008o`050?ooo`002?l01@3o
ool000Go00<0ool01?l00`3oo`03o`030?oo00Co00<0ool00ol01@3oool000Co00D0oooo0003o`05
0?ooo`001?l01@3oool000?o00<0ool00_l01@3oool000?o00<0ool00_l01@3oool000?o00D0oooo
0004o`050?ooo`000ol00`3oo`02o`050?ooo`000ol01@3oool000Co00<0ool0<Ol0023o0P02o`03
0?oo00Co00D0oooo0003o`030?oo00;o00D0oooo0003o`030?oo00;o00D0oooo0003o`050?ooo`00
1?l01@3oool000So00D0oooo0008o`050?ooo`001Ol00`3oo`04o`030?oo00?o00<0ool01?l00`3o
o`03o`050?ooo`001?l01@3oool000?o00D0oooo0004o`050?ooo`000ol00`3oo`02o`050?ooo`00
0ol00`3oo`02o`050?ooo`000ol01@3oool000Co00D0oooo0003o`030?oo00;o00D0oooo0003o`05
0?ooo`001?l00`3oo`0ao`008?l01@3oool000Ko00D0oooo0003o`030?oo00;o00D0oooo0003o`03
0?oo00;o00D0oooo0003o`050?ooo`001?l01@3oool000So00D0oooo0008o`050?ooo`001Ol00`3o
o`04o`030?oo00?o00<0ool01?l00`3oo`03o`050?ooo`001?l01@3oool000?o00D0oooo0004o`05
0?ooo`000ol00`3oo`02o`050?ooo`000ol00`3oo`02o`050?ooo`000ol01@3oool000Co00D0oooo
0003o`030?oo00;o00D0oooo0003o`050?ooo`001?l00`3oo`0ao`008?l01@3oool000Ko00D0oooo
0003o`030?oo00;o00D0oooo0003o`030?oo00;o00D0oooo0003o`050?ooo`001?l01@3oool000So
00D0oooo0008o`050?ooo`001Ol00`3oo`04o`030?oo00?o00<0ool01?l00`3oo`03o`050?ooo`00
1?l01@3oool000?o00D0oooo0004o`050?ooo`000ol00`3oo`02o`050?ooo`000ol00`3oo`02o`05
0?ooo`000ol01@3oool000Co00D0oooo0003o`030?oo00;o00D0oooo0003o`050?ooo`001?l00`3o
o`0ao`008?l01@3oool000Ko00D0oooo0003o`030?oo00;o00D0oooo0003o`030?oo00;o00D0oooo
0003o`050?ooo`001?l01@3oool000So00D0oooo0008o`050?ooo`001Ol00`3oo`04o`030?oo00?o
00<0ool01?l00`3oo`03o`050?ooo`001?l01@3oool000?o00D0oooo0004o`050?ooo`000ol00`3o
o`02o`050?ooo`000ol00`3oo`02o`050?ooo`000ol01@3oool000Co00D0oooo0003o`030?oo00;o
00D0oooo0003o`050?ooo`001?l00`3oo`0ao`008?l200;o00<0ool01?l01@3oool000?o00<0ool0
0_l01@3oool000?o00<0ool00_l01@3oool000?o00D0oooo0004o`050?ooo`002?l01@3oool000So
00D0oooo0005o`030?oo00Co00<0ool00ol00`3oo`04o`030?oo00?o00D0oooo0004o`050?ooo`00
0ol01@3oool000Co00D0oooo0003o`030?oo00;o00D0oooo0003o`030?oo00;o00D0oooo0003o`05
0?ooo`001?l01@3oool000?o00<0ool00_l01@3oool000?o00D0oooo0004o`030?oo037o000Po`05
0?ooo`001_l01@3oool000?o00<0ool00_l01@3oool000?o00<0ool00_l01@3oool000?o00D0oooo
0004o`050?ooo`002?l01@3oool000So00D0oooo0005o`030?oo00Co00<0ool00ol00`3oo`04o`03
0?oo00?o00D0oooo0004o`050?ooo`000ol01@3oool000Co00D0oooo0003o`030?oo00;o00D0oooo
0003o`030?oo00;o00D0oooo0003o`050?ooo`001?l01@3oool000?o00<0ool00_l01@3oool000?o
00D0oooo0004o`030?oo037o000Po`050?ooo`001_l01@3oool000?o00<0ool00_l01@3oool000?o
00<0ool00_l01@3oool000?o00D0oooo0004o`050?ooo`002?l01@3oool000So00D0oooo0005o`03
0?oo00Co00<0ool00ol00`3oo`04o`030?oo00?o00D0oooo0004o`050?ooo`000ol01@3oool000Co
00D0oooo0003o`030?oo00;o00D0oooo0003o`030?oo00;o00D0oooo0003o`050?ooo`001?l01@3o
ool000?o00<0ool00_l01@3oool000?o00D0oooo0004o`030?oo037o000Po`050?ooo`001_l01@3o
ool000?o00<0ool00_l01@3oool000?o00<0ool00_l01@3oool000?o00D0oooo0004o`050?ooo`00
2?l01@3oool000So00D0oooo0005o`030?oo00Co00<0ool00ol00`3oo`04o`030?oo00?o00D0oooo
0004o`050?ooo`000ol01@3oool000Co00D0oooo0003o`030?oo00;o00D0oooo0003o`030?oo00;o
00D0oooo0003o`050?ooo`001?l01@3oool000?o00<0ool00_l01@3oool000?o00D0oooo0004o`03
0?oo037o000Po`800_l00`3oo`04o`050?ooo`000ol00`3oo`02o`050?ooo`000ol00`3oo`02o`05
0?ooo`000ol01@3oool000Co00D0oooo0008o`050?ooo`002?l01@3oool000Go00<0ool01?l00`3o
o`03o`030?oo00Co00<0ool00ol01@3oool000Co00D0oooo0003o`050?ooo`001?l01@3oool000?o
00<0ool00_l01@3oool000?o00<0ool00_l01@3oool000?o00D0oooo0004o`050?ooo`000ol00`3o
o`02o`050?ooo`000ol01@3oool000Co00<0ool0<Ol0023o00D0oooo0006o`050?ooo`000ol00`3o
o`02o`050?ooo`000ol00`3oo`02o`050?ooo`000ol01@3oool000Co00D0oooo0008o`050?ooo`00
2?l01@3oool000Go00<0ool01?l00`3oo`03o`030?oo00Co00<0ool00ol01@3oool000Co00D0oooo
0003o`050?ooo`001?l01@3oool000?o00<0ool00_l01@3oool000?o00<0ool00_l01@3oool000?o
00D0oooo0004o`050?ooo`000ol00`3oo`02o`050?ooo`000ol01@3oool000Co00<0ool0<Ol001Wo
0P05o`050?ooo`001_l01@3oool000?o00<0ool00_l01@3oool000?o00<0ool00_l01@3oool000?o
00D0oooo0004o`050?ooo`002?l01@3oool000So00D0oooo0005o`030?oo00Co00<0ool00ol00`3o
o`04o`030?oo00?o00D0oooo0004o`050?ooo`000ol01@3oool000Co00D0oooo0003o`030?oo00;o
00D0oooo0003o`030?oo00;o00D0oooo0003o`050?ooo`001?l01@3oool000?o00<0ool00_l01@3o
ool000?o00D0oooo0004o`030?oo037o000Io`030?l000Co00D0oooo0006o`050?ooo`000ol00`3o
o`02o`050?ooo`000ol00`3oo`02o`050?ooo`000ol01@3oool000Co00D0oooo0008o`050?ooo`00
2?l01@3oool000Go00<0ool01?l00`3oo`03o`030?oo00Co00<0ool00ol01@3oool000Co00D0oooo
0003o`050?ooo`001?l01@3oool000?o00<0ool00_l01@3oool000?o00<0ool00_l01@3oool000?o
00D0oooo0004o`050?ooo`000ol00`3oo`02o`050?ooo`000ol01@3oool000Co00<0ool0<Ol001Wo
00<0o`001?l200;o00<0ool01?l01@3oool000?o00<0ool00_l01@3oool000?o00<0ool00_l01@3o
ool000?o00D0oooo0004o`050?ooo`002?l01@3oool000So00D0oooo0005o`030?oo00Co00<0ool0
0ol00`3oo`04o`030?oo00?o00D0oooo0004o`050?ooo`000ol01@3oool000Co00D0oooo0003o`03
0?oo00;o00D0oooo0003o`030?oo00;o00D0oooo0003o`050?ooo`001?l01@3oool000?o00<0ool0
0_l01@3oool000?o00D0oooo0004o`030?oo037o000Io`801Ol01@3oool000Ko00D0oooo0003o`03
0?oo00;o00D0oooo0003o`030?oo00;o00D0oooo0003o`050?ooo`001?l01@3oool000So00D0oooo
0008o`050?ooo`001Ol00`3oo`04o`030?oo00?o00<0ool01?l00`3oo`03o`050?ooo`001?l01@3o
ool000?o00D0oooo0004o`050?ooo`000ol00`3oo`02o`050?ooo`000ol00`3oo`02o`050?ooo`00
0ol01@3oool000Co00D0oooo0003o`030?oo00;o00D0oooo0003o`050?ooo`001?l00`3oo`0ao`00
6Ol00`3oo`04o`050?ooo`001_l01@3oool000?o00<0ool00_l01@3oool000?o00<0ool00_l01@3o
ool000?o00D0oooo0004o`050?ooo`002?l01@3oool000So00D0oooo0005o`030?oo00Co00<0ool0
0ol00`3oo`04o`030?oo00?o00D0oooo0004o`050?ooo`000ol01@3oool000Co00D0oooo0003o`03
0?oo00;o00D0oooo0003o`030?oo00;o00D0oooo0003o`050?ooo`001?l01@3oool000?o00<0ool0
0_l01@3oool000?o00D0oooo0004o`030?oo037o000Jo`801?l01@3oool000Ko00D0oooo0003o`03
0?oo00;o00D0oooo0003o`030?oo00;o00D0oooo0003o`050?ooo`001?l01@3oool000So00D0oooo
0008o`050?ooo`001Ol00`3oo`04o`030?oo00?o00<0ool01?l00`3oo`03o`050?ooo`001?l01@3o
ool000?o00D0oooo0004o`050?ooo`000ol00`3oo`02o`050?ooo`000ol00`3oo`02o`050?ooo`00
0ol01@3oool000Co00D0oooo0003o`030?oo00;o00D0oooo0003o`050?ooo`001?l00`3oo`0ao`00
8?l200;o00<0ool01?l01@3oool000?o00<0ool00_l01@3oool000?o00<0ool00_l01@3oool000?o
00D0oooo0004o`050?ooo`002?l01@3oool000So00D0oooo0005o`030?oo00Co00<0ool00ol00`3o
o`04o`030?oo00?o00D0oooo0004o`050?ooo`000ol01@3oool000Co00D0oooo0003o`030?oo00;o
00D0oooo0003o`030?oo00;o00D0oooo0003o`050?ooo`001?l01@3oool000?o00<0ool00_l01@3o
ool000?o00D0oooo0004o`030?oo037o000Po`050?ooo`001_l01@3oool000?o00<0ool00_l01@3o
ool000?o00<0ool00_l01@3oool000?o00D0oooo0004o`050?ooo`002?l01@3oool000So00D0oooo
0005o`030?oo00Co00<0ool00ol00`3oo`04o`030?oo00?o00D0oooo0004o`050?ooo`000ol01@3o
ool000Co00D0oooo0003o`030?oo00;o00D0oooo0003o`030?oo00;o00D0oooo0003o`050?ooo`00
1?l01@3oool000?o00<0ool00_l01@3oool000?o00D0oooo0004o`030?oo037o000Po`040?ooo`P0
0ol0103oool600?o00@0oooo1P03o`040?ooo`D01?l0103oool:00?o2P03o`L01_l700Ko1`03o`03
0?oo00;o1@03o`040?ooo`H00ol0103oool600?o00@0oooo1P03o`040?ooo`D01?l0103oool500Co
00@0oooo1@03o`030?oo00;o00<0ool0<Ol0023o00<0ool0ool9o`008?l00`3oo`3oo`Wo000Po`80
ool:o`00ool/o`00ool/o`00ool/o`00ool/o`00ool/o`00ool/o`00ool/o`00O?l20:go001no`03
0?oo013o0P07o`801ol208Ko001`o`8000?o00000P02o`030?oo00<000Co00000ol200So0P02o`<0
0ol0103oool200Co00<0ool0Q?l0073o00L0oooo0?l000;o00<0o`000_l0103oo`03o`030?oo00Oo
00@0ool00_l00`3oo`02o`030?oo00?o00D0oooo0026o`00LOl300;o00H0ool0o`02o`040?oo00?o
0`07o`040?oo00;o00<0ool00_l00`3oo`02o`030?oo00;o00<0ool0Q?l0077o00@0o`3o1003o`<0
0_l0103oool300Oo00@0ool00_l00`3oo`02o`030?oo00?o00D0oooo0026o`00L_l00`3oo`0<o`03
0?oo00_o00@0ool00_l00`3oo`02o`070?ooo`3o0003o`030?oo08Co001ao`803Ol200ko0P02o`80
1?l200?o00@0oooo0P26o`00ool/o`00ool/o`00ool/o`00ool/o`00ool/o`00ool/o`006Ol30003
o`3o00@00_l30?oo1?l001[o00D0ool0o`0300;o00@0ool0ool4o`006_l300Co00@0ool00_l00`3o
o`3oo`;o000Jo`040?oo00;o0P03o`<0ool4o`006_l0103oo`09o`030?oo0?oo0_l001Wo1009o`80
ool4o`00ool/o`00ool/o`00ool/o`00\
\>"],
  ImageRangeCache->{{{0, 298}, {184, 0}} -> {-15.1683, -0.852359, 0.465795, 
  0.0473544}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00952381 -0.747664 2.46815 [
[(20)] .21429 .2396 0 2 Msboxa
[(40)] .40476 .2396 0 2 Msboxa
[(60)] .59524 .2396 0 2 Msboxa
[(80)] .78571 .2396 0 2 Msboxa
[(100)] .97619 .2396 0 2 Msboxa
[(No.)] 1.025 .2396 -1 0 Msboxa
[(Error n)] .5 .61803 0 -2 0 0 1 Mouter Mrotsboxa
[(0.35)] .01131 .11619 1 0 Msboxa
[(0.45)] .01131 .36301 1 0 Msboxa
[(0.5)] .01131 .48641 1 0 Msboxa
[(0.55)] .01131 .60982 1 0 Msboxa
[(n)] .02381 .61803 0 -4 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 .61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.21429 .2396 m
.21429 .24585 L
s
P
[(20)] .21429 .2396 0 2 Mshowa
p
.002 w
.40476 .2396 m
.40476 .24585 L
s
P
[(40)] .40476 .2396 0 2 Mshowa
p
.002 w
.59524 .2396 m
.59524 .24585 L
s
P
[(60)] .59524 .2396 0 2 Mshowa
p
.002 w
.78571 .2396 m
.78571 .24585 L
s
P
[(80)] .78571 .2396 0 2 Mshowa
p
.002 w
.97619 .2396 m
.97619 .24585 L
s
P
[(100)] .97619 .2396 0 2 Mshowa
p
.001 w
.0619 .2396 m
.0619 .24335 L
s
P
p
.001 w
.1 .2396 m
.1 .24335 L
s
P
p
.001 w
.1381 .2396 m
.1381 .24335 L
s
P
p
.001 w
.17619 .2396 m
.17619 .24335 L
s
P
p
.001 w
.25238 .2396 m
.25238 .24335 L
s
P
p
.001 w
.29048 .2396 m
.29048 .24335 L
s
P
p
.001 w
.32857 .2396 m
.32857 .24335 L
s
P
p
.001 w
.36667 .2396 m
.36667 .24335 L
s
P
p
.001 w
.44286 .2396 m
.44286 .24335 L
s
P
p
.001 w
.48095 .2396 m
.48095 .24335 L
s
P
p
.001 w
.51905 .2396 m
.51905 .24335 L
s
P
p
.001 w
.55714 .2396 m
.55714 .24335 L
s
P
p
.001 w
.63333 .2396 m
.63333 .24335 L
s
P
p
.001 w
.67143 .2396 m
.67143 .24335 L
s
P
p
.001 w
.70952 .2396 m
.70952 .24335 L
s
P
p
.001 w
.74762 .2396 m
.74762 .24335 L
s
P
p
.001 w
.82381 .2396 m
.82381 .24335 L
s
P
p
.001 w
.8619 .2396 m
.8619 .24335 L
s
P
p
.001 w
.9 .2396 m
.9 .24335 L
s
P
p
.001 w
.9381 .2396 m
.9381 .24335 L
s
P
[(No.)] 1.025 .2396 -1 0 Mshowa
p
.002 w
0 .2396 m
1 .2396 L
s
P
[(Error n)] .5 .61803 0 -2 0 0 1 Mouter Mrotshowa
p
.002 w
.02381 .11619 m
.03006 .11619 L
s
P
[(0.35)] .01131 .11619 1 0 Mshowa
p
.002 w
.02381 .36301 m
.03006 .36301 L
s
P
[(0.45)] .01131 .36301 1 0 Mshowa
p
.002 w
.02381 .48641 m
.03006 .48641 L
s
P
[(0.5)] .01131 .48641 1 0 Mshowa
p
.002 w
.02381 .60982 m
.03006 .60982 L
s
P
[(0.55)] .01131 .60982 1 0 Mshowa
p
.001 w
.02381 .14087 m
.02756 .14087 L
s
P
p
.001 w
.02381 .16555 m
.02756 .16555 L
s
P
p
.001 w
.02381 .19023 m
.02756 .19023 L
s
P
p
.001 w
.02381 .21492 m
.02756 .21492 L
s
P
p
.001 w
.02381 .26428 m
.02756 .26428 L
s
P
p
.001 w
.02381 .28896 m
.02756 .28896 L
s
P
p
.001 w
.02381 .31364 m
.02756 .31364 L
s
P
p
.001 w
.02381 .33832 m
.02756 .33832 L
s
P
p
.001 w
.02381 .38769 m
.02756 .38769 L
s
P
p
.001 w
.02381 .41237 m
.02756 .41237 L
s
P
p
.001 w
.02381 .43705 m
.02756 .43705 L
s
P
p
.001 w
.02381 .46173 m
.02756 .46173 L
s
P
p
.001 w
.02381 .5111 m
.02756 .5111 L
s
P
p
.001 w
.02381 .53578 m
.02756 .53578 L
s
P
p
.001 w
.02381 .56046 m
.02756 .56046 L
s
P
p
.001 w
.02381 .58514 m
.02756 .58514 L
s
P
p
.001 w
.02381 .09151 m
.02756 .09151 L
s
P
p
.001 w
.02381 .06683 m
.02756 .06683 L
s
P
p
.001 w
.02381 .04215 m
.02756 .04215 L
s
P
p
.001 w
.02381 .01746 m
.02756 .01746 L
s
P
[(n)] .02381 .61803 0 -4 Mshowa
p
.002 w
.02381 0 m
.02381 .61803 L
s
P
P
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.004 w
s
s
.05032 .61803 m
.05238 .19313 L
s
.05238 .19313 m
.0619 .28178 L
.07143 .1089 L
.08095 .2808 L
.09048 .30631 L
.1 .15868 L
.10952 .20269 L
.11905 .26374 L
.12857 .11711 L
.1381 .29915 L
.14762 .29193 L
.15714 .11332 L
.16667 .22662 L
.17619 .24431 L
.18571 .15679 L
.19524 .31166 L
.20476 .2723 L
.21429 .06269 L
.22381 .24858 L
.23333 .22244 L
.24286 .19207 L
.25238 .31821 L
.2619 .24745 L
.27143 .01613 L
.28095 .26829 L
.29048 .19831 L
.3 .22294 L
.30952 .31876 L
.31905 .21742 L
.32857 .06215 L
.3381 .28539 L
.34762 .1721 L
.35714 .24941 L
.36667 .31329 L
.37619 .18227 L
.38571 .11305 L
.39524 .2995 L
.40476 .14397 L
.41429 .27151 L
.42381 .30187 L
.43333 .14206 L
.44286 .15876 L
.45238 .31016 L
.4619 .11407 L
.47143 .28929 L
.48095 .28463 L
.49048 .09693 L
.5 .19896 L
.50952 .3169 L
.51905 .0825 L
Mistroke
.52857 .30284 L
.5381 .26176 L
.54762 .04707 L
.55714 .23343 L
.56667 .31926 L
.57619 .04937 L
.58571 .31226 L
.59524 .23355 L
.60476 .02058 L
.61429 .26207 L
.62381 .31684 L
.63333 .01472 L
.64286 .31768 L
.65238 .20033 L
.6619 .07301 L
.67143 .28484 L
.68095 .30928 L
.69048 .03399 L
.7 .31925 L
.70952 .17894 L
.71905 .12113 L
.72857 .30178 L
.7381 .29629 L
.74762 .06745 L
.75714 .31716 L
.76667 .16939 L
.77619 .16461 L
.78571 .31298 L
.79524 .27767 L
.80476 .09922 L
.81429 .31159 L
.82381 .15682 L
.83333 .20315 L
.84286 .31855 L
.85238 .25332 L
.8619 .12934 L
.87143 .30273 L
.88095 .14146 L
.89048 .23651 L
.9 .31861 L
.90952 .22318 L
.91905 .15786 L
.92857 .29076 L
.9381 .12351 L
.94762 .26447 L
.95714 .31327 L
.96667 .18731 L
.97619 .18477 L
Mfstroke
% End of Graphics
MathPictureEnd\
\>"], "Graphics",
  PageWidth->Infinity,
  Evaluatable->False,
  ImageSize->{299, 185},
  ImageMargins->{{100, Inherited}, {Inherited, 0}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004[0000^@P10`40000100000800002008200000
P800P020P<30`<3L`:K:l:C8l3<006H009T00<`0000c03<c06Hc09Tc0<`c0?lc001V03=V06IV09UV
0<aV0?mV002I03>I06JI09VI0<bI0?nI003<03?<06K<09W<0<c<0?o<03?o06Ko09Wo0<co0000<c<0
<fH0<iT0<l`0<ol0<`0c<c<c<fHc<iTc<l`c<olc<`1V<c=V<fIV<iUV<laV<omV<`2I<c>I<fJI<iVI
<lbI<onI<`3<<c?<<fK<<iW<<lc<<oo<<`3o<c?o<fKo<iWo<lco<ooo<`00IS<0IVH0IYT0I/`0I_l0
IP0cIS<cIVHcIYTcI/`cI_lcIP1VIS=VIVIVIYUVI/aVI_mVIP2IIS>IIVJIIYVII/bII_nIIP3<IS?<
IVK<IYW<I/c<I_o<IP3oIS?oIVKoIYWoI/coI_ooIP00VC<0VFH0VIT0VL`0VOl0V@0cVC<cVFHcVITc
VL`cVOlcV@1VVC=VVFIVVIUVVLaVVOmVV@2IVC>IVFJIVIVIVLbIVOnIV@3<VC?<VFK<VIW<VLc<VOo<
V@3oVC?oVFKoVIWoVLcoVOooV@00c3<0c6H0c9T0c<`0c?l0c00cc3<cc6Hcc9Tcc<`cc?lcc01Vc3=V
c6IVc9UVc<aVc?mVc02Ic3>Ic6JIc9VIc<bIc?nIc03<c3?<c6K<c9W<c<c<c?o<c03oc3?oc6Koc9Wo
c<coc?ooc3<0ofH0oiT0ol`0o`0coc<cofHcoiTcol`coolco`1Voc=VofIVoiUVolaVoomVo`2Ioc>I
ofJIoiVIolbIoonIo`3<oc?<ofK<oiW<olc<ooo<oc?oofKooiWoolcoo`410@820P<30`@410D51@H6
1PL71`P820T92@X:2P/;2``<30h>3Pl?3a0@414A4A8B4Q<C4a@D5000000000000000000000000000
00000?okl:2PY820P?l0003o0?oo0000ool0o`3ooooooooo;?l001co00<0ool0ool=o`007?l00`3o
o`3oo`go000Lo`030?oo0?oo3Ol001co00<0ool0UOl00`3oo`1do`007?l203co00<0ool0Eol00`3o
o`1do`007?l00`3oo`0ko`030?oo053o00<0ool01?l00`3oo`1do`007?l00`3oo`0ko`030?oo053o
00<0ool01?l00`3oo`1do`007?l00`3oo`0ko`030?oo053o00<0ool01?l00`3oo`1do`007?l00`3o
o`0ko`030?oo053o00<0ool01?l00`3oo`0;o`030?oo06Ko000Lo`030?oo03_o00<0ool0D?l00`3o
o`04o`030?oo00_o00<0ool0I_l001co0P0lo`030?oo053o00<0ool01?l00`3oo`0;o`030?oo06Ko
000Lo`030?oo03_o00<0ool0@Ol00`3oo`0<o`030?oo00Co00<0ool02ol00`3oo`1Vo`007?l00`3o
o`0ko`030?oo047o00<0ool01?l00`3oo`05o`030?oo00Co00<0ool02ol00`3oo`1Vo`007?l00`3o
o`0ko`030?oo047o00<0ool01?l00`3oo`05o`030?oo00Co00<0ool02ol00`3oo`1Vo`007?l00`3o
o`0jo`80@ol00`3oo`04o`030?oo00Co0P06o`030?oo00_o00<0ool0I_l001co00<0ool0;?l00`3o
o`0;o`803Ol00`3oo`0co`030?oo00Co00<0ool01?l200Ko00<0ool02ol00`3oo`1Vo`007?l202go
00<0ool02ol200go00<0ool0<ol00`3oo`04o`030?oo00Co0P05o`803Ol00`3oo`1Vo`007?l00`3o
o`0/o`030?oo00_o0P0=o`030?oo03?o00<0ool01?l00`3oo`04o`801Ol200go00<0ool02ol00`3o
o`1Ho`007?l00`3oo`0/o`030?oo00_o0P0=o`030?oo03?o00<0ool01?l00`3oo`04o`801Ol200Ko
00<0ool01?l00`3oo`0;o`030?oo05So000Lo`030?oo02co00<0ool02ol200go00<0ool0<ol200Go
00<0ool01?l200Go0P06o`030?oo00Co00<0ool02ol00`3oo`1Ho`007?l00`3oo`0/o`030?oo00_o
00<0o`003?l00`3oo`0/o`030?oo00Co0P05o`030?oo00Co00<0o`001?l200Ko00<0ool01?l00`3o
o`0;o`030?oo05So000Lo`030?oo02co00<0ool02ol00`3o000<o`030?oo02co00<0ool01?l200Go
00<0ool01?l00`3o0004o`801_l00`3oo`04o`030?oo00_o00<0ool0F?l001co00<0ool0;?l00`3o
o`0;o`030?l000_o0P0^o`030?oo00Co0P05o`030?oo00Co00<0o`001?l00`3o0005o`030?oo00Co
00<0ool02ol00`3oo`1Ho`007?l202go0P0<o`030?l000_o0P0^o`030?oo00Co0P05o`801Ol00`3o
0004o`030?l000Go00<0ool01?l00`3oo`0;o`030?oo05So000Lo`030?oo02co0P0<o`030?l000_o
0P0Wo`030?oo00Co00<0ool01?l200Go0P05o`030?l000Co00<0o`001?l200Ko00<0ool02ol00`3o
o`0;o`030?oo04[o000Lo`030?oo02co0P0<o`030?l000_o0P0Wo`030?oo00Co00<0ool00ol00`3o
0005o`801Ol00`3o0004o`030?l000Co0P06o`030?oo00_o00<0ool02ol00`3oo`1:o`007?l00`3o
o`0/o`803?l00`3o000;o`809ol00`3oo`04o`030?oo00?o00<0o`001Ol200Go00<0o`001?l00`3o
0004o`801Ol00`3o000<o`030?oo00_o00<0ool0B_l000Oo00<0ool00_l0103oool200Co00<0ool0
0ol00`3oo`09o`030?oo023o0P0<o`030?l000_o0P0Wo`030?oo00Co00<0ool00ol00`3o0005o`80
1Ol00`3o0004o`030?l000Co0P05o`030?l000co00<0ool02ol00`3oo`1:o`001_l00`3o0009o`06
0?oo0?l01?l00`3oo`09o`030?oo01;o00<0ool02_l00`3o000<o`030?l000_o0P0=o`030?oo013o
00<0ool01?l00`3oo`04o`030?oo00?o00<0o`001Ol200Go00<0o`001?l00`3o0004o`801Ol00`3o
000<o`030?oo00_o00<0ool0B_l000Ko00<0o`002?l00`3oo`03o`030?oo00;o0`09o`030?oo00_o
00<0ool01?l00`3oo`0:o`030?l000co00<0o`002ol00`3o000<o`030?oo013o00<0ool01?l00`3o
o`04o`030?oo00?o00<0o`001?l00`3o0005o`030?l000Co00<0o`001?l200Go00<0o`003?l00`3o
o`0;o`030?oo04[o0006o`030?l000Wo00<0ool00P05o`030?oo00Wo00<0ool02ol00`3oo`04o`03
0?oo00[o00<0o`003?l00`3o000;o`030?l000co00<0ool04?l00`3oo`04o`030?oo00Co0P04o`03
0?l000Co00<0o`001Ol00`3o0004o`030?l000Co0P05o`030?l000Go00<0ool01?l00`3oo`0;o`03
0?oo01ko00<0ool0:Ol000Ko00<0o`001ol00`3o0002o`030?oo00Co00<0ool02Ol00`3oo`0;o`03
0?oo00Co00<0ool02_l00`3o000<o`030?l000_o00<0o`003?l00`3oo`0@o`030?oo00Co0P05o`80
1?l00`3o0004o`030?l000Go00<0o`001?l00`3o0004o`801Ol00`3o0005o`030?oo00?o0P0=o`03
0?oo01ko00<0ool0:Ol000Oo00<0ool01ol0103oool300Co00<0ool02Ol00`3oo`0;o`030?oo00Co
00<0ool02_l00`3o000<o`030?l000_o00<0o`003?l00`3oo`0@o`030?oo00Co0P05o`801?l00`3o
0004o`030?l000Co00@0ool01?l00`3o0004o`030?l000Co00<0o`001Ol00`3oo`03o`803Ol00`3o
o`0<o`030?oo00oo00<0ool0:Ol001co00<0ool02Ol00`3oo`0;o`030?oo00Co0P0;o`030?l000_o
00@0ool02ol00`3o000;o`804_l00`3oo`04o`801Ol200Co00<0o`001?l00`3o0004o`040?oo00Co
00<0o`001?l00`3o0004o`030?l000Go00<0ool00ol00`3o000<o`803Ol00`3oo`0?o`030?oo02Wo
000Lo`030?oo00Wo00<0ool02ol00`3oo`04o`802ol00`3o000;o`040?oo00_o00<0o`002ol201;o
00<0ool01?l200Go0P04o`030?l000Co00<0o`001?l0103oo`04o`030?l000?o00@0ool01?l00`3o
0004o`801Ol00`3o000<o`803Ol00`3oo`0?o`030?oo02Wo000Lo`802Ol200go00<0ool01?l200_o
00<0o`002ol0103oo`0:o`040?oo00_o0P0;o`030?oo00Co00<0ool01?l200Co00<0o`001?l0103o
o`03o`030?l000Co00@0ool01?l00`3o0003o`040?oo00Co00<0o`001?l200Go00<0o`003?l200go
00D0oooo000=o`030?oo02Wo000Lo`030?oo00So0P0=o`030?oo00Co0P0;o`030?l000_o00@0ool0
2_l0103oo`0;o`801?l00`3oo`04o`801Ol00`3oo`03o`030?l000Co00<0o`001?l0103oo`03o`03
0?l000Co00@0ool01?l00`3o0003o`040?oo00Co00<0o`001?l200Go00<0o`002ol00`3o000=o`05
0?ooo`003Ol202[o000Lo`030?oo00So0P0=o`030?oo00Co0P0;o`030?l000_o00@0ool02_l0103o
o`0;o`801?l00`3oo`04o`801Ol00`3oo`03o`030?l000Co00<0o`001?l0103oo`03o`030?l000Co
00@0ool01?l00`3o0003o`040?oo00Co00<0o`001?l200Go00<0o`002ol00`3o000=o`050?ooo`00
3Ol202[o000Lo`030?oo00So00<0o`002ol200Ko0P0;o`030?l000_o00@0ool02_l0103oo`0;o`80
1?l00`3oo`04o`030?l000Co00<0ool00ol00`3o0004o`030?l000Co00@0ool00ol00`3o0004o`04
0?oo00Co00<0o`000ol0103oo`04o`030?l000Co0P05o`030?l000_o00<0o`003?l200?o00<0ool0
2ol202[o000Lo`030?oo00So00<0o`001Ol00`3oo`03o`801Ol00`3o0005o`030?oo00?o00@0ool0
2_l0103oo`0:o`040?oo00_o0P04o`030?oo00Co00<0o`001?l200Co00<0o`001?l00`3o0004o`04
0?oo00?o00<0o`001?l0103oo`04o`030?l000?o00@0ool01?l00`3o0004o`801Ol00`3o000;o`03
0?l000?o00<0ool01_l200?o0P08o`040?ooo`80:_l001co00<0ool02?l00`3o0005o`030?oo00?o
0P05o`030?l000Go00<0ool00ol0103oo`0:o`040?oo00[o00@0ool02ol00`3o0003o`030?oo00Co
00<0o`001?l200Co00<0o`001?l00`3o0004o`040?oo00?o00<0o`001?l0103oo`04o`030?l000?o
00@0ool01?l00`3o0004o`801Ol00`3o000;o`030?l000?o00<0ool01_l200?o0P08o`040?ooo`80
:_l001co0P09o`030?l000Go00<0ool00ol00`3o0004o`030?l000Go00<0ool00ol0103oo`0:o`04
0?oo00[o00@0ool02_l0103oo`03o`030?oo00Co00<0o`000ol00`3o0004o`030?l000Co00<0o`00
1?l0103oo`03o`030?l000Co00@0ool00ol0103oo`03o`040?oo00Co00<0o`000ol00`3o0005o`03
0?l000Go00<0ool00ol00`3o0003o`030?oo00Ko0P03o`802?l01P3oo`3o02[o000Lo`030?oo00So
00<0o`001Ol200Co00<0o`001?l0103oo`04o`030?oo00?o00@0ool02_l0103oo`0:o`040?oo00[o
00@0ool00ol00`3oo`04o`030?l000?o00<0o`001?l00`3o0004o`030?l000Co00@0ool00ol00`3o
0004o`040?oo00?o00@0ool00ol0103oo`04o`030?l000?o00@0ool01?l00`3o0003o`<01Ol00`3o
0003o`801ol200?o0P07o`800_l00`3o000Zo`007?l00`3oo`08o`030?l000Go0P04o`030?l000Co
00@0ool01?l00`3oo`03o`040?oo00[o00@0ool02_l0103oo`03o`030?oo00Co00@0ool00_l200Ko
00<0o`000ol00`3o0004o`040?oo00?o00<0o`001?l0103oo`03o`030?l000Co00@0ool00ol0103o
o`03o`040?oo00Co00<0o`000ol0103oo`04o`030?l000?o00<0o`001Ol00`3o0003o`801ol00`3o
0002o`801ol200;o00<0o`00:_l001co00<0ool02?l00`3o0005o`801?l00`3o0004o`040?oo00Co
00<0ool00ol0103oo`0:o`040?oo00[o00@0ool00ol00`3oo`04o`040?oo00;o00<0o`001Ol00`3o
0003o`030?l000Co00@0ool00ol00`3o0004o`040?oo00?o00<0o`001?l0103oo`03o`040?oo00?o
00@0ool01?l00`3o0003o`040?oo00Co00<0o`000ol00`3o0005o`030?l000?o0P07o`030?l000;o
0P07o`800_l00`3o000Zo`007?l00`3oo`08o`030?l000Go0P04o`030?l000Co00@0ool00ol200;o
1002o`030?oo00So00@0ool02_l0103oo`03o`030?oo00Co00<0ool010000ol00003o`040?oo00?o
00<0o`001?l0103oo`03o`030?l000Co00@0ool00ol0103o0003o`8000?o0?l00_l0103oo`02o`05
0?ooo`001?l00`3o0003o`040?oo00Co00<0o`000ol00`3o0004o`8000?o0?l00_l200Oo00L0o`3o
0?l000Oo0P02o`030?l000D00_l00`3oo`02o`030?oo01_o000Lo`030?oo00So00<0o`001Ol200Co
00<0o`001?l0103oo`03o`050?l0o`000_l00`3o000200Wo00@0ool02_l0103oo`03o`030?oo00Co
00D0ool0o`020004o`3o00;o00D0oooo0002o`030?l000Co00@0ool00ol00`3o0004o`040?oo00?o
00<0o`000P02o`040?l000?o00@0ool00_l01@3oool000Co00<0o`000ol0103oo`04o`030?l000?o
1002o`050?l0o`000ol200Oo00L0o`3o0?l000Oo0P02o`030?l000;o00@0oooo0`02o`030?l001co
000Lo`802Ol00`3o0005o`801?l00`3o0004o`040?oo00?o00<0o`000_l0103o0?l300Wo00@0ool0
2_l0103oo`03o`030?oo00Co00<0ool010001?l0o`02o`050?ooo`000_l00`3o0004o`040?oo00?o
00<0o`001?l0103oo`03o`030?l000800_l0103o0003o`040?oo00;o00D0oooo0004o`030?l000?o
00@0ool01?l00`3o0003o`@00_l01@3o0?l000?o0P07o`050?l0o`000_l00`3oo`03o`030?l000;o
00<0o`000_l01`3oool0o`000_l00`3o000Lo`007?l00`3oo`04o`070?ooo`3o0005o`030?l000?o
00<0o`001?l0103oo`03o`030?l000;o00@0o`3o0`04o`030?oo00;o00@0ool02Ol01@3oool000;o
00<0o`001Ol01@3oo`3o008000Co0?l00_l01@3oool000;o00<0o`001?l0103oo`03o`040?oo00?o
00@0ool00ol0103o0003o`040?l000?o00@0ool00_l01@3oool000Co00<0o`000ol0103oo`04o`03
0?l000?o00@0o`000_l01@3o0?l000?o00<0o`001Ol01P3oo`3o00;o00<0ool00ol01P3oo`3o00;o
00<0o`000ol00`3o0002o`030?l001co000Lo`030?oo00Co00@0ool00_l00`3oo`02o`040?oo00?o
00<0o`001?l0103oo`03o`060?l0o`3o0P001?l00004o`030?oo00;o00@0ool00_l00`3oo`04o`05
0?ooo`000_l00`3o0005o`030?oo00@000Co0?l00_l01@3oool000;o00<0o`001?l0103oo`03o`04
0?oo00?o00@0ool00ol0103o0003o`040?l000?o00@0ool00_l01@3oool000Co00<0o`000ol0103o
o`04o`030?l000;o00D0o`3o0002o`050?l0o`000_l0103oo`05o`060?oo0?l00_l00`3oo`03o`06
0?oo0?l00_l00`3o0003o`030?l000;o00<0o`007?l001co00<0ool01?l0103oo`02o`030?oo00;o
00@0ool00ol00`3o0004o`040?oo00?o00<0o`000_l00`3o0002o`030?oo00;o0P04o`040?oo00;o
0P05o`050?ooo`000_l00`3o0005o`050?oo0?l00P000ol00003o`050?ooo`000_l00`3o0004o`04
0?oo00?o00@0ool00ol0103oo`03o`030?oo008000Co0?l00_l0103oo`02o`040?oo00?o00<0ool0
0_l00`3o0002o`050?ooo`001?l00`3o0002o`030?oo00800ol20005o`3oo`000_l00`3oo`03o`06
0?oo0?l00_l00`3oo`03o`060?oo0?l00_l300?o0P04o`030?oo01_o000Lo`030?oo00Co00@0ool0
0_l00`3oo`02o`040?oo00?o00<0o`001?l0103oo`03o`030?l000Co00@0ool01?l200Co00H0oooo
0?l200Go00D0oooo0002o`030?l000Co00D0oooo0002o`030?l000Co00D0oooo0002o`030?l000Co
00@0ool00ol0103oo`03o`050?ooo`000_l0103oo`02o`030?oo00;o00@0ool00_l0103oo`03o`03
0?oo00;o00<0o`000_l01@3oool000Co00<0o`000_l01@3oool000Co00H0ool0o`02o`030?oo00?o
00H0ool0o`02o`030?oo00?o00H0ool0o`02o`030?oo00?o00<0ool08Ol001co00<0ool01?l0103o
o`02o`030?oo00;o00@0ool00ol00`3o0004o`050?ooo`000_l00`3o0004o`040?oo00?o00<0o`00
0ol00`3oo`02o`050?l0o`001?l01@3oool000;o00<0o`001?l01@3oool000;o00<0o`001?l01@3o
ool000;o00<0o`001?l0103oo`03o`040?oo00;o00<0ool00_l0103oo`02o`040?oo00Co00@0ool0
0_l0103oo`03o`030?oo00;o00<0o`000_l01@3oool000Co00<0o`000_l01@3oool000Co00H0ool0
o`02o`030?oo00?o00H0ool0o`02o`030?oo00?o00H0ool0o`02o`030?oo00;o00<0ool08_l001co
0P05o`040?oo00;o00<0ool00_l01@3oool000;o00<0o`001?l01@3oool000;o00<0o`001?l0103o
o`03o`030?l000?o00<0ool00_l01@3o0?l000Co00D0oooo0002o`030?l000Co00D0oooo0002o`03
0?l000Co00D0oooo0002o`030?l000Co00@0ool00ol0103oo`02o`030?oo00;o00@0ool00_l0103o
o`04o`040?oo00;o00@0ool00ol00`3oo`02o`030?l000;o00D0oooo0004o`030?l000;o00D0oooo
0004o`060?oo0?l00_l00`3oo`03o`060?oo0?l00_l00`3oo`02o`070?ooo`3o0002o`030?oo00;o
00<0ool08_l001co00<0ool01?l20005o`3oo`001?l01@3oool000;o00<0o`001?l01@3oool000;o
00<0o`000ol01@3oool000;o00@0ool00ol00`3oo`02o`800ol01@3oool000?o00H0ool0o`04o`05
0?ooo`000_l00`3o0004o`050?ooo`000_l00`3o0004o`050?ooo`000_l0103oo`02o`030?oo00;o
00@0ool00_l0103oo`04o`040?oo00;o00@0ool00ol00`3oo`02o`030?l000;o00D0oooo0004o`03
0?l000;o00D0oooo0004o`060?oo0?l00_l00`3oo`03o`060?oo0?l00_l00`3oo`02o`070?ooo`3o
0002o`030?oo00;o00<0ool08_l001co00<0ool01?l20005o`3oo`001?l01@3oool000;o00<0o`00
1?l01@3oool000;o00<0o`000ol00`3oo`02o`030?l000;o00D0oooo0004o`800ol01@3oool000?o
00H0ool0o`04o`070?ooo`3o0002o`030?oo00;o00D0oooo0002o`030?l000Co00D0oooo0002o`04
0?oo00;o00<0ool00_l0103oo`02o`040?oo00Co00@0ool00_l0103oo`03o`030?oo00;o00<0o`00
0_l01@3oool000Co00<0o`000_l01@3oool000Co00H0ool0o`03o`030?oo00;o00H0ool0o`03o`05
0?ooo`000ol00`3o0002o`030?oo00;o00<0ool08_l001co00<0ool01?l20005o`3oo`001?l01`3o
ool0o`000_l00`3oo`02o`070?ooo`3o0002o`050?ooo`001?l00`3o0003o`040?oo00Co0P03o`05
0?ooo`000ol01P3oo`3o00Co00L0oooo0?l000;o00<0ool00_l01@3oool000;o00<0o`001?l01@3o
ool000;o00@0ool00_l00`3oo`02o`040?oo00;o00@0ool01?l0103oo`02o`040?oo00?o00<0ool0
0_l00`3o0002o`050?ooo`001?l00`3o0002o`050?ooo`001?l01P3oo`3o00?o00<0ool00_l01P3o
o`3o00?o00D0oooo0003o`030?l000;o00<0ool00_l00`3oo`0Ro`007?l00`3oo`04o`8000Go0?oo
0004o`070?ooo`3o0002o`030?oo00;o00L0oooo0?l000;o00D0oooo0004o`801?l0103oo`04o`80
0ol01@3oool000Co0P02o`030?oo00;o00L0oooo0?l000;o00<0ool00_l01@3oool000;o00<0o`00
1?l01@3oool000;o00@0ool00_l00`3oo`02o`040?oo00;o00@0ool01?l0103oo`02o`040?oo00?o
00<0ool00_l00`3o0002o`050?ooo`001?l00`3o0002o`050?ooo`001?l01P3oo`3o00?o00<0ool0
0_l01P3oo`3o00?o00D0oooo0003o`030?l000;o00<0ool00_l00`3oo`0<o`<000Co0?oo0P03o`03
0?oo00Oo000Lo`030?oo00Co0P001Ol0ool000Co00<0ool00_l200;o00<0ool00_l00`3oo`02o`80
0ol0103oo`04o`801?l0103oo`04o`800ol01@3oool000Co0P03o`050?ooo`000ol00`3o0002o`03
0?oo00;o00<0ool00_l01@3o0?l000Co00D0oooo0002o`040?oo00;o00<0ool00_l0103oo`02o`04
0?oo00Co00@0ool00_l00`3o0005o`070?ooo`3o0002o`050?ooo`001?l00`3o0002o`050?ooo`00
0ol01`3oool0o`000ol01@3oool000?o00<0o`000ol01@3oool000?o00<0o`000_l00`3oo`02o`03
0?oo00go00H0o`00o`02o`030?oo00[o000FooX01_l01P3o003o00;o00<0ool02_l001co00<0ool0
1?l400?o00@0oooo0P03o`800_l200?o00<0ool00ol01@3oool000;o00<0o`000_l200Co0P000ol0
o`03o`<00_l01@3oool000;o00@0o`000ol01@3o0?l000?o00L0o`3o0?l000?o00X0ool0o`3o0?l0
0ol00`3oo`02o`030?oo008000Go0?oo0004o`040?oo00;o00@0ool01?l01`3oo`3o0?l00P05o`04
0?oo00;o00<0ool00P02o`060?ooo`3o0P02o`030?oo00;o0P000ol0o`02o`040?l000;o00D0oooo
0002o`8000?o0?l00_l01@3o0?l000?o00@0o`000_l01@3oool000;o00<0ool02_l20004o`3oo`80
3Ol001co00<0ool01?l20003o`3o00;o00D0oooo0004o`800_l01@3oool000Ko00D0oooo0002o`03
0?l000;o00<0ool00ol0103oo`04o`801?l00`3o0005o`800ol01@3oool000?o00L0o`3o0?l000?o
00<0ool00_l00`3o0002o`040?oo00Co00@0ool00_l0103oo`04o`040?oo00;o00@0ool01?l0103o
o`03o`801Ol0103oo`02o`040?oo00?o00D0oooo0002o`030?l000Go0P000ol0o`02o`030?l000?o
00D0oooo0003o`030?l000?o00@0ool01?l00`3o0003o`050?ooo`000_l00`3oo`0:o`8000?o0?l0
4?l001co00<0ool01?l20003o`3o00;o00D0oooo0004o`800_l01@3oool000[o00@0ool01?l00`3o
o`03o`040?oo00Co00<0ool00ol00`3o0005o`800ol0103oo`04o`030?l000?o00D0oooo0004o`03
0?l000;o00@0ool01?l0103oo`02o`040?oo00Co00@0ool00_l0103oo`04o`040?oo00?o0P05o`04
0?oo00?o0P04o`050?ooo`000_l00`3o0005o`040?oo00?o00<0o`000ol01@3oool000?o00<0o`00
0ol0103oo`04o`801?l0103oo`0?o`8000?o00004Ol001co00<0ool01?l300Co00D0oooo0005o`05
0?ooo`000_l00`3oo`08o`040?oo00[o00@0ool01?l00`3oo`03o`030?l000Go0P03o`040?oo00Go
0P03o`050?ooo`001?l00`3o0002o`040?oo00Co00@0ool00_l0103oo`04o`030?l000?o00<0o`00
1Ol0103oo`03o`801Ol0103oo`03o`801?l01@3oool000;o00<0o`001Ol0103oo`03o`030?l000?o
00D0oooo0003o`030?l000?o00@0ool01?l200Co00@0ool09Ol001co00<0ool01?l300Co00D0oooo
0005o`050?ooo`000_l00`3oo`08o`040?oo00[o00@0ool01?l00`3oo`03o`030?l000Go0P03o`04
0?oo00Go0P03o`050?ooo`001?l00`3o0002o`040?oo00Go00<0o`000_l0103oo`05o`800ol00`3o
0005o`040?oo00?o0P05o`040?oo00?o0P05o`040?oo00?o0P05o`040?oo00?o00<0o`000ol01@3o
ool000?o00<0o`001?l00`3o0005o`030?oo00;o00@0ool09Ol001co0P05o`030?l000Co00D0oooo
0005o`050?ooo`000_l00`3oo`08o`040?oo00[o00@0ool01?l00`3oo`03o`030?l000Go0P03o`04
0?oo00Go0P03o`040?oo00Go0P03o`040?oo00Go0P03o`040?oo00Go0P03o`030?l000Go00@0ool0
0ol200Go00@0ool00ol200Go00@0ool00ol200Go00@0ool00ol00`3o0004o`040?oo00Co00<0ool0
0ol00`3o0005o`030?oo00;o00@0ool09Ol001co00<0ool01?l00`3o0004o`050?ooo`002Ol0103o
o`0:o`040?oo00[o00<0o`001Ol00`3oo`03o`030?l000Go0P04o`030?l000Go0P03o`040?oo00Go
0P03o`040?oo00Go0P04o`030?l000Go0P03o`030?l000Go00@0ool00ol200Go00@0ool00ol200Go
00@0ool00ol200Go00@0ool00ol00`3o0004o`040?oo00Co00<0ool00ol00`3o0005o`030?oo00;o
00@0ool09Ol001co00<0ool01?l00`3o0004o`040?oo00[o00@0ool02_l0103oo`0:o`030?l000_o
00<0o`001Ol00`3oo`03o`030?l000Go0P03o`040?oo00Go0P03o`040?oo00Go0P04o`030?l000Go
0P04o`801Ol00`3o0004o`801Ol0103oo`03o`801Ol0103oo`03o`801Ol0103oo`03o`030?l000Co
00<0o`001Ol00`3oo`03o`030?l000Go00<0ool00_l0103oo`0Uo`007?l00`3oo`04o`030?l000Co
00@0ool02_l0103oo`0:o`040?oo00[o00<0o`002ol00`3o0005o`030?oo00?o00<0o`001Ol00`3o
o`02o`040?oo00Go0P03o`040?oo00Go0P04o`801_l200Co0P05o`030?l000Co0P05o`040?oo00?o
0P05o`040?oo00?o0P05o`040?oo00?o0P05o`030?l000Go00<0ool00ol00`3o0005o`030?oo00;o
00@0ool09Ol001co00<0ool01?l00`3o0004o`040?oo00[o00@0ool02_l0103oo`0:o`030?l000_o
00<0o`001Ol00`3oo`03o`030?l000Go00<0ool00ol00`3o0005o`800ol0103oo`05o`801?l200Ko
0P04o`801_l200Co0P05o`040?oo00?o0P05o`040?oo00?o0P05o`040?oo00Co00<0ool00ol00`3o
0005o`030?oo00?o00<0o`001Ol00`3oo`03o`030?l002Go000Lo`030?oo00Co00<0o`001?l0103o
o`0:o`040?oo00[o00<0o`002ol00`3o000;o`030?l000Go00<0ool00ol00`3o0005o`030?oo00?o
00<0o`001Ol200?o00@0ool01Ol200Co0P06o`801?l200Ko0P04o`801Ol0103oo`03o`801Ol0103o
o`03o`801Ol0103oo`04o`030?oo00?o00<0o`001Ol00`3oo`03o`030?l000Go00<0ool00ol00`3o
000Uo`007?l00`3oo`04o`030?oo00Go00<0o`002_l0103oo`0;o`802ol00`3o000;o`030?l000Go
00<0ool00ol00`3o0005o`030?oo00Co0P06o`060?ooo`3o0P05o`801?l200Ko0P04o`801_l200Co
0P05o`040?oo00?o0P05o`040?oo00?o0P05o`040?oo00Co00<0ool00ol00`3o0005o`030?oo00?o
00<0o`001Ol00`3oo`03o`030?l002Go000Lo`801Ol00`3oo`05o`030?l000[o00@0ool02ol200co
0P0;o`030?l000_o00<0o`001Ol00`3oo`04o`801_l0103oool200Oo0P04o`801_l200Co0P06o`80
1?l00`3oo`05o`030?l000?o0P05o`040?oo00?o0P06o`801Ol00`3oo`03o`030?l000Go00<0ool0
0ol00`3o0005o`030?oo00?o00<0o`009Ol001co00<0ool01?l00`3oo`06o`802_l300co0P0<o`80
3?l00`3oo`0:o`801_l00`3oo`04o`801_l00`3oo`0:o`801?l00`3oo`05o`801?l00`3oo`05o`80
1?l00`3oo`05o`030?l000?o0P05o`040?oo00?o00<0ool01Ol200Go00<0ool00ol00`3o0005o`03
0?oo00?o0P0<o`809_l001co00<0ool01?l00`3oo`06o`802_l00`3oo`0<o`803?l200co00<0ool0
2ol00`3oo`04o`030?oo00Go00<0ool01?l00`3oo`0;o`030?oo00;o00<0ool01_l00`3oo`02o`03
0?oo00Go0P04o`030?oo00Ko0P03o`030?oo00Co0`04o`030?oo00Go0P05o`030?oo00?o00<0o`00
1Ol00`3oo`04o`030?oo00[o0P0Vo`007?l00`3oo`04o`030?oo00Oo00<0ool05ol00`3oo`0;o`03
0?oo00_o00<0ool02ol00`3oo`0<o`030?oo00Co00<0ool02ol00`3oo`02o`030?oo00Ko00<0ool0
0_l00`3oo`05o`801?l00`3oo`06o`800ol00`3oo`04o`030?oo00Co00<0ool01Ol200Go00<0ool0
1?l00`3oo`04o`030?oo00Co00<0ool02ol00`3oo`0To`007?l00`3oo`04o`030?oo00Oo00<0ool0
5ol00`3oo`0;o`030?oo00_o00<0ool02ol00`3oo`0Co`030?oo00_o00<0ool02ol00`3oo`02o`03
0?oo00Ko00<0ool00_l00`3oo`07o`050?ooo`003Ol00`3oo`05o`030?oo00Co00<0ool01?l00`3o
o`0;o`030?oo00_o00<0ool09?l001co00<0ool01?l00`3oo`0Qo`030?oo00_o00<0ool02ol00`3o
o`0;o`030?oo01?o00<0ool02ol00`3oo`0;o`030?oo00;o00<0ool01_l00`3oo`02o`030?oo00Oo
00D0oooo000=o`030?oo00Go00<0ool01?l00`3oo`04o`030?oo00_o00<0ool02ol00`3oo`0To`00
7?l200Go00<0ool0;ol00`3oo`0;o`030?oo00_o00<0ool08Ol00`3oo`0;o`030?oo00_o00<0ool0
0_l00`3oo`0;o`030?oo00_o00<0ool01Ol00`3oo`0;o`030?oo00_o00<0ool02ol00`3oo`0To`00
7?l00`3oo`04o`030?oo02oo00<0ool02ol00`3oo`0_o`030?oo00_o00<0ool02ol00`3oo`02o`03
0?oo00_o00<0ool02ol00`3oo`0Co`030?oo00_o00<0ool0<_l001co00<0ool01?l00`3oo`3oo`Ko
000Lo`030?oo00Co00<0ool0ool6o`007?l00`3oo`04o`030?oo0?oo1_l001co00<0ool01?l00`3o
o`3oo`Ko000Lo`801Ol00`3oo`3oo`Ko000Lo`030?oo00Co00<0ool0ool6o`007?l00`3oo`04o`03
0?oo0?oo1_l001co00<0ool01?l00`3oo`3oo`Ko0007o`030?oo00;o00<0ool00_l300;o00<0ool0
0ol00`3oo`04o`030?oo0?oo1_l000Ko00<0o`002Ol01P3oo`3o00Co00<0ool01?l00`3oo`3oo`Ko
0006o`030?l000Oo1003o`030?oo00;o0`04o`030?oo0?oo1_l000Ko00<0o`001ol00`3o0002o`80
1Ol00`3oo`04o`030?oo0?oo1_l000Ko00<0o`002?l200;o00<0ool01?l00`3oo`04o`030?oo0?oo
1_l000Oo00<0ool02?l00`3oo`0300Co00<0ool01?l00`3oo`3oo`Ko000Lo`030?oo00Co00<0ool0
ool6o`007?l00`3oo`04o`030?oo0?oo1_l001co0P05o`030?oo0?oo1_l001co00<0ool01?l00`3o
o`3oo`Ko000Lo`030?oo00Co00<0ool0ool6o`007?l00`3oo`04o`030?oo0?oo1_l001co00<0ool0
1?l00`3oo`3oo`Ko000Lo`030?oo00Co00<0ool0ool6o`007?l200Go00<0ool0ool6o`007?l00`3o
o`04o`030?oo0?oo1_l001co00<0ool01?l00`3oo`3oo`Ko000Lo`030?oo00Co00<0ool0ool6o`00
7?l00`3oo`04o`030?oo0?oo1_l001co00<0ool01?l00`3oo`3oo`Ko000Lo`801Ol00`3oo`3oo`Ko
000Lo`030?oo00Co00<0ool0ool6o`007?l00`3oo`04o`030?oo0?oo1_l001co00<0ool01?l00`3o
o`3oo`Ko000Lo`030?oo00Co00<0ool0ool6o`007?l00`3oo`04o`030?oo0?oo1_l001co00<0ool0
1?l00`3oo`3oo`Ko000Lo`801Ol00`3oo`3oo`Ko000Lo`030?oo00Co00<0ool0ool6o`007?l00`3o
o`04o`030?oo0?oo1_l001co00<0ool01?l00`3oo`3oo`Ko000<o`030?oo00;o00<0ool00_l00`3o
o`03o`030?oo00Co00<0ool0ool6o`002ol00`3o0007o`030?l000Co00<0ool01?l00`3oo`3oo`Ko
000;o`030?l000Wo00<0ool00_l300Co00<0ool0ool6o`002ol00`3o0007o`801Ol00`3oo`04o`03
0?oo0?oo1_l000_o00<0o`001ol00`3oo`04o`030?oo00Co00<0ool0ool6o`003?l00`3oo`06o`<0
1?l00`3oo`04o`030?oo0?oo1_l001co00<0ool01?l00`3oo`3oo`Ko000Lo`030?oo00Co00<0ool0
ool6o`007?l200Go00<0ool0ool6o`007?l00`3oo`04o`030?oo0?oo1_l001co00<0ool01?l00`3o
o`3oo`Ko000Lo`030?oo00Co00<0ool0ool6o`007?l00`3oo`04o`030?oo0?oo1_l001co00<0ool0
1?l00`3oo`3oo`Ko000Lo`801Ol00`3oo`3oo`Ko000Lo`030?oo00Co00<0ool0ool6o`007?l00`3o
o`04o`030?oo0?oo1_l001co00<0ool01?l00`3oo`3oo`Ko000Lo`030?oo00Co00<0ool0ool6o`00
7?l00`3oo`04o`030?oo0?oo1_l001co0P05o`030?oo0?oo1_l001co00<0ool01?l00`3oo`3oo`Ko
000Lo`030?oo00Co00<0ool0ool6o`007?l00`3oo`04o`030?oo0?oo1_l001co00<0ool01?l00`3o
o`3oo`Ko000Lo`030?oo00Co00<0ool0ool6o`007?l200Go00<0ool0ool6o`007?l00`3oo`04o`03
0?oo0?oo1_l001co00<0ool01?l00`3oo`3oo`Ko000Lo`030?oo00Co00<0ool0ool6o`001ol00`3o
o`02o`030?oo00;o00<0ool00_l00`3oo`03o`030?oo00Co00<0ool0ool6o`001_l00`3o0007o`03
0?l000;o00<0o`001?l00`3oo`04o`030?oo0?oo1_l000Ko00<0o`002Ol00`3oo`02o`030?oo00;o
0`04o`030?oo0?oo1_l000Ko00<0o`001ol200?o0P05o`030?oo00Co00<0ool0ool6o`001_l00`3o
0007o`030?oo00;o00<0ool01?l00`3oo`04o`030?oo0?oo1_l000Oo00<0ool01_l300;o0`3ooaCo
003oobco003oobco003oobco003oobco003oobco003oobco003oobco003oobco0021o`D000Co0000
0_l300?o0P02o`<01_l200;o00<0ool0QOl008;o00@0ool00_l00`3oo`02o`050?ooo`000_l0103o
o`08o`040?oo08Oo0022o`030?oo00?o00<0ool00_l01@3oool000;o00@0ool02?l0103oo`27o`00
P_l200?o10000ol0000200;o0P02o`@01Ol408So0022o`040?oo0:Go0021o`D0YOl00?oo;?l00?oo
;?l00?oo;?l00?oo;?l00?oo;?l00?oo;?l001[o0P02o`030?oo0?oo2ol001_o00@0ool0ool=o`00
6ol0103oo`3oo`go000Jo`@0ool>o`00ool/o`00ool/o`00ool/o`00ool/o`00ool/o`00\
\>"],
  ImageRangeCache->{{{0, 298}, {184, 0}} -> {-12.0373, 0.302518, 0.42207, 
  0.00162864}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(ComputeForwardKinematic[Links, Motors]\), 
    \(\(ComputeInverseDynamics[Links, Motors]; \)\), 
    \(\(TrajectoryPlanning["\<Puma.trj\>"]; \)\), 
    \(\(ShowPositionsL[1]; \)\), 
    \(\(ShowPositionsL[2]; \)\), 
    \(\(ShowPositionsL[3]; \)\), 
    \(\(ShowPositionsM[1]; \)\), 
    \(\(ShowPositionsM[2]; \)\), 
    \(\(ShowPositionsM[3]; \)\), 
    \(\(ShowVelocityL[1]; \)\), 
    \(\(ShowVelocityL[2]; \)\), 
    \(\(ShowVelocityL[3]; \)\), 
    \(\(ShowVelocityM[1]; \)\), 
    \(\(ShowVelocityM[2]; \)\), 
    \(\(ShowVelocityM[3]; \)\), 
    \(\(ShowAccelerationL[1]; \)\), 
    \(\(ShowAccelerationL[2]; \)\), 
    \(\(ShowAccelerationL[3]; \)\), 
    \(\(ShowAccelerationM[1]; \)\), 
    \(\(ShowAccelerationM[2]; \)\), 
    \(\(ShowAccelerationM[3]; \)\), 
    \(\(GenerateForce[]; \)\), 
    \(\(ShowForceL[1]; \)\), 
    \(\(ShowForceL[2]; \)\), 
    \(\(ShowForceL[3]; \)\), 
    \(\(ShowForceM[1]; \)\), 
    \(\(ShowForceM[2]; \)\), 
    \(\(ShowForceM[3]; \)\), 
    \(\(ForwardDynamics[Links, Motors]; \)\), 
    \(\(GenerateAccelerations[]; \)\), 
    \(\(ShowAccelerationL[1]; \)\), 
    \(\(ShowAccelerationL[2]; \)\), 
    \(\(ShowAccelerationL[3]; \)\), 
    \(\(ShowAccelerationM[1]; \)\), 
    \(\(ShowAccelerationM[2]; \)\), 
    \(\(ShowAccelerationM[3]; \)\)}], "Input",
  PageWidth->Infinity,
  FontFamily->"Courier New",
  FontSize->10,
  FontWeight->"Plain",
  FontSlant->"Plain",
  FontTracking->"Plain",
  FontVariations->{"Underline"->False,
  "Outline"->False,
  "Shadow"->False}],

Cell[OutputFormData["\<\
No Input Form Generated




\
\>", "\<\
Computing Velocity ...
 Computed 3 velocities  ...
VelLPlus[3]=
 Transpose[Fil[4][3]].VelLMinus[4]
VelLMinus[3]=
 Transpose[Al[3]].VelLPlus[3]+Transpose[Hl[3]]*Qpl[3]
VelMPlus[3]=
 Transpose[Fim[4][3]].VelLMinus[4]
VelMMinus[3]=
 Transpose[Am[3]].VelMPlus[3]+Transpose[Hm[3]]*Qpm[3]

 Computed 2 velocities  ...
VelLPlus[2]=
 Transpose[Fil[3][2]].VelLMinus[3]
VelLMinus[2]=
 Transpose[Al[2]].VelLPlus[2]+Transpose[Hl[2]]*Qpl[2]
VelMPlus[2]=
 Transpose[Fim[2][2]].VelLMinus[3]
VelMMinus[2]=
 Transpose[Am[2]].VelMPlus[2]+Transpose[Hm[2]]*Qpm[2]

 Computed 1 velocities  ...
VelLPlus[1]=
 Transpose[Fil[2][1]].VelLMinus[2]
VelLMinus[1]=
 Transpose[Al[1]].VelLPlus[1]+Transpose[Hl[1]]*Qpl[1]
VelMPlus[1]=
 Transpose[Fim[2][1]].VelLMinus[2]
VelMMinus[1]=
 Transpose[Am[1]].VelMPlus[1]+Transpose[Hm[1]]*Qpm[1]

Computing Acceleration ...

Computing Coroilis and centrifugal accelerations - a matrices ...
       a:  1
       a:  2
       a:  3
Coroilis and centrifugal accelerations have been prepared ...
Computed 3 Acceleration  ...
 AccLMinus[3]=
  Transpose[Al[3]].Transpose[Fil[4][3]].AccLMinus[4] +Transpose[Hl[3]] \
*Qppl[3]+al[3]
 AccMMinus[3]=
  Transpose[Am[3]].Transpose[Fim[4][3]].AccLMinus[4] +Transpose[Hm[3]] \
*Qppm[3]+am[3]

Computed 2 Acceleration  ...
 AccLMinus[2]=
  Transpose[Al[2]].Transpose[Fil[3][2]].AccLMinus[3] +Transpose[Hl[2]] \
*Qppl[2]+al[2]
 AccMMinus[2]=
  Transpose[Am[2]].Transpose[Fim[2][2]].AccLMinus[3] +Transpose[Hm[2]] \
*Qppm[2]+am[2]

Computed 1 Acceleration  ...
 AccLMinus[1]=
  Transpose[Al[1]].Transpose[Fil[2][1]].AccLMinus[2] +Transpose[Hl[1]] \
*Qppl[1]+al[1]
 AccMMinus[1]=
  Transpose[Am[1]].Transpose[Fim[2][1]].AccLMinus[2] +Transpose[Hm[1]] \
*Qppm[1]+am[1]


Computing inverse dynamics ...

Computing Force ...

fmPlus[1]=Mm[1].AccMMinus[1]+bm[1]
fmMinus[1]=Am[1].fmPlus[1]
flMinus[1]=Ml[1].AccLMinus[1]+bl[1]
flPlus[1]=Al[1].flMinus[1]
  + {0, 0, 0, 0, 0, 0}
 Tl[1]=Hl[1].flMinus[1]
 Tm[1]=Hm[1].matfmPlus[1]
      Force  1 has been done ...


fmPlus[2]=Mm[2].AccMMinus[2]+bm[2]
fmMinus[2]=Am[2].fmPlus[2]
flMinus[2]=Ml[2].AccLMinus[2]+bl[2]
                     + Fim[2][2].Am[2].fmPlus[2]
                      + Fil[2][1].Al[1].flMinus[1]
flPlus[2]=Al[2].flMinus[2]
 Tl[2]=Hl[2].flMinus[2]
 Tm[2]=Hm[2].matfmPlus[2]
      Force  2 has been done ...


fmPlus[3]=Mm[3].AccMMinus[3]+bm[3]
fmMinus[3]=Am[3].fmPlus[3]
flMinus[3]=Ml[3].AccLMinus[3]+bl[3]
                      + Fil[3][2].Al[2].flMinus[2]
flPlus[3]=Al[3].flMinus[3]
 Tl[3]=Hl[3].flMinus[3]
 Tm[3]=Hm[3].matfmPlus[3]
      Force  3 has been done ...


Inverse dynamics has been done ...


Trajectory planning ...
      Step  1 of 3 has been done ...
      Step  2 of 3 has been done ...
      Step  3 of 3 has been done ...
Trajectory have been planed ...
Generate force ....
done

Computing forward dynamics ...

  P[1]=Fil[1][0].Al[0].P[0].Transpose[Al[0]].Transpose[Fil[1][0]]
  zminusl[1]=Fil[1][0].Al[0].zplusl[0]+bl[1]+P[1].al[1]
  Dm[1]=Hm[1].Mm[1].Transpose[Hm[1]]
  Dl[1]=Hl[1].P[1].Transpose[Hl[1]]
  DmInv[1]  =1/Dm[1]
  DlInv[1]  =1/Dl[1]
  Gl[1]=P[1].Transpose[Hl[1]].DlInv[1]
  Gm[1]=Mm[1].Transpose[Hm[1]].DmInv[1]
  lambda[1]=Fim[1][0].Am[0].Mm[1].Transpose[Hm[1]]
  Km[1]=lambda[1].DmInv[1]
  Kl[1]=Fil[2][1].Al[1].Gl[1]
  epsl[1]=Tl[1]-Hl[1].zminusl[1]
  epsm[1]=Tm[1]-Hm[1].zminusm[1]
  Nil[1] =DlInv[1].epsl[1]
  Nim[1]=DmInv[1].epsm[1]
  zplusl[1] =zminusl[1]+Gl[1].epsl[1]
     Iteration  1 of 6 have been done.
  P[2]=Fil[2][1].Al[1].P[1].Transpose[Al[1]].Transpose[Fil[2][1]]
    -Kl[1].Dl[1].Transpose[Kl[1]]
    -Km[2].Dm[2].Transpose[Km[2]]
  zminusl[2]=Fil[2][1].Al[1].zplusl[1]+bl[2]+P[2].al[2]
    +Fim[2][2].Am[2].zplusm[2]
  Dm[2]=Hm[2].Mm[2].Transpose[Hm[2]]
  Dl[2]=Hl[2].P[2].Transpose[Hl[2]]
  DmInv[2]  =1/Dm[2]
  DlInv[2]  =1/Dl[2]
  Gl[2]=P[2].Transpose[Hl[2]].DlInv[2]
  Gm[2]=Mm[2].Transpose[Hm[2]].DmInv[2]
  lambda[2]=Fim[2][1].Am[1].Mm[2].Transpose[Hm[2]]
  Km[2]=lambda[2].DmInv[2]
  Kl[2]=Fil[3][2].Al[2].Gl[2]
  epsl[2]=Tl[2]-Hl[2].zminusl[2]
  epsm[2]=Tm[2]-Hm[2].zminusm[2]
  Nil[2] =DlInv[2].epsl[2]
  Nim[2]=DmInv[2].epsm[2]
  zplusl[2] =zminusl[2]+Gl[2].epsl[2]
     Iteration  2 of 6 have been done.
  P[3]=Fil[3][2].Al[2].P[2].Transpose[Al[2]].Transpose[Fil[3][2]]
    -Kl[2].Dl[2].Transpose[Kl[2]]
  zminusl[3]=Fil[3][2].Al[2].zplusl[2]+bl[3]+P[3].al[3]
  Dm[3]=Hm[3].Mm[3].Transpose[Hm[3]]
  Dl[3]=Hl[3].P[3].Transpose[Hl[3]]
  DmInv[3]  =1/Dm[3]
  DlInv[3]  =1/Dl[3]
  Gl[3]=P[3].Transpose[Hl[3]].DlInv[3]
  Gm[3]=Mm[3].Transpose[Hm[3]].DmInv[3]
  lambda[3]=Fim[3][2].Am[2].Mm[3].Transpose[Hm[3]]
  Km[3]=lambda[3].DmInv[3]
  Kl[3]=Fil[4][3].Al[3].Gl[3]
  epsl[3]=Tl[3]-Hl[3].zminusl[3]
  epsm[3]=Tm[3]-Hm[3].zminusm[3]
  Nil[3] =DlInv[3].epsl[3]
  Nim[3]=DmInv[3].epsm[3]
  zplusl[3] =zminusl[3]+Gl[3].epsl[3]
     Iteration  3 of 6 have been done.
  alfaplusl[3]=Transpose[Al[3]].Transpose[Fil[4][3]].alfal[4]
  alfaplusm[3]=Transpose[Am[3]].Transpose[Fim[4][3]].alfal[4]
  Qbisl[3]=Nil[3]-Transpose[Gl[3]].alfaplusl[3]
  Qbism[3]=Nim[3]-Transpose[Gm[3]].alfaplusm[3]
    alfal[3]=alfaplusl[3]+Transpose[Hl[3]].Qbisl[3]+al[3]
     Iteration  4 of 6 have been done.
  alfaplusl[2]=Transpose[Al[2]].Transpose[Fil[3][2]].alfal[3]
  alfaplusm[2]=Transpose[Am[2]].Transpose[Fim[2][2]].alfal[3]
  Qbisl[2]=Nil[2]-Transpose[Gl[2]].alfaplusl[2]
  Qbism[2]=Nim[2]-Transpose[Gm[2]].alfaplusm[2]
    alfal[2]=alfaplusl[2]+Transpose[Hl[2]].Qbisl[2]+al[2]
     Iteration  5 of 6 have been done.
  alfaplusl[1]=Transpose[Al[1]].Transpose[Fil[2][1]].alfal[2]
  alfaplusm[1]=Transpose[Am[1]].Transpose[Fim[2][1]].alfal[2]
  Qbisl[1]=Nil[1]-Transpose[Gl[1]].alfaplusl[1]
  Qbism[1]=Nim[1]-Transpose[Gm[1]].alfaplusm[1]
     Iteration  6 of 6 have been done.
Forward dynamics done...

Generating new accelerations tables ...


Accelerations tables have been generated.
\
\>"], "Print",
  PageWidth->Infinity,
  Evaluatable->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0.460346 0.106386 [
[(1)] .2619 .46035 0 2 Msboxa
[(2)] .5 .46035 0 2 Msboxa
[(3)] .7381 .46035 0 2 Msboxa
[(4)] .97619 .46035 0 2 Msboxa
[([s])] 1.025 .46035 -1 0 Msboxa
[(-4)] .01131 .0348 1 0 Msboxa
[(-3)] .01131 .14119 1 0 Msboxa
[(-2)] .01131 .24757 1 0 Msboxa
[(-1)] .01131 .35396 1 0 Msboxa
[(1)] .01131 .56673 1 0 Msboxa
[([Rad])] .02381 .61803 0 -4 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 .61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.2619 .46035 m
.2619 .4666 L
s
P
[(1)] .2619 .46035 0 2 Mshowa
p
.002 w
.5 .46035 m
.5 .4666 L
s
P
[(2)] .5 .46035 0 2 Mshowa
p
.002 w
.7381 .46035 m
.7381 .4666 L
s
P
[(3)] .7381 .46035 0 2 Mshowa
p
.002 w
.97619 .46035 m
.97619 .4666 L
s
P
[(4)] .97619 .46035 0 2 Mshowa
p
.001 w
.07143 .46035 m
.07143 .4641 L
s
P
p
.001 w
.11905 .46035 m
.11905 .4641 L
s
P
p
.001 w
.16667 .46035 m
.16667 .4641 L
s
P
p
.001 w
.21429 .46035 m
.21429 .4641 L
s
P
p
.001 w
.30952 .46035 m
.30952 .4641 L
s
P
p
.001 w
.35714 .46035 m
.35714 .4641 L
s
P
p
.001 w
.40476 .46035 m
.40476 .4641 L
s
P
p
.001 w
.45238 .46035 m
.45238 .4641 L
s
P
p
.001 w
.54762 .46035 m
.54762 .4641 L
s
P
p
.001 w
.59524 .46035 m
.59524 .4641 L
s
P
p
.001 w
.64286 .46035 m
.64286 .4641 L
s
P
p
.001 w
.69048 .46035 m
.69048 .4641 L
s
P
p
.001 w
.78571 .46035 m
.78571 .4641 L
s
P
p
.001 w
.83333 .46035 m
.83333 .4641 L
s
P
p
.001 w
.88095 .46035 m
.88095 .4641 L
s
P
p
.001 w
.92857 .46035 m
.92857 .4641 L
s
P
[([s])] 1.025 .46035 -1 0 Mshowa
p
.002 w
0 .46035 m
1 .46035 L
s
P
p
.002 w
.02381 .0348 m
.03006 .0348 L
s
P
[(-4)] .01131 .0348 1 0 Mshowa
p
.002 w
.02381 .14119 m
.03006 .14119 L
s
P
[(-3)] .01131 .14119 1 0 Mshowa
p
.002 w
.02381 .24757 m
.03006 .24757 L
s
P
[(-2)] .01131 .24757 1 0 Mshowa
p
.002 w
.02381 .35396 m
.03006 .35396 L
s
P
[(-1)] .01131 .35396 1 0 Mshowa
p
.002 w
.02381 .56673 m
.03006 .56673 L
s
P
[(1)] .01131 .56673 1 0 Mshowa
p
.001 w
.02381 .05608 m
.02756 .05608 L
s
P
p
.001 w
.02381 .07735 m
.02756 .07735 L
s
P
p
.001 w
.02381 .09863 m
.02756 .09863 L
s
P
p
.001 w
.02381 .11991 m
.02756 .11991 L
s
P
p
.001 w
.02381 .16246 m
.02756 .16246 L
s
P
p
.001 w
.02381 .18374 m
.02756 .18374 L
s
P
p
.001 w
.02381 .20502 m
.02756 .20502 L
s
P
p
.001 w
.02381 .2263 m
.02756 .2263 L
s
P
p
.001 w
.02381 .26885 m
.02756 .26885 L
s
P
p
.001 w
.02381 .29013 m
.02756 .29013 L
s
P
p
.001 w
.02381 .3114 m
.02756 .3114 L
s
P
p
.001 w
.02381 .33268 m
.02756 .33268 L
s
P
p
.001 w
.02381 .37524 m
.02756 .37524 L
s
P
p
.001 w
.02381 .39651 m
.02756 .39651 L
s
P
p
.001 w
.02381 .41779 m
.02756 .41779 L
s
P
p
.001 w
.02381 .43907 m
.02756 .43907 L
s
P
p
.001 w
.02381 .48162 m
.02756 .48162 L
s
P
p
.001 w
.02381 .5029 m
.02756 .5029 L
s
P
p
.001 w
.02381 .52418 m
.02756 .52418 L
s
P
p
.001 w
.02381 .54545 m
.02756 .54545 L
s
P
p
.001 w
.02381 .01352 m
.02756 .01352 L
s
P
p
.001 w
.02381 .58801 m
.02756 .58801 L
s
P
p
.001 w
.02381 .60929 m
.02756 .60929 L
s
P
[([Rad])] .02381 .61803 0 -4 Mshowa
p
.002 w
.02381 0 m
.02381 .61803 L
s
P
P
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
p
.004 w
.03333 .01472 m
.04286 .01476 L
.05238 .01486 L
.0619 .01506 L
.07143 .01538 L
.08095 .01585 L
.09048 .01649 L
.1 .01732 L
.10952 .01837 L
.11905 .01964 L
.12857 .02117 L
.1381 .02296 L
.14762 .02502 L
.15714 .02738 L
.16667 .03003 L
.17619 .033 L
.18571 .03627 L
.19524 .03987 L
.20476 .0438 L
.21429 .04805 L
.22381 .05264 L
.23333 .05756 L
.24286 .06281 L
.25238 .06839 L
.2619 .0743 L
.27143 .08053 L
.28095 .08708 L
.29048 .09395 L
.3 .10112 L
.30952 .10858 L
.31905 .11634 L
.32857 .12438 L
.3381 .13269 L
.34762 .14126 L
.35714 .15008 L
.36667 .15913 L
.37619 .16841 L
.38571 .17789 L
.39524 .18757 L
.40476 .19744 L
.41429 .20746 L
.42381 .21764 L
.43333 .22795 L
.44286 .23838 L
.45238 .24891 L
.4619 .25953 L
.47143 .27022 L
.48095 .28096 L
.49048 .29173 L
.5 .30252 L
Mistroke
.50952 .31331 L
.51905 .32408 L
.52857 .33482 L
.5381 .3455 L
.54762 .35612 L
.55714 .36665 L
.56667 .37709 L
.57619 .3874 L
.58571 .39757 L
.59524 .4076 L
.60476 .41746 L
.61429 .42714 L
.62381 .43663 L
.63333 .4459 L
.64286 .45496 L
.65238 .46377 L
.6619 .47234 L
.67143 .48065 L
.68095 .48869 L
.69048 .49645 L
.7 .50392 L
.70952 .51109 L
.71905 .51795 L
.72857 .52451 L
.7381 .53074 L
.74762 .53665 L
.75714 .54223 L
.76667 .54748 L
.77619 .5524 L
.78571 .55698 L
.79524 .56124 L
.80476 .56516 L
.81429 .56876 L
.82381 .57204 L
.83333 .575 L
.84286 .57766 L
.85238 .58001 L
.8619 .58208 L
.87143 .58387 L
.88095 .58539 L
.89048 .58667 L
.9 .58772 L
.90952 .58855 L
.91905 .58919 L
.92857 .58965 L
.9381 .58997 L
.94762 .59017 L
.95714 .59028 L
.96667 .59032 L
.97619 .59032 L
Mistroke
Mfstroke
[(  Position Ql[ 1 ])] .5 .60332 0 0 Mshowa
P
% End of Graphics
MathPictureEnd\
\>"], "Graphics",
  PageWidth->Infinity,
  Evaluatable->False,
  ImageSize->{299, 185},
  ImageMargins->{{80, Inherited}, {Inherited, 0}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0.505218 0.127744 [
[(1)] .2619 .50522 0 2 Msboxa
[(2)] .5 .50522 0 2 Msboxa
[(3)] .7381 .50522 0 2 Msboxa
[(4)] .97619 .50522 0 2 Msboxa
[([s])] 1.025 .50522 -1 0 Msboxa
[(-3)] .01131 .12199 1 0 Msboxa
[(-2)] .01131 .24973 1 0 Msboxa
[(-1)] .01131 .37747 1 0 Msboxa
[([Rad])] .02381 .61803 0 -4 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 .61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.2619 .50522 m
.2619 .51147 L
s
P
[(1)] .2619 .50522 0 2 Mshowa
p
.002 w
.5 .50522 m
.5 .51147 L
s
P
[(2)] .5 .50522 0 2 Mshowa
p
.002 w
.7381 .50522 m
.7381 .51147 L
s
P
[(3)] .7381 .50522 0 2 Mshowa
p
.002 w
.97619 .50522 m
.97619 .51147 L
s
P
[(4)] .97619 .50522 0 2 Mshowa
p
.001 w
.07143 .50522 m
.07143 .50897 L
s
P
p
.001 w
.11905 .50522 m
.11905 .50897 L
s
P
p
.001 w
.16667 .50522 m
.16667 .50897 L
s
P
p
.001 w
.21429 .50522 m
.21429 .50897 L
s
P
p
.001 w
.30952 .50522 m
.30952 .50897 L
s
P
p
.001 w
.35714 .50522 m
.35714 .50897 L
s
P
p
.001 w
.40476 .50522 m
.40476 .50897 L
s
P
p
.001 w
.45238 .50522 m
.45238 .50897 L
s
P
p
.001 w
.54762 .50522 m
.54762 .50897 L
s
P
p
.001 w
.59524 .50522 m
.59524 .50897 L
s
P
p
.001 w
.64286 .50522 m
.64286 .50897 L
s
P
p
.001 w
.69048 .50522 m
.69048 .50897 L
s
P
p
.001 w
.78571 .50522 m
.78571 .50897 L
s
P
p
.001 w
.83333 .50522 m
.83333 .50897 L
s
P
p
.001 w
.88095 .50522 m
.88095 .50897 L
s
P
p
.001 w
.92857 .50522 m
.92857 .50897 L
s
P
[([s])] 1.025 .50522 -1 0 Mshowa
p
.002 w
0 .50522 m
1 .50522 L
s
P
p
.002 w
.02381 .12199 m
.03006 .12199 L
s
P
[(-3)] .01131 .12199 1 0 Mshowa
p
.002 w
.02381 .24973 m
.03006 .24973 L
s
P
[(-2)] .01131 .24973 1 0 Mshowa
p
.002 w
.02381 .37747 m
.03006 .37747 L
s
P
[(-1)] .01131 .37747 1 0 Mshowa
p
.001 w
.02381 .01979 m
.02756 .01979 L
s
P
p
.001 w
.02381 .04534 m
.02756 .04534 L
s
P
p
.001 w
.02381 .07089 m
.02756 .07089 L
s
P
p
.001 w
.02381 .09644 m
.02756 .09644 L
s
P
p
.001 w
.02381 .14753 m
.02756 .14753 L
s
P
p
.001 w
.02381 .17308 m
.02756 .17308 L
s
P
p
.001 w
.02381 .19863 m
.02756 .19863 L
s
P
p
.001 w
.02381 .22418 m
.02756 .22418 L
s
P
p
.001 w
.02381 .27528 m
.02756 .27528 L
s
P
p
.001 w
.02381 .30083 m
.02756 .30083 L
s
P
p
.001 w
.02381 .32638 m
.02756 .32638 L
s
P
p
.001 w
.02381 .35193 m
.02756 .35193 L
s
P
p
.001 w
.02381 .40302 m
.02756 .40302 L
s
P
p
.001 w
.02381 .42857 m
.02756 .42857 L
s
P
p
.001 w
.02381 .45412 m
.02756 .45412 L
s
P
p
.001 w
.02381 .47967 m
.02756 .47967 L
s
P
p
.001 w
.02381 .53077 m
.02756 .53077 L
s
P
p
.001 w
.02381 .55632 m
.02756 .55632 L
s
P
p
.001 w
.02381 .58186 m
.02756 .58186 L
s
P
p
.001 w
.02381 .60741 m
.02756 .60741 L
s
P
[([Rad])] .02381 .61803 0 -4 Mshowa
p
.002 w
.02381 0 m
.02381 .61803 L
s
P
P
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
p
.004 w
.03333 .01472 m
.04286 .01476 L
.05238 .01486 L
.0619 .01506 L
.07143 .01539 L
.08095 .01586 L
.09048 .0165 L
.1 .01734 L
.10952 .01839 L
.11905 .01968 L
.12857 .02121 L
.1381 .02302 L
.14762 .0251 L
.15714 .02747 L
.16667 .03014 L
.17619 .03313 L
.18571 .03643 L
.19524 .04005 L
.20476 .04401 L
.21429 .04829 L
.22381 .05291 L
.23333 .05786 L
.24286 .06315 L
.25238 .06877 L
.2619 .07472 L
.27143 .081 L
.28095 .0876 L
.29048 .09451 L
.3 .10173 L
.30952 .10925 L
.31905 .11706 L
.32857 .12516 L
.3381 .13353 L
.34762 .14216 L
.35714 .15104 L
.36667 .16016 L
.37619 .1695 L
.38571 .17905 L
.39524 .1888 L
.40476 .19873 L
.41429 .20883 L
.42381 .21908 L
.43333 .22946 L
.44286 .23997 L
.45238 .25057 L
.4619 .26127 L
.47143 .27203 L
.48095 .28284 L
.49048 .29369 L
.5 .30456 L
Mistroke
.50952 .31542 L
.51905 .32627 L
.52857 .33709 L
.5381 .34785 L
.54762 .35854 L
.55714 .36915 L
.56667 .37965 L
.57619 .39004 L
.58571 .40029 L
.59524 .41039 L
.60476 .42032 L
.61429 .43007 L
.62381 .43962 L
.63333 .44896 L
.64286 .45808 L
.65238 .46696 L
.6619 .47559 L
.67143 .48396 L
.68095 .49205 L
.69048 .49987 L
.7 .50739 L
.70952 .51461 L
.71905 .52152 L
.72857 .52812 L
.7381 .53439 L
.74762 .54034 L
.75714 .54596 L
.76667 .55125 L
.77619 .55621 L
.78571 .56083 L
.79524 .56511 L
.80476 .56906 L
.81429 .57269 L
.82381 .57599 L
.83333 .57897 L
.84286 .58165 L
.85238 .58402 L
.8619 .5861 L
.87143 .5879 L
.88095 .58944 L
.89048 .59072 L
.9 .59178 L
.90952 .59262 L
.91905 .59326 L
.92857 .59373 L
.9381 .59405 L
.94762 .59425 L
.95714 .59436 L
.96667 .59439 L
.97619 .5944 L
Mistroke
Mfstroke
[(  Position Ql[ 2 ])] .5 .60332 0 0 Mshowa
P
% End of Graphics
MathPictureEnd\
\>"], "Graphics",
  PageWidth->Infinity,
  Evaluatable->False,
  ImageSize->{299, 185},
  ImageMargins->{{80, Inherited}, {Inherited, 0}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0.295003 0.107062 [
[(1)] .2619 .295 0 2 Msboxa
[(2)] .5 .295 0 2 Msboxa
[(3)] .7381 .295 0 2 Msboxa
[(4)] .97619 .295 0 2 Msboxa
[([s])] 1.025 .295 -1 0 Msboxa
[(-2)] .01131 .08088 1 0 Msboxa
[(-1)] .01131 .18794 1 0 Msboxa
[(1)] .01131 .40206 1 0 Msboxa
[(2)] .01131 .50913 1 0 Msboxa
[(3)] .01131 .61619 1 0 Msboxa
[([Rad])] .02381 .61803 0 -4 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 .61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.2619 .295 m
.2619 .30125 L
s
P
[(1)] .2619 .295 0 2 Mshowa
p
.002 w
.5 .295 m
.5 .30125 L
s
P
[(2)] .5 .295 0 2 Mshowa
p
.002 w
.7381 .295 m
.7381 .30125 L
s
P
[(3)] .7381 .295 0 2 Mshowa
p
.002 w
.97619 .295 m
.97619 .30125 L
s
P
[(4)] .97619 .295 0 2 Mshowa
p
.001 w
.07143 .295 m
.07143 .29875 L
s
P
p
.001 w
.11905 .295 m
.11905 .29875 L
s
P
p
.001 w
.16667 .295 m
.16667 .29875 L
s
P
p
.001 w
.21429 .295 m
.21429 .29875 L
s
P
p
.001 w
.30952 .295 m
.30952 .29875 L
s
P
p
.001 w
.35714 .295 m
.35714 .29875 L
s
P
p
.001 w
.40476 .295 m
.40476 .29875 L
s
P
p
.001 w
.45238 .295 m
.45238 .29875 L
s
P
p
.001 w
.54762 .295 m
.54762 .29875 L
s
P
p
.001 w
.59524 .295 m
.59524 .29875 L
s
P
p
.001 w
.64286 .295 m
.64286 .29875 L
s
P
p
.001 w
.69048 .295 m
.69048 .29875 L
s
P
p
.001 w
.78571 .295 m
.78571 .29875 L
s
P
p
.001 w
.83333 .295 m
.83333 .29875 L
s
P
p
.001 w
.88095 .295 m
.88095 .29875 L
s
P
p
.001 w
.92857 .295 m
.92857 .29875 L
s
P
[([s])] 1.025 .295 -1 0 Mshowa
p
.002 w
0 .295 m
1 .295 L
s
P
p
.002 w
.02381 .08088 m
.03006 .08088 L
s
P
[(-2)] .01131 .08088 1 0 Mshowa
p
.002 w
.02381 .18794 m
.03006 .18794 L
s
P
[(-1)] .01131 .18794 1 0 Mshowa
p
.002 w
.02381 .40206 m
.03006 .40206 L
s
P
[(1)] .01131 .40206 1 0 Mshowa
p
.002 w
.02381 .50913 m
.03006 .50913 L
s
P
[(2)] .01131 .50913 1 0 Mshowa
p
.002 w
.02381 .61619 m
.03006 .61619 L
s
P
[(3)] .01131 .61619 1 0 Mshowa
p
.001 w
.02381 .10229 m
.02756 .10229 L
s
P
p
.001 w
.02381 .1237 m
.02756 .1237 L
s
P
p
.001 w
.02381 .14512 m
.02756 .14512 L
s
P
p
.001 w
.02381 .16653 m
.02756 .16653 L
s
P
p
.001 w
.02381 .20935 m
.02756 .20935 L
s
P
p
.001 w
.02381 .23077 m
.02756 .23077 L
s
P
p
.001 w
.02381 .25218 m
.02756 .25218 L
s
P
p
.001 w
.02381 .27359 m
.02756 .27359 L
s
P
p
.001 w
.02381 .31642 m
.02756 .31642 L
s
P
p
.001 w
.02381 .33783 m
.02756 .33783 L
s
P
p
.001 w
.02381 .35924 m
.02756 .35924 L
s
P
p
.001 w
.02381 .38065 m
.02756 .38065 L
s
P
p
.001 w
.02381 .42348 m
.02756 .42348 L
s
P
p
.001 w
.02381 .44489 m
.02756 .44489 L
s
P
p
.001 w
.02381 .4663 m
.02756 .4663 L
s
P
p
.001 w
.02381 .48771 m
.02756 .48771 L
s
P
p
.001 w
.02381 .53054 m
.02756 .53054 L
s
P
p
.001 w
.02381 .55195 m
.02756 .55195 L
s
P
p
.001 w
.02381 .57336 m
.02756 .57336 L
s
P
p
.001 w
.02381 .59478 m
.02756 .59478 L
s
P
p
.001 w
.02381 .05947 m
.02756 .05947 L
s
P
p
.001 w
.02381 .03805 m
.02756 .03805 L
s
P
p
.001 w
.02381 .01664 m
.02756 .01664 L
s
P
[([Rad])] .02381 .61803 0 -4 Mshowa
p
.002 w
.02381 0 m
.02381 .61803 L
s
P
P
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
p
.004 w
.03333 .01472 m
.04286 .01476 L
.05238 .01486 L
.0619 .01505 L
.07143 .01536 L
.08095 .01582 L
.09048 .01644 L
.1 .01725 L
.10952 .01827 L
.11905 .01951 L
.12857 .021 L
.1381 .02274 L
.14762 .02475 L
.15714 .02705 L
.16667 .02963 L
.17619 .03252 L
.18571 .03571 L
.19524 .03922 L
.20476 .04304 L
.21429 .04718 L
.22381 .05165 L
.23333 .05644 L
.24286 .06155 L
.25238 .06699 L
.2619 .07274 L
.27143 .07881 L
.28095 .08519 L
.29048 .09188 L
.3 .09886 L
.30952 .10613 L
.31905 .11369 L
.32857 .12152 L
.3381 .12961 L
.34762 .13796 L
.35714 .14655 L
.36667 .15536 L
.37619 .1644 L
.38571 .17363 L
.39524 .18306 L
.40476 .19266 L
.41429 .20243 L
.42381 .21234 L
.43333 .22238 L
.44286 .23254 L
.45238 .2428 L
.4619 .25314 L
.47143 .26355 L
.48095 .274 L
.49048 .28449 L
.5 .295 L
Mistroke
.50952 .30551 L
.51905 .316 L
.52857 .32646 L
.5381 .33687 L
.54762 .34721 L
.55714 .35746 L
.56667 .36762 L
.57619 .37766 L
.58571 .38758 L
.59524 .39734 L
.60476 .40694 L
.61429 .41637 L
.62381 .42561 L
.63333 .43464 L
.64286 .44346 L
.65238 .45205 L
.6619 .46039 L
.67143 .46849 L
.68095 .47632 L
.69048 .48387 L
.7 .49115 L
.70952 .49813 L
.71905 .50481 L
.72857 .51119 L
.7381 .51726 L
.74762 .52302 L
.75714 .52845 L
.76667 .53356 L
.77619 .53835 L
.78571 .54282 L
.79524 .54697 L
.80476 .55079 L
.81429 .55429 L
.82381 .55749 L
.83333 .56037 L
.84286 .56296 L
.85238 .56525 L
.8619 .56726 L
.87143 .56901 L
.88095 .57049 L
.89048 .57174 L
.9 .57275 L
.90952 .57356 L
.91905 .57419 L
.92857 .57464 L
.9381 .57495 L
.94762 .57515 L
.95714 .57525 L
.96667 .57528 L
.97619 .57529 L
Mistroke
Mfstroke
[(  Position Ql[ 3 ])] .5 .60332 0 0 Mshowa
P
% End of Graphics
MathPictureEnd\
\>"], "Graphics",
  PageWidth->Infinity,
  Evaluatable->False,
  ImageSize->{299, 185},
  ImageMargins->{{80, Inherited}, {Inherited, 0}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0.460346 0.00169919 [
[(1)] .2619 .46035 0 2 Msboxa
[(2)] .5 .46035 0 2 Msboxa
[(3)] .7381 .46035 0 2 Msboxa
[(4)] .97619 .46035 0 2 Msboxa
[([s])] 1.025 .46035 -1 0 Msboxa
[(-250)] .01131 .03555 1 0 Msboxa
[(-200)] .01131 .12051 1 0 Msboxa
[(-150)] .01131 .20547 1 0 Msboxa
[(-100)] .01131 .29043 1 0 Msboxa
[(-50)] .01131 .37539 1 0 Msboxa
[(50)] .01131 .54531 1 0 Msboxa
[([Rad])] .02381 .61803 0 -4 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 .61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.2619 .46035 m
.2619 .4666 L
s
P
[(1)] .2619 .46035 0 2 Mshowa
p
.002 w
.5 .46035 m
.5 .4666 L
s
P
[(2)] .5 .46035 0 2 Mshowa
p
.002 w
.7381 .46035 m
.7381 .4666 L
s
P
[(3)] .7381 .46035 0 2 Mshowa
p
.002 w
.97619 .46035 m
.97619 .4666 L
s
P
[(4)] .97619 .46035 0 2 Mshowa
p
.001 w
.07143 .46035 m
.07143 .4641 L
s
P
p
.001 w
.11905 .46035 m
.11905 .4641 L
s
P
p
.001 w
.16667 .46035 m
.16667 .4641 L
s
P
p
.001 w
.21429 .46035 m
.21429 .4641 L
s
P
p
.001 w
.30952 .46035 m
.30952 .4641 L
s
P
p
.001 w
.35714 .46035 m
.35714 .4641 L
s
P
p
.001 w
.40476 .46035 m
.40476 .4641 L
s
P
p
.001 w
.45238 .46035 m
.45238 .4641 L
s
P
p
.001 w
.54762 .46035 m
.54762 .4641 L
s
P
p
.001 w
.59524 .46035 m
.59524 .4641 L
s
P
p
.001 w
.64286 .46035 m
.64286 .4641 L
s
P
p
.001 w
.69048 .46035 m
.69048 .4641 L
s
P
p
.001 w
.78571 .46035 m
.78571 .4641 L
s
P
p
.001 w
.83333 .46035 m
.83333 .4641 L
s
P
p
.001 w
.88095 .46035 m
.88095 .4641 L
s
P
p
.001 w
.92857 .46035 m
.92857 .4641 L
s
P
[([s])] 1.025 .46035 -1 0 Mshowa
p
.002 w
0 .46035 m
1 .46035 L
s
P
p
.002 w
.02381 .03555 m
.03006 .03555 L
s
P
[(-250)] .01131 .03555 1 0 Mshowa
p
.002 w
.02381 .12051 m
.03006 .12051 L
s
P
[(-200)] .01131 .12051 1 0 Mshowa
p
.002 w
.02381 .20547 m
.03006 .20547 L
s
P
[(-150)] .01131 .20547 1 0 Mshowa
p
.002 w
.02381 .29043 m
.03006 .29043 L
s
P
[(-100)] .01131 .29043 1 0 Mshowa
p
.002 w
.02381 .37539 m
.03006 .37539 L
s
P
[(-50)] .01131 .37539 1 0 Mshowa
p
.002 w
.02381 .54531 m
.03006 .54531 L
s
P
[(50)] .01131 .54531 1 0 Mshowa
p
.001 w
.02381 .05254 m
.02756 .05254 L
s
P
p
.001 w
.02381 .06953 m
.02756 .06953 L
s
P
p
.001 w
.02381 .08652 m
.02756 .08652 L
s
P
p
.001 w
.02381 .10352 m
.02756 .10352 L
s
P
p
.001 w
.02381 .1375 m
.02756 .1375 L
s
P
p
.001 w
.02381 .15449 m
.02756 .15449 L
s
P
p
.001 w
.02381 .17148 m
.02756 .17148 L
s
P
p
.001 w
.02381 .18847 m
.02756 .18847 L
s
P
p
.001 w
.02381 .22246 m
.02756 .22246 L
s
P
p
.001 w
.02381 .23945 m
.02756 .23945 L
s
P
p
.001 w
.02381 .25644 m
.02756 .25644 L
s
P
p
.001 w
.02381 .27343 m
.02756 .27343 L
s
P
p
.001 w
.02381 .30742 m
.02756 .30742 L
s
P
p
.001 w
.02381 .32441 m
.02756 .32441 L
s
P
p
.001 w
.02381 .3414 m
.02756 .3414 L
s
P
p
.001 w
.02381 .35839 m
.02756 .35839 L
s
P
p
.001 w
.02381 .39238 m
.02756 .39238 L
s
P
p
.001 w
.02381 .40937 m
.02756 .40937 L
s
P
p
.001 w
.02381 .42636 m
.02756 .42636 L
s
P
p
.001 w
.02381 .44335 m
.02756 .44335 L
s
P
p
.001 w
.02381 .47734 m
.02756 .47734 L
s
P
p
.001 w
.02381 .49433 m
.02756 .49433 L
s
P
p
.001 w
.02381 .51132 m
.02756 .51132 L
s
P
p
.001 w
.02381 .52831 m
.02756 .52831 L
s
P
p
.001 w
.02381 .01856 m
.02756 .01856 L
s
P
p
.001 w
.02381 .00156 m
.02756 .00156 L
s
P
p
.001 w
.02381 .5623 m
.02756 .5623 L
s
P
p
.001 w
.02381 .57929 m
.02756 .57929 L
s
P
p
.001 w
.02381 .59628 m
.02756 .59628 L
s
P
p
.001 w
.02381 .61327 m
.02756 .61327 L
s
P
[([Rad])] .02381 .61803 0 -4 Mshowa
p
.002 w
.02381 0 m
.02381 .61803 L
s
P
P
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
p
.004 w
.03333 .01472 m
.04286 .01476 L
.05238 .01486 L
.0619 .01506 L
.07143 .01538 L
.08095 .01585 L
.09048 .01649 L
.1 .01732 L
.10952 .01837 L
.11905 .01964 L
.12857 .02117 L
.1381 .02296 L
.14762 .02502 L
.15714 .02738 L
.16667 .03003 L
.17619 .033 L
.18571 .03627 L
.19524 .03987 L
.20476 .0438 L
.21429 .04805 L
.22381 .05264 L
.23333 .05756 L
.24286 .06281 L
.25238 .06839 L
.2619 .0743 L
.27143 .08053 L
.28095 .08708 L
.29048 .09395 L
.3 .10112 L
.30952 .10858 L
.31905 .11634 L
.32857 .12438 L
.3381 .13269 L
.34762 .14126 L
.35714 .15008 L
.36667 .15913 L
.37619 .16841 L
.38571 .17789 L
.39524 .18757 L
.40476 .19744 L
.41429 .20746 L
.42381 .21764 L
.43333 .22795 L
.44286 .23838 L
.45238 .24891 L
.4619 .25953 L
.47143 .27022 L
.48095 .28096 L
.49048 .29173 L
.5 .30252 L
Mistroke
.50952 .31331 L
.51905 .32408 L
.52857 .33482 L
.5381 .3455 L
.54762 .35612 L
.55714 .36665 L
.56667 .37709 L
.57619 .3874 L
.58571 .39757 L
.59524 .4076 L
.60476 .41746 L
.61429 .42714 L
.62381 .43663 L
.63333 .4459 L
.64286 .45496 L
.65238 .46377 L
.6619 .47234 L
.67143 .48065 L
.68095 .48869 L
.69048 .49645 L
.7 .50392 L
.70952 .51109 L
.71905 .51795 L
.72857 .52451 L
.7381 .53074 L
.74762 .53665 L
.75714 .54223 L
.76667 .54748 L
.77619 .5524 L
.78571 .55698 L
.79524 .56124 L
.80476 .56516 L
.81429 .56876 L
.82381 .57204 L
.83333 .575 L
.84286 .57766 L
.85238 .58001 L
.8619 .58208 L
.87143 .58387 L
.88095 .58539 L
.89048 .58667 L
.9 .58772 L
.90952 .58855 L
.91905 .58919 L
.92857 .58965 L
.9381 .58997 L
.94762 .59017 L
.95714 .59028 L
.96667 .59032 L
.97619 .59032 L
Mistroke
Mfstroke
[(  Position Qm[ 1 ])] .5 .60332 0 0 Mshowa
P
% End of Graphics
MathPictureEnd\
\>"], "Graphics",
  PageWidth->Infinity,
  Evaluatable->False,
  ImageSize->{299, 185},
  ImageMargins->{{80, Inherited}, {Inherited, 0}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0.505218 0.00118987 [
[(1)] .2619 .50522 0 2 Msboxa
[(2)] .5 .50522 0 2 Msboxa
[(3)] .7381 .50522 0 2 Msboxa
[(4)] .97619 .50522 0 2 Msboxa
[([s])] 1.025 .50522 -1 0 Msboxa
[(-400)] .01131 .02927 1 0 Msboxa
[(-300)] .01131 .14826 1 0 Msboxa
[(-200)] .01131 .26724 1 0 Msboxa
[(-100)] .01131 .38623 1 0 Msboxa
[([Rad])] .02381 .61803 0 -4 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 .61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.2619 .50522 m
.2619 .51147 L
s
P
[(1)] .2619 .50522 0 2 Mshowa
p
.002 w
.5 .50522 m
.5 .51147 L
s
P
[(2)] .5 .50522 0 2 Mshowa
p
.002 w
.7381 .50522 m
.7381 .51147 L
s
P
[(3)] .7381 .50522 0 2 Mshowa
p
.002 w
.97619 .50522 m
.97619 .51147 L
s
P
[(4)] .97619 .50522 0 2 Mshowa
p
.001 w
.07143 .50522 m
.07143 .50897 L
s
P
p
.001 w
.11905 .50522 m
.11905 .50897 L
s
P
p
.001 w
.16667 .50522 m
.16667 .50897 L
s
P
p
.001 w
.21429 .50522 m
.21429 .50897 L
s
P
p
.001 w
.30952 .50522 m
.30952 .50897 L
s
P
p
.001 w
.35714 .50522 m
.35714 .50897 L
s
P
p
.001 w
.40476 .50522 m
.40476 .50897 L
s
P
p
.001 w
.45238 .50522 m
.45238 .50897 L
s
P
p
.001 w
.54762 .50522 m
.54762 .50897 L
s
P
p
.001 w
.59524 .50522 m
.59524 .50897 L
s
P
p
.001 w
.64286 .50522 m
.64286 .50897 L
s
P
p
.001 w
.69048 .50522 m
.69048 .50897 L
s
P
p
.001 w
.78571 .50522 m
.78571 .50897 L
s
P
p
.001 w
.83333 .50522 m
.83333 .50897 L
s
P
p
.001 w
.88095 .50522 m
.88095 .50897 L
s
P
p
.001 w
.92857 .50522 m
.92857 .50897 L
s
P
[([s])] 1.025 .50522 -1 0 Mshowa
p
.002 w
0 .50522 m
1 .50522 L
s
P
p
.002 w
.02381 .02927 m
.03006 .02927 L
s
P
[(-400)] .01131 .02927 1 0 Mshowa
p
.002 w
.02381 .14826 m
.03006 .14826 L
s
P
[(-300)] .01131 .14826 1 0 Mshowa
p
.002 w
.02381 .26724 m
.03006 .26724 L
s
P
[(-200)] .01131 .26724 1 0 Mshowa
p
.002 w
.02381 .38623 m
.03006 .38623 L
s
P
[(-100)] .01131 .38623 1 0 Mshowa
p
.001 w
.02381 .05307 m
.02756 .05307 L
s
P
p
.001 w
.02381 .07687 m
.02756 .07687 L
s
P
p
.001 w
.02381 .10066 m
.02756 .10066 L
s
P
p
.001 w
.02381 .12446 m
.02756 .12446 L
s
P
p
.001 w
.02381 .17205 m
.02756 .17205 L
s
P
p
.001 w
.02381 .19585 m
.02756 .19585 L
s
P
p
.001 w
.02381 .21965 m
.02756 .21965 L
s
P
p
.001 w
.02381 .24345 m
.02756 .24345 L
s
P
p
.001 w
.02381 .29104 m
.02756 .29104 L
s
P
p
.001 w
.02381 .31484 m
.02756 .31484 L
s
P
p
.001 w
.02381 .33864 m
.02756 .33864 L
s
P
p
.001 w
.02381 .36243 m
.02756 .36243 L
s
P
p
.001 w
.02381 .41003 m
.02756 .41003 L
s
P
p
.001 w
.02381 .43383 m
.02756 .43383 L
s
P
p
.001 w
.02381 .45762 m
.02756 .45762 L
s
P
p
.001 w
.02381 .48142 m
.02756 .48142 L
s
P
p
.001 w
.02381 .00547 m
.02756 .00547 L
s
P
p
.001 w
.02381 .52902 m
.02756 .52902 L
s
P
p
.001 w
.02381 .55281 m
.02756 .55281 L
s
P
p
.001 w
.02381 .57661 m
.02756 .57661 L
s
P
p
.001 w
.02381 .60041 m
.02756 .60041 L
s
P
[([Rad])] .02381 .61803 0 -4 Mshowa
p
.002 w
.02381 0 m
.02381 .61803 L
s
P
P
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
p
.004 w
.03333 .01472 m
.04286 .01476 L
.05238 .01486 L
.0619 .01506 L
.07143 .01539 L
.08095 .01586 L
.09048 .0165 L
.1 .01734 L
.10952 .01839 L
.11905 .01968 L
.12857 .02121 L
.1381 .02302 L
.14762 .0251 L
.15714 .02747 L
.16667 .03014 L
.17619 .03313 L
.18571 .03643 L
.19524 .04005 L
.20476 .04401 L
.21429 .04829 L
.22381 .05291 L
.23333 .05786 L
.24286 .06315 L
.25238 .06877 L
.2619 .07472 L
.27143 .081 L
.28095 .0876 L
.29048 .09451 L
.3 .10173 L
.30952 .10925 L
.31905 .11706 L
.32857 .12516 L
.3381 .13353 L
.34762 .14216 L
.35714 .15104 L
.36667 .16016 L
.37619 .1695 L
.38571 .17905 L
.39524 .1888 L
.40476 .19873 L
.41429 .20883 L
.42381 .21908 L
.43333 .22946 L
.44286 .23997 L
.45238 .25057 L
.4619 .26127 L
.47143 .27203 L
.48095 .28284 L
.49048 .29369 L
.5 .30456 L
Mistroke
.50952 .31542 L
.51905 .32627 L
.52857 .33709 L
.5381 .34785 L
.54762 .35854 L
.55714 .36915 L
.56667 .37965 L
.57619 .39004 L
.58571 .40029 L
.59524 .41039 L
.60476 .42032 L
.61429 .43007 L
.62381 .43962 L
.63333 .44896 L
.64286 .45808 L
.65238 .46696 L
.6619 .47559 L
.67143 .48396 L
.68095 .49205 L
.69048 .49987 L
.7 .50739 L
.70952 .51461 L
.71905 .52152 L
.72857 .52812 L
.7381 .53439 L
.74762 .54034 L
.75714 .54596 L
.76667 .55125 L
.77619 .55621 L
.78571 .56083 L
.79524 .56511 L
.80476 .56906 L
.81429 .57269 L
.82381 .57599 L
.83333 .57897 L
.84286 .58165 L
.85238 .58402 L
.8619 .5861 L
.87143 .5879 L
.88095 .58944 L
.89048 .59072 L
.9 .59178 L
.90952 .59262 L
.91905 .59326 L
.92857 .59373 L
.9381 .59405 L
.94762 .59425 L
.95714 .59436 L
.96667 .59439 L
.97619 .5944 L
Mistroke
Mfstroke
[(  Position Qm[ 2 ])] .5 .60332 0 0 Mshowa
P
% End of Graphics
MathPictureEnd\
\>"], "Graphics",
  PageWidth->Infinity,
  Evaluatable->False,
  ImageSize->{299, 185},
  ImageMargins->{{80, Inherited}, {Inherited, 0}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0.295003 0.00199408 [
[(1)] .2619 .295 0 2 Msboxa
[(2)] .5 .295 0 2 Msboxa
[(3)] .7381 .295 0 2 Msboxa
[(4)] .97619 .295 0 2 Msboxa
[([s])] 1.025 .295 -1 0 Msboxa
[(-100)] .01131 .0956 1 0 Msboxa
[(-50)] .01131 .1953 1 0 Msboxa
[(50)] .01131 .39471 1 0 Msboxa
[(100)] .01131 .49441 1 0 Msboxa
[(150)] .01131 .59411 1 0 Msboxa
[([Rad])] .02381 .61803 0 -4 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 .61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.2619 .295 m
.2619 .30125 L
s
P
[(1)] .2619 .295 0 2 Mshowa
p
.002 w
.5 .295 m
.5 .30125 L
s
P
[(2)] .5 .295 0 2 Mshowa
p
.002 w
.7381 .295 m
.7381 .30125 L
s
P
[(3)] .7381 .295 0 2 Mshowa
p
.002 w
.97619 .295 m
.97619 .30125 L
s
P
[(4)] .97619 .295 0 2 Mshowa
p
.001 w
.07143 .295 m
.07143 .29875 L
s
P
p
.001 w
.11905 .295 m
.11905 .29875 L
s
P
p
.001 w
.16667 .295 m
.16667 .29875 L
s
P
p
.001 w
.21429 .295 m
.21429 .29875 L
s
P
p
.001 w
.30952 .295 m
.30952 .29875 L
s
P
p
.001 w
.35714 .295 m
.35714 .29875 L
s
P
p
.001 w
.40476 .295 m
.40476 .29875 L
s
P
p
.001 w
.45238 .295 m
.45238 .29875 L
s
P
p
.001 w
.54762 .295 m
.54762 .29875 L
s
P
p
.001 w
.59524 .295 m
.59524 .29875 L
s
P
p
.001 w
.64286 .295 m
.64286 .29875 L
s
P
p
.001 w
.69048 .295 m
.69048 .29875 L
s
P
p
.001 w
.78571 .295 m
.78571 .29875 L
s
P
p
.001 w
.83333 .295 m
.83333 .29875 L
s
P
p
.001 w
.88095 .295 m
.88095 .29875 L
s
P
p
.001 w
.92857 .295 m
.92857 .29875 L
s
P
[([s])] 1.025 .295 -1 0 Mshowa
p
.002 w
0 .295 m
1 .295 L
s
P
p
.002 w
.02381 .0956 m
.03006 .0956 L
s
P
[(-100)] .01131 .0956 1 0 Mshowa
p
.002 w
.02381 .1953 m
.03006 .1953 L
s
P
[(-50)] .01131 .1953 1 0 Mshowa
p
.002 w
.02381 .39471 m
.03006 .39471 L
s
P
[(50)] .01131 .39471 1 0 Mshowa
p
.002 w
.02381 .49441 m
.03006 .49441 L
s
P
[(100)] .01131 .49441 1 0 Mshowa
p
.002 w
.02381 .59411 m
.03006 .59411 L
s
P
[(150)] .01131 .59411 1 0 Mshowa
p
.001 w
.02381 .01583 m
.02756 .01583 L
s
P
p
.001 w
.02381 .03577 m
.02756 .03577 L
s
P
p
.001 w
.02381 .05571 m
.02756 .05571 L
s
P
p
.001 w
.02381 .07565 m
.02756 .07565 L
s
P
p
.001 w
.02381 .11554 m
.02756 .11554 L
s
P
p
.001 w
.02381 .13548 m
.02756 .13548 L
s
P
p
.001 w
.02381 .15542 m
.02756 .15542 L
s
P
p
.001 w
.02381 .17536 m
.02756 .17536 L
s
P
p
.001 w
.02381 .21524 m
.02756 .21524 L
s
P
p
.001 w
.02381 .23518 m
.02756 .23518 L
s
P
p
.001 w
.02381 .25512 m
.02756 .25512 L
s
P
p
.001 w
.02381 .27506 m
.02756 .27506 L
s
P
p
.001 w
.02381 .31494 m
.02756 .31494 L
s
P
p
.001 w
.02381 .33488 m
.02756 .33488 L
s
P
p
.001 w
.02381 .35482 m
.02756 .35482 L
s
P
p
.001 w
.02381 .37477 m
.02756 .37477 L
s
P
p
.001 w
.02381 .41465 m
.02756 .41465 L
s
P
p
.001 w
.02381 .43459 m
.02756 .43459 L
s
P
p
.001 w
.02381 .45453 m
.02756 .45453 L
s
P
p
.001 w
.02381 .47447 m
.02756 .47447 L
s
P
p
.001 w
.02381 .51435 m
.02756 .51435 L
s
P
p
.001 w
.02381 .53429 m
.02756 .53429 L
s
P
p
.001 w
.02381 .55423 m
.02756 .55423 L
s
P
p
.001 w
.02381 .57417 m
.02756 .57417 L
s
P
p
.001 w
.02381 .61405 m
.02756 .61405 L
s
P
[([Rad])] .02381 .61803 0 -4 Mshowa
p
.002 w
.02381 0 m
.02381 .61803 L
s
P
P
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
p
.004 w
.03333 .01472 m
.04286 .01476 L
.05238 .01486 L
.0619 .01505 L
.07143 .01536 L
.08095 .01582 L
.09048 .01644 L
.1 .01725 L
.10952 .01827 L
.11905 .01951 L
.12857 .021 L
.1381 .02274 L
.14762 .02475 L
.15714 .02705 L
.16667 .02963 L
.17619 .03252 L
.18571 .03571 L
.19524 .03922 L
.20476 .04304 L
.21429 .04718 L
.22381 .05165 L
.23333 .05644 L
.24286 .06155 L
.25238 .06699 L
.2619 .07274 L
.27143 .07881 L
.28095 .08519 L
.29048 .09188 L
.3 .09886 L
.30952 .10613 L
.31905 .11369 L
.32857 .12152 L
.3381 .12961 L
.34762 .13796 L
.35714 .14655 L
.36667 .15536 L
.37619 .1644 L
.38571 .17363 L
.39524 .18306 L
.40476 .19266 L
.41429 .20243 L
.42381 .21234 L
.43333 .22238 L
.44286 .23254 L
.45238 .2428 L
.4619 .25314 L
.47143 .26355 L
.48095 .274 L
.49048 .28449 L
.5 .295 L
Mistroke
.50952 .30551 L
.51905 .316 L
.52857 .32646 L
.5381 .33687 L
.54762 .34721 L
.55714 .35746 L
.56667 .36762 L
.57619 .37766 L
.58571 .38758 L
.59524 .39734 L
.60476 .40694 L
.61429 .41637 L
.62381 .42561 L
.63333 .43464 L
.64286 .44346 L
.65238 .45205 L
.6619 .46039 L
.67143 .46849 L
.68095 .47632 L
.69048 .48387 L
.7 .49115 L
.70952 .49813 L
.71905 .50481 L
.72857 .51119 L
.7381 .51726 L
.74762 .52302 L
.75714 .52845 L
.76667 .53356 L
.77619 .53835 L
.78571 .54282 L
.79524 .54697 L
.80476 .55079 L
.81429 .55429 L
.82381 .55749 L
.83333 .56037 L
.84286 .56296 L
.85238 .56525 L
.8619 .56726 L
.87143 .56901 L
.88095 .57049 L
.89048 .57174 L
.9 .57275 L
.90952 .57356 L
.91905 .57419 L
.92857 .57464 L
.9381 .57495 L
.94762 .57515 L
.95714 .57525 L
.96667 .57528 L
.97619 .57529 L
Mistroke
Mfstroke
[(  Position Qm[ 3 ])] .5 .60332 0 0 Mshowa
P
% End of Graphics
MathPictureEnd\
\>"], "Graphics",
  PageWidth->Infinity,
  Evaluatable->False,
  ImageSize->{299, 185},
  ImageMargins->{{80, Inherited}, {Inherited, 0}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0.0147151 0.210984 [
[(1)] .2619 .01472 0 2 Msboxa
[(2)] .5 .01472 0 2 Msboxa
[(3)] .7381 .01472 0 2 Msboxa
[(4)] .97619 .01472 0 2 Msboxa
[([s])] 1.025 .01472 -1 0 Msboxa
[(0.5)] .01131 .12021 1 0 Msboxa
[(1)] .01131 .2257 1 0 Msboxa
[(1.5)] .01131 .33119 1 0 Msboxa
[(2)] .01131 .43668 1 0 Msboxa
[(2.5)] .01131 .54218 1 0 Msboxa
[([Rad/s])] .02381 .61803 0 -4 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 .61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.2619 .01472 m
.2619 .02097 L
s
P
[(1)] .2619 .01472 0 2 Mshowa
p
.002 w
.5 .01472 m
.5 .02097 L
s
P
[(2)] .5 .01472 0 2 Mshowa
p
.002 w
.7381 .01472 m
.7381 .02097 L
s
P
[(3)] .7381 .01472 0 2 Mshowa
p
.002 w
.97619 .01472 m
.97619 .02097 L
s
P
[(4)] .97619 .01472 0 2 Mshowa
p
.001 w
.07143 .01472 m
.07143 .01847 L
s
P
p
.001 w
.11905 .01472 m
.11905 .01847 L
s
P
p
.001 w
.16667 .01472 m
.16667 .01847 L
s
P
p
.001 w
.21429 .01472 m
.21429 .01847 L
s
P
p
.001 w
.30952 .01472 m
.30952 .01847 L
s
P
p
.001 w
.35714 .01472 m
.35714 .01847 L
s
P
p
.001 w
.40476 .01472 m
.40476 .01847 L
s
P
p
.001 w
.45238 .01472 m
.45238 .01847 L
s
P
p
.001 w
.54762 .01472 m
.54762 .01847 L
s
P
p
.001 w
.59524 .01472 m
.59524 .01847 L
s
P
p
.001 w
.64286 .01472 m
.64286 .01847 L
s
P
p
.001 w
.69048 .01472 m
.69048 .01847 L
s
P
p
.001 w
.78571 .01472 m
.78571 .01847 L
s
P
p
.001 w
.83333 .01472 m
.83333 .01847 L
s
P
p
.001 w
.88095 .01472 m
.88095 .01847 L
s
P
p
.001 w
.92857 .01472 m
.92857 .01847 L
s
P
[([s])] 1.025 .01472 -1 0 Mshowa
p
.002 w
0 .01472 m
1 .01472 L
s
P
p
.002 w
.02381 .12021 m
.03006 .12021 L
s
P
[(0.5)] .01131 .12021 1 0 Mshowa
p
.002 w
.02381 .2257 m
.03006 .2257 L
s
P
[(1)] .01131 .2257 1 0 Mshowa
p
.002 w
.02381 .33119 m
.03006 .33119 L
s
P
[(1.5)] .01131 .33119 1 0 Mshowa
p
.002 w
.02381 .43668 m
.03006 .43668 L
s
P
[(2)] .01131 .43668 1 0 Mshowa
p
.002 w
.02381 .54218 m
.03006 .54218 L
s
P
[(2.5)] .01131 .54218 1 0 Mshowa
p
.001 w
.02381 .03581 m
.02756 .03581 L
s
P
p
.001 w
.02381 .05691 m
.02756 .05691 L
s
P
p
.001 w
.02381 .07801 m
.02756 .07801 L
s
P
p
.001 w
.02381 .09911 m
.02756 .09911 L
s
P
p
.001 w
.02381 .14131 m
.02756 .14131 L
s
P
p
.001 w
.02381 .1624 m
.02756 .1624 L
s
P
p
.001 w
.02381 .1835 m
.02756 .1835 L
s
P
p
.001 w
.02381 .2046 m
.02756 .2046 L
s
P
p
.001 w
.02381 .2468 m
.02756 .2468 L
s
P
p
.001 w
.02381 .2679 m
.02756 .2679 L
s
P
p
.001 w
.02381 .28899 m
.02756 .28899 L
s
P
p
.001 w
.02381 .31009 m
.02756 .31009 L
s
P
p
.001 w
.02381 .35229 m
.02756 .35229 L
s
P
p
.001 w
.02381 .37339 m
.02756 .37339 L
s
P
p
.001 w
.02381 .39449 m
.02756 .39449 L
s
P
p
.001 w
.02381 .41559 m
.02756 .41559 L
s
P
p
.001 w
.02381 .45778 m
.02756 .45778 L
s
P
p
.001 w
.02381 .47888 m
.02756 .47888 L
s
P
p
.001 w
.02381 .49998 m
.02756 .49998 L
s
P
p
.001 w
.02381 .52108 m
.02756 .52108 L
s
P
p
.001 w
.02381 .56327 m
.02756 .56327 L
s
P
p
.001 w
.02381 .58437 m
.02756 .58437 L
s
P
p
.001 w
.02381 .60547 m
.02756 .60547 L
s
P
[([Rad/s])] .02381 .61803 0 -4 Mshowa
p
.002 w
.02381 0 m
.02381 .61803 L
s
P
P
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
p
.004 w
.03333 .01472 m
.04286 .018 L
.05238 .02197 L
.0619 .02734 L
.07143 .03403 L
.08095 .04195 L
.09048 .051 L
.1 .06109 L
.10952 .07214 L
.11905 .08406 L
.12857 .09677 L
.1381 .11019 L
.14762 .12423 L
.15714 .13882 L
.16667 .15389 L
.17619 .16936 L
.18571 .18517 L
.19524 .20123 L
.20476 .2175 L
.21429 .23389 L
.22381 .25035 L
.23333 .26682 L
.24286 .28324 L
.25238 .29955 L
.2619 .31571 L
.27143 .33164 L
.28095 .34732 L
.29048 .36268 L
.3 .37768 L
.30952 .39228 L
.31905 .40643 L
.32857 .4201 L
.3381 .43325 L
.34762 .44583 L
.35714 .45783 L
.36667 .4692 L
.37619 .47991 L
.38571 .48994 L
.39524 .49927 L
.40476 .50786 L
.41429 .5157 L
.42381 .52276 L
.43333 .52904 L
.44286 .53451 L
.45238 .53916 L
.4619 .54298 L
.47143 .54596 L
.48095 .5481 L
.49048 .54938 L
.5 .54981 L
Mistroke
.50952 .54938 L
.51905 .5481 L
.52857 .54596 L
.5381 .54298 L
.54762 .53916 L
.55714 .53451 L
.56667 .52904 L
.57619 .52276 L
.58571 .5157 L
.59524 .50786 L
.60476 .49927 L
.61429 .48994 L
.62381 .47991 L
.63333 .4692 L
.64286 .45783 L
.65238 .44583 L
.6619 .43325 L
.67143 .4201 L
.68095 .40643 L
.69048 .39228 L
.7 .37768 L
.70952 .36268 L
.71905 .34732 L
.72857 .33164 L
.7381 .31571 L
.74762 .29955 L
.75714 .28324 L
.76667 .26682 L
.77619 .25035 L
.78571 .23389 L
.79524 .2175 L
.80476 .20123 L
.81429 .18517 L
.82381 .16936 L
.83333 .15389 L
.84286 .13882 L
.85238 .12423 L
.8619 .11019 L
.87143 .09677 L
.88095 .08406 L
.89048 .07214 L
.9 .06109 L
.90952 .051 L
.91905 .04195 L
.92857 .03403 L
.9381 .02734 L
.94762 .02197 L
.95714 .018 L
.96667 .01555 L
.97619 .01472 L
Mistroke
Mfstroke
[(  Velocity Q'l[ 1 ])] .5 .60332 0 0 Mshowa
P
% End of Graphics
MathPictureEnd\
\>"], "Graphics",
  PageWidth->Infinity,
  Evaluatable->False,
  ImageSize->{299, 185},
  ImageMargins->{{80, Inherited}, {Inherited, 0}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0.0147151 0.251558 [
[(1)] .2619 .01472 0 2 Msboxa
[(2)] .5 .01472 0 2 Msboxa
[(3)] .7381 .01472 0 2 Msboxa
[(4)] .97619 .01472 0 2 Msboxa
[([s])] 1.025 .01472 -1 0 Msboxa
[(0.5)] .01131 .14049 1 0 Msboxa
[(1)] .01131 .26627 1 0 Msboxa
[(1.5)] .01131 .39205 1 0 Msboxa
[(2)] .01131 .51783 1 0 Msboxa
[([Rad/s])] .02381 .61803 0 -4 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 .61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.2619 .01472 m
.2619 .02097 L
s
P
[(1)] .2619 .01472 0 2 Mshowa
p
.002 w
.5 .01472 m
.5 .02097 L
s
P
[(2)] .5 .01472 0 2 Mshowa
p
.002 w
.7381 .01472 m
.7381 .02097 L
s
P
[(3)] .7381 .01472 0 2 Mshowa
p
.002 w
.97619 .01472 m
.97619 .02097 L
s
P
[(4)] .97619 .01472 0 2 Mshowa
p
.001 w
.07143 .01472 m
.07143 .01847 L
s
P
p
.001 w
.11905 .01472 m
.11905 .01847 L
s
P
p
.001 w
.16667 .01472 m
.16667 .01847 L
s
P
p
.001 w
.21429 .01472 m
.21429 .01847 L
s
P
p
.001 w
.30952 .01472 m
.30952 .01847 L
s
P
p
.001 w
.35714 .01472 m
.35714 .01847 L
s
P
p
.001 w
.40476 .01472 m
.40476 .01847 L
s
P
p
.001 w
.45238 .01472 m
.45238 .01847 L
s
P
p
.001 w
.54762 .01472 m
.54762 .01847 L
s
P
p
.001 w
.59524 .01472 m
.59524 .01847 L
s
P
p
.001 w
.64286 .01472 m
.64286 .01847 L
s
P
p
.001 w
.69048 .01472 m
.69048 .01847 L
s
P
p
.001 w
.78571 .01472 m
.78571 .01847 L
s
P
p
.001 w
.83333 .01472 m
.83333 .01847 L
s
P
p
.001 w
.88095 .01472 m
.88095 .01847 L
s
P
p
.001 w
.92857 .01472 m
.92857 .01847 L
s
P
[([s])] 1.025 .01472 -1 0 Mshowa
p
.002 w
0 .01472 m
1 .01472 L
s
P
p
.002 w
.02381 .14049 m
.03006 .14049 L
s
P
[(0.5)] .01131 .14049 1 0 Mshowa
p
.002 w
.02381 .26627 m
.03006 .26627 L
s
P
[(1)] .01131 .26627 1 0 Mshowa
p
.002 w
.02381 .39205 m
.03006 .39205 L
s
P
[(1.5)] .01131 .39205 1 0 Mshowa
p
.002 w
.02381 .51783 m
.03006 .51783 L
s
P
[(2)] .01131 .51783 1 0 Mshowa
p
.001 w
.02381 .03987 m
.02756 .03987 L
s
P
p
.001 w
.02381 .06503 m
.02756 .06503 L
s
P
p
.001 w
.02381 .09018 m
.02756 .09018 L
s
P
p
.001 w
.02381 .11534 m
.02756 .11534 L
s
P
p
.001 w
.02381 .16565 m
.02756 .16565 L
s
P
p
.001 w
.02381 .19081 m
.02756 .19081 L
s
P
p
.001 w
.02381 .21596 m
.02756 .21596 L
s
P
p
.001 w
.02381 .24112 m
.02756 .24112 L
s
P
p
.001 w
.02381 .29143 m
.02756 .29143 L
s
P
p
.001 w
.02381 .31658 m
.02756 .31658 L
s
P
p
.001 w
.02381 .34174 m
.02756 .34174 L
s
P
p
.001 w
.02381 .3669 m
.02756 .3669 L
s
P
p
.001 w
.02381 .41721 m
.02756 .41721 L
s
P
p
.001 w
.02381 .44236 m
.02756 .44236 L
s
P
p
.001 w
.02381 .46752 m
.02756 .46752 L
s
P
p
.001 w
.02381 .49268 m
.02756 .49268 L
s
P
p
.001 w
.02381 .54299 m
.02756 .54299 L
s
P
p
.001 w
.02381 .56814 m
.02756 .56814 L
s
P
p
.001 w
.02381 .5933 m
.02756 .5933 L
s
P
[([Rad/s])] .02381 .61803 0 -4 Mshowa
p
.002 w
.02381 0 m
.02381 .61803 L
s
P
P
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
p
.004 w
.03333 .01472 m
.04286 .018 L
.05238 .02197 L
.0619 .02734 L
.07143 .03403 L
.08095 .04195 L
.09048 .051 L
.1 .06109 L
.10952 .07214 L
.11905 .08406 L
.12857 .09677 L
.1381 .11019 L
.14762 .12423 L
.15714 .13882 L
.16667 .15389 L
.17619 .16936 L
.18571 .18517 L
.19524 .20123 L
.20476 .2175 L
.21429 .23389 L
.22381 .25035 L
.23333 .26682 L
.24286 .28324 L
.25238 .29955 L
.2619 .31571 L
.27143 .33164 L
.28095 .34732 L
.29048 .36268 L
.3 .37768 L
.30952 .39228 L
.31905 .40643 L
.32857 .4201 L
.3381 .43325 L
.34762 .44583 L
.35714 .45783 L
.36667 .4692 L
.37619 .47991 L
.38571 .48994 L
.39524 .49927 L
.40476 .50786 L
.41429 .5157 L
.42381 .52276 L
.43333 .52904 L
.44286 .53451 L
.45238 .53916 L
.4619 .54298 L
.47143 .54596 L
.48095 .5481 L
.49048 .54938 L
.5 .54981 L
Mistroke
.50952 .54938 L
.51905 .5481 L
.52857 .54596 L
.5381 .54298 L
.54762 .53916 L
.55714 .53451 L
.56667 .52904 L
.57619 .52276 L
.58571 .5157 L
.59524 .50786 L
.60476 .49927 L
.61429 .48994 L
.62381 .47991 L
.63333 .4692 L
.64286 .45783 L
.65238 .44583 L
.6619 .43325 L
.67143 .4201 L
.68095 .40643 L
.69048 .39228 L
.7 .37768 L
.70952 .36268 L
.71905 .34732 L
.72857 .33164 L
.7381 .31571 L
.74762 .29955 L
.75714 .28324 L
.76667 .26682 L
.77619 .25035 L
.78571 .23389 L
.79524 .2175 L
.80476 .20123 L
.81429 .18517 L
.82381 .16936 L
.83333 .15389 L
.84286 .13882 L
.85238 .12423 L
.8619 .11019 L
.87143 .09677 L
.88095 .08406 L
.89048 .07214 L
.9 .06109 L
.90952 .051 L
.91905 .04195 L
.92857 .03403 L
.9381 .02734 L
.94762 .02197 L
.95714 .018 L
.96667 .01555 L
.97619 .01472 L
Mistroke
Mfstroke
[(  Velocity Q'l[ 2 ])] .5 .60332 0 0 Mshowa
P
% End of Graphics
MathPictureEnd\
\>"], "Graphics",
  PageWidth->Infinity,
  Evaluatable->False,
  ImageSize->{299, 185},
  ImageMargins->{{80, Inherited}, {Inherited, 0}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0.0147151 0.218017 [
[(1)] .2619 .01472 0 2 Msboxa
[(2)] .5 .01472 0 2 Msboxa
[(3)] .7381 .01472 0 2 Msboxa
[(4)] .97619 .01472 0 2 Msboxa
[([s])] 1.025 .01472 -1 0 Msboxa
[(0.5)] .01131 .12372 1 0 Msboxa
[(1)] .01131 .23273 1 0 Msboxa
[(1.5)] .01131 .34174 1 0 Msboxa
[(2)] .01131 .45075 1 0 Msboxa
[(2.5)] .01131 .55976 1 0 Msboxa
[([Rad/s])] .02381 .61803 0 -4 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 .61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.2619 .01472 m
.2619 .02097 L
s
P
[(1)] .2619 .01472 0 2 Mshowa
p
.002 w
.5 .01472 m
.5 .02097 L
s
P
[(2)] .5 .01472 0 2 Mshowa
p
.002 w
.7381 .01472 m
.7381 .02097 L
s
P
[(3)] .7381 .01472 0 2 Mshowa
p
.002 w
.97619 .01472 m
.97619 .02097 L
s
P
[(4)] .97619 .01472 0 2 Mshowa
p
.001 w
.07143 .01472 m
.07143 .01847 L
s
P
p
.001 w
.11905 .01472 m
.11905 .01847 L
s
P
p
.001 w
.16667 .01472 m
.16667 .01847 L
s
P
p
.001 w
.21429 .01472 m
.21429 .01847 L
s
P
p
.001 w
.30952 .01472 m
.30952 .01847 L
s
P
p
.001 w
.35714 .01472 m
.35714 .01847 L
s
P
p
.001 w
.40476 .01472 m
.40476 .01847 L
s
P
p
.001 w
.45238 .01472 m
.45238 .01847 L
s
P
p
.001 w
.54762 .01472 m
.54762 .01847 L
s
P
p
.001 w
.59524 .01472 m
.59524 .01847 L
s
P
p
.001 w
.64286 .01472 m
.64286 .01847 L
s
P
p
.001 w
.69048 .01472 m
.69048 .01847 L
s
P
p
.001 w
.78571 .01472 m
.78571 .01847 L
s
P
p
.001 w
.83333 .01472 m
.83333 .01847 L
s
P
p
.001 w
.88095 .01472 m
.88095 .01847 L
s
P
p
.001 w
.92857 .01472 m
.92857 .01847 L
s
P
[([s])] 1.025 .01472 -1 0 Mshowa
p
.002 w
0 .01472 m
1 .01472 L
s
P
p
.002 w
.02381 .12372 m
.03006 .12372 L
s
P
[(0.5)] .01131 .12372 1 0 Mshowa
p
.002 w
.02381 .23273 m
.03006 .23273 L
s
P
[(1)] .01131 .23273 1 0 Mshowa
p
.002 w
.02381 .34174 m
.03006 .34174 L
s
P
[(1.5)] .01131 .34174 1 0 Mshowa
p
.002 w
.02381 .45075 m
.03006 .45075 L
s
P
[(2)] .01131 .45075 1 0 Mshowa
p
.002 w
.02381 .55976 m
.03006 .55976 L
s
P
[(2.5)] .01131 .55976 1 0 Mshowa
p
.001 w
.02381 .03652 m
.02756 .03652 L
s
P
p
.001 w
.02381 .05832 m
.02756 .05832 L
s
P
p
.001 w
.02381 .08012 m
.02756 .08012 L
s
P
p
.001 w
.02381 .10192 m
.02756 .10192 L
s
P
p
.001 w
.02381 .14553 m
.02756 .14553 L
s
P
p
.001 w
.02381 .16733 m
.02756 .16733 L
s
P
p
.001 w
.02381 .18913 m
.02756 .18913 L
s
P
p
.001 w
.02381 .21093 m
.02756 .21093 L
s
P
p
.001 w
.02381 .25453 m
.02756 .25453 L
s
P
p
.001 w
.02381 .27634 m
.02756 .27634 L
s
P
p
.001 w
.02381 .29814 m
.02756 .29814 L
s
P
p
.001 w
.02381 .31994 m
.02756 .31994 L
s
P
p
.001 w
.02381 .36354 m
.02756 .36354 L
s
P
p
.001 w
.02381 .38534 m
.02756 .38534 L
s
P
p
.001 w
.02381 .40715 m
.02756 .40715 L
s
P
p
.001 w
.02381 .42895 m
.02756 .42895 L
s
P
p
.001 w
.02381 .47255 m
.02756 .47255 L
s
P
p
.001 w
.02381 .49435 m
.02756 .49435 L
s
P
p
.001 w
.02381 .51615 m
.02756 .51615 L
s
P
p
.001 w
.02381 .53796 m
.02756 .53796 L
s
P
p
.001 w
.02381 .58156 m
.02756 .58156 L
s
P
p
.001 w
.02381 .60336 m
.02756 .60336 L
s
P
[([Rad/s])] .02381 .61803 0 -4 Mshowa
p
.002 w
.02381 0 m
.02381 .61803 L
s
P
P
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
p
.004 w
.03333 .01472 m
.04286 .018 L
.05238 .02197 L
.0619 .02734 L
.07143 .03403 L
.08095 .04195 L
.09048 .051 L
.1 .06109 L
.10952 .07214 L
.11905 .08406 L
.12857 .09677 L
.1381 .11019 L
.14762 .12423 L
.15714 .13882 L
.16667 .15389 L
.17619 .16936 L
.18571 .18517 L
.19524 .20123 L
.20476 .2175 L
.21429 .23389 L
.22381 .25035 L
.23333 .26682 L
.24286 .28324 L
.25238 .29955 L
.2619 .31571 L
.27143 .33164 L
.28095 .34732 L
.29048 .36268 L
.3 .37768 L
.30952 .39228 L
.31905 .40643 L
.32857 .4201 L
.3381 .43325 L
.34762 .44583 L
.35714 .45783 L
.36667 .4692 L
.37619 .47991 L
.38571 .48994 L
.39524 .49927 L
.40476 .50786 L
.41429 .5157 L
.42381 .52276 L
.43333 .52904 L
.44286 .53451 L
.45238 .53916 L
.4619 .54298 L
.47143 .54596 L
.48095 .5481 L
.49048 .54938 L
.5 .54981 L
Mistroke
.50952 .54938 L
.51905 .5481 L
.52857 .54596 L
.5381 .54298 L
.54762 .53916 L
.55714 .53451 L
.56667 .52904 L
.57619 .52276 L
.58571 .5157 L
.59524 .50786 L
.60476 .49927 L
.61429 .48994 L
.62381 .47991 L
.63333 .4692 L
.64286 .45783 L
.65238 .44583 L
.6619 .43325 L
.67143 .4201 L
.68095 .40643 L
.69048 .39228 L
.7 .37768 L
.70952 .36268 L
.71905 .34732 L
.72857 .33164 L
.7381 .31571 L
.74762 .29955 L
.75714 .28324 L
.76667 .26682 L
.77619 .25035 L
.78571 .23389 L
.79524 .2175 L
.80476 .20123 L
.81429 .18517 L
.82381 .16936 L
.83333 .15389 L
.84286 .13882 L
.85238 .12423 L
.8619 .11019 L
.87143 .09677 L
.88095 .08406 L
.89048 .07214 L
.9 .06109 L
.90952 .051 L
.91905 .04195 L
.92857 .03403 L
.9381 .02734 L
.94762 .02197 L
.95714 .018 L
.96667 .01555 L
.97619 .01472 L
Mistroke
Mfstroke
[(  Velocity Q'l[ 3 ])] .5 .60332 0 0 Mshowa
P
% End of Graphics
MathPictureEnd\
\>"], "Graphics",
  PageWidth->Infinity,
  Evaluatable->False,
  ImageSize->{299, 185},
  ImageMargins->{{80, Inherited}, {Inherited, 0}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0.0147151 0.00336982 [
[(1)] .2619 .01472 0 2 Msboxa
[(2)] .5 .01472 0 2 Msboxa
[(3)] .7381 .01472 0 2 Msboxa
[(4)] .97619 .01472 0 2 Msboxa
[([s])] 1.025 .01472 -1 0 Msboxa
[(25)] .01131 .09896 1 0 Msboxa
[(50)] .01131 .18321 1 0 Msboxa
[(75)] .01131 .26745 1 0 Msboxa
[(100)] .01131 .3517 1 0 Msboxa
[(125)] .01131 .43594 1 0 Msboxa
[(150)] .01131 .52019 1 0 Msboxa
[(175)] .01131 .60443 1 0 Msboxa
[([Rad/s])] .02381 .61803 0 -4 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 .61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.2619 .01472 m
.2619 .02097 L
s
P
[(1)] .2619 .01472 0 2 Mshowa
p
.002 w
.5 .01472 m
.5 .02097 L
s
P
[(2)] .5 .01472 0 2 Mshowa
p
.002 w
.7381 .01472 m
.7381 .02097 L
s
P
[(3)] .7381 .01472 0 2 Mshowa
p
.002 w
.97619 .01472 m
.97619 .02097 L
s
P
[(4)] .97619 .01472 0 2 Mshowa
p
.001 w
.07143 .01472 m
.07143 .01847 L
s
P
p
.001 w
.11905 .01472 m
.11905 .01847 L
s
P
p
.001 w
.16667 .01472 m
.16667 .01847 L
s
P
p
.001 w
.21429 .01472 m
.21429 .01847 L
s
P
p
.001 w
.30952 .01472 m
.30952 .01847 L
s
P
p
.001 w
.35714 .01472 m
.35714 .01847 L
s
P
p
.001 w
.40476 .01472 m
.40476 .01847 L
s
P
p
.001 w
.45238 .01472 m
.45238 .01847 L
s
P
p
.001 w
.54762 .01472 m
.54762 .01847 L
s
P
p
.001 w
.59524 .01472 m
.59524 .01847 L
s
P
p
.001 w
.64286 .01472 m
.64286 .01847 L
s
P
p
.001 w
.69048 .01472 m
.69048 .01847 L
s
P
p
.001 w
.78571 .01472 m
.78571 .01847 L
s
P
p
.001 w
.83333 .01472 m
.83333 .01847 L
s
P
p
.001 w
.88095 .01472 m
.88095 .01847 L
s
P
p
.001 w
.92857 .01472 m
.92857 .01847 L
s
P
[([s])] 1.025 .01472 -1 0 Mshowa
p
.002 w
0 .01472 m
1 .01472 L
s
P
p
.002 w
.02381 .09896 m
.03006 .09896 L
s
P
[(25)] .01131 .09896 1 0 Mshowa
p
.002 w
.02381 .18321 m
.03006 .18321 L
s
P
[(50)] .01131 .18321 1 0 Mshowa
p
.002 w
.02381 .26745 m
.03006 .26745 L
s
P
[(75)] .01131 .26745 1 0 Mshowa
p
.002 w
.02381 .3517 m
.03006 .3517 L
s
P
[(100)] .01131 .3517 1 0 Mshowa
p
.002 w
.02381 .43594 m
.03006 .43594 L
s
P
[(125)] .01131 .43594 1 0 Mshowa
p
.002 w
.02381 .52019 m
.03006 .52019 L
s
P
[(150)] .01131 .52019 1 0 Mshowa
p
.002 w
.02381 .60443 m
.03006 .60443 L
s
P
[(175)] .01131 .60443 1 0 Mshowa
p
.001 w
.02381 .03156 m
.02756 .03156 L
s
P
p
.001 w
.02381 .04841 m
.02756 .04841 L
s
P
p
.001 w
.02381 .06526 m
.02756 .06526 L
s
P
p
.001 w
.02381 .08211 m
.02756 .08211 L
s
P
p
.001 w
.02381 .11581 m
.02756 .11581 L
s
P
p
.001 w
.02381 .13266 m
.02756 .13266 L
s
P
p
.001 w
.02381 .14951 m
.02756 .14951 L
s
P
p
.001 w
.02381 .16636 m
.02756 .16636 L
s
P
p
.001 w
.02381 .20006 m
.02756 .20006 L
s
P
p
.001 w
.02381 .2169 m
.02756 .2169 L
s
P
p
.001 w
.02381 .23375 m
.02756 .23375 L
s
P
p
.001 w
.02381 .2506 m
.02756 .2506 L
s
P
p
.001 w
.02381 .2843 m
.02756 .2843 L
s
P
p
.001 w
.02381 .30115 m
.02756 .30115 L
s
P
p
.001 w
.02381 .318 m
.02756 .318 L
s
P
p
.001 w
.02381 .33485 m
.02756 .33485 L
s
P
p
.001 w
.02381 .36855 m
.02756 .36855 L
s
P
p
.001 w
.02381 .38539 m
.02756 .38539 L
s
P
p
.001 w
.02381 .40224 m
.02756 .40224 L
s
P
p
.001 w
.02381 .41909 m
.02756 .41909 L
s
P
p
.001 w
.02381 .45279 m
.02756 .45279 L
s
P
p
.001 w
.02381 .46964 m
.02756 .46964 L
s
P
p
.001 w
.02381 .48649 m
.02756 .48649 L
s
P
p
.001 w
.02381 .50334 m
.02756 .50334 L
s
P
p
.001 w
.02381 .53704 m
.02756 .53704 L
s
P
p
.001 w
.02381 .55389 m
.02756 .55389 L
s
P
p
.001 w
.02381 .57073 m
.02756 .57073 L
s
P
p
.001 w
.02381 .58758 m
.02756 .58758 L
s
P
[([Rad/s])] .02381 .61803 0 -4 Mshowa
p
.002 w
.02381 0 m
.02381 .61803 L
s
P
P
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
p
.004 w
.03333 .01472 m
.04286 .018 L
.05238 .02197 L
.0619 .02734 L
.07143 .03403 L
.08095 .04195 L
.09048 .051 L
.1 .06109 L
.10952 .07214 L
.11905 .08406 L
.12857 .09677 L
.1381 .11019 L
.14762 .12423 L
.15714 .13882 L
.16667 .15389 L
.17619 .16936 L
.18571 .18517 L
.19524 .20123 L
.20476 .2175 L
.21429 .23389 L
.22381 .25035 L
.23333 .26682 L
.24286 .28324 L
.25238 .29955 L
.2619 .31571 L
.27143 .33164 L
.28095 .34732 L
.29048 .36268 L
.3 .37768 L
.30952 .39228 L
.31905 .40643 L
.32857 .4201 L
.3381 .43325 L
.34762 .44583 L
.35714 .45783 L
.36667 .4692 L
.37619 .47991 L
.38571 .48994 L
.39524 .49927 L
.40476 .50786 L
.41429 .5157 L
.42381 .52276 L
.43333 .52904 L
.44286 .53451 L
.45238 .53916 L
.4619 .54298 L
.47143 .54596 L
.48095 .5481 L
.49048 .54938 L
.5 .54981 L
Mistroke
.50952 .54938 L
.51905 .5481 L
.52857 .54596 L
.5381 .54298 L
.54762 .53916 L
.55714 .53451 L
.56667 .52904 L
.57619 .52276 L
.58571 .5157 L
.59524 .50786 L
.60476 .49927 L
.61429 .48994 L
.62381 .47991 L
.63333 .4692 L
.64286 .45783 L
.65238 .44583 L
.6619 .43325 L
.67143 .4201 L
.68095 .40643 L
.69048 .39228 L
.7 .37768 L
.70952 .36268 L
.71905 .34732 L
.72857 .33164 L
.7381 .31571 L
.74762 .29955 L
.75714 .28324 L
.76667 .26682 L
.77619 .25035 L
.78571 .23389 L
.79524 .2175 L
.80476 .20123 L
.81429 .18517 L
.82381 .16936 L
.83333 .15389 L
.84286 .13882 L
.85238 .12423 L
.8619 .11019 L
.87143 .09677 L
.88095 .08406 L
.89048 .07214 L
.9 .06109 L
.90952 .051 L
.91905 .04195 L
.92857 .03403 L
.9381 .02734 L
.94762 .02197 L
.95714 .018 L
.96667 .01555 L
.97619 .01472 L
Mistroke
Mfstroke
[(  Velocity Q'm[ 1 ])] .5 .60332 0 0 Mshowa
P
% End of Graphics
MathPictureEnd\
\>"], "Graphics",
  PageWidth->Infinity,
  Evaluatable->False,
  ImageSize->{299, 185},
  ImageMargins->{{80, Inherited}, {Inherited, 0}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0.0147151 0.00234313 [
[(1)] .2619 .01472 0 2 Msboxa
[(2)] .5 .01472 0 2 Msboxa
[(3)] .7381 .01472 0 2 Msboxa
[(4)] .97619 .01472 0 2 Msboxa
[([s])] 1.025 .01472 -1 0 Msboxa
[(50)] .01131 .13187 1 0 Msboxa
[(100)] .01131 .24903 1 0 Msboxa
[(150)] .01131 .36618 1 0 Msboxa
[(200)] .01131 .48334 1 0 Msboxa
[(250)] .01131 .6005 1 0 Msboxa
[([Rad/s])] .02381 .61803 0 -4 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 .61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.2619 .01472 m
.2619 .02097 L
s
P
[(1)] .2619 .01472 0 2 Mshowa
p
.002 w
.5 .01472 m
.5 .02097 L
s
P
[(2)] .5 .01472 0 2 Mshowa
p
.002 w
.7381 .01472 m
.7381 .02097 L
s
P
[(3)] .7381 .01472 0 2 Mshowa
p
.002 w
.97619 .01472 m
.97619 .02097 L
s
P
[(4)] .97619 .01472 0 2 Mshowa
p
.001 w
.07143 .01472 m
.07143 .01847 L
s
P
p
.001 w
.11905 .01472 m
.11905 .01847 L
s
P
p
.001 w
.16667 .01472 m
.16667 .01847 L
s
P
p
.001 w
.21429 .01472 m
.21429 .01847 L
s
P
p
.001 w
.30952 .01472 m
.30952 .01847 L
s
P
p
.001 w
.35714 .01472 m
.35714 .01847 L
s
P
p
.001 w
.40476 .01472 m
.40476 .01847 L
s
P
p
.001 w
.45238 .01472 m
.45238 .01847 L
s
P
p
.001 w
.54762 .01472 m
.54762 .01847 L
s
P
p
.001 w
.59524 .01472 m
.59524 .01847 L
s
P
p
.001 w
.64286 .01472 m
.64286 .01847 L
s
P
p
.001 w
.69048 .01472 m
.69048 .01847 L
s
P
p
.001 w
.78571 .01472 m
.78571 .01847 L
s
P
p
.001 w
.83333 .01472 m
.83333 .01847 L
s
P
p
.001 w
.88095 .01472 m
.88095 .01847 L
s
P
p
.001 w
.92857 .01472 m
.92857 .01847 L
s
P
[([s])] 1.025 .01472 -1 0 Mshowa
p
.002 w
0 .01472 m
1 .01472 L
s
P
p
.002 w
.02381 .13187 m
.03006 .13187 L
s
P
[(50)] .01131 .13187 1 0 Mshowa
p
.002 w
.02381 .24903 m
.03006 .24903 L
s
P
[(100)] .01131 .24903 1 0 Mshowa
p
.002 w
.02381 .36618 m
.03006 .36618 L
s
P
[(150)] .01131 .36618 1 0 Mshowa
p
.002 w
.02381 .48334 m
.03006 .48334 L
s
P
[(200)] .01131 .48334 1 0 Mshowa
p
.002 w
.02381 .6005 m
.03006 .6005 L
s
P
[(250)] .01131 .6005 1 0 Mshowa
p
.001 w
.02381 .03815 m
.02756 .03815 L
s
P
p
.001 w
.02381 .06158 m
.02756 .06158 L
s
P
p
.001 w
.02381 .08501 m
.02756 .08501 L
s
P
p
.001 w
.02381 .10844 m
.02756 .10844 L
s
P
p
.001 w
.02381 .1553 m
.02756 .1553 L
s
P
p
.001 w
.02381 .17873 m
.02756 .17873 L
s
P
p
.001 w
.02381 .20217 m
.02756 .20217 L
s
P
p
.001 w
.02381 .2256 m
.02756 .2256 L
s
P
p
.001 w
.02381 .27246 m
.02756 .27246 L
s
P
p
.001 w
.02381 .29589 m
.02756 .29589 L
s
P
p
.001 w
.02381 .31932 m
.02756 .31932 L
s
P
p
.001 w
.02381 .34275 m
.02756 .34275 L
s
P
p
.001 w
.02381 .38962 m
.02756 .38962 L
s
P
p
.001 w
.02381 .41305 m
.02756 .41305 L
s
P
p
.001 w
.02381 .43648 m
.02756 .43648 L
s
P
p
.001 w
.02381 .45991 m
.02756 .45991 L
s
P
p
.001 w
.02381 .50677 m
.02756 .50677 L
s
P
p
.001 w
.02381 .5302 m
.02756 .5302 L
s
P
p
.001 w
.02381 .55363 m
.02756 .55363 L
s
P
p
.001 w
.02381 .57707 m
.02756 .57707 L
s
P
[([Rad/s])] .02381 .61803 0 -4 Mshowa
p
.002 w
.02381 0 m
.02381 .61803 L
s
P
P
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
p
.004 w
.03333 .01472 m
.04286 .018 L
.05238 .02197 L
.0619 .02734 L
.07143 .03403 L
.08095 .04195 L
.09048 .051 L
.1 .06109 L
.10952 .07214 L
.11905 .08406 L
.12857 .09677 L
.1381 .11019 L
.14762 .12423 L
.15714 .13882 L
.16667 .15389 L
.17619 .16936 L
.18571 .18517 L
.19524 .20123 L
.20476 .2175 L
.21429 .23389 L
.22381 .25035 L
.23333 .26682 L
.24286 .28324 L
.25238 .29955 L
.2619 .31571 L
.27143 .33164 L
.28095 .34732 L
.29048 .36268 L
.3 .37768 L
.30952 .39228 L
.31905 .40643 L
.32857 .4201 L
.3381 .43325 L
.34762 .44583 L
.35714 .45783 L
.36667 .4692 L
.37619 .47991 L
.38571 .48994 L
.39524 .49927 L
.40476 .50786 L
.41429 .5157 L
.42381 .52276 L
.43333 .52904 L
.44286 .53451 L
.45238 .53916 L
.4619 .54298 L
.47143 .54596 L
.48095 .5481 L
.49048 .54938 L
.5 .54981 L
Mistroke
.50952 .54938 L
.51905 .5481 L
.52857 .54596 L
.5381 .54298 L
.54762 .53916 L
.55714 .53451 L
.56667 .52904 L
.57619 .52276 L
.58571 .5157 L
.59524 .50786 L
.60476 .49927 L
.61429 .48994 L
.62381 .47991 L
.63333 .4692 L
.64286 .45783 L
.65238 .44583 L
.6619 .43325 L
.67143 .4201 L
.68095 .40643 L
.69048 .39228 L
.7 .37768 L
.70952 .36268 L
.71905 .34732 L
.72857 .33164 L
.7381 .31571 L
.74762 .29955 L
.75714 .28324 L
.76667 .26682 L
.77619 .25035 L
.78571 .23389 L
.79524 .2175 L
.80476 .20123 L
.81429 .18517 L
.82381 .16936 L
.83333 .15389 L
.84286 .13882 L
.85238 .12423 L
.8619 .11019 L
.87143 .09677 L
.88095 .08406 L
.89048 .07214 L
.9 .06109 L
.90952 .051 L
.91905 .04195 L
.92857 .03403 L
.9381 .02734 L
.94762 .02197 L
.95714 .018 L
.96667 .01555 L
.97619 .01472 L
Mistroke
Mfstroke
[(  Velocity Q'm[ 2 ])] .5 .60332 0 0 Mshowa
P
% End of Graphics
MathPictureEnd\
\>"], "Graphics",
  PageWidth->Infinity,
  Evaluatable->False,
  ImageSize->{299, 185},
  ImageMargins->{{80, Inherited}, {Inherited, 0}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0.0147151 0.00406066 [
[(1)] .2619 .01472 0 2 Msboxa
[(2)] .5 .01472 0 2 Msboxa
[(3)] .7381 .01472 0 2 Msboxa
[(4)] .97619 .01472 0 2 Msboxa
[([s])] 1.025 .01472 -1 0 Msboxa
[(20)] .01131 .09593 1 0 Msboxa
[(40)] .01131 .17714 1 0 Msboxa
[(60)] .01131 .25835 1 0 Msboxa
[(80)] .01131 .33957 1 0 Msboxa
[(100)] .01131 .42078 1 0 Msboxa
[(120)] .01131 .50199 1 0 Msboxa
[(140)] .01131 .58321 1 0 Msboxa
[([Rad/s])] .02381 .61803 0 -4 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 .61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.2619 .01472 m
.2619 .02097 L
s
P
[(1)] .2619 .01472 0 2 Mshowa
p
.002 w
.5 .01472 m
.5 .02097 L
s
P
[(2)] .5 .01472 0 2 Mshowa
p
.002 w
.7381 .01472 m
.7381 .02097 L
s
P
[(3)] .7381 .01472 0 2 Mshowa
p
.002 w
.97619 .01472 m
.97619 .02097 L
s
P
[(4)] .97619 .01472 0 2 Mshowa
p
.001 w
.07143 .01472 m
.07143 .01847 L
s
P
p
.001 w
.11905 .01472 m
.11905 .01847 L
s
P
p
.001 w
.16667 .01472 m
.16667 .01847 L
s
P
p
.001 w
.21429 .01472 m
.21429 .01847 L
s
P
p
.001 w
.30952 .01472 m
.30952 .01847 L
s
P
p
.001 w
.35714 .01472 m
.35714 .01847 L
s
P
p
.001 w
.40476 .01472 m
.40476 .01847 L
s
P
p
.001 w
.45238 .01472 m
.45238 .01847 L
s
P
p
.001 w
.54762 .01472 m
.54762 .01847 L
s
P
p
.001 w
.59524 .01472 m
.59524 .01847 L
s
P
p
.001 w
.64286 .01472 m
.64286 .01847 L
s
P
p
.001 w
.69048 .01472 m
.69048 .01847 L
s
P
p
.001 w
.78571 .01472 m
.78571 .01847 L
s
P
p
.001 w
.83333 .01472 m
.83333 .01847 L
s
P
p
.001 w
.88095 .01472 m
.88095 .01847 L
s
P
p
.001 w
.92857 .01472 m
.92857 .01847 L
s
P
[([s])] 1.025 .01472 -1 0 Mshowa
p
.002 w
0 .01472 m
1 .01472 L
s
P
p
.002 w
.02381 .09593 m
.03006 .09593 L
s
P
[(20)] .01131 .09593 1 0 Mshowa
p
.002 w
.02381 .17714 m
.03006 .17714 L
s
P
[(40)] .01131 .17714 1 0 Mshowa
p
.002 w
.02381 .25835 m
.03006 .25835 L
s
P
[(60)] .01131 .25835 1 0 Mshowa
p
.002 w
.02381 .33957 m
.03006 .33957 L
s
P
[(80)] .01131 .33957 1 0 Mshowa
p
.002 w
.02381 .42078 m
.03006 .42078 L
s
P
[(100)] .01131 .42078 1 0 Mshowa
p
.002 w
.02381 .50199 m
.03006 .50199 L
s
P
[(120)] .01131 .50199 1 0 Mshowa
p
.002 w
.02381 .58321 m
.03006 .58321 L
s
P
[(140)] .01131 .58321 1 0 Mshowa
p
.001 w
.02381 .03096 m
.02756 .03096 L
s
P
p
.001 w
.02381 .0472 m
.02756 .0472 L
s
P
p
.001 w
.02381 .06344 m
.02756 .06344 L
s
P
p
.001 w
.02381 .07969 m
.02756 .07969 L
s
P
p
.001 w
.02381 .11217 m
.02756 .11217 L
s
P
p
.001 w
.02381 .12841 m
.02756 .12841 L
s
P
p
.001 w
.02381 .14466 m
.02756 .14466 L
s
P
p
.001 w
.02381 .1609 m
.02756 .1609 L
s
P
p
.001 w
.02381 .19338 m
.02756 .19338 L
s
P
p
.001 w
.02381 .20963 m
.02756 .20963 L
s
P
p
.001 w
.02381 .22587 m
.02756 .22587 L
s
P
p
.001 w
.02381 .24211 m
.02756 .24211 L
s
P
p
.001 w
.02381 .2746 m
.02756 .2746 L
s
P
p
.001 w
.02381 .29084 m
.02756 .29084 L
s
P
p
.001 w
.02381 .30708 m
.02756 .30708 L
s
P
p
.001 w
.02381 .32333 m
.02756 .32333 L
s
P
p
.001 w
.02381 .35581 m
.02756 .35581 L
s
P
p
.001 w
.02381 .37205 m
.02756 .37205 L
s
P
p
.001 w
.02381 .3883 m
.02756 .3883 L
s
P
p
.001 w
.02381 .40454 m
.02756 .40454 L
s
P
p
.001 w
.02381 .43702 m
.02756 .43702 L
s
P
p
.001 w
.02381 .45327 m
.02756 .45327 L
s
P
p
.001 w
.02381 .46951 m
.02756 .46951 L
s
P
p
.001 w
.02381 .48575 m
.02756 .48575 L
s
P
p
.001 w
.02381 .51824 m
.02756 .51824 L
s
P
p
.001 w
.02381 .53448 m
.02756 .53448 L
s
P
p
.001 w
.02381 .55072 m
.02756 .55072 L
s
P
p
.001 w
.02381 .56697 m
.02756 .56697 L
s
P
p
.001 w
.02381 .59945 m
.02756 .59945 L
s
P
p
.001 w
.02381 .61569 m
.02756 .61569 L
s
P
[([Rad/s])] .02381 .61803 0 -4 Mshowa
p
.002 w
.02381 0 m
.02381 .61803 L
s
P
P
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
p
.004 w
.03333 .01472 m
.04286 .018 L
.05238 .02197 L
.0619 .02734 L
.07143 .03403 L
.08095 .04195 L
.09048 .051 L
.1 .06109 L
.10952 .07214 L
.11905 .08406 L
.12857 .09677 L
.1381 .11019 L
.14762 .12423 L
.15714 .13882 L
.16667 .15389 L
.17619 .16936 L
.18571 .18517 L
.19524 .20123 L
.20476 .2175 L
.21429 .23389 L
.22381 .25035 L
.23333 .26682 L
.24286 .28324 L
.25238 .29955 L
.2619 .31571 L
.27143 .33164 L
.28095 .34732 L
.29048 .36268 L
.3 .37768 L
.30952 .39228 L
.31905 .40643 L
.32857 .4201 L
.3381 .43325 L
.34762 .44583 L
.35714 .45783 L
.36667 .4692 L
.37619 .47991 L
.38571 .48994 L
.39524 .49927 L
.40476 .50786 L
.41429 .5157 L
.42381 .52276 L
.43333 .52904 L
.44286 .53451 L
.45238 .53916 L
.4619 .54298 L
.47143 .54596 L
.48095 .5481 L
.49048 .54938 L
.5 .54981 L
Mistroke
.50952 .54938 L
.51905 .5481 L
.52857 .54596 L
.5381 .54298 L
.54762 .53916 L
.55714 .53451 L
.56667 .52904 L
.57619 .52276 L
.58571 .5157 L
.59524 .50786 L
.60476 .49927 L
.61429 .48994 L
.62381 .47991 L
.63333 .4692 L
.64286 .45783 L
.65238 .44583 L
.6619 .43325 L
.67143 .4201 L
.68095 .40643 L
.69048 .39228 L
.7 .37768 L
.70952 .36268 L
.71905 .34732 L
.72857 .33164 L
.7381 .31571 L
.74762 .29955 L
.75714 .28324 L
.76667 .26682 L
.77619 .25035 L
.78571 .23389 L
.79524 .2175 L
.80476 .20123 L
.81429 .18517 L
.82381 .16936 L
.83333 .15389 L
.84286 .13882 L
.85238 .12423 L
.8619 .11019 L
.87143 .09677 L
.88095 .08406 L
.89048 .07214 L
.9 .06109 L
.90952 .051 L
.91905 .04195 L
.92857 .03403 L
.9381 .02734 L
.94762 .02197 L
.95714 .018 L
.96667 .01555 L
.97619 .01472 L
Mistroke
Mfstroke
[(  Velocity Q'm[ 3 ])] .5 .60332 0 0 Mshowa
P
% End of Graphics
MathPictureEnd\
\>"], "Graphics",
  PageWidth->Infinity,
  Evaluatable->False,
  ImageSize->{299, 185},
  ImageMargins->{{80, Inherited}, {Inherited, 0}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0.295003 0.143568 [
[(1)] .2619 .295 0 2 Msboxa
[(2)] .5 .295 0 2 Msboxa
[(3)] .7381 .295 0 2 Msboxa
[(4)] .97619 .295 0 2 Msboxa
[([s])] 1.025 .295 -1 0 Msboxa
[(-2)] .01131 .00787 1 0 Msboxa
[(-1)] .01131 .15143 1 0 Msboxa
[(1)] .01131 .43857 1 0 Msboxa
[(2)] .01131 .58214 1 0 Msboxa
[([Rad/s2])] .02381 .61803 0 -4 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 .61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.2619 .295 m
.2619 .30125 L
s
P
[(1)] .2619 .295 0 2 Mshowa
p
.002 w
.5 .295 m
.5 .30125 L
s
P
[(2)] .5 .295 0 2 Mshowa
p
.002 w
.7381 .295 m
.7381 .30125 L
s
P
[(3)] .7381 .295 0 2 Mshowa
p
.002 w
.97619 .295 m
.97619 .30125 L
s
P
[(4)] .97619 .295 0 2 Mshowa
p
.001 w
.07143 .295 m
.07143 .29875 L
s
P
p
.001 w
.11905 .295 m
.11905 .29875 L
s
P
p
.001 w
.16667 .295 m
.16667 .29875 L
s
P
p
.001 w
.21429 .295 m
.21429 .29875 L
s
P
p
.001 w
.30952 .295 m
.30952 .29875 L
s
P
p
.001 w
.35714 .295 m
.35714 .29875 L
s
P
p
.001 w
.40476 .295 m
.40476 .29875 L
s
P
p
.001 w
.45238 .295 m
.45238 .29875 L
s
P
p
.001 w
.54762 .295 m
.54762 .29875 L
s
P
p
.001 w
.59524 .295 m
.59524 .29875 L
s
P
p
.001 w
.64286 .295 m
.64286 .29875 L
s
P
p
.001 w
.69048 .295 m
.69048 .29875 L
s
P
p
.001 w
.78571 .295 m
.78571 .29875 L
s
P
p
.001 w
.83333 .295 m
.83333 .29875 L
s
P
p
.001 w
.88095 .295 m
.88095 .29875 L
s
P
p
.001 w
.92857 .295 m
.92857 .29875 L
s
P
[([s])] 1.025 .295 -1 0 Mshowa
p
.002 w
0 .295 m
1 .295 L
s
P
p
.002 w
.02381 .00787 m
.03006 .00787 L
s
P
[(-2)] .01131 .00787 1 0 Mshowa
p
.002 w
.02381 .15143 m
.03006 .15143 L
s
P
[(-1)] .01131 .15143 1 0 Mshowa
p
.002 w
.02381 .43857 m
.03006 .43857 L
s
P
[(1)] .01131 .43857 1 0 Mshowa
p
.002 w
.02381 .58214 m
.03006 .58214 L
s
P
[(2)] .01131 .58214 1 0 Mshowa
p
.001 w
.02381 .03658 m
.02756 .03658 L
s
P
p
.001 w
.02381 .06529 m
.02756 .06529 L
s
P
p
.001 w
.02381 .09401 m
.02756 .09401 L
s
P
p
.001 w
.02381 .12272 m
.02756 .12272 L
s
P
p
.001 w
.02381 .18015 m
.02756 .18015 L
s
P
p
.001 w
.02381 .20886 m
.02756 .20886 L
s
P
p
.001 w
.02381 .23758 m
.02756 .23758 L
s
P
p
.001 w
.02381 .26629 m
.02756 .26629 L
s
P
p
.001 w
.02381 .32372 m
.02756 .32372 L
s
P
p
.001 w
.02381 .35243 m
.02756 .35243 L
s
P
p
.001 w
.02381 .38114 m
.02756 .38114 L
s
P
p
.001 w
.02381 .40986 m
.02756 .40986 L
s
P
p
.001 w
.02381 .46728 m
.02756 .46728 L
s
P
p
.001 w
.02381 .496 m
.02756 .496 L
s
P
p
.001 w
.02381 .52471 m
.02756 .52471 L
s
P
p
.001 w
.02381 .55343 m
.02756 .55343 L
s
P
p
.001 w
.02381 .61085 m
.02756 .61085 L
s
P
[([Rad/s2])] .02381 .61803 0 -4 Mshowa
p
.002 w
.02381 0 m
.02381 .61803 L
s
P
P
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
p
.004 w
.03333 .295 m
.04286 .34981 L
.05238 .37468 L
.0619 .39791 L
.07143 .41953 L
.08095 .43958 L
.09048 .45809 L
.1 .47509 L
.10952 .49063 L
.11905 .50473 L
.12857 .51744 L
.1381 .52878 L
.14762 .5388 L
.15714 .54752 L
.16667 .55498 L
.17619 .56122 L
.18571 .56627 L
.19524 .57017 L
.20476 .57295 L
.21429 .57464 L
.22381 .57529 L
.23333 .57492 L
.24286 .57358 L
.25238 .57129 L
.2619 .56809 L
.27143 .56402 L
.28095 .55911 L
.29048 .55339 L
.3 .54691 L
.30952 .53969 L
.31905 .53177 L
.32857 .52319 L
.3381 .51398 L
.34762 .50417 L
.35714 .49381 L
.36667 .48292 L
.37619 .47154 L
.38571 .45971 L
.39524 .44746 L
.40476 .43482 L
.41429 .42184 L
.42381 .40854 L
.43333 .39496 L
.44286 .38113 L
.45238 .3671 L
.4619 .35289 L
.47143 .33854 L
.48095 .32409 L
.49048 .30956 L
.5 .295 L
Mistroke
.50952 .28044 L
.51905 .26592 L
.52857 .25147 L
.5381 .23712 L
.54762 .22291 L
.55714 .20887 L
.56667 .19505 L
.57619 .18147 L
.58571 .16817 L
.59524 .15518 L
.60476 .14255 L
.61429 .13029 L
.62381 .11846 L
.63333 .10708 L
.64286 .0962 L
.65238 .08583 L
.6619 .07603 L
.67143 .06682 L
.68095 .05823 L
.69048 .05032 L
.7 .0431 L
.70952 .03661 L
.71905 .0309 L
.72857 .02599 L
.7381 .02192 L
.74762 .01872 L
.75714 .01643 L
.76667 .01508 L
.77619 .01472 L
.78571 .01536 L
.79524 .01706 L
.80476 .01984 L
.81429 .02373 L
.82381 .02878 L
.83333 .03502 L
.84286 .04249 L
.85238 .05121 L
.8619 .06122 L
.87143 .07257 L
.88095 .08527 L
.89048 .09938 L
.9 .11491 L
.90952 .13192 L
.91905 .15043 L
.92857 .17048 L
.9381 .19209 L
.94762 .21532 L
.95714 .24019 L
.96667 .26674 L
.97619 .295 L
Mistroke
Mfstroke
[(  Acceleration Q''l[ 1 ])] .5 .60332 0 0 Mshowa
P
% End of Graphics
MathPictureEnd\
\>"], "Graphics",
  PageWidth->Infinity,
  Evaluatable->False,
  ImageSize->{299, 185},
  ImageMargins->{{80, Inherited}, {Inherited, 0}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0.295003 0.171178 [
[(1)] .2619 .295 0 2 Msboxa
[(2)] .5 .295 0 2 Msboxa
[(3)] .7381 .295 0 2 Msboxa
[(4)] .97619 .295 0 2 Msboxa
[([s])] 1.025 .295 -1 0 Msboxa
[(-1.5)] .01131 .03824 1 0 Msboxa
[(-1)] .01131 .12382 1 0 Msboxa
[(-0.5)] .01131 .20941 1 0 Msboxa
[(0.5)] .01131 .38059 1 0 Msboxa
[(1)] .01131 .46618 1 0 Msboxa
[(1.5)] .01131 .55177 1 0 Msboxa
[([Rad/s2])] .02381 .61803 0 -4 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 .61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.2619 .295 m
.2619 .30125 L
s
P
[(1)] .2619 .295 0 2 Mshowa
p
.002 w
.5 .295 m
.5 .30125 L
s
P
[(2)] .5 .295 0 2 Mshowa
p
.002 w
.7381 .295 m
.7381 .30125 L
s
P
[(3)] .7381 .295 0 2 Mshowa
p
.002 w
.97619 .295 m
.97619 .30125 L
s
P
[(4)] .97619 .295 0 2 Mshowa
p
.001 w
.07143 .295 m
.07143 .29875 L
s
P
p
.001 w
.11905 .295 m
.11905 .29875 L
s
P
p
.001 w
.16667 .295 m
.16667 .29875 L
s
P
p
.001 w
.21429 .295 m
.21429 .29875 L
s
P
p
.001 w
.30952 .295 m
.30952 .29875 L
s
P
p
.001 w
.35714 .295 m
.35714 .29875 L
s
P
p
.001 w
.40476 .295 m
.40476 .29875 L
s
P
p
.001 w
.45238 .295 m
.45238 .29875 L
s
P
p
.001 w
.54762 .295 m
.54762 .29875 L
s
P
p
.001 w
.59524 .295 m
.59524 .29875 L
s
P
p
.001 w
.64286 .295 m
.64286 .29875 L
s
P
p
.001 w
.69048 .295 m
.69048 .29875 L
s
P
p
.001 w
.78571 .295 m
.78571 .29875 L
s
P
p
.001 w
.83333 .295 m
.83333 .29875 L
s
P
p
.001 w
.88095 .295 m
.88095 .29875 L
s
P
p
.001 w
.92857 .295 m
.92857 .29875 L
s
P
[([s])] 1.025 .295 -1 0 Mshowa
p
.002 w
0 .295 m
1 .295 L
s
P
p
.002 w
.02381 .03824 m
.03006 .03824 L
s
P
[(-1.5)] .01131 .03824 1 0 Mshowa
p
.002 w
.02381 .12382 m
.03006 .12382 L
s
P
[(-1)] .01131 .12382 1 0 Mshowa
p
.002 w
.02381 .20941 m
.03006 .20941 L
s
P
[(-0.5)] .01131 .20941 1 0 Mshowa
p
.002 w
.02381 .38059 m
.03006 .38059 L
s
P
[(0.5)] .01131 .38059 1 0 Mshowa
p
.002 w
.02381 .46618 m
.03006 .46618 L
s
P
[(1)] .01131 .46618 1 0 Mshowa
p
.002 w
.02381 .55177 m
.03006 .55177 L
s
P
[(1.5)] .01131 .55177 1 0 Mshowa
p
.001 w
.02381 .05535 m
.02756 .05535 L
s
P
p
.001 w
.02381 .07247 m
.02756 .07247 L
s
P
p
.001 w
.02381 .08959 m
.02756 .08959 L
s
P
p
.001 w
.02381 .10671 m
.02756 .10671 L
s
P
p
.001 w
.02381 .14094 m
.02756 .14094 L
s
P
p
.001 w
.02381 .15806 m
.02756 .15806 L
s
P
p
.001 w
.02381 .17518 m
.02756 .17518 L
s
P
p
.001 w
.02381 .1923 m
.02756 .1923 L
s
P
p
.001 w
.02381 .22653 m
.02756 .22653 L
s
P
p
.001 w
.02381 .24365 m
.02756 .24365 L
s
P
p
.001 w
.02381 .26077 m
.02756 .26077 L
s
P
p
.001 w
.02381 .27788 m
.02756 .27788 L
s
P
p
.001 w
.02381 .31212 m
.02756 .31212 L
s
P
p
.001 w
.02381 .32924 m
.02756 .32924 L
s
P
p
.001 w
.02381 .34636 m
.02756 .34636 L
s
P
p
.001 w
.02381 .36347 m
.02756 .36347 L
s
P
p
.001 w
.02381 .39771 m
.02756 .39771 L
s
P
p
.001 w
.02381 .41483 m
.02756 .41483 L
s
P
p
.001 w
.02381 .43194 m
.02756 .43194 L
s
P
p
.001 w
.02381 .44906 m
.02756 .44906 L
s
P
p
.001 w
.02381 .4833 m
.02756 .4833 L
s
P
p
.001 w
.02381 .50042 m
.02756 .50042 L
s
P
p
.001 w
.02381 .51753 m
.02756 .51753 L
s
P
p
.001 w
.02381 .53465 m
.02756 .53465 L
s
P
p
.001 w
.02381 .02112 m
.02756 .02112 L
s
P
p
.001 w
.02381 .004 m
.02756 .004 L
s
P
p
.001 w
.02381 .56889 m
.02756 .56889 L
s
P
p
.001 w
.02381 .586 m
.02756 .586 L
s
P
p
.001 w
.02381 .60312 m
.02756 .60312 L
s
P
[([Rad/s2])] .02381 .61803 0 -4 Mshowa
p
.002 w
.02381 0 m
.02381 .61803 L
s
P
P
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
p
.004 w
.03333 .295 m
.04286 .34981 L
.05238 .37468 L
.0619 .39791 L
.07143 .41953 L
.08095 .43958 L
.09048 .45809 L
.1 .47509 L
.10952 .49063 L
.11905 .50473 L
.12857 .51744 L
.1381 .52878 L
.14762 .5388 L
.15714 .54752 L
.16667 .55498 L
.17619 .56122 L
.18571 .56627 L
.19524 .57017 L
.20476 .57295 L
.21429 .57464 L
.22381 .57529 L
.23333 .57492 L
.24286 .57358 L
.25238 .57129 L
.2619 .56809 L
.27143 .56402 L
.28095 .55911 L
.29048 .55339 L
.3 .54691 L
.30952 .53969 L
.31905 .53177 L
.32857 .52319 L
.3381 .51398 L
.34762 .50417 L
.35714 .49381 L
.36667 .48292 L
.37619 .47154 L
.38571 .45971 L
.39524 .44746 L
.40476 .43482 L
.41429 .42184 L
.42381 .40854 L
.43333 .39496 L
.44286 .38113 L
.45238 .3671 L
.4619 .35289 L
.47143 .33854 L
.48095 .32409 L
.49048 .30956 L
.5 .295 L
Mistroke
.50952 .28044 L
.51905 .26592 L
.52857 .25147 L
.5381 .23712 L
.54762 .22291 L
.55714 .20887 L
.56667 .19505 L
.57619 .18147 L
.58571 .16817 L
.59524 .15518 L
.60476 .14255 L
.61429 .13029 L
.62381 .11846 L
.63333 .10708 L
.64286 .0962 L
.65238 .08583 L
.6619 .07603 L
.67143 .06682 L
.68095 .05823 L
.69048 .05032 L
.7 .0431 L
.70952 .03661 L
.71905 .0309 L
.72857 .02599 L
.7381 .02192 L
.74762 .01872 L
.75714 .01643 L
.76667 .01508 L
.77619 .01472 L
.78571 .01536 L
.79524 .01706 L
.80476 .01984 L
.81429 .02373 L
.82381 .02878 L
.83333 .03502 L
.84286 .04249 L
.85238 .05121 L
.8619 .06122 L
.87143 .07257 L
.88095 .08527 L
.89048 .09938 L
.9 .11491 L
.90952 .13192 L
.91905 .15043 L
.92857 .17048 L
.9381 .19209 L
.94762 .21532 L
.95714 .24019 L
.96667 .26674 L
.97619 .295 L
Mistroke
Mfstroke
[(  Acceleration Q''l[ 2 ])] .5 .60332 0 0 Mshowa
P
% End of Graphics
MathPictureEnd\
\>"], "Graphics",
  PageWidth->Infinity,
  Evaluatable->False,
  ImageSize->{299, 185},
  ImageMargins->{{80, Inherited}, {Inherited, 0}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0.295003 0.148354 [
[(1)] .2619 .295 0 2 Msboxa
[(2)] .5 .295 0 2 Msboxa
[(3)] .7381 .295 0 2 Msboxa
[(4)] .97619 .295 0 2 Msboxa
[([s])] 1.025 .295 -1 0 Msboxa
[(-1)] .01131 .14665 1 0 Msboxa
[(1)] .01131 .44336 1 0 Msboxa
[(2)] .01131 .59171 1 0 Msboxa
[([Rad/s2])] .02381 .61803 0 -4 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 .61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.2619 .295 m
.2619 .30125 L
s
P
[(1)] .2619 .295 0 2 Mshowa
p
.002 w
.5 .295 m
.5 .30125 L
s
P
[(2)] .5 .295 0 2 Mshowa
p
.002 w
.7381 .295 m
.7381 .30125 L
s
P
[(3)] .7381 .295 0 2 Mshowa
p
.002 w
.97619 .295 m
.97619 .30125 L
s
P
[(4)] .97619 .295 0 2 Mshowa
p
.001 w
.07143 .295 m
.07143 .29875 L
s
P
p
.001 w
.11905 .295 m
.11905 .29875 L
s
P
p
.001 w
.16667 .295 m
.16667 .29875 L
s
P
p
.001 w
.21429 .295 m
.21429 .29875 L
s
P
p
.001 w
.30952 .295 m
.30952 .29875 L
s
P
p
.001 w
.35714 .295 m
.35714 .29875 L
s
P
p
.001 w
.40476 .295 m
.40476 .29875 L
s
P
p
.001 w
.45238 .295 m
.45238 .29875 L
s
P
p
.001 w
.54762 .295 m
.54762 .29875 L
s
P
p
.001 w
.59524 .295 m
.59524 .29875 L
s
P
p
.001 w
.64286 .295 m
.64286 .29875 L
s
P
p
.001 w
.69048 .295 m
.69048 .29875 L
s
P
p
.001 w
.78571 .295 m
.78571 .29875 L
s
P
p
.001 w
.83333 .295 m
.83333 .29875 L
s
P
p
.001 w
.88095 .295 m
.88095 .29875 L
s
P
p
.001 w
.92857 .295 m
.92857 .29875 L
s
P
[([s])] 1.025 .295 -1 0 Mshowa
p
.002 w
0 .295 m
1 .295 L
s
P
p
.002 w
.02381 .14665 m
.03006 .14665 L
s
P
[(-1)] .01131 .14665 1 0 Mshowa
p
.002 w
.02381 .44336 m
.03006 .44336 L
s
P
[(1)] .01131 .44336 1 0 Mshowa
p
.002 w
.02381 .59171 m
.03006 .59171 L
s
P
[(2)] .01131 .59171 1 0 Mshowa
p
.001 w
.02381 .02797 m
.02756 .02797 L
s
P
p
.001 w
.02381 .05764 m
.02756 .05764 L
s
P
p
.001 w
.02381 .08731 m
.02756 .08731 L
s
P
p
.001 w
.02381 .11698 m
.02756 .11698 L
s
P
p
.001 w
.02381 .17632 m
.02756 .17632 L
s
P
p
.001 w
.02381 .20599 m
.02756 .20599 L
s
P
p
.001 w
.02381 .23566 m
.02756 .23566 L
s
P
p
.001 w
.02381 .26533 m
.02756 .26533 L
s
P
p
.001 w
.02381 .32467 m
.02756 .32467 L
s
P
p
.001 w
.02381 .35434 m
.02756 .35434 L
s
P
p
.001 w
.02381 .38402 m
.02756 .38402 L
s
P
p
.001 w
.02381 .41369 m
.02756 .41369 L
s
P
p
.001 w
.02381 .47303 m
.02756 .47303 L
s
P
p
.001 w
.02381 .5027 m
.02756 .5027 L
s
P
p
.001 w
.02381 .53237 m
.02756 .53237 L
s
P
p
.001 w
.02381 .56204 m
.02756 .56204 L
s
P
[([Rad/s2])] .02381 .61803 0 -4 Mshowa
p
.002 w
.02381 0 m
.02381 .61803 L
s
P
P
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
p
.004 w
.03333 .295 m
.04286 .34981 L
.05238 .37468 L
.0619 .39791 L
.07143 .41953 L
.08095 .43958 L
.09048 .45809 L
.1 .47509 L
.10952 .49063 L
.11905 .50473 L
.12857 .51744 L
.1381 .52878 L
.14762 .5388 L
.15714 .54752 L
.16667 .55498 L
.17619 .56122 L
.18571 .56627 L
.19524 .57017 L
.20476 .57295 L
.21429 .57464 L
.22381 .57529 L
.23333 .57492 L
.24286 .57358 L
.25238 .57129 L
.2619 .56809 L
.27143 .56402 L
.28095 .55911 L
.29048 .55339 L
.3 .54691 L
.30952 .53969 L
.31905 .53177 L
.32857 .52319 L
.3381 .51398 L
.34762 .50417 L
.35714 .49381 L
.36667 .48292 L
.37619 .47154 L
.38571 .45971 L
.39524 .44746 L
.40476 .43482 L
.41429 .42184 L
.42381 .40854 L
.43333 .39496 L
.44286 .38113 L
.45238 .3671 L
.4619 .35289 L
.47143 .33854 L
.48095 .32409 L
.49048 .30956 L
.5 .295 L
Mistroke
.50952 .28044 L
.51905 .26592 L
.52857 .25147 L
.5381 .23712 L
.54762 .22291 L
.55714 .20887 L
.56667 .19505 L
.57619 .18147 L
.58571 .16817 L
.59524 .15518 L
.60476 .14255 L
.61429 .13029 L
.62381 .11846 L
.63333 .10708 L
.64286 .0962 L
.65238 .08583 L
.6619 .07603 L
.67143 .06682 L
.68095 .05823 L
.69048 .05032 L
.7 .0431 L
.70952 .03661 L
.71905 .0309 L
.72857 .02599 L
.7381 .02192 L
.74762 .01872 L
.75714 .01643 L
.76667 .01508 L
.77619 .01472 L
.78571 .01536 L
.79524 .01706 L
.80476 .01984 L
.81429 .02373 L
.82381 .02878 L
.83333 .03502 L
.84286 .04249 L
.85238 .05121 L
.8619 .06122 L
.87143 .07257 L
.88095 .08527 L
.89048 .09938 L
.9 .11491 L
.90952 .13192 L
.91905 .15043 L
.92857 .17048 L
.9381 .19209 L
.94762 .21532 L
.95714 .24019 L
.96667 .26674 L
.97619 .295 L
Mistroke
Mfstroke
[(  Acceleration Q''l[ 3 ])] .5 .60332 0 0 Mshowa
P
% End of Graphics
MathPictureEnd\
\>"], "Graphics",
  PageWidth->Infinity,
  Evaluatable->False,
  ImageSize->{299, 185},
  ImageMargins->{{80, Inherited}, {Inherited, 0}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0.295003 0.00229306 [
[(1)] .2619 .295 0 2 Msboxa
[(2)] .5 .295 0 2 Msboxa
[(3)] .7381 .295 0 2 Msboxa
[(4)] .97619 .295 0 2 Msboxa
[([s])] 1.025 .295 -1 0 Msboxa
[(-100)] .01131 .0657 1 0 Msboxa
[(-50)] .01131 .18035 1 0 Msboxa
[(50)] .01131 .40966 1 0 Msboxa
[(100)] .01131 .52431 1 0 Msboxa
[([Rad/s2])] .02381 .61803 0 -4 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 .61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.2619 .295 m
.2619 .30125 L
s
P
[(1)] .2619 .295 0 2 Mshowa
p
.002 w
.5 .295 m
.5 .30125 L
s
P
[(2)] .5 .295 0 2 Mshowa
p
.002 w
.7381 .295 m
.7381 .30125 L
s
P
[(3)] .7381 .295 0 2 Mshowa
p
.002 w
.97619 .295 m
.97619 .30125 L
s
P
[(4)] .97619 .295 0 2 Mshowa
p
.001 w
.07143 .295 m
.07143 .29875 L
s
P
p
.001 w
.11905 .295 m
.11905 .29875 L
s
P
p
.001 w
.16667 .295 m
.16667 .29875 L
s
P
p
.001 w
.21429 .295 m
.21429 .29875 L
s
P
p
.001 w
.30952 .295 m
.30952 .29875 L
s
P
p
.001 w
.35714 .295 m
.35714 .29875 L
s
P
p
.001 w
.40476 .295 m
.40476 .29875 L
s
P
p
.001 w
.45238 .295 m
.45238 .29875 L
s
P
p
.001 w
.54762 .295 m
.54762 .29875 L
s
P
p
.001 w
.59524 .295 m
.59524 .29875 L
s
P
p
.001 w
.64286 .295 m
.64286 .29875 L
s
P
p
.001 w
.69048 .295 m
.69048 .29875 L
s
P
p
.001 w
.78571 .295 m
.78571 .29875 L
s
P
p
.001 w
.83333 .295 m
.83333 .29875 L
s
P
p
.001 w
.88095 .295 m
.88095 .29875 L
s
P
p
.001 w
.92857 .295 m
.92857 .29875 L
s
P
[([s])] 1.025 .295 -1 0 Mshowa
p
.002 w
0 .295 m
1 .295 L
s
P
p
.002 w
.02381 .0657 m
.03006 .0657 L
s
P
[(-100)] .01131 .0657 1 0 Mshowa
p
.002 w
.02381 .18035 m
.03006 .18035 L
s
P
[(-50)] .01131 .18035 1 0 Mshowa
p
.002 w
.02381 .40966 m
.03006 .40966 L
s
P
[(50)] .01131 .40966 1 0 Mshowa
p
.002 w
.02381 .52431 m
.03006 .52431 L
s
P
[(100)] .01131 .52431 1 0 Mshowa
p
.001 w
.02381 .08863 m
.02756 .08863 L
s
P
p
.001 w
.02381 .11156 m
.02756 .11156 L
s
P
p
.001 w
.02381 .13449 m
.02756 .13449 L
s
P
p
.001 w
.02381 .15742 m
.02756 .15742 L
s
P
p
.001 w
.02381 .20328 m
.02756 .20328 L
s
P
p
.001 w
.02381 .22621 m
.02756 .22621 L
s
P
p
.001 w
.02381 .24914 m
.02756 .24914 L
s
P
p
.001 w
.02381 .27207 m
.02756 .27207 L
s
P
p
.001 w
.02381 .31793 m
.02756 .31793 L
s
P
p
.001 w
.02381 .34086 m
.02756 .34086 L
s
P
p
.001 w
.02381 .36379 m
.02756 .36379 L
s
P
p
.001 w
.02381 .38673 m
.02756 .38673 L
s
P
p
.001 w
.02381 .43259 m
.02756 .43259 L
s
P
p
.001 w
.02381 .45552 m
.02756 .45552 L
s
P
p
.001 w
.02381 .47845 m
.02756 .47845 L
s
P
p
.001 w
.02381 .50138 m
.02756 .50138 L
s
P
p
.001 w
.02381 .04277 m
.02756 .04277 L
s
P
p
.001 w
.02381 .01984 m
.02756 .01984 L
s
P
p
.001 w
.02381 .54724 m
.02756 .54724 L
s
P
p
.001 w
.02381 .57017 m
.02756 .57017 L
s
P
p
.001 w
.02381 .5931 m
.02756 .5931 L
s
P
p
.001 w
.02381 .61603 m
.02756 .61603 L
s
P
[([Rad/s2])] .02381 .61803 0 -4 Mshowa
p
.002 w
.02381 0 m
.02381 .61803 L
s
P
P
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
p
.004 w
.03333 .295 m
.04286 .34981 L
.05238 .37468 L
.0619 .39791 L
.07143 .41953 L
.08095 .43958 L
.09048 .45809 L
.1 .47509 L
.10952 .49063 L
.11905 .50473 L
.12857 .51744 L
.1381 .52878 L
.14762 .5388 L
.15714 .54752 L
.16667 .55498 L
.17619 .56122 L
.18571 .56627 L
.19524 .57017 L
.20476 .57295 L
.21429 .57464 L
.22381 .57529 L
.23333 .57492 L
.24286 .57358 L
.25238 .57129 L
.2619 .56809 L
.27143 .56402 L
.28095 .55911 L
.29048 .55339 L
.3 .54691 L
.30952 .53969 L
.31905 .53177 L
.32857 .52319 L
.3381 .51398 L
.34762 .50417 L
.35714 .49381 L
.36667 .48292 L
.37619 .47154 L
.38571 .45971 L
.39524 .44746 L
.40476 .43482 L
.41429 .42184 L
.42381 .40854 L
.43333 .39496 L
.44286 .38113 L
.45238 .3671 L
.4619 .35289 L
.47143 .33854 L
.48095 .32409 L
.49048 .30956 L
.5 .295 L
Mistroke
.50952 .28044 L
.51905 .26592 L
.52857 .25147 L
.5381 .23712 L
.54762 .22291 L
.55714 .20887 L
.56667 .19505 L
.57619 .18147 L
.58571 .16817 L
.59524 .15518 L
.60476 .14255 L
.61429 .13029 L
.62381 .11846 L
.63333 .10708 L
.64286 .0962 L
.65238 .08583 L
.6619 .07603 L
.67143 .06682 L
.68095 .05823 L
.69048 .05032 L
.7 .0431 L
.70952 .03661 L
.71905 .0309 L
.72857 .02599 L
.7381 .02192 L
.74762 .01872 L
.75714 .01643 L
.76667 .01508 L
.77619 .01472 L
.78571 .01536 L
.79524 .01706 L
.80476 .01984 L
.81429 .02373 L
.82381 .02878 L
.83333 .03502 L
.84286 .04249 L
.85238 .05121 L
.8619 .06122 L
.87143 .07257 L
.88095 .08527 L
.89048 .09938 L
.9 .11491 L
.90952 .13192 L
.91905 .15043 L
.92857 .17048 L
.9381 .19209 L
.94762 .21532 L
.95714 .24019 L
.96667 .26674 L
.97619 .295 L
Mistroke
Mfstroke
[(  Acceleration Q''m[ 1 ])] .5 .60332 0 0 Mshowa
P
% End of Graphics
MathPictureEnd\
\>"], "Graphics",
  PageWidth->Infinity,
  Evaluatable->False,
  ImageSize->{299, 185},
  ImageMargins->{{80, Inherited}, {Inherited, 0}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0.295003 0.00159443 [
[(1)] .2619 .295 0 2 Msboxa
[(2)] .5 .295 0 2 Msboxa
[(3)] .7381 .295 0 2 Msboxa
[(4)] .97619 .295 0 2 Msboxa
[([s])] 1.025 .295 -1 0 Msboxa
[(-150)] .01131 .05584 1 0 Msboxa
[(-100)] .01131 .13556 1 0 Msboxa
[(-50)] .01131 .21528 1 0 Msboxa
[(50)] .01131 .37472 1 0 Msboxa
[(100)] .01131 .45445 1 0 Msboxa
[(150)] .01131 .53417 1 0 Msboxa
[(200)] .01131 .61389 1 0 Msboxa
[([Rad/s2])] .02381 .61803 0 -4 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 .61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.2619 .295 m
.2619 .30125 L
s
P
[(1)] .2619 .295 0 2 Mshowa
p
.002 w
.5 .295 m
.5 .30125 L
s
P
[(2)] .5 .295 0 2 Mshowa
p
.002 w
.7381 .295 m
.7381 .30125 L
s
P
[(3)] .7381 .295 0 2 Mshowa
p
.002 w
.97619 .295 m
.97619 .30125 L
s
P
[(4)] .97619 .295 0 2 Mshowa
p
.001 w
.07143 .295 m
.07143 .29875 L
s
P
p
.001 w
.11905 .295 m
.11905 .29875 L
s
P
p
.001 w
.16667 .295 m
.16667 .29875 L
s
P
p
.001 w
.21429 .295 m
.21429 .29875 L
s
P
p
.001 w
.30952 .295 m
.30952 .29875 L
s
P
p
.001 w
.35714 .295 m
.35714 .29875 L
s
P
p
.001 w
.40476 .295 m
.40476 .29875 L
s
P
p
.001 w
.45238 .295 m
.45238 .29875 L
s
P
p
.001 w
.54762 .295 m
.54762 .29875 L
s
P
p
.001 w
.59524 .295 m
.59524 .29875 L
s
P
p
.001 w
.64286 .295 m
.64286 .29875 L
s
P
p
.001 w
.69048 .295 m
.69048 .29875 L
s
P
p
.001 w
.78571 .295 m
.78571 .29875 L
s
P
p
.001 w
.83333 .295 m
.83333 .29875 L
s
P
p
.001 w
.88095 .295 m
.88095 .29875 L
s
P
p
.001 w
.92857 .295 m
.92857 .29875 L
s
P
[([s])] 1.025 .295 -1 0 Mshowa
p
.002 w
0 .295 m
1 .295 L
s
P
p
.002 w
.02381 .05584 m
.03006 .05584 L
s
P
[(-150)] .01131 .05584 1 0 Mshowa
p
.002 w
.02381 .13556 m
.03006 .13556 L
s
P
[(-100)] .01131 .13556 1 0 Mshowa
p
.002 w
.02381 .21528 m
.03006 .21528 L
s
P
[(-50)] .01131 .21528 1 0 Mshowa
p
.002 w
.02381 .37472 m
.03006 .37472 L
s
P
[(50)] .01131 .37472 1 0 Mshowa
p
.002 w
.02381 .45445 m
.03006 .45445 L
s
P
[(100)] .01131 .45445 1 0 Mshowa
p
.002 w
.02381 .53417 m
.03006 .53417 L
s
P
[(150)] .01131 .53417 1 0 Mshowa
p
.002 w
.02381 .61389 m
.03006 .61389 L
s
P
[(200)] .01131 .61389 1 0 Mshowa
p
.001 w
.02381 .07178 m
.02756 .07178 L
s
P
p
.001 w
.02381 .08773 m
.02756 .08773 L
s
P
p
.001 w
.02381 .10367 m
.02756 .10367 L
s
P
p
.001 w
.02381 .11962 m
.02756 .11962 L
s
P
p
.001 w
.02381 .1515 m
.02756 .1515 L
s
P
p
.001 w
.02381 .16745 m
.02756 .16745 L
s
P
p
.001 w
.02381 .18339 m
.02756 .18339 L
s
P
p
.001 w
.02381 .19934 m
.02756 .19934 L
s
P
p
.001 w
.02381 .23123 m
.02756 .23123 L
s
P
p
.001 w
.02381 .24717 m
.02756 .24717 L
s
P
p
.001 w
.02381 .26311 m
.02756 .26311 L
s
P
p
.001 w
.02381 .27906 m
.02756 .27906 L
s
P
p
.001 w
.02381 .31095 m
.02756 .31095 L
s
P
p
.001 w
.02381 .32689 m
.02756 .32689 L
s
P
p
.001 w
.02381 .34284 m
.02756 .34284 L
s
P
p
.001 w
.02381 .35878 m
.02756 .35878 L
s
P
p
.001 w
.02381 .39067 m
.02756 .39067 L
s
P
p
.001 w
.02381 .40661 m
.02756 .40661 L
s
P
p
.001 w
.02381 .42256 m
.02756 .42256 L
s
P
p
.001 w
.02381 .4385 m
.02756 .4385 L
s
P
p
.001 w
.02381 .47039 m
.02756 .47039 L
s
P
p
.001 w
.02381 .48633 m
.02756 .48633 L
s
P
p
.001 w
.02381 .50228 m
.02756 .50228 L
s
P
p
.001 w
.02381 .51822 m
.02756 .51822 L
s
P
p
.001 w
.02381 .55011 m
.02756 .55011 L
s
P
p
.001 w
.02381 .56606 m
.02756 .56606 L
s
P
p
.001 w
.02381 .582 m
.02756 .582 L
s
P
p
.001 w
.02381 .59794 m
.02756 .59794 L
s
P
p
.001 w
.02381 .03989 m
.02756 .03989 L
s
P
p
.001 w
.02381 .02395 m
.02756 .02395 L
s
P
p
.001 w
.02381 .00801 m
.02756 .00801 L
s
P
[([Rad/s2])] .02381 .61803 0 -4 Mshowa
p
.002 w
.02381 0 m
.02381 .61803 L
s
P
P
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
p
.004 w
.03333 .295 m
.04286 .34981 L
.05238 .37468 L
.0619 .39791 L
.07143 .41953 L
.08095 .43958 L
.09048 .45809 L
.1 .47509 L
.10952 .49063 L
.11905 .50473 L
.12857 .51744 L
.1381 .52878 L
.14762 .5388 L
.15714 .54752 L
.16667 .55498 L
.17619 .56122 L
.18571 .56627 L
.19524 .57017 L
.20476 .57295 L
.21429 .57464 L
.22381 .57529 L
.23333 .57492 L
.24286 .57358 L
.25238 .57129 L
.2619 .56809 L
.27143 .56402 L
.28095 .55911 L
.29048 .55339 L
.3 .54691 L
.30952 .53969 L
.31905 .53177 L
.32857 .52319 L
.3381 .51398 L
.34762 .50417 L
.35714 .49381 L
.36667 .48292 L
.37619 .47154 L
.38571 .45971 L
.39524 .44746 L
.40476 .43482 L
.41429 .42184 L
.42381 .40854 L
.43333 .39496 L
.44286 .38113 L
.45238 .3671 L
.4619 .35289 L
.47143 .33854 L
.48095 .32409 L
.49048 .30956 L
.5 .295 L
Mistroke
.50952 .28044 L
.51905 .26592 L
.52857 .25147 L
.5381 .23712 L
.54762 .22291 L
.55714 .20887 L
.56667 .19505 L
.57619 .18147 L
.58571 .16817 L
.59524 .15518 L
.60476 .14255 L
.61429 .13029 L
.62381 .11846 L
.63333 .10708 L
.64286 .0962 L
.65238 .08583 L
.6619 .07603 L
.67143 .06682 L
.68095 .05823 L
.69048 .05032 L
.7 .0431 L
.70952 .03661 L
.71905 .0309 L
.72857 .02599 L
.7381 .02192 L
.74762 .01872 L
.75714 .01643 L
.76667 .01508 L
.77619 .01472 L
.78571 .01536 L
.79524 .01706 L
.80476 .01984 L
.81429 .02373 L
.82381 .02878 L
.83333 .03502 L
.84286 .04249 L
.85238 .05121 L
.8619 .06122 L
.87143 .07257 L
.88095 .08527 L
.89048 .09938 L
.9 .11491 L
.90952 .13192 L
.91905 .15043 L
.92857 .17048 L
.9381 .19209 L
.94762 .21532 L
.95714 .24019 L
.96667 .26674 L
.97619 .295 L
Mistroke
Mfstroke
[(  Acceleration Q''m[ 2 ])] .5 .60332 0 0 Mshowa
P
% End of Graphics
MathPictureEnd\
\>"], "Graphics",
  PageWidth->Infinity,
  Evaluatable->False,
  ImageSize->{299, 185},
  ImageMargins->{{80, Inherited}, {Inherited, 0}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0.295003 0.00276316 [
[(1)] .2619 .295 0 2 Msboxa
[(2)] .5 .295 0 2 Msboxa
[(3)] .7381 .295 0 2 Msboxa
[(4)] .97619 .295 0 2 Msboxa
[([s])] 1.025 .295 -1 0 Msboxa
[(-100)] .01131 .01869 1 0 Msboxa
[(-50)] .01131 .15684 1 0 Msboxa
[(50)] .01131 .43316 1 0 Msboxa
[(100)] .01131 .57132 1 0 Msboxa
[([Rad/s2])] .02381 .61803 0 -4 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 .61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.2619 .295 m
.2619 .30125 L
s
P
[(1)] .2619 .295 0 2 Mshowa
p
.002 w
.5 .295 m
.5 .30125 L
s
P
[(2)] .5 .295 0 2 Mshowa
p
.002 w
.7381 .295 m
.7381 .30125 L
s
P
[(3)] .7381 .295 0 2 Mshowa
p
.002 w
.97619 .295 m
.97619 .30125 L
s
P
[(4)] .97619 .295 0 2 Mshowa
p
.001 w
.07143 .295 m
.07143 .29875 L
s
P
p
.001 w
.11905 .295 m
.11905 .29875 L
s
P
p
.001 w
.16667 .295 m
.16667 .29875 L
s
P
p
.001 w
.21429 .295 m
.21429 .29875 L
s
P
p
.001 w
.30952 .295 m
.30952 .29875 L
s
P
p
.001 w
.35714 .295 m
.35714 .29875 L
s
P
p
.001 w
.40476 .295 m
.40476 .29875 L
s
P
p
.001 w
.45238 .295 m
.45238 .29875 L
s
P
p
.001 w
.54762 .295 m
.54762 .29875 L
s
P
p
.001 w
.59524 .295 m
.59524 .29875 L
s
P
p
.001 w
.64286 .295 m
.64286 .29875 L
s
P
p
.001 w
.69048 .295 m
.69048 .29875 L
s
P
p
.001 w
.78571 .295 m
.78571 .29875 L
s
P
p
.001 w
.83333 .295 m
.83333 .29875 L
s
P
p
.001 w
.88095 .295 m
.88095 .29875 L
s
P
p
.001 w
.92857 .295 m
.92857 .29875 L
s
P
[([s])] 1.025 .295 -1 0 Mshowa
p
.002 w
0 .295 m
1 .295 L
s
P
p
.002 w
.02381 .01869 m
.03006 .01869 L
s
P
[(-100)] .01131 .01869 1 0 Mshowa
p
.002 w
.02381 .15684 m
.03006 .15684 L
s
P
[(-50)] .01131 .15684 1 0 Mshowa
p
.002 w
.02381 .43316 m
.03006 .43316 L
s
P
[(50)] .01131 .43316 1 0 Mshowa
p
.002 w
.02381 .57132 m
.03006 .57132 L
s
P
[(100)] .01131 .57132 1 0 Mshowa
p
.001 w
.02381 .04632 m
.02756 .04632 L
s
P
p
.001 w
.02381 .07395 m
.02756 .07395 L
s
P
p
.001 w
.02381 .10158 m
.02756 .10158 L
s
P
p
.001 w
.02381 .12921 m
.02756 .12921 L
s
P
p
.001 w
.02381 .18448 m
.02756 .18448 L
s
P
p
.001 w
.02381 .21211 m
.02756 .21211 L
s
P
p
.001 w
.02381 .23974 m
.02756 .23974 L
s
P
p
.001 w
.02381 .26737 m
.02756 .26737 L
s
P
p
.001 w
.02381 .32263 m
.02756 .32263 L
s
P
p
.001 w
.02381 .35027 m
.02756 .35027 L
s
P
p
.001 w
.02381 .3779 m
.02756 .3779 L
s
P
p
.001 w
.02381 .40553 m
.02756 .40553 L
s
P
p
.001 w
.02381 .46079 m
.02756 .46079 L
s
P
p
.001 w
.02381 .48842 m
.02756 .48842 L
s
P
p
.001 w
.02381 .51606 m
.02756 .51606 L
s
P
p
.001 w
.02381 .54369 m
.02756 .54369 L
s
P
p
.001 w
.02381 .59895 m
.02756 .59895 L
s
P
[([Rad/s2])] .02381 .61803 0 -4 Mshowa
p
.002 w
.02381 0 m
.02381 .61803 L
s
P
P
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
p
.004 w
.03333 .295 m
.04286 .34981 L
.05238 .37468 L
.0619 .39791 L
.07143 .41953 L
.08095 .43958 L
.09048 .45809 L
.1 .47509 L
.10952 .49063 L
.11905 .50473 L
.12857 .51744 L
.1381 .52878 L
.14762 .5388 L
.15714 .54752 L
.16667 .55498 L
.17619 .56122 L
.18571 .56627 L
.19524 .57017 L
.20476 .57295 L
.21429 .57464 L
.22381 .57529 L
.23333 .57492 L
.24286 .57358 L
.25238 .57129 L
.2619 .56809 L
.27143 .56402 L
.28095 .55911 L
.29048 .55339 L
.3 .54691 L
.30952 .53969 L
.31905 .53177 L
.32857 .52319 L
.3381 .51398 L
.34762 .50417 L
.35714 .49381 L
.36667 .48292 L
.37619 .47154 L
.38571 .45971 L
.39524 .44746 L
.40476 .43482 L
.41429 .42184 L
.42381 .40854 L
.43333 .39496 L
.44286 .38113 L
.45238 .3671 L
.4619 .35289 L
.47143 .33854 L
.48095 .32409 L
.49048 .30956 L
.5 .295 L
Mistroke
.50952 .28044 L
.51905 .26592 L
.52857 .25147 L
.5381 .23712 L
.54762 .22291 L
.55714 .20887 L
.56667 .19505 L
.57619 .18147 L
.58571 .16817 L
.59524 .15518 L
.60476 .14255 L
.61429 .13029 L
.62381 .11846 L
.63333 .10708 L
.64286 .0962 L
.65238 .08583 L
.6619 .07603 L
.67143 .06682 L
.68095 .05823 L
.69048 .05032 L
.7 .0431 L
.70952 .03661 L
.71905 .0309 L
.72857 .02599 L
.7381 .02192 L
.74762 .01872 L
.75714 .01643 L
.76667 .01508 L
.77619 .01472 L
.78571 .01536 L
.79524 .01706 L
.80476 .01984 L
.81429 .02373 L
.82381 .02878 L
.83333 .03502 L
.84286 .04249 L
.85238 .05121 L
.8619 .06122 L
.87143 .07257 L
.88095 .08527 L
.89048 .09938 L
.9 .11491 L
.90952 .13192 L
.91905 .15043 L
.92857 .17048 L
.9381 .19209 L
.94762 .21532 L
.95714 .24019 L
.96667 .26674 L
.97619 .295 L
Mistroke
Mfstroke
[(  Acceleration Q''m[ 3 ])] .5 .60332 0 0 Mshowa
P
% End of Graphics
MathPictureEnd\
\>"], "Graphics",
  PageWidth->Infinity,
  Evaluatable->False,
  ImageSize->{299, 185},
  ImageMargins->{{80, Inherited}, {Inherited, 0}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0.295958 0.0337046 [
[(1)] .2619 .29596 0 2 Msboxa
[(2)] .5 .29596 0 2 Msboxa
[(3)] .7381 .29596 0 2 Msboxa
[(4)] .97619 .29596 0 2 Msboxa
[([s])] 1.025 .29596 -1 0 Msboxa
[(-7.5)] .01131 .04317 1 0 Msboxa
[(-5)] .01131 .12744 1 0 Msboxa
[(-2.5)] .01131 .2117 1 0 Msboxa
[(2.5)] .01131 .38022 1 0 Msboxa
[(5)] .01131 .46448 1 0 Msboxa
[(7.5)] .01131 .54874 1 0 Msboxa
[([Nm])] .02381 .61803 0 -4 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 .61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.2619 .29596 m
.2619 .30221 L
s
P
[(1)] .2619 .29596 0 2 Mshowa
p
.002 w
.5 .29596 m
.5 .30221 L
s
P
[(2)] .5 .29596 0 2 Mshowa
p
.002 w
.7381 .29596 m
.7381 .30221 L
s
P
[(3)] .7381 .29596 0 2 Mshowa
p
.002 w
.97619 .29596 m
.97619 .30221 L
s
P
[(4)] .97619 .29596 0 2 Mshowa
p
.001 w
.07143 .29596 m
.07143 .29971 L
s
P
p
.001 w
.11905 .29596 m
.11905 .29971 L
s
P
p
.001 w
.16667 .29596 m
.16667 .29971 L
s
P
p
.001 w
.21429 .29596 m
.21429 .29971 L
s
P
p
.001 w
.30952 .29596 m
.30952 .29971 L
s
P
p
.001 w
.35714 .29596 m
.35714 .29971 L
s
P
p
.001 w
.40476 .29596 m
.40476 .29971 L
s
P
p
.001 w
.45238 .29596 m
.45238 .29971 L
s
P
p
.001 w
.54762 .29596 m
.54762 .29971 L
s
P
p
.001 w
.59524 .29596 m
.59524 .29971 L
s
P
p
.001 w
.64286 .29596 m
.64286 .29971 L
s
P
p
.001 w
.69048 .29596 m
.69048 .29971 L
s
P
p
.001 w
.78571 .29596 m
.78571 .29971 L
s
P
p
.001 w
.83333 .29596 m
.83333 .29971 L
s
P
p
.001 w
.88095 .29596 m
.88095 .29971 L
s
P
p
.001 w
.92857 .29596 m
.92857 .29971 L
s
P
[([s])] 1.025 .29596 -1 0 Mshowa
p
.002 w
0 .29596 m
1 .29596 L
s
P
p
.002 w
.02381 .04317 m
.03006 .04317 L
s
P
[(-7.5)] .01131 .04317 1 0 Mshowa
p
.002 w
.02381 .12744 m
.03006 .12744 L
s
P
[(-5)] .01131 .12744 1 0 Mshowa
p
.002 w
.02381 .2117 m
.03006 .2117 L
s
P
[(-2.5)] .01131 .2117 1 0 Mshowa
p
.002 w
.02381 .38022 m
.03006 .38022 L
s
P
[(2.5)] .01131 .38022 1 0 Mshowa
p
.002 w
.02381 .46448 m
.03006 .46448 L
s
P
[(5)] .01131 .46448 1 0 Mshowa
p
.002 w
.02381 .54874 m
.03006 .54874 L
s
P
[(7.5)] .01131 .54874 1 0 Mshowa
p
.001 w
.02381 .06003 m
.02756 .06003 L
s
P
p
.001 w
.02381 .07688 m
.02756 .07688 L
s
P
p
.001 w
.02381 .09373 m
.02756 .09373 L
s
P
p
.001 w
.02381 .11058 m
.02756 .11058 L
s
P
p
.001 w
.02381 .14429 m
.02756 .14429 L
s
P
p
.001 w
.02381 .16114 m
.02756 .16114 L
s
P
p
.001 w
.02381 .17799 m
.02756 .17799 L
s
P
p
.001 w
.02381 .19484 m
.02756 .19484 L
s
P
p
.001 w
.02381 .22855 m
.02756 .22855 L
s
P
p
.001 w
.02381 .2454 m
.02756 .2454 L
s
P
p
.001 w
.02381 .26225 m
.02756 .26225 L
s
P
p
.001 w
.02381 .27911 m
.02756 .27911 L
s
P
p
.001 w
.02381 .31281 m
.02756 .31281 L
s
P
p
.001 w
.02381 .32966 m
.02756 .32966 L
s
P
p
.001 w
.02381 .34652 m
.02756 .34652 L
s
P
p
.001 w
.02381 .36337 m
.02756 .36337 L
s
P
p
.001 w
.02381 .39707 m
.02756 .39707 L
s
P
p
.001 w
.02381 .41392 m
.02756 .41392 L
s
P
p
.001 w
.02381 .43078 m
.02756 .43078 L
s
P
p
.001 w
.02381 .44763 m
.02756 .44763 L
s
P
p
.001 w
.02381 .48133 m
.02756 .48133 L
s
P
p
.001 w
.02381 .49819 m
.02756 .49819 L
s
P
p
.001 w
.02381 .51504 m
.02756 .51504 L
s
P
p
.001 w
.02381 .53189 m
.02756 .53189 L
s
P
p
.001 w
.02381 .02632 m
.02756 .02632 L
s
P
p
.001 w
.02381 .00947 m
.02756 .00947 L
s
P
p
.001 w
.02381 .56559 m
.02756 .56559 L
s
P
p
.001 w
.02381 .58245 m
.02756 .58245 L
s
P
p
.001 w
.02381 .5993 m
.02756 .5993 L
s
P
p
.001 w
.02381 .61615 m
.02756 .61615 L
s
P
[([Nm])] .02381 .61803 0 -4 Mshowa
p
.002 w
.02381 0 m
.02381 .61803 L
s
P
P
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
p
.004 w
.03333 .01472 m
.04286 .01895 L
.05238 .0208 L
.0619 .02245 L
.07143 .0239 L
.08095 .02512 L
.09048 .02614 L
.1 .02697 L
.10952 .02763 L
.11905 .02817 L
.12857 .02866 L
.1381 .02917 L
.14762 .02981 L
.15714 .0307 L
.16667 .03198 L
.17619 .03381 L
.18571 .03637 L
.19524 .03987 L
.20476 .04451 L
.21429 .05053 L
.22381 .05815 L
.23333 .06762 L
.24286 .07917 L
.25238 .09302 L
.2619 .10938 L
.27143 .12842 L
.28095 .15027 L
.29048 .175 L
.3 .20262 L
.30952 .23301 L
.31905 .26597 L
.32857 .30114 L
.3381 .33798 L
.34762 .3758 L
.35714 .4137 L
.36667 .4506 L
.37619 .48524 L
.38571 .51624 L
.39524 .54214 L
.40476 .56149 L
.41429 .57294 L
.42381 .57538 L
.43333 .56799 L
.44286 .55042 L
.45238 .52282 L
.4619 .48587 L
.47143 .44084 L
.48095 .3895 L
.49048 .33405 L
.5 .27698 L
Mistroke
.50952 .22087 L
.51905 .16829 L
.52857 .12155 L
.5381 .08261 L
.54762 .05293 L
.55714 .03341 L
.56667 .02436 L
.57619 .02557 L
.58571 .03633 L
.59524 .05554 L
.60476 .08185 L
.61429 .11373 L
.62381 .14964 L
.63333 .18806 L
.64286 .22763 L
.65238 .26712 L
.6619 .30553 L
.67143 .34208 L
.68095 .37616 L
.69048 .40737 L
.7 .43546 L
.70952 .46033 L
.71905 .48198 L
.72857 .50051 L
.7381 .51606 L
.74762 .52886 L
.75714 .53913 L
.76667 .54713 L
.77619 .55314 L
.78571 .55743 L
.79524 .56026 L
.80476 .5619 L
.81429 .56259 L
.82381 .56255 L
.83333 .562 L
.84286 .5611 L
.85238 .56004 L
.8619 .55893 L
.87143 .5579 L
.88095 .55704 L
.89048 .55641 L
.9 .55608 L
.90952 .55605 L
.91905 .55636 L
.92857 .557 L
.9381 .55795 L
.94762 .5592 L
.95714 .5607 L
.96667 .56243 L
.97619 .56432 L
Mistroke
Mfstroke
[(  Torque Tl[ 1 ])] .5 .60332 0 0 Mshowa
P
% End of Graphics
MathPictureEnd\
\>"], "Graphics",
  PageWidth->Infinity,
  Evaluatable->False,
  ImageSize->{299, 185},
  ImageMargins->{{80, Inherited}, {Inherited, 0}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0.291787 0.005808 [
[(1)] .2619 .29179 0 2 Msboxa
[(2)] .5 .29179 0 2 Msboxa
[(3)] .7381 .29179 0 2 Msboxa
[(4)] .97619 .29179 0 2 Msboxa
[([s])] 1.025 .29179 -1 0 Msboxa
[(-40)] .01131 .05947 1 0 Msboxa
[(-20)] .01131 .17563 1 0 Msboxa
[(20)] .01131 .40795 1 0 Msboxa
[(40)] .01131 .52411 1 0 Msboxa
[([Nm])] .02381 .61803 0 -4 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 .61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.2619 .29179 m
.2619 .29804 L
s
P
[(1)] .2619 .29179 0 2 Mshowa
p
.002 w
.5 .29179 m
.5 .29804 L
s
P
[(2)] .5 .29179 0 2 Mshowa
p
.002 w
.7381 .29179 m
.7381 .29804 L
s
P
[(3)] .7381 .29179 0 2 Mshowa
p
.002 w
.97619 .29179 m
.97619 .29804 L
s
P
[(4)] .97619 .29179 0 2 Mshowa
p
.001 w
.07143 .29179 m
.07143 .29554 L
s
P
p
.001 w
.11905 .29179 m
.11905 .29554 L
s
P
p
.001 w
.16667 .29179 m
.16667 .29554 L
s
P
p
.001 w
.21429 .29179 m
.21429 .29554 L
s
P
p
.001 w
.30952 .29179 m
.30952 .29554 L
s
P
p
.001 w
.35714 .29179 m
.35714 .29554 L
s
P
p
.001 w
.40476 .29179 m
.40476 .29554 L
s
P
p
.001 w
.45238 .29179 m
.45238 .29554 L
s
P
p
.001 w
.54762 .29179 m
.54762 .29554 L
s
P
p
.001 w
.59524 .29179 m
.59524 .29554 L
s
P
p
.001 w
.64286 .29179 m
.64286 .29554 L
s
P
p
.001 w
.69048 .29179 m
.69048 .29554 L
s
P
p
.001 w
.78571 .29179 m
.78571 .29554 L
s
P
p
.001 w
.83333 .29179 m
.83333 .29554 L
s
P
p
.001 w
.88095 .29179 m
.88095 .29554 L
s
P
p
.001 w
.92857 .29179 m
.92857 .29554 L
s
P
[([s])] 1.025 .29179 -1 0 Mshowa
p
.002 w
0 .29179 m
1 .29179 L
s
P
p
.002 w
.02381 .05947 m
.03006 .05947 L
s
P
[(-40)] .01131 .05947 1 0 Mshowa
p
.002 w
.02381 .17563 m
.03006 .17563 L
s
P
[(-20)] .01131 .17563 1 0 Mshowa
p
.002 w
.02381 .40795 m
.03006 .40795 L
s
P
[(20)] .01131 .40795 1 0 Mshowa
p
.002 w
.02381 .52411 m
.03006 .52411 L
s
P
[(40)] .01131 .52411 1 0 Mshowa
p
.001 w
.02381 .0827 m
.02756 .0827 L
s
P
p
.001 w
.02381 .10593 m
.02756 .10593 L
s
P
p
.001 w
.02381 .12916 m
.02756 .12916 L
s
P
p
.001 w
.02381 .1524 m
.02756 .1524 L
s
P
p
.001 w
.02381 .19886 m
.02756 .19886 L
s
P
p
.001 w
.02381 .22209 m
.02756 .22209 L
s
P
p
.001 w
.02381 .24532 m
.02756 .24532 L
s
P
p
.001 w
.02381 .26856 m
.02756 .26856 L
s
P
p
.001 w
.02381 .31502 m
.02756 .31502 L
s
P
p
.001 w
.02381 .33825 m
.02756 .33825 L
s
P
p
.001 w
.02381 .36148 m
.02756 .36148 L
s
P
p
.001 w
.02381 .38472 m
.02756 .38472 L
s
P
p
.001 w
.02381 .43118 m
.02756 .43118 L
s
P
p
.001 w
.02381 .45441 m
.02756 .45441 L
s
P
p
.001 w
.02381 .47764 m
.02756 .47764 L
s
P
p
.001 w
.02381 .50088 m
.02756 .50088 L
s
P
p
.001 w
.02381 .03624 m
.02756 .03624 L
s
P
p
.001 w
.02381 .013 m
.02756 .013 L
s
P
p
.001 w
.02381 .54734 m
.02756 .54734 L
s
P
p
.001 w
.02381 .57057 m
.02756 .57057 L
s
P
p
.001 w
.02381 .5938 m
.02756 .5938 L
s
P
p
.001 w
.02381 .61704 m
.02756 .61704 L
s
P
[([Nm])] .02381 .61803 0 -4 Mshowa
p
.002 w
.02381 0 m
.02381 .61803 L
s
P
P
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
p
.004 w
.03333 .41032 m
.04286 .41349 L
.05238 .41501 L
.0619 .41653 L
.07143 .41809 L
.08095 .41971 L
.09048 .42142 L
.1 .42326 L
.10952 .42525 L
.11905 .42741 L
.12857 .42978 L
.1381 .43238 L
.14762 .43524 L
.15714 .43837 L
.16667 .44182 L
.17619 .44559 L
.18571 .44971 L
.19524 .4542 L
.20476 .45907 L
.21429 .46434 L
.22381 .47 L
.23333 .47607 L
.24286 .48253 L
.25238 .48937 L
.2619 .49656 L
.27143 .50408 L
.28095 .51186 L
.29048 .51985 L
.3 .52795 L
.30952 .53606 L
.31905 .54401 L
.32857 .55164 L
.3381 .5587 L
.34762 .56492 L
.35714 .56997 L
.36667 .57347 L
.37619 .575 L
.38571 .57409 L
.39524 .57027 L
.40476 .5631 L
.41429 .55217 L
.42381 .53715 L
.43333 .51785 L
.44286 .49423 L
.45238 .46643 L
.4619 .43478 L
.47143 .39984 L
.48095 .36231 L
.49048 .32307 L
.5 .28309 L
Mistroke
.50952 .2434 L
.51905 .205 L
.52857 .16881 L
.5381 .13564 L
.54762 .10612 L
.55714 .08069 L
.56667 .05957 L
.57619 .04282 L
.58571 .03028 L
.59524 .02168 L
.60476 .01665 L
.61429 .01472 L
.62381 .01541 L
.63333 .01825 L
.64286 .02278 L
.65238 .02859 L
.6619 .03532 L
.67143 .04265 L
.68095 .05034 L
.69048 .05819 L
.7 .06603 L
.70952 .07375 L
.71905 .08125 L
.72857 .08847 L
.7381 .09535 L
.74762 .10187 L
.75714 .108 L
.76667 .11374 L
.77619 .11908 L
.78571 .12403 L
.79524 .12859 L
.80476 .13279 L
.81429 .13664 L
.82381 .14017 L
.83333 .14338 L
.84286 .14631 L
.85238 .14899 L
.8619 .15142 L
.87143 .15365 L
.88095 .15569 L
.89048 .15756 L
.9 .1593 L
.90952 .16092 L
.91905 .16244 L
.92857 .1639 L
.9381 .16531 L
.94762 .1667 L
.95714 .1681 L
.96667 .16954 L
.97619 .17104 L
Mistroke
Mfstroke
[(  Torque Tl[ 2 ])] .5 .60332 0 0 Mshowa
P
% End of Graphics
MathPictureEnd\
\>"], "Graphics",
  PageWidth->Infinity,
  Evaluatable->False,
  ImageSize->{299, 185},
  ImageMargins->{{80, Inherited}, {Inherited, 0}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0.300319 0.0213312 [
[(1)] .2619 .30032 0 2 Msboxa
[(2)] .5 .30032 0 2 Msboxa
[(3)] .7381 .30032 0 2 Msboxa
[(4)] .97619 .30032 0 2 Msboxa
[([s])] 1.025 .30032 -1 0 Msboxa
[(-10)] .01131 .08701 1 0 Msboxa
[(-5)] .01131 .19366 1 0 Msboxa
[(5)] .01131 .40698 1 0 Msboxa
[(10)] .01131 .51363 1 0 Msboxa
[([Nm])] .02381 .61803 0 -4 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 .61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.2619 .30032 m
.2619 .30657 L
s
P
[(1)] .2619 .30032 0 2 Mshowa
p
.002 w
.5 .30032 m
.5 .30657 L
s
P
[(2)] .5 .30032 0 2 Mshowa
p
.002 w
.7381 .30032 m
.7381 .30657 L
s
P
[(3)] .7381 .30032 0 2 Mshowa
p
.002 w
.97619 .30032 m
.97619 .30657 L
s
P
[(4)] .97619 .30032 0 2 Mshowa
p
.001 w
.07143 .30032 m
.07143 .30407 L
s
P
p
.001 w
.11905 .30032 m
.11905 .30407 L
s
P
p
.001 w
.16667 .30032 m
.16667 .30407 L
s
P
p
.001 w
.21429 .30032 m
.21429 .30407 L
s
P
p
.001 w
.30952 .30032 m
.30952 .30407 L
s
P
p
.001 w
.35714 .30032 m
.35714 .30407 L
s
P
p
.001 w
.40476 .30032 m
.40476 .30407 L
s
P
p
.001 w
.45238 .30032 m
.45238 .30407 L
s
P
p
.001 w
.54762 .30032 m
.54762 .30407 L
s
P
p
.001 w
.59524 .30032 m
.59524 .30407 L
s
P
p
.001 w
.64286 .30032 m
.64286 .30407 L
s
P
p
.001 w
.69048 .30032 m
.69048 .30407 L
s
P
p
.001 w
.78571 .30032 m
.78571 .30407 L
s
P
p
.001 w
.83333 .30032 m
.83333 .30407 L
s
P
p
.001 w
.88095 .30032 m
.88095 .30407 L
s
P
p
.001 w
.92857 .30032 m
.92857 .30407 L
s
P
[([s])] 1.025 .30032 -1 0 Mshowa
p
.002 w
0 .30032 m
1 .30032 L
s
P
p
.002 w
.02381 .08701 m
.03006 .08701 L
s
P
[(-10)] .01131 .08701 1 0 Mshowa
p
.002 w
.02381 .19366 m
.03006 .19366 L
s
P
[(-5)] .01131 .19366 1 0 Mshowa
p
.002 w
.02381 .40698 m
.03006 .40698 L
s
P
[(5)] .01131 .40698 1 0 Mshowa
p
.002 w
.02381 .51363 m
.03006 .51363 L
s
P
[(10)] .01131 .51363 1 0 Mshowa
p
.001 w
.02381 .10834 m
.02756 .10834 L
s
P
p
.001 w
.02381 .12967 m
.02756 .12967 L
s
P
p
.001 w
.02381 .151 m
.02756 .151 L
s
P
p
.001 w
.02381 .17233 m
.02756 .17233 L
s
P
p
.001 w
.02381 .21499 m
.02756 .21499 L
s
P
p
.001 w
.02381 .23633 m
.02756 .23633 L
s
P
p
.001 w
.02381 .25766 m
.02756 .25766 L
s
P
p
.001 w
.02381 .27899 m
.02756 .27899 L
s
P
p
.001 w
.02381 .32165 m
.02756 .32165 L
s
P
p
.001 w
.02381 .34298 m
.02756 .34298 L
s
P
p
.001 w
.02381 .36431 m
.02756 .36431 L
s
P
p
.001 w
.02381 .38564 m
.02756 .38564 L
s
P
p
.001 w
.02381 .42831 m
.02756 .42831 L
s
P
p
.001 w
.02381 .44964 m
.02756 .44964 L
s
P
p
.001 w
.02381 .47097 m
.02756 .47097 L
s
P
p
.001 w
.02381 .4923 m
.02756 .4923 L
s
P
p
.001 w
.02381 .53496 m
.02756 .53496 L
s
P
p
.001 w
.02381 .55629 m
.02756 .55629 L
s
P
p
.001 w
.02381 .57763 m
.02756 .57763 L
s
P
p
.001 w
.02381 .59896 m
.02756 .59896 L
s
P
p
.001 w
.02381 .06568 m
.02756 .06568 L
s
P
p
.001 w
.02381 .04434 m
.02756 .04434 L
s
P
p
.001 w
.02381 .02301 m
.02756 .02301 L
s
P
p
.001 w
.02381 .00168 m
.02756 .00168 L
s
P
[([Nm])] .02381 .61803 0 -4 Mshowa
p
.002 w
.02381 0 m
.02381 .61803 L
s
P
P
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
p
.004 w
.03333 .30032 m
.04286 .31821 L
.05238 .32635 L
.0619 .33401 L
.07143 .34122 L
.08095 .34802 L
.09048 .35448 L
.1 .36063 L
.10952 .36654 L
.11905 .37224 L
.12857 .37779 L
.1381 .38325 L
.14762 .38864 L
.15714 .39403 L
.16667 .39945 L
.17619 .40494 L
.18571 .41053 L
.19524 .41625 L
.20476 .42214 L
.21429 .42821 L
.22381 .43446 L
.23333 .44088 L
.24286 .44743 L
.25238 .45403 L
.2619 .46052 L
.27143 .46667 L
.28095 .47211 L
.29048 .47634 L
.3 .47867 L
.30952 .47826 L
.31905 .47408 L
.32857 .46498 L
.3381 .44981 L
.34762 .42753 L
.35714 .39742 L
.36667 .35926 L
.37619 .31358 L
.38571 .26184 L
.39524 .20648 L
.40476 .15095 L
.41429 .09945 L
.42381 .05663 L
.43333 .02708 L
.44286 .01472 L
.45238 .02219 L
.4619 .05042 L
.47143 .09827 L
.48095 .16248 L
.49048 .23798 L
.5 .31839 L
Mistroke
.50952 .39678 L
.51905 .46647 L
.52857 .52183 L
.5381 .55891 L
.54762 .57577 L
.55714 .57257 L
.56667 .55134 L
.57619 .51554 L
.58571 .46949 L
.59524 .41776 L
.60476 .36465 L
.61429 .31381 L
.62381 .26793 L
.63333 .22873 L
.64286 .19699 L
.65238 .17273 L
.6619 .15538 L
.67143 .14405 L
.68095 .13766 L
.69048 .13514 L
.7 .13551 L
.70952 .13793 L
.71905 .14176 L
.72857 .14647 L
.7381 .15172 L
.74762 .15726 L
.75714 .16291 L
.76667 .16859 L
.77619 .17421 L
.78571 .17976 L
.79524 .18522 L
.80476 .19057 L
.81429 .19583 L
.82381 .201 L
.83333 .20611 L
.84286 .21119 L
.85238 .21625 L
.8619 .22134 L
.87143 .22649 L
.88095 .23176 L
.89048 .23717 L
.9 .24278 L
.90952 .24864 L
.91905 .25479 L
.92857 .26129 L
.9381 .26816 L
.94762 .27547 L
.95714 .28324 L
.96667 .29152 L
.97619 .30032 L
Mistroke
Mfstroke
[(  Torque Tl[ 3 ])] .5 .60332 0 0 Mshowa
P
% End of Graphics
MathPictureEnd\
\>"], "Graphics",
  PageWidth->Infinity,
  Evaluatable->False,
  ImageSize->{299, 185},
  ImageMargins->{{80, Inherited}, {Inherited, 0}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0.300134 427.936 [
[(1)] .2619 .30013 0 2 Msboxa
[(2)] .5 .30013 0 2 Msboxa
[(3)] .7381 .30013 0 2 Msboxa
[(4)] .97619 .30013 0 2 Msboxa
[([s])] 1.025 .30013 -1 0 Msboxa
[(-0.0006)] .01131 .04337 1 0 Msboxa
[(-0.0004)] .01131 .12896 1 0 Msboxa
[(-0.0002)] .01131 .21455 1 0 Msboxa
[(0.0002)] .01131 .38572 1 0 Msboxa
[(0.0004)] .01131 .47131 1 0 Msboxa
[(0.0006)] .01131 .5569 1 0 Msboxa
[([Nm])] .02381 .61803 0 -4 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 .61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.2619 .30013 m
.2619 .30638 L
s
P
[(1)] .2619 .30013 0 2 Mshowa
p
.002 w
.5 .30013 m
.5 .30638 L
s
P
[(2)] .5 .30013 0 2 Mshowa
p
.002 w
.7381 .30013 m
.7381 .30638 L
s
P
[(3)] .7381 .30013 0 2 Mshowa
p
.002 w
.97619 .30013 m
.97619 .30638 L
s
P
[(4)] .97619 .30013 0 2 Mshowa
p
.001 w
.07143 .30013 m
.07143 .30388 L
s
P
p
.001 w
.11905 .30013 m
.11905 .30388 L
s
P
p
.001 w
.16667 .30013 m
.16667 .30388 L
s
P
p
.001 w
.21429 .30013 m
.21429 .30388 L
s
P
p
.001 w
.30952 .30013 m
.30952 .30388 L
s
P
p
.001 w
.35714 .30013 m
.35714 .30388 L
s
P
p
.001 w
.40476 .30013 m
.40476 .30388 L
s
P
p
.001 w
.45238 .30013 m
.45238 .30388 L
s
P
p
.001 w
.54762 .30013 m
.54762 .30388 L
s
P
p
.001 w
.59524 .30013 m
.59524 .30388 L
s
P
p
.001 w
.64286 .30013 m
.64286 .30388 L
s
P
p
.001 w
.69048 .30013 m
.69048 .30388 L
s
P
p
.001 w
.78571 .30013 m
.78571 .30388 L
s
P
p
.001 w
.83333 .30013 m
.83333 .30388 L
s
P
p
.001 w
.88095 .30013 m
.88095 .30388 L
s
P
p
.001 w
.92857 .30013 m
.92857 .30388 L
s
P
[([s])] 1.025 .30013 -1 0 Mshowa
p
.002 w
0 .30013 m
1 .30013 L
s
P
p
.002 w
.02381 .04337 m
.03006 .04337 L
s
P
[(-0.0006)] .01131 .04337 1 0 Mshowa
p
.002 w
.02381 .12896 m
.03006 .12896 L
s
P
[(-0.0004)] .01131 .12896 1 0 Mshowa
p
.002 w
.02381 .21455 m
.03006 .21455 L
s
P
[(-0.0002)] .01131 .21455 1 0 Mshowa
p
.002 w
.02381 .38572 m
.03006 .38572 L
s
P
[(0.0002)] .01131 .38572 1 0 Mshowa
p
.002 w
.02381 .47131 m
.03006 .47131 L
s
P
[(0.0004)] .01131 .47131 1 0 Mshowa
p
.002 w
.02381 .5569 m
.03006 .5569 L
s
P
[(0.0006)] .01131 .5569 1 0 Mshowa
p
.001 w
.02381 .06049 m
.02756 .06049 L
s
P
p
.001 w
.02381 .07761 m
.02756 .07761 L
s
P
p
.001 w
.02381 .09472 m
.02756 .09472 L
s
P
p
.001 w
.02381 .11184 m
.02756 .11184 L
s
P
p
.001 w
.02381 .14608 m
.02756 .14608 L
s
P
p
.001 w
.02381 .16319 m
.02756 .16319 L
s
P
p
.001 w
.02381 .18031 m
.02756 .18031 L
s
P
p
.001 w
.02381 .19743 m
.02756 .19743 L
s
P
p
.001 w
.02381 .23166 m
.02756 .23166 L
s
P
p
.001 w
.02381 .24878 m
.02756 .24878 L
s
P
p
.001 w
.02381 .2659 m
.02756 .2659 L
s
P
p
.001 w
.02381 .28302 m
.02756 .28302 L
s
P
p
.001 w
.02381 .31725 m
.02756 .31725 L
s
P
p
.001 w
.02381 .33437 m
.02756 .33437 L
s
P
p
.001 w
.02381 .35149 m
.02756 .35149 L
s
P
p
.001 w
.02381 .3686 m
.02756 .3686 L
s
P
p
.001 w
.02381 .40284 m
.02756 .40284 L
s
P
p
.001 w
.02381 .41996 m
.02756 .41996 L
s
P
p
.001 w
.02381 .43707 m
.02756 .43707 L
s
P
p
.001 w
.02381 .45419 m
.02756 .45419 L
s
P
p
.001 w
.02381 .48843 m
.02756 .48843 L
s
P
p
.001 w
.02381 .50554 m
.02756 .50554 L
s
P
p
.001 w
.02381 .52266 m
.02756 .52266 L
s
P
p
.001 w
.02381 .53978 m
.02756 .53978 L
s
P
p
.001 w
.02381 .02625 m
.02756 .02625 L
s
P
p
.001 w
.02381 .00914 m
.02756 .00914 L
s
P
p
.001 w
.02381 .57401 m
.02756 .57401 L
s
P
p
.001 w
.02381 .59113 m
.02756 .59113 L
s
P
p
.001 w
.02381 .60825 m
.02756 .60825 L
s
P
[([Nm])] .02381 .61803 0 -4 Mshowa
p
.002 w
.02381 0 m
.02381 .61803 L
s
P
P
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
p
.004 w
.03333 .30013 m
.04286 .35434 L
.05238 .37893 L
.0619 .4019 L
.07143 .42327 L
.08095 .44308 L
.09048 .46136 L
.1 .47815 L
.10952 .49346 L
.11905 .50735 L
.12857 .51984 L
.1381 .53097 L
.14762 .54076 L
.15714 .54927 L
.16667 .55652 L
.17619 .56254 L
.18571 .56739 L
.19524 .5711 L
.20476 .5737 L
.21429 .57524 L
.22381 .57576 L
.23333 .5753 L
.24286 .5739 L
.25238 .57161 L
.2619 .56847 L
.27143 .56453 L
.28095 .55982 L
.29048 .55438 L
.3 .54826 L
.30952 .54149 L
.31905 .53412 L
.32857 .52617 L
.3381 .51768 L
.34762 .50868 L
.35714 .4992 L
.36667 .48926 L
.37619 .47889 L
.38571 .4681 L
.39524 .45692 L
.40476 .44536 L
.41429 .43343 L
.42381 .42114 L
.43333 .40852 L
.44286 .39558 L
.45238 .38233 L
.4619 .36878 L
.47143 .35497 L
.48095 .3409 L
.49048 .3266 L
.5 .31212 L
Mistroke
.50952 .29746 L
.51905 .28268 L
.52857 .26782 L
.5381 .25292 L
.54762 .23802 L
.55714 .22318 L
.56667 .20845 L
.57619 .19389 L
.58571 .17955 L
.59524 .16548 L
.60476 .15175 L
.61429 .13841 L
.62381 .12552 L
.63333 .11311 L
.64286 .10126 L
.65238 .08999 L
.6619 .07936 L
.67143 .06942 L
.68095 .06019 L
.69048 .05171 L
.7 .04403 L
.70952 .03717 L
.71905 .03117 L
.72857 .02605 L
.7381 .02185 L
.74762 .01858 L
.75714 .01629 L
.76667 .01499 L
.77619 .01472 L
.78571 .01549 L
.79524 .01734 L
.80476 .0203 L
.81429 .0244 L
.82381 .02967 L
.83333 .03613 L
.84286 .04382 L
.85238 .05277 L
.8619 .06302 L
.87143 .0746 L
.88095 .08754 L
.89048 .10189 L
.9 .11767 L
.90952 .13493 L
.91905 .15369 L
.92857 .17401 L
.9381 .19591 L
.94762 .21944 L
.95714 .24463 L
.96667 .27151 L
.97619 .30013 L
Mistroke
Mfstroke
[(  Torque Tm[ 1 ])] .5 .60332 0 0 Mshowa
P
% End of Graphics
MathPictureEnd\
\>"], "Graphics",
  PageWidth->Infinity,
  Evaluatable->False,
  ImageSize->{299, 185},
  ImageMargins->{{80, Inherited}, {Inherited, 0}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0.295003 418.901 [
[(1)] .2619 .295 0 2 Msboxa
[(2)] .5 .295 0 2 Msboxa
[(3)] .7381 .295 0 2 Msboxa
[(4)] .97619 .295 0 2 Msboxa
[([s])] 1.025 .295 -1 0 Msboxa
[(-0.0006)] .01131 .04366 1 0 Msboxa
[(-0.0004)] .01131 .12744 1 0 Msboxa
[(-0.0002)] .01131 .21122 1 0 Msboxa
[(0.0002)] .01131 .37878 1 0 Msboxa
[(0.0004)] .01131 .46256 1 0 Msboxa
[(0.0006)] .01131 .54634 1 0 Msboxa
[([Nm])] .02381 .61803 0 -4 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 .61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.2619 .295 m
.2619 .30125 L
s
P
[(1)] .2619 .295 0 2 Mshowa
p
.002 w
.5 .295 m
.5 .30125 L
s
P
[(2)] .5 .295 0 2 Mshowa
p
.002 w
.7381 .295 m
.7381 .30125 L
s
P
[(3)] .7381 .295 0 2 Mshowa
p
.002 w
.97619 .295 m
.97619 .30125 L
s
P
[(4)] .97619 .295 0 2 Mshowa
p
.001 w
.07143 .295 m
.07143 .29875 L
s
P
p
.001 w
.11905 .295 m
.11905 .29875 L
s
P
p
.001 w
.16667 .295 m
.16667 .29875 L
s
P
p
.001 w
.21429 .295 m
.21429 .29875 L
s
P
p
.001 w
.30952 .295 m
.30952 .29875 L
s
P
p
.001 w
.35714 .295 m
.35714 .29875 L
s
P
p
.001 w
.40476 .295 m
.40476 .29875 L
s
P
p
.001 w
.45238 .295 m
.45238 .29875 L
s
P
p
.001 w
.54762 .295 m
.54762 .29875 L
s
P
p
.001 w
.59524 .295 m
.59524 .29875 L
s
P
p
.001 w
.64286 .295 m
.64286 .29875 L
s
P
p
.001 w
.69048 .295 m
.69048 .29875 L
s
P
p
.001 w
.78571 .295 m
.78571 .29875 L
s
P
p
.001 w
.83333 .295 m
.83333 .29875 L
s
P
p
.001 w
.88095 .295 m
.88095 .29875 L
s
P
p
.001 w
.92857 .295 m
.92857 .29875 L
s
P
[([s])] 1.025 .295 -1 0 Mshowa
p
.002 w
0 .295 m
1 .295 L
s
P
p
.002 w
.02381 .04366 m
.03006 .04366 L
s
P
[(-0.0006)] .01131 .04366 1 0 Mshowa
p
.002 w
.02381 .12744 m
.03006 .12744 L
s
P
[(-0.0004)] .01131 .12744 1 0 Mshowa
p
.002 w
.02381 .21122 m
.03006 .21122 L
s
P
[(-0.0002)] .01131 .21122 1 0 Mshowa
p
.002 w
.02381 .37878 m
.03006 .37878 L
s
P
[(0.0002)] .01131 .37878 1 0 Mshowa
p
.002 w
.02381 .46256 m
.03006 .46256 L
s
P
[(0.0004)] .01131 .46256 1 0 Mshowa
p
.002 w
.02381 .54634 m
.03006 .54634 L
s
P
[(0.0006)] .01131 .54634 1 0 Mshowa
p
.001 w
.02381 .06042 m
.02756 .06042 L
s
P
p
.001 w
.02381 .07717 m
.02756 .07717 L
s
P
p
.001 w
.02381 .09393 m
.02756 .09393 L
s
P
p
.001 w
.02381 .11069 m
.02756 .11069 L
s
P
p
.001 w
.02381 .1442 m
.02756 .1442 L
s
P
p
.001 w
.02381 .16095 m
.02756 .16095 L
s
P
p
.001 w
.02381 .17771 m
.02756 .17771 L
s
P
p
.001 w
.02381 .19447 m
.02756 .19447 L
s
P
p
.001 w
.02381 .22798 m
.02756 .22798 L
s
P
p
.001 w
.02381 .24473 m
.02756 .24473 L
s
P
p
.001 w
.02381 .26149 m
.02756 .26149 L
s
P
p
.001 w
.02381 .27825 m
.02756 .27825 L
s
P
p
.001 w
.02381 .31176 m
.02756 .31176 L
s
P
p
.001 w
.02381 .32851 m
.02756 .32851 L
s
P
p
.001 w
.02381 .34527 m
.02756 .34527 L
s
P
p
.001 w
.02381 .36203 m
.02756 .36203 L
s
P
p
.001 w
.02381 .39554 m
.02756 .39554 L
s
P
p
.001 w
.02381 .41229 m
.02756 .41229 L
s
P
p
.001 w
.02381 .42905 m
.02756 .42905 L
s
P
p
.001 w
.02381 .44581 m
.02756 .44581 L
s
P
p
.001 w
.02381 .47932 m
.02756 .47932 L
s
P
p
.001 w
.02381 .49608 m
.02756 .49608 L
s
P
p
.001 w
.02381 .51283 m
.02756 .51283 L
s
P
p
.001 w
.02381 .52959 m
.02756 .52959 L
s
P
p
.001 w
.02381 .02691 m
.02756 .02691 L
s
P
p
.001 w
.02381 .01015 m
.02756 .01015 L
s
P
p
.001 w
.02381 .5631 m
.02756 .5631 L
s
P
p
.001 w
.02381 .57986 m
.02756 .57986 L
s
P
p
.001 w
.02381 .59661 m
.02756 .59661 L
s
P
p
.001 w
.02381 .61337 m
.02756 .61337 L
s
P
[([Nm])] .02381 .61803 0 -4 Mshowa
p
.002 w
.02381 0 m
.02381 .61803 L
s
P
P
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
p
.004 w
.03333 .295 m
.04286 .34981 L
.05238 .37468 L
.0619 .39791 L
.07143 .41953 L
.08095 .43958 L
.09048 .45809 L
.1 .47509 L
.10952 .49063 L
.11905 .50473 L
.12857 .51744 L
.1381 .52878 L
.14762 .5388 L
.15714 .54752 L
.16667 .55498 L
.17619 .56122 L
.18571 .56627 L
.19524 .57017 L
.20476 .57295 L
.21429 .57464 L
.22381 .57529 L
.23333 .57492 L
.24286 .57358 L
.25238 .57129 L
.2619 .56809 L
.27143 .56402 L
.28095 .55911 L
.29048 .55339 L
.3 .54691 L
.30952 .53969 L
.31905 .53177 L
.32857 .52319 L
.3381 .51398 L
.34762 .50417 L
.35714 .49381 L
.36667 .48292 L
.37619 .47154 L
.38571 .45971 L
.39524 .44746 L
.40476 .43482 L
.41429 .42184 L
.42381 .40854 L
.43333 .39496 L
.44286 .38113 L
.45238 .3671 L
.4619 .35289 L
.47143 .33854 L
.48095 .32409 L
.49048 .30956 L
.5 .295 L
Mistroke
.50952 .28044 L
.51905 .26592 L
.52857 .25147 L
.5381 .23712 L
.54762 .22291 L
.55714 .20887 L
.56667 .19505 L
.57619 .18147 L
.58571 .16817 L
.59524 .15518 L
.60476 .14255 L
.61429 .13029 L
.62381 .11846 L
.63333 .10708 L
.64286 .0962 L
.65238 .08583 L
.6619 .07603 L
.67143 .06682 L
.68095 .05823 L
.69048 .05032 L
.7 .0431 L
.70952 .03661 L
.71905 .0309 L
.72857 .02599 L
.7381 .02192 L
.74762 .01872 L
.75714 .01643 L
.76667 .01508 L
.77619 .01472 L
.78571 .01536 L
.79524 .01706 L
.80476 .01984 L
.81429 .02373 L
.82381 .02878 L
.83333 .03502 L
.84286 .04249 L
.85238 .05121 L
.8619 .06122 L
.87143 .07257 L
.88095 .08527 L
.89048 .09938 L
.9 .11491 L
.90952 .13192 L
.91905 .15043 L
.92857 .17048 L
.9381 .19209 L
.94762 .21532 L
.95714 .24019 L
.96667 .26674 L
.97619 .295 L
Mistroke
Mfstroke
[(  Torque Tm[ 2 ])] .5 .60332 0 0 Mshowa
P
% End of Graphics
MathPictureEnd\
\>"], "Graphics",
  PageWidth->Infinity,
  Evaluatable->False,
  ImageSize->{299, 185},
  ImageMargins->{{80, Inherited}, {Inherited, 0}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0.295003 594.884 [
[(1)] .2619 .295 0 2 Msboxa
[(2)] .5 .295 0 2 Msboxa
[(3)] .7381 .295 0 2 Msboxa
[(4)] .97619 .295 0 2 Msboxa
[([s])] 1.025 .295 -1 0 Msboxa
[(-0.0004)] .01131 .05705 1 0 Msboxa
[(-0.0002)] .01131 .17603 1 0 Msboxa
[(0.0002)] .01131 .41398 1 0 Msboxa
[(0.0004)] .01131 .53296 1 0 Msboxa
[([Nm])] .02381 .61803 0 -4 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 .61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.2619 .295 m
.2619 .30125 L
s
P
[(1)] .2619 .295 0 2 Mshowa
p
.002 w
.5 .295 m
.5 .30125 L
s
P
[(2)] .5 .295 0 2 Mshowa
p
.002 w
.7381 .295 m
.7381 .30125 L
s
P
[(3)] .7381 .295 0 2 Mshowa
p
.002 w
.97619 .295 m
.97619 .30125 L
s
P
[(4)] .97619 .295 0 2 Mshowa
p
.001 w
.07143 .295 m
.07143 .29875 L
s
P
p
.001 w
.11905 .295 m
.11905 .29875 L
s
P
p
.001 w
.16667 .295 m
.16667 .29875 L
s
P
p
.001 w
.21429 .295 m
.21429 .29875 L
s
P
p
.001 w
.30952 .295 m
.30952 .29875 L
s
P
p
.001 w
.35714 .295 m
.35714 .29875 L
s
P
p
.001 w
.40476 .295 m
.40476 .29875 L
s
P
p
.001 w
.45238 .295 m
.45238 .29875 L
s
P
p
.001 w
.54762 .295 m
.54762 .29875 L
s
P
p
.001 w
.59524 .295 m
.59524 .29875 L
s
P
p
.001 w
.64286 .295 m
.64286 .29875 L
s
P
p
.001 w
.69048 .295 m
.69048 .29875 L
s
P
p
.001 w
.78571 .295 m
.78571 .29875 L
s
P
p
.001 w
.83333 .295 m
.83333 .29875 L
s
P
p
.001 w
.88095 .295 m
.88095 .29875 L
s
P
p
.001 w
.92857 .295 m
.92857 .29875 L
s
P
[([s])] 1.025 .295 -1 0 Mshowa
p
.002 w
0 .295 m
1 .295 L
s
P
p
.002 w
.02381 .05705 m
.03006 .05705 L
s
P
[(-0.0004)] .01131 .05705 1 0 Mshowa
p
.002 w
.02381 .17603 m
.03006 .17603 L
s
P
[(-0.0002)] .01131 .17603 1 0 Mshowa
p
.002 w
.02381 .41398 m
.03006 .41398 L
s
P
[(0.0002)] .01131 .41398 1 0 Mshowa
p
.002 w
.02381 .53296 m
.03006 .53296 L
s
P
[(0.0004)] .01131 .53296 1 0 Mshowa
p
.001 w
.02381 .08084 m
.02756 .08084 L
s
P
p
.001 w
.02381 .10464 m
.02756 .10464 L
s
P
p
.001 w
.02381 .12844 m
.02756 .12844 L
s
P
p
.001 w
.02381 .15223 m
.02756 .15223 L
s
P
p
.001 w
.02381 .19982 m
.02756 .19982 L
s
P
p
.001 w
.02381 .22362 m
.02756 .22362 L
s
P
p
.001 w
.02381 .24741 m
.02756 .24741 L
s
P
p
.001 w
.02381 .27121 m
.02756 .27121 L
s
P
p
.001 w
.02381 .3188 m
.02756 .3188 L
s
P
p
.001 w
.02381 .34259 m
.02756 .34259 L
s
P
p
.001 w
.02381 .36639 m
.02756 .36639 L
s
P
p
.001 w
.02381 .39018 m
.02756 .39018 L
s
P
p
.001 w
.02381 .43777 m
.02756 .43777 L
s
P
p
.001 w
.02381 .46157 m
.02756 .46157 L
s
P
p
.001 w
.02381 .48537 m
.02756 .48537 L
s
P
p
.001 w
.02381 .50916 m
.02756 .50916 L
s
P
p
.001 w
.02381 .03325 m
.02756 .03325 L
s
P
p
.001 w
.02381 .00946 m
.02756 .00946 L
s
P
p
.001 w
.02381 .55675 m
.02756 .55675 L
s
P
p
.001 w
.02381 .58055 m
.02756 .58055 L
s
P
p
.001 w
.02381 .60434 m
.02756 .60434 L
s
P
[([Nm])] .02381 .61803 0 -4 Mshowa
p
.002 w
.02381 0 m
.02381 .61803 L
s
P
P
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
p
.004 w
.03333 .295 m
.04286 .34981 L
.05238 .37468 L
.0619 .39791 L
.07143 .41953 L
.08095 .43958 L
.09048 .45809 L
.1 .47509 L
.10952 .49063 L
.11905 .50473 L
.12857 .51744 L
.1381 .52878 L
.14762 .5388 L
.15714 .54752 L
.16667 .55498 L
.17619 .56122 L
.18571 .56627 L
.19524 .57017 L
.20476 .57295 L
.21429 .57464 L
.22381 .57529 L
.23333 .57492 L
.24286 .57358 L
.25238 .57129 L
.2619 .56809 L
.27143 .56402 L
.28095 .55911 L
.29048 .55339 L
.3 .54691 L
.30952 .53969 L
.31905 .53177 L
.32857 .52319 L
.3381 .51398 L
.34762 .50417 L
.35714 .49381 L
.36667 .48292 L
.37619 .47154 L
.38571 .45971 L
.39524 .44746 L
.40476 .43482 L
.41429 .42184 L
.42381 .40854 L
.43333 .39496 L
.44286 .38113 L
.45238 .3671 L
.4619 .35289 L
.47143 .33854 L
.48095 .32409 L
.49048 .30956 L
.5 .295 L
Mistroke
.50952 .28044 L
.51905 .26592 L
.52857 .25147 L
.5381 .23712 L
.54762 .22291 L
.55714 .20887 L
.56667 .19505 L
.57619 .18147 L
.58571 .16817 L
.59524 .15518 L
.60476 .14255 L
.61429 .13029 L
.62381 .11846 L
.63333 .10708 L
.64286 .0962 L
.65238 .08583 L
.6619 .07603 L
.67143 .06682 L
.68095 .05823 L
.69048 .05032 L
.7 .0431 L
.70952 .03661 L
.71905 .0309 L
.72857 .02599 L
.7381 .02192 L
.74762 .01872 L
.75714 .01643 L
.76667 .01508 L
.77619 .01472 L
.78571 .01536 L
.79524 .01706 L
.80476 .01984 L
.81429 .02373 L
.82381 .02878 L
.83333 .03502 L
.84286 .04249 L
.85238 .05121 L
.8619 .06122 L
.87143 .07257 L
.88095 .08527 L
.89048 .09938 L
.9 .11491 L
.90952 .13192 L
.91905 .15043 L
.92857 .17048 L
.9381 .19209 L
.94762 .21532 L
.95714 .24019 L
.96667 .26674 L
.97619 .295 L
Mistroke
Mfstroke
[(  Torque Tm[ 3 ])] .5 .60332 0 0 Mshowa
P
% End of Graphics
MathPictureEnd\
\>"], "Graphics",
  PageWidth->Infinity,
  Evaluatable->False,
  ImageSize->{299, 185},
  ImageMargins->{{80, Inherited}, {Inherited, 0}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0.295004 0.143571 [
[(1)] .2619 .295 0 2 Msboxa
[(2)] .5 .295 0 2 Msboxa
[(3)] .7381 .295 0 2 Msboxa
[(4)] .97619 .295 0 2 Msboxa
[([s])] 1.025 .295 -1 0 Msboxa
[(-2)] .01131 .00786 1 0 Msboxa
[(-1)] .01131 .15143 1 0 Msboxa
[(1)] .01131 .43857 1 0 Msboxa
[(2)] .01131 .58215 1 0 Msboxa
[([Rad/s2])] .02381 .61803 0 -4 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 .61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.2619 .295 m
.2619 .30125 L
s
P
[(1)] .2619 .295 0 2 Mshowa
p
.002 w
.5 .295 m
.5 .30125 L
s
P
[(2)] .5 .295 0 2 Mshowa
p
.002 w
.7381 .295 m
.7381 .30125 L
s
P
[(3)] .7381 .295 0 2 Mshowa
p
.002 w
.97619 .295 m
.97619 .30125 L
s
P
[(4)] .97619 .295 0 2 Mshowa
p
.001 w
.07143 .295 m
.07143 .29875 L
s
P
p
.001 w
.11905 .295 m
.11905 .29875 L
s
P
p
.001 w
.16667 .295 m
.16667 .29875 L
s
P
p
.001 w
.21429 .295 m
.21429 .29875 L
s
P
p
.001 w
.30952 .295 m
.30952 .29875 L
s
P
p
.001 w
.35714 .295 m
.35714 .29875 L
s
P
p
.001 w
.40476 .295 m
.40476 .29875 L
s
P
p
.001 w
.45238 .295 m
.45238 .29875 L
s
P
p
.001 w
.54762 .295 m
.54762 .29875 L
s
P
p
.001 w
.59524 .295 m
.59524 .29875 L
s
P
p
.001 w
.64286 .295 m
.64286 .29875 L
s
P
p
.001 w
.69048 .295 m
.69048 .29875 L
s
P
p
.001 w
.78571 .295 m
.78571 .29875 L
s
P
p
.001 w
.83333 .295 m
.83333 .29875 L
s
P
p
.001 w
.88095 .295 m
.88095 .29875 L
s
P
p
.001 w
.92857 .295 m
.92857 .29875 L
s
P
[([s])] 1.025 .295 -1 0 Mshowa
p
.002 w
0 .295 m
1 .295 L
s
P
p
.002 w
.02381 .00786 m
.03006 .00786 L
s
P
[(-2)] .01131 .00786 1 0 Mshowa
p
.002 w
.02381 .15143 m
.03006 .15143 L
s
P
[(-1)] .01131 .15143 1 0 Mshowa
p
.002 w
.02381 .43857 m
.03006 .43857 L
s
P
[(1)] .01131 .43857 1 0 Mshowa
p
.002 w
.02381 .58215 m
.03006 .58215 L
s
P
[(2)] .01131 .58215 1 0 Mshowa
p
.001 w
.02381 .03658 m
.02756 .03658 L
s
P
p
.001 w
.02381 .06529 m
.02756 .06529 L
s
P
p
.001 w
.02381 .094 m
.02756 .094 L
s
P
p
.001 w
.02381 .12272 m
.02756 .12272 L
s
P
p
.001 w
.02381 .18015 m
.02756 .18015 L
s
P
p
.001 w
.02381 .20886 m
.02756 .20886 L
s
P
p
.001 w
.02381 .23758 m
.02756 .23758 L
s
P
p
.001 w
.02381 .26629 m
.02756 .26629 L
s
P
p
.001 w
.02381 .32372 m
.02756 .32372 L
s
P
p
.001 w
.02381 .35243 m
.02756 .35243 L
s
P
p
.001 w
.02381 .38115 m
.02756 .38115 L
s
P
p
.001 w
.02381 .40986 m
.02756 .40986 L
s
P
p
.001 w
.02381 .46729 m
.02756 .46729 L
s
P
p
.001 w
.02381 .496 m
.02756 .496 L
s
P
p
.001 w
.02381 .52472 m
.02756 .52472 L
s
P
p
.001 w
.02381 .55343 m
.02756 .55343 L
s
P
p
.001 w
.02381 .61086 m
.02756 .61086 L
s
P
[([Rad/s2])] .02381 .61803 0 -4 Mshowa
p
.002 w
.02381 0 m
.02381 .61803 L
s
P
P
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
p
.004 w
.03333 .295 m
.04286 .34981 L
.05238 .37469 L
.0619 .39791 L
.07143 .41953 L
.08095 .43958 L
.09048 .45809 L
.1 .4751 L
.10952 .49063 L
.11905 .50474 L
.12857 .51744 L
.1381 .52879 L
.14762 .5388 L
.15714 .54752 L
.16667 .55499 L
.17619 .56122 L
.18571 .56628 L
.19524 .57017 L
.20476 .57295 L
.21429 .57464 L
.22381 .57529 L
.23333 .57492 L
.24286 .57358 L
.25238 .57128 L
.2619 .56809 L
.27143 .56401 L
.28095 .5591 L
.29048 .55339 L
.3 .5469 L
.30952 .53968 L
.31905 .53177 L
.32857 .52319 L
.3381 .51398 L
.34762 .50418 L
.35714 .49381 L
.36667 .48293 L
.37619 .47155 L
.38571 .45972 L
.39524 .44747 L
.40476 .43484 L
.41429 .42185 L
.42381 .40855 L
.43333 .39497 L
.44286 .38114 L
.45238 .36711 L
.4619 .35289 L
.47143 .33854 L
.48095 .32409 L
.49048 .30956 L
.5 .295 L
Mistroke
.50952 .28044 L
.51905 .26592 L
.52857 .25146 L
.5381 .23711 L
.54762 .2229 L
.55714 .20886 L
.56667 .19504 L
.57619 .18146 L
.58571 .16816 L
.59524 .15517 L
.60476 .14254 L
.61429 .13029 L
.62381 .11845 L
.63333 .10708 L
.64286 .09619 L
.65238 .08583 L
.6619 .07603 L
.67143 .06682 L
.68095 .05824 L
.69048 .05032 L
.7 .04311 L
.70952 .03662 L
.71905 .03091 L
.72857 .02599 L
.7381 .02192 L
.74762 .01872 L
.75714 .01643 L
.76667 .01508 L
.77619 .01472 L
.78571 .01536 L
.79524 .01706 L
.80476 .01983 L
.81429 .02373 L
.82381 .02878 L
.83333 .03502 L
.84286 .04248 L
.85238 .0512 L
.8619 .06122 L
.87143 .07256 L
.88095 .08527 L
.89048 .09937 L
.9 .11491 L
.90952 .13192 L
.91905 .15043 L
.92857 .17047 L
.9381 .19209 L
.94762 .21532 L
.95714 .24019 L
.96667 .26674 L
.97619 .295 L
Mistroke
Mfstroke
[(  Acceleration Q''l[ 1 ])] .5 .60332 0 0 Mshowa
P
% End of Graphics
MathPictureEnd\
\>"], "Graphics",
  PageWidth->Infinity,
  Evaluatable->False,
  ImageSize->{299, 185},
  ImageMargins->{{80, Inherited}, {Inherited, 0}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0.295003 0.171181 [
[(1)] .2619 .295 0 2 Msboxa
[(2)] .5 .295 0 2 Msboxa
[(3)] .7381 .295 0 2 Msboxa
[(4)] .97619 .295 0 2 Msboxa
[([s])] 1.025 .295 -1 0 Msboxa
[(-1.5)] .01131 .03823 1 0 Msboxa
[(-1)] .01131 .12382 1 0 Msboxa
[(-0.5)] .01131 .20941 1 0 Msboxa
[(0.5)] .01131 .38059 1 0 Msboxa
[(1)] .01131 .46618 1 0 Msboxa
[(1.5)] .01131 .55177 1 0 Msboxa
[([Rad/s2])] .02381 .61803 0 -4 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 .61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.2619 .295 m
.2619 .30125 L
s
P
[(1)] .2619 .295 0 2 Mshowa
p
.002 w
.5 .295 m
.5 .30125 L
s
P
[(2)] .5 .295 0 2 Mshowa
p
.002 w
.7381 .295 m
.7381 .30125 L
s
P
[(3)] .7381 .295 0 2 Mshowa
p
.002 w
.97619 .295 m
.97619 .30125 L
s
P
[(4)] .97619 .295 0 2 Mshowa
p
.001 w
.07143 .295 m
.07143 .29875 L
s
P
p
.001 w
.11905 .295 m
.11905 .29875 L
s
P
p
.001 w
.16667 .295 m
.16667 .29875 L
s
P
p
.001 w
.21429 .295 m
.21429 .29875 L
s
P
p
.001 w
.30952 .295 m
.30952 .29875 L
s
P
p
.001 w
.35714 .295 m
.35714 .29875 L
s
P
p
.001 w
.40476 .295 m
.40476 .29875 L
s
P
p
.001 w
.45238 .295 m
.45238 .29875 L
s
P
p
.001 w
.54762 .295 m
.54762 .29875 L
s
P
p
.001 w
.59524 .295 m
.59524 .29875 L
s
P
p
.001 w
.64286 .295 m
.64286 .29875 L
s
P
p
.001 w
.69048 .295 m
.69048 .29875 L
s
P
p
.001 w
.78571 .295 m
.78571 .29875 L
s
P
p
.001 w
.83333 .295 m
.83333 .29875 L
s
P
p
.001 w
.88095 .295 m
.88095 .29875 L
s
P
p
.001 w
.92857 .295 m
.92857 .29875 L
s
P
[([s])] 1.025 .295 -1 0 Mshowa
p
.002 w
0 .295 m
1 .295 L
s
P
p
.002 w
.02381 .03823 m
.03006 .03823 L
s
P
[(-1.5)] .01131 .03823 1 0 Mshowa
p
.002 w
.02381 .12382 m
.03006 .12382 L
s
P
[(-1)] .01131 .12382 1 0 Mshowa
p
.002 w
.02381 .20941 m
.03006 .20941 L
s
P
[(-0.5)] .01131 .20941 1 0 Mshowa
p
.002 w
.02381 .38059 m
.03006 .38059 L
s
P
[(0.5)] .01131 .38059 1 0 Mshowa
p
.002 w
.02381 .46618 m
.03006 .46618 L
s
P
[(1)] .01131 .46618 1 0 Mshowa
p
.002 w
.02381 .55177 m
.03006 .55177 L
s
P
[(1.5)] .01131 .55177 1 0 Mshowa
p
.001 w
.02381 .05535 m
.02756 .05535 L
s
P
p
.001 w
.02381 .07247 m
.02756 .07247 L
s
P
p
.001 w
.02381 .08959 m
.02756 .08959 L
s
P
p
.001 w
.02381 .1067 m
.02756 .1067 L
s
P
p
.001 w
.02381 .14094 m
.02756 .14094 L
s
P
p
.001 w
.02381 .15806 m
.02756 .15806 L
s
P
p
.001 w
.02381 .17518 m
.02756 .17518 L
s
P
p
.001 w
.02381 .19229 m
.02756 .19229 L
s
P
p
.001 w
.02381 .22653 m
.02756 .22653 L
s
P
p
.001 w
.02381 .24365 m
.02756 .24365 L
s
P
p
.001 w
.02381 .26077 m
.02756 .26077 L
s
P
p
.001 w
.02381 .27788 m
.02756 .27788 L
s
P
p
.001 w
.02381 .31212 m
.02756 .31212 L
s
P
p
.001 w
.02381 .32924 m
.02756 .32924 L
s
P
p
.001 w
.02381 .34636 m
.02756 .34636 L
s
P
p
.001 w
.02381 .36348 m
.02756 .36348 L
s
P
p
.001 w
.02381 .39771 m
.02756 .39771 L
s
P
p
.001 w
.02381 .41483 m
.02756 .41483 L
s
P
p
.001 w
.02381 .43195 m
.02756 .43195 L
s
P
p
.001 w
.02381 .44907 m
.02756 .44907 L
s
P
p
.001 w
.02381 .4833 m
.02756 .4833 L
s
P
p
.001 w
.02381 .50042 m
.02756 .50042 L
s
P
p
.001 w
.02381 .51754 m
.02756 .51754 L
s
P
p
.001 w
.02381 .53466 m
.02756 .53466 L
s
P
p
.001 w
.02381 .02111 m
.02756 .02111 L
s
P
p
.001 w
.02381 .00399 m
.02756 .00399 L
s
P
p
.001 w
.02381 .56889 m
.02756 .56889 L
s
P
p
.001 w
.02381 .58601 m
.02756 .58601 L
s
P
p
.001 w
.02381 .60313 m
.02756 .60313 L
s
P
[([Rad/s2])] .02381 .61803 0 -4 Mshowa
p
.002 w
.02381 0 m
.02381 .61803 L
s
P
P
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
p
.004 w
.03333 .295 m
.04286 .34981 L
.05238 .37468 L
.0619 .39791 L
.07143 .41953 L
.08095 .43958 L
.09048 .45809 L
.1 .47509 L
.10952 .49063 L
.11905 .50473 L
.12857 .51744 L
.1381 .52878 L
.14762 .5388 L
.15714 .54752 L
.16667 .55498 L
.17619 .56122 L
.18571 .56627 L
.19524 .57017 L
.20476 .57295 L
.21429 .57464 L
.22381 .57529 L
.23333 .57492 L
.24286 .57358 L
.25238 .57129 L
.2619 .56809 L
.27143 .56402 L
.28095 .55911 L
.29048 .55339 L
.3 .54691 L
.30952 .53969 L
.31905 .53178 L
.32857 .5232 L
.3381 .51398 L
.34762 .50418 L
.35714 .49381 L
.36667 .48292 L
.37619 .47155 L
.38571 .45971 L
.39524 .44746 L
.40476 .43482 L
.41429 .42183 L
.42381 .40853 L
.43333 .39495 L
.44286 .38112 L
.45238 .36709 L
.4619 .35288 L
.47143 .33853 L
.48095 .32408 L
.49048 .30956 L
.5 .295 L
Mistroke
.50952 .28045 L
.51905 .26593 L
.52857 .25147 L
.5381 .23713 L
.54762 .22292 L
.55714 .20888 L
.56667 .19506 L
.57619 .18147 L
.58571 .16817 L
.59524 .15519 L
.60476 .14255 L
.61429 .13029 L
.62381 .11846 L
.63333 .10708 L
.64286 .09619 L
.65238 .08583 L
.6619 .07602 L
.67143 .06681 L
.68095 .05823 L
.69048 .05031 L
.7 .04309 L
.70952 .03661 L
.71905 .0309 L
.72857 .02599 L
.7381 .02191 L
.74762 .01872 L
.75714 .01643 L
.76667 .01508 L
.77619 .01472 L
.78571 .01536 L
.79524 .01706 L
.80476 .01984 L
.81429 .02373 L
.82381 .02878 L
.83333 .03502 L
.84286 .04249 L
.85238 .05121 L
.8619 .06122 L
.87143 .07257 L
.88095 .08527 L
.89048 .09938 L
.9 .11491 L
.90952 .13192 L
.91905 .15043 L
.92857 .17047 L
.9381 .19209 L
.94762 .21532 L
.95714 .24019 L
.96667 .26674 L
.97619 .295 L
Mistroke
Mfstroke
[(  Acceleration Q''l[ 2 ])] .5 .60332 0 0 Mshowa
P
% End of Graphics
MathPictureEnd\
\>"], "Graphics",
  PageWidth->Infinity,
  Evaluatable->False,
  ImageSize->{299, 185},
  ImageMargins->{{80, Inherited}, {Inherited, 0}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0.295002 0.148328 [
[(1)] .2619 .295 0 2 Msboxa
[(2)] .5 .295 0 2 Msboxa
[(3)] .7381 .295 0 2 Msboxa
[(4)] .97619 .295 0 2 Msboxa
[([s])] 1.025 .295 -1 0 Msboxa
[(-1)] .01131 .14667 1 0 Msboxa
[(1)] .01131 .44333 1 0 Msboxa
[(2)] .01131 .59166 1 0 Msboxa
[([Rad/s2])] .02381 .61803 0 -4 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 .61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.2619 .295 m
.2619 .30125 L
s
P
[(1)] .2619 .295 0 2 Mshowa
p
.002 w
.5 .295 m
.5 .30125 L
s
P
[(2)] .5 .295 0 2 Mshowa
p
.002 w
.7381 .295 m
.7381 .30125 L
s
P
[(3)] .7381 .295 0 2 Mshowa
p
.002 w
.97619 .295 m
.97619 .30125 L
s
P
[(4)] .97619 .295 0 2 Mshowa
p
.001 w
.07143 .295 m
.07143 .29875 L
s
P
p
.001 w
.11905 .295 m
.11905 .29875 L
s
P
p
.001 w
.16667 .295 m
.16667 .29875 L
s
P
p
.001 w
.21429 .295 m
.21429 .29875 L
s
P
p
.001 w
.30952 .295 m
.30952 .29875 L
s
P
p
.001 w
.35714 .295 m
.35714 .29875 L
s
P
p
.001 w
.40476 .295 m
.40476 .29875 L
s
P
p
.001 w
.45238 .295 m
.45238 .29875 L
s
P
p
.001 w
.54762 .295 m
.54762 .29875 L
s
P
p
.001 w
.59524 .295 m
.59524 .29875 L
s
P
p
.001 w
.64286 .295 m
.64286 .29875 L
s
P
p
.001 w
.69048 .295 m
.69048 .29875 L
s
P
p
.001 w
.78571 .295 m
.78571 .29875 L
s
P
p
.001 w
.83333 .295 m
.83333 .29875 L
s
P
p
.001 w
.88095 .295 m
.88095 .29875 L
s
P
p
.001 w
.92857 .295 m
.92857 .29875 L
s
P
[([s])] 1.025 .295 -1 0 Mshowa
p
.002 w
0 .295 m
1 .295 L
s
P
p
.002 w
.02381 .14667 m
.03006 .14667 L
s
P
[(-1)] .01131 .14667 1 0 Mshowa
p
.002 w
.02381 .44333 m
.03006 .44333 L
s
P
[(1)] .01131 .44333 1 0 Mshowa
p
.002 w
.02381 .59166 m
.03006 .59166 L
s
P
[(2)] .01131 .59166 1 0 Mshowa
p
.001 w
.02381 .02801 m
.02756 .02801 L
s
P
p
.001 w
.02381 .05768 m
.02756 .05768 L
s
P
p
.001 w
.02381 .08734 m
.02756 .08734 L
s
P
p
.001 w
.02381 .11701 m
.02756 .11701 L
s
P
p
.001 w
.02381 .17634 m
.02756 .17634 L
s
P
p
.001 w
.02381 .20601 m
.02756 .20601 L
s
P
p
.001 w
.02381 .23567 m
.02756 .23567 L
s
P
p
.001 w
.02381 .26534 m
.02756 .26534 L
s
P
p
.001 w
.02381 .32467 m
.02756 .32467 L
s
P
p
.001 w
.02381 .35433 m
.02756 .35433 L
s
P
p
.001 w
.02381 .384 m
.02756 .384 L
s
P
p
.001 w
.02381 .41366 m
.02756 .41366 L
s
P
p
.001 w
.02381 .473 m
.02756 .473 L
s
P
p
.001 w
.02381 .50266 m
.02756 .50266 L
s
P
p
.001 w
.02381 .53233 m
.02756 .53233 L
s
P
p
.001 w
.02381 .56199 m
.02756 .56199 L
s
P
[([Rad/s2])] .02381 .61803 0 -4 Mshowa
p
.002 w
.02381 0 m
.02381 .61803 L
s
P
P
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
p
.004 w
.03333 .295 m
.04286 .34981 L
.05238 .37468 L
.0619 .3979 L
.07143 .41952 L
.08095 .43957 L
.09048 .45808 L
.1 .47508 L
.10952 .49062 L
.11905 .50472 L
.12857 .51743 L
.1381 .52877 L
.14762 .53879 L
.15714 .54751 L
.16667 .55497 L
.17619 .56121 L
.18571 .56627 L
.19524 .57017 L
.20476 .57295 L
.21429 .57464 L
.22381 .57529 L
.23333 .57492 L
.24286 .57358 L
.25238 .57129 L
.2619 .56809 L
.27143 .56402 L
.28095 .5591 L
.29048 .55339 L
.3 .5469 L
.30952 .53968 L
.31905 .53175 L
.32857 .52317 L
.3381 .51395 L
.34762 .50414 L
.35714 .49377 L
.36667 .48288 L
.37619 .4715 L
.38571 .45966 L
.39524 .4474 L
.40476 .43476 L
.41429 .42178 L
.42381 .40847 L
.43333 .39489 L
.44286 .38106 L
.45238 .36703 L
.4619 .35283 L
.47143 .33848 L
.48095 .32404 L
.49048 .30954 L
.5 .295 L
Mistroke
.50952 .28047 L
.51905 .26596 L
.52857 .25152 L
.5381 .23718 L
.54762 .22297 L
.55714 .20894 L
.56667 .19511 L
.57619 .18153 L
.58571 .16823 L
.59524 .15524 L
.60476 .1426 L
.61429 .13035 L
.62381 .11851 L
.63333 .10713 L
.64286 .09623 L
.65238 .08586 L
.6619 .07605 L
.67143 .06684 L
.68095 .05825 L
.69048 .05033 L
.7 .0431 L
.70952 .03662 L
.71905 .0309 L
.72857 .02599 L
.7381 .02191 L
.74762 .01872 L
.75714 .01643 L
.76667 .01508 L
.77619 .01472 L
.78571 .01536 L
.79524 .01706 L
.80476 .01984 L
.81429 .02374 L
.82381 .02879 L
.83333 .03503 L
.84286 .0425 L
.85238 .05122 L
.8619 .06123 L
.87143 .07258 L
.88095 .08528 L
.89048 .09939 L
.9 .11492 L
.90952 .13193 L
.91905 .15044 L
.92857 .17048 L
.9381 .1921 L
.94762 .21533 L
.95714 .2402 L
.96667 .26674 L
.97619 .295 L
Mistroke
Mfstroke
[(  Acceleration Q''l[ 3 ])] .5 .60332 0 0 Mshowa
P
% End of Graphics
MathPictureEnd\
\>"], "Graphics",
  PageWidth->Infinity,
  Evaluatable->False,
  ImageSize->{299, 185},
  ImageMargins->{{80, Inherited}, {Inherited, 0}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0.295002 0.00229306 [
[(1)] .2619 .295 0 2 Msboxa
[(2)] .5 .295 0 2 Msboxa
[(3)] .7381 .295 0 2 Msboxa
[(4)] .97619 .295 0 2 Msboxa
[([s])] 1.025 .295 -1 0 Msboxa
[(-100)] .01131 .0657 1 0 Msboxa
[(-50)] .01131 .18035 1 0 Msboxa
[(50)] .01131 .40965 1 0 Msboxa
[(100)] .01131 .52431 1 0 Msboxa
[([Rad/s2])] .02381 .61803 0 -4 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 .61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.2619 .295 m
.2619 .30125 L
s
P
[(1)] .2619 .295 0 2 Mshowa
p
.002 w
.5 .295 m
.5 .30125 L
s
P
[(2)] .5 .295 0 2 Mshowa
p
.002 w
.7381 .295 m
.7381 .30125 L
s
P
[(3)] .7381 .295 0 2 Mshowa
p
.002 w
.97619 .295 m
.97619 .30125 L
s
P
[(4)] .97619 .295 0 2 Mshowa
p
.001 w
.07143 .295 m
.07143 .29875 L
s
P
p
.001 w
.11905 .295 m
.11905 .29875 L
s
P
p
.001 w
.16667 .295 m
.16667 .29875 L
s
P
p
.001 w
.21429 .295 m
.21429 .29875 L
s
P
p
.001 w
.30952 .295 m
.30952 .29875 L
s
P
p
.001 w
.35714 .295 m
.35714 .29875 L
s
P
p
.001 w
.40476 .295 m
.40476 .29875 L
s
P
p
.001 w
.45238 .295 m
.45238 .29875 L
s
P
p
.001 w
.54762 .295 m
.54762 .29875 L
s
P
p
.001 w
.59524 .295 m
.59524 .29875 L
s
P
p
.001 w
.64286 .295 m
.64286 .29875 L
s
P
p
.001 w
.69048 .295 m
.69048 .29875 L
s
P
p
.001 w
.78571 .295 m
.78571 .29875 L
s
P
p
.001 w
.83333 .295 m
.83333 .29875 L
s
P
p
.001 w
.88095 .295 m
.88095 .29875 L
s
P
p
.001 w
.92857 .295 m
.92857 .29875 L
s
P
[([s])] 1.025 .295 -1 0 Mshowa
p
.002 w
0 .295 m
1 .295 L
s
P
p
.002 w
.02381 .0657 m
.03006 .0657 L
s
P
[(-100)] .01131 .0657 1 0 Mshowa
p
.002 w
.02381 .18035 m
.03006 .18035 L
s
P
[(-50)] .01131 .18035 1 0 Mshowa
p
.002 w
.02381 .40965 m
.03006 .40965 L
s
P
[(50)] .01131 .40965 1 0 Mshowa
p
.002 w
.02381 .52431 m
.03006 .52431 L
s
P
[(100)] .01131 .52431 1 0 Mshowa
p
.001 w
.02381 .08863 m
.02756 .08863 L
s
P
p
.001 w
.02381 .11156 m
.02756 .11156 L
s
P
p
.001 w
.02381 .13449 m
.02756 .13449 L
s
P
p
.001 w
.02381 .15742 m
.02756 .15742 L
s
P
p
.001 w
.02381 .20328 m
.02756 .20328 L
s
P
p
.001 w
.02381 .22621 m
.02756 .22621 L
s
P
p
.001 w
.02381 .24914 m
.02756 .24914 L
s
P
p
.001 w
.02381 .27207 m
.02756 .27207 L
s
P
p
.001 w
.02381 .31793 m
.02756 .31793 L
s
P
p
.001 w
.02381 .34086 m
.02756 .34086 L
s
P
p
.001 w
.02381 .36379 m
.02756 .36379 L
s
P
p
.001 w
.02381 .38672 m
.02756 .38672 L
s
P
p
.001 w
.02381 .43259 m
.02756 .43259 L
s
P
p
.001 w
.02381 .45552 m
.02756 .45552 L
s
P
p
.001 w
.02381 .47845 m
.02756 .47845 L
s
P
p
.001 w
.02381 .50138 m
.02756 .50138 L
s
P
p
.001 w
.02381 .04277 m
.02756 .04277 L
s
P
p
.001 w
.02381 .01983 m
.02756 .01983 L
s
P
p
.001 w
.02381 .54724 m
.02756 .54724 L
s
P
p
.001 w
.02381 .57017 m
.02756 .57017 L
s
P
p
.001 w
.02381 .5931 m
.02756 .5931 L
s
P
p
.001 w
.02381 .61603 m
.02756 .61603 L
s
P
[([Rad/s2])] .02381 .61803 0 -4 Mshowa
p
.002 w
.02381 0 m
.02381 .61803 L
s
P
P
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
p
.004 w
.03333 .295 m
.04286 .34981 L
.05238 .37468 L
.0619 .39791 L
.07143 .41953 L
.08095 .43958 L
.09048 .45809 L
.1 .47509 L
.10952 .49063 L
.11905 .50473 L
.12857 .51744 L
.1381 .52878 L
.14762 .5388 L
.15714 .54752 L
.16667 .55498 L
.17619 .56122 L
.18571 .56627 L
.19524 .57017 L
.20476 .57295 L
.21429 .57464 L
.22381 .57529 L
.23333 .57492 L
.24286 .57358 L
.25238 .57129 L
.2619 .56809 L
.27143 .56402 L
.28095 .55911 L
.29048 .55339 L
.3 .54691 L
.30952 .53969 L
.31905 .53177 L
.32857 .52319 L
.3381 .51398 L
.34762 .50417 L
.35714 .49381 L
.36667 .48292 L
.37619 .47154 L
.38571 .45971 L
.39524 .44746 L
.40476 .43482 L
.41429 .42184 L
.42381 .40854 L
.43333 .39496 L
.44286 .38113 L
.45238 .3671 L
.4619 .35289 L
.47143 .33854 L
.48095 .32408 L
.49048 .30956 L
.5 .295 L
Mistroke
.50952 .28044 L
.51905 .26592 L
.52857 .25147 L
.5381 .23712 L
.54762 .22291 L
.55714 .20887 L
.56667 .19505 L
.57619 .18147 L
.58571 .16817 L
.59524 .15518 L
.60476 .14254 L
.61429 .13029 L
.62381 .11846 L
.63333 .10708 L
.64286 .09619 L
.65238 .08583 L
.6619 .07603 L
.67143 .06682 L
.68095 .05823 L
.69048 .05032 L
.7 .0431 L
.70952 .03661 L
.71905 .0309 L
.72857 .02599 L
.7381 .02192 L
.74762 .01872 L
.75714 .01643 L
.76667 .01508 L
.77619 .01472 L
.78571 .01536 L
.79524 .01706 L
.80476 .01984 L
.81429 .02373 L
.82381 .02878 L
.83333 .03502 L
.84286 .04249 L
.85238 .05121 L
.8619 .06122 L
.87143 .07257 L
.88095 .08527 L
.89048 .09938 L
.9 .11491 L
.90952 .13192 L
.91905 .15043 L
.92857 .17047 L
.9381 .19209 L
.94762 .21532 L
.95714 .24019 L
.96667 .26674 L
.97619 .295 L
Mistroke
Mfstroke
[(  Acceleration Q''m[ 1 ])] .5 .60332 0 0 Mshowa
P
% End of Graphics
MathPictureEnd\
\>"], "Graphics",
  PageWidth->Infinity,
  Evaluatable->False,
  ImageSize->{299, 185},
  ImageMargins->{{80, Inherited}, {Inherited, 0}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0.295003 0.00159443 [
[(1)] .2619 .295 0 2 Msboxa
[(2)] .5 .295 0 2 Msboxa
[(3)] .7381 .295 0 2 Msboxa
[(4)] .97619 .295 0 2 Msboxa
[([s])] 1.025 .295 -1 0 Msboxa
[(-150)] .01131 .05584 1 0 Msboxa
[(-100)] .01131 .13556 1 0 Msboxa
[(-50)] .01131 .21528 1 0 Msboxa
[(50)] .01131 .37472 1 0 Msboxa
[(100)] .01131 .45445 1 0 Msboxa
[(150)] .01131 .53417 1 0 Msboxa
[(200)] .01131 .61389 1 0 Msboxa
[([Rad/s2])] .02381 .61803 0 -4 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 .61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.2619 .295 m
.2619 .30125 L
s
P
[(1)] .2619 .295 0 2 Mshowa
p
.002 w
.5 .295 m
.5 .30125 L
s
P
[(2)] .5 .295 0 2 Mshowa
p
.002 w
.7381 .295 m
.7381 .30125 L
s
P
[(3)] .7381 .295 0 2 Mshowa
p
.002 w
.97619 .295 m
.97619 .30125 L
s
P
[(4)] .97619 .295 0 2 Mshowa
p
.001 w
.07143 .295 m
.07143 .29875 L
s
P
p
.001 w
.11905 .295 m
.11905 .29875 L
s
P
p
.001 w
.16667 .295 m
.16667 .29875 L
s
P
p
.001 w
.21429 .295 m
.21429 .29875 L
s
P
p
.001 w
.30952 .295 m
.30952 .29875 L
s
P
p
.001 w
.35714 .295 m
.35714 .29875 L
s
P
p
.001 w
.40476 .295 m
.40476 .29875 L
s
P
p
.001 w
.45238 .295 m
.45238 .29875 L
s
P
p
.001 w
.54762 .295 m
.54762 .29875 L
s
P
p
.001 w
.59524 .295 m
.59524 .29875 L
s
P
p
.001 w
.64286 .295 m
.64286 .29875 L
s
P
p
.001 w
.69048 .295 m
.69048 .29875 L
s
P
p
.001 w
.78571 .295 m
.78571 .29875 L
s
P
p
.001 w
.83333 .295 m
.83333 .29875 L
s
P
p
.001 w
.88095 .295 m
.88095 .29875 L
s
P
p
.001 w
.92857 .295 m
.92857 .29875 L
s
P
[([s])] 1.025 .295 -1 0 Mshowa
p
.002 w
0 .295 m
1 .295 L
s
P
p
.002 w
.02381 .05584 m
.03006 .05584 L
s
P
[(-150)] .01131 .05584 1 0 Mshowa
p
.002 w
.02381 .13556 m
.03006 .13556 L
s
P
[(-100)] .01131 .13556 1 0 Mshowa
p
.002 w
.02381 .21528 m
.03006 .21528 L
s
P
[(-50)] .01131 .21528 1 0 Mshowa
p
.002 w
.02381 .37472 m
.03006 .37472 L
s
P
[(50)] .01131 .37472 1 0 Mshowa
p
.002 w
.02381 .45445 m
.03006 .45445 L
s
P
[(100)] .01131 .45445 1 0 Mshowa
p
.002 w
.02381 .53417 m
.03006 .53417 L
s
P
[(150)] .01131 .53417 1 0 Mshowa
p
.002 w
.02381 .61389 m
.03006 .61389 L
s
P
[(200)] .01131 .61389 1 0 Mshowa
p
.001 w
.02381 .07178 m
.02756 .07178 L
s
P
p
.001 w
.02381 .08773 m
.02756 .08773 L
s
P
p
.001 w
.02381 .10367 m
.02756 .10367 L
s
P
p
.001 w
.02381 .11962 m
.02756 .11962 L
s
P
p
.001 w
.02381 .1515 m
.02756 .1515 L
s
P
p
.001 w
.02381 .16745 m
.02756 .16745 L
s
P
p
.001 w
.02381 .18339 m
.02756 .18339 L
s
P
p
.001 w
.02381 .19934 m
.02756 .19934 L
s
P
p
.001 w
.02381 .23123 m
.02756 .23123 L
s
P
p
.001 w
.02381 .24717 m
.02756 .24717 L
s
P
p
.001 w
.02381 .26311 m
.02756 .26311 L
s
P
p
.001 w
.02381 .27906 m
.02756 .27906 L
s
P
p
.001 w
.02381 .31095 m
.02756 .31095 L
s
P
p
.001 w
.02381 .32689 m
.02756 .32689 L
s
P
p
.001 w
.02381 .34284 m
.02756 .34284 L
s
P
p
.001 w
.02381 .35878 m
.02756 .35878 L
s
P
p
.001 w
.02381 .39067 m
.02756 .39067 L
s
P
p
.001 w
.02381 .40661 m
.02756 .40661 L
s
P
p
.001 w
.02381 .42256 m
.02756 .42256 L
s
P
p
.001 w
.02381 .4385 m
.02756 .4385 L
s
P
p
.001 w
.02381 .47039 m
.02756 .47039 L
s
P
p
.001 w
.02381 .48633 m
.02756 .48633 L
s
P
p
.001 w
.02381 .50228 m
.02756 .50228 L
s
P
p
.001 w
.02381 .51822 m
.02756 .51822 L
s
P
p
.001 w
.02381 .55011 m
.02756 .55011 L
s
P
p
.001 w
.02381 .56606 m
.02756 .56606 L
s
P
p
.001 w
.02381 .582 m
.02756 .582 L
s
P
p
.001 w
.02381 .59794 m
.02756 .59794 L
s
P
p
.001 w
.02381 .03989 m
.02756 .03989 L
s
P
p
.001 w
.02381 .02395 m
.02756 .02395 L
s
P
p
.001 w
.02381 .00801 m
.02756 .00801 L
s
P
[([Rad/s2])] .02381 .61803 0 -4 Mshowa
p
.002 w
.02381 0 m
.02381 .61803 L
s
P
P
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
p
.004 w
.03333 .295 m
.04286 .34981 L
.05238 .37468 L
.0619 .39791 L
.07143 .41953 L
.08095 .43958 L
.09048 .45809 L
.1 .47509 L
.10952 .49063 L
.11905 .50473 L
.12857 .51744 L
.1381 .52878 L
.14762 .5388 L
.15714 .54752 L
.16667 .55498 L
.17619 .56122 L
.18571 .56627 L
.19524 .57017 L
.20476 .57295 L
.21429 .57464 L
.22381 .57529 L
.23333 .57492 L
.24286 .57358 L
.25238 .57129 L
.2619 .56809 L
.27143 .56402 L
.28095 .55911 L
.29048 .55339 L
.3 .54691 L
.30952 .53969 L
.31905 .53177 L
.32857 .52319 L
.3381 .51398 L
.34762 .50417 L
.35714 .49381 L
.36667 .48292 L
.37619 .47154 L
.38571 .45971 L
.39524 .44746 L
.40476 .43482 L
.41429 .42184 L
.42381 .40854 L
.43333 .39496 L
.44286 .38113 L
.45238 .3671 L
.4619 .35289 L
.47143 .33854 L
.48095 .32409 L
.49048 .30956 L
.5 .295 L
Mistroke
.50952 .28044 L
.51905 .26592 L
.52857 .25147 L
.5381 .23712 L
.54762 .22291 L
.55714 .20887 L
.56667 .19505 L
.57619 .18147 L
.58571 .16817 L
.59524 .15518 L
.60476 .14255 L
.61429 .13029 L
.62381 .11846 L
.63333 .10708 L
.64286 .0962 L
.65238 .08583 L
.6619 .07603 L
.67143 .06682 L
.68095 .05823 L
.69048 .05032 L
.7 .0431 L
.70952 .03661 L
.71905 .0309 L
.72857 .02599 L
.7381 .02192 L
.74762 .01872 L
.75714 .01643 L
.76667 .01508 L
.77619 .01472 L
.78571 .01536 L
.79524 .01706 L
.80476 .01984 L
.81429 .02373 L
.82381 .02878 L
.83333 .03502 L
.84286 .04249 L
.85238 .05121 L
.8619 .06122 L
.87143 .07257 L
.88095 .08527 L
.89048 .09938 L
.9 .11491 L
.90952 .13192 L
.91905 .15043 L
.92857 .17048 L
.9381 .19209 L
.94762 .21532 L
.95714 .24019 L
.96667 .26674 L
.97619 .295 L
Mistroke
Mfstroke
[(  Acceleration Q''m[ 2 ])] .5 .60332 0 0 Mshowa
P
% End of Graphics
MathPictureEnd\
\>"], "Graphics",
  PageWidth->Infinity,
  Evaluatable->False,
  ImageSize->{299, 185},
  ImageMargins->{{80, Inherited}, {Inherited, 0}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0.295003 0.00276316 [
[(1)] .2619 .295 0 2 Msboxa
[(2)] .5 .295 0 2 Msboxa
[(3)] .7381 .295 0 2 Msboxa
[(4)] .97619 .295 0 2 Msboxa
[([s])] 1.025 .295 -1 0 Msboxa
[(-100)] .01131 .01869 1 0 Msboxa
[(-50)] .01131 .15684 1 0 Msboxa
[(50)] .01131 .43316 1 0 Msboxa
[(100)] .01131 .57132 1 0 Msboxa
[([Rad/s2])] .02381 .61803 0 -4 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 .61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.2619 .295 m
.2619 .30125 L
s
P
[(1)] .2619 .295 0 2 Mshowa
p
.002 w
.5 .295 m
.5 .30125 L
s
P
[(2)] .5 .295 0 2 Mshowa
p
.002 w
.7381 .295 m
.7381 .30125 L
s
P
[(3)] .7381 .295 0 2 Mshowa
p
.002 w
.97619 .295 m
.97619 .30125 L
s
P
[(4)] .97619 .295 0 2 Mshowa
p
.001 w
.07143 .295 m
.07143 .29875 L
s
P
p
.001 w
.11905 .295 m
.11905 .29875 L
s
P
p
.001 w
.16667 .295 m
.16667 .29875 L
s
P
p
.001 w
.21429 .295 m
.21429 .29875 L
s
P
p
.001 w
.30952 .295 m
.30952 .29875 L
s
P
p
.001 w
.35714 .295 m
.35714 .29875 L
s
P
p
.001 w
.40476 .295 m
.40476 .29875 L
s
P
p
.001 w
.45238 .295 m
.45238 .29875 L
s
P
p
.001 w
.54762 .295 m
.54762 .29875 L
s
P
p
.001 w
.59524 .295 m
.59524 .29875 L
s
P
p
.001 w
.64286 .295 m
.64286 .29875 L
s
P
p
.001 w
.69048 .295 m
.69048 .29875 L
s
P
p
.001 w
.78571 .295 m
.78571 .29875 L
s
P
p
.001 w
.83333 .295 m
.83333 .29875 L
s
P
p
.001 w
.88095 .295 m
.88095 .29875 L
s
P
p
.001 w
.92857 .295 m
.92857 .29875 L
s
P
[([s])] 1.025 .295 -1 0 Mshowa
p
.002 w
0 .295 m
1 .295 L
s
P
p
.002 w
.02381 .01869 m
.03006 .01869 L
s
P
[(-100)] .01131 .01869 1 0 Mshowa
p
.002 w
.02381 .15684 m
.03006 .15684 L
s
P
[(-50)] .01131 .15684 1 0 Mshowa
p
.002 w
.02381 .43316 m
.03006 .43316 L
s
P
[(50)] .01131 .43316 1 0 Mshowa
p
.002 w
.02381 .57132 m
.03006 .57132 L
s
P
[(100)] .01131 .57132 1 0 Mshowa
p
.001 w
.02381 .04632 m
.02756 .04632 L
s
P
p
.001 w
.02381 .07395 m
.02756 .07395 L
s
P
p
.001 w
.02381 .10158 m
.02756 .10158 L
s
P
p
.001 w
.02381 .12921 m
.02756 .12921 L
s
P
p
.001 w
.02381 .18448 m
.02756 .18448 L
s
P
p
.001 w
.02381 .21211 m
.02756 .21211 L
s
P
p
.001 w
.02381 .23974 m
.02756 .23974 L
s
P
p
.001 w
.02381 .26737 m
.02756 .26737 L
s
P
p
.001 w
.02381 .32263 m
.02756 .32263 L
s
P
p
.001 w
.02381 .35027 m
.02756 .35027 L
s
P
p
.001 w
.02381 .3779 m
.02756 .3779 L
s
P
p
.001 w
.02381 .40553 m
.02756 .40553 L
s
P
p
.001 w
.02381 .46079 m
.02756 .46079 L
s
P
p
.001 w
.02381 .48842 m
.02756 .48842 L
s
P
p
.001 w
.02381 .51606 m
.02756 .51606 L
s
P
p
.001 w
.02381 .54369 m
.02756 .54369 L
s
P
p
.001 w
.02381 .59895 m
.02756 .59895 L
s
P
[([Rad/s2])] .02381 .61803 0 -4 Mshowa
p
.002 w
.02381 0 m
.02381 .61803 L
s
P
P
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
p
.004 w
.03333 .295 m
.04286 .34981 L
.05238 .37468 L
.0619 .39791 L
.07143 .41953 L
.08095 .43958 L
.09048 .45809 L
.1 .47509 L
.10952 .49063 L
.11905 .50473 L
.12857 .51744 L
.1381 .52878 L
.14762 .5388 L
.15714 .54752 L
.16667 .55498 L
.17619 .56122 L
.18571 .56627 L
.19524 .57017 L
.20476 .57295 L
.21429 .57464 L
.22381 .57529 L
.23333 .57492 L
.24286 .57358 L
.25238 .57129 L
.2619 .56809 L
.27143 .56402 L
.28095 .55911 L
.29048 .55339 L
.3 .54691 L
.30952 .53969 L
.31905 .53177 L
.32857 .52319 L
.3381 .51398 L
.34762 .50417 L
.35714 .49381 L
.36667 .48292 L
.37619 .47154 L
.38571 .45971 L
.39524 .44746 L
.40476 .43482 L
.41429 .42184 L
.42381 .40854 L
.43333 .39496 L
.44286 .38113 L
.45238 .3671 L
.4619 .35289 L
.47143 .33854 L
.48095 .32409 L
.49048 .30956 L
.5 .295 L
Mistroke
.50952 .28044 L
.51905 .26592 L
.52857 .25147 L
.5381 .23712 L
.54762 .22291 L
.55714 .20887 L
.56667 .19505 L
.57619 .18147 L
.58571 .16817 L
.59524 .15518 L
.60476 .14255 L
.61429 .13029 L
.62381 .11846 L
.63333 .10708 L
.64286 .0962 L
.65238 .08583 L
.6619 .07603 L
.67143 .06682 L
.68095 .05823 L
.69048 .05032 L
.7 .0431 L
.70952 .03661 L
.71905 .0309 L
.72857 .02599 L
.7381 .02192 L
.74762 .01872 L
.75714 .01643 L
.76667 .01508 L
.77619 .01472 L
.78571 .01536 L
.79524 .01706 L
.80476 .01984 L
.81429 .02373 L
.82381 .02878 L
.83333 .03502 L
.84286 .04249 L
.85238 .05121 L
.8619 .06122 L
.87143 .07257 L
.88095 .08527 L
.89048 .09938 L
.9 .11491 L
.90952 .13192 L
.91905 .15043 L
.92857 .17048 L
.9381 .19209 L
.94762 .21532 L
.95714 .24019 L
.96667 .26674 L
.97619 .295 L
Mistroke
Mfstroke
[(  Acceleration Q''m[ 3 ])] .5 .60332 0 0 Mshowa
P
% End of Graphics
MathPictureEnd\
\>"], "Graphics",
  PageWidth->Infinity,
  Evaluatable->False,
  ImageSize->{299, 185},
  ImageMargins->{{80, Inherited}, {Inherited, 0}},
  ImageCacheValid->False]
}, Open  ]]
},
FrontEndVersion->"Microsoft Windows 3.0",
ScreenRectangle->{{0, 1024}, {0, 712}},
WindowToolbars->{},
CellGrouping->Manual,
WindowSize->{703, 643},
WindowMargins->{{Automatic, 45}, {Automatic, -3}},
PrintingCopies->1,
PrintingPageRange->{2, 2},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False}
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1731, 51, 682, 18, 48, "Input"],
Cell[2416, 71, 236, 7, 54, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2689, 83, 1471, 31, 101, "Input"],
Cell[4163, 116, 669, 18, 90, "Output"],
Cell[4835, 136, 669, 18, 118, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5541, 159, 743, 19, 86, "Input"],
Cell[6287, 180, 869, 22, 118, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7193, 207, 325, 11, 41, "Input"],
Cell[7521, 220, 109, 3, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7667, 228, 2348, 51, 86, "Input"],
Cell[10018, 281, 1775, 35, 29, "Output"],
Cell[11796, 318, 1268, 26, 29, "Output"]
}, Open  ]],
Cell[13079, 347, 4114, 91, 1023, "Input"],
Cell[17196, 440, 515, 25, 174, "Print"],

Cell[CellGroupData[{
Cell[17736, 469, 704, 19, 160, "Input"],
Cell[18443, 490, 1400, 43, 324, "Print"],
Cell[19846, 535, 16977, 661, 193, 5600, 515, "GraphicsData", 
"PostScript", "Graphics"],
Cell[36826, 1198, 14739, 628, 193, 5557, 509, "GraphicsData", 
"PostScript", "Graphics"],
Cell[51568, 1828, 15626, 649, 193, 5666, 521, "GraphicsData", 
"PostScript", "Graphics"],
Cell[67197, 2479, 19333, 646, 193, 5122, 465, "GraphicsData", 
"PostScript", "Graphics"],
Cell[86533, 3127, 37640, 916, 193, 5604, 515, "GraphicsData", 
"PostScript", "Graphics"],
Cell[124176, 4045, 36920, 907, 193, 5599, 515, "GraphicsData", 
"PostScript", "Graphics"],
Cell[161099, 4954, 47857, 1042, 193, 5603, 515, "GraphicsData", 
"PostScript", "Graphics"],
Cell[208959, 5998, 27458, 746, 193, 5091, 465, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[236454, 6749, 1540, 45, 551, "Input"],
Cell[237997, 6796, 5951, 200, 1844, "Print"],
Cell[243951, 6998, 5131, 463, 193, 4984, 458, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[249085, 7463, 4811, 429, 193, 4664, 424, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[253899, 7894, 5090, 463, 193, 4943, 458, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[258992, 8359, 5581, 513, 193, 5434, 508, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[264576, 8874, 4983, 443, 193, 4836, 438, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[269562, 9319, 5194, 475, 193, 5047, 470, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[274759, 9796, 5150, 463, 193, 5003, 458, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[279912, 10261, 4869, 431, 193, 4722, 426, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[284784, 10694, 5119, 457, 193, 4972, 452, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[289906, 11153, 5601, 509, 193, 5454, 504, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[295510, 11664, 5027, 445, 193, 4880, 440, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[300540, 12111, 5695, 521, 193, 5548, 516, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[306238, 12634, 4724, 419, 193, 4577, 414, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[310965, 13055, 5488, 507, 193, 5341, 502, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[316456, 13564, 4572, 405, 193, 4425, 400, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[321031, 13971, 4961, 449, 193, 4814, 444, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[325995, 14422, 5699, 527, 193, 5552, 522, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[331697, 14951, 4740, 419, 193, 4593, 414, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[336440, 15372, 5579, 513, 193, 5432, 508, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[342022, 15887, 4993, 449, 193, 4846, 444, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[347018, 16338, 5099, 461, 193, 4952, 456, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[352120, 16801, 5582, 507, 193, 5435, 502, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[357705, 17310, 5568, 513, 193, 5421, 508, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[363276, 17825, 4929, 443, 193, 4782, 438, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[368208, 18270, 4719, 419, 193, 4572, 414, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[372930, 18691, 5498, 507, 193, 5351, 502, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[378431, 19200, 4560, 405, 193, 4413, 400, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[382994, 19607, 4962, 449, 193, 4815, 444, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[387959, 20058, 5699, 527, 193, 5552, 522, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[393661, 20587, 4740, 419, 193, 4593, 414, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

